
<?php

use App\Models\Faq;
use App\Models\Blog;
use App\Models\Font;
use App\Models\Slider;
use App\Models\Product;
use App\Models\Service;
use App\Models\Category;
use App\Models\Settings;
use App\Models\Testimonial;
use App\Models\BlogCategory;
use App\Models\HomepageSection;
use App\Models\ProductVariation;
use Illuminate\Support\Facades\Storage;

function logo()
{
    $logo = Settings::value('logo');

    if ($logo != NULL) {
        if (Storage::exists($logo)) {
            return asset(Storage::url($logo));
        }
    }
}

function services()
{
    return Service::latest()->get();
}

function products()
{
    return Product::latest()->get();
}

function faqs()
{
    return Faq::latest()->get();
}

function blogs()
{
    return Blog::latest()->get();
}

function slider()
{
    return Slider::latest()->get();
}

function testimonials()
{
    return Testimonial::latest()->get();
}

function categories()
{
    return Category::latest()->get();
}

function blog_categories()
{
    return BlogCategory::latest()->get();
}

function get_settings()
{
    return Settings::first();
}

function get_cover_section()
{
    return HomepageSection::where('name', 'cover')->first();
}

function get_welcome_section()
{
    return HomepageSection::where('name', 'welcome')->first();
}

function get_services_section()
{
    $section = HomepageSection::where('name', 'services')->first();

    if ($section) {
        $section->services = Service::select('id', 'name', 'alias')->whereIn('id', explode(',', $section->services))->get();

        return $section;
    }

    return false;
}

function get_promo_page_section()
{
    return HomepageSection::where('name', 'promo_page')->first();
}

function get_seasonal_highlights_section()
{
    $section = HomepageSection::where('name', 'seasonal_highlights')->first();

    $productIds = explode(',', $section->products);

    $products = Product::join('product_variations', 'product_variations.product_id', '=', 'products.id')
        ->join('product_categories', 'product_categories.product_id', '=', 'products.id')
        ->join('categories', 'product_categories.cat_id', '=', 'categories.id')
        ->whereIn('product_variations.id', $productIds)
        ->select('categories.alias as cat_alias', 'products.id', 'products.product_code', 'product_variations.price', 'product_variations.image', 'product_categories.cat_id as product_cat_id', 'product_variations.id as variation_id')
        ->get()
        ->map(function ($product) {
            $path = 'public/products/' . $product->id . '/' . $product->image;

            if (Storage::exists($path)) {
                $product->image = asset(Storage::url($path));

                $product->url = route('productDetail', [
                    'category' => $product->cat_alias,
                    'product_code' => $product->product_code,
                    'variation_id' => $product->variation_id
                ]);

                return $product;
            }

            return null;
        })
        ->filter();

    $section->products = $products;

    return $section;
}

function get_outlet_section()
{
    $section = HomepageSection::where('name', 'outlet')->first();

    $productIds = explode(',', $section->products);

    $products = Product::join('product_variations', 'product_variations.product_id', '=', 'products.id')
        ->join('product_categories', 'product_categories.product_id', '=', 'products.id')
        ->join('categories', 'product_categories.cat_id', '=', 'categories.id')
        ->whereIn('product_variations.id', $productIds)
        ->select('categories.alias as cat_alias', 'products.id', 'products.product_code', 'product_variations.price', 'product_variations.image', 'product_categories.cat_id as product_cat_id', 'product_variations.id as variation_id')
        ->get()
        ->map(function ($product) {
            $path = 'public/products/' . $product->id . '/' . $product->image;

            if (Storage::exists($path)) {
                $product->image = asset(Storage::url($path));

                $product->url = route('productDetail', [
                    'category' => $product->cat_alias,
                    'product_code' => $product->product_code,
                    'variation_id' => $product->variation_id
                ]);

                return $product;
            }

            return null;
        })
        ->filter();

    $section->products = $products;

    return $section;
}

function get_bookings_section()
{
    return HomepageSection::where('name', 'bookings')->first();
}

function get_testimonials_section()
{
    $section = HomepageSection::where('name', 'testimonials')->first();

    if ($section) {
        $section->testimonials = Testimonial::select('id', 'name', 'rating', 'content')->whereIn('id', explode(',', $section->testimonials))->get();
        $section->rating = (int)$section->rating;

        return $section;
    }

    return false;
}

function get_contact_section()
{
    return HomepageSection::where('name', 'contact')->first();
}

function get_contact_us_section()
{
    return Settings::select('email', 'phone', 'location')->first();
}

function nameToAlias($name)
{
    return strtolower(trim(preg_replace('/\s+/', '-', $name)));
}

function aliasToName($name)
{
    return ucwords(str_replace('-', ' ', $name));
}

function getCategories($id=0)
{
    return Category::where('active', 1)
    ->where('parent_id',$id)
    ->orderBy('rank', 'asc')->get();
}

function get_active_sections() {
    return HomepageSection::where('active', 1)->orderBy('order')->pluck('name');
}

function seasonal_highlights_products() {
    $cid = Category::where('alias', 'seasonal-highlight')->value('id');

    return Product::join('product_categories', 'product_categories.product_id', '=', 'products.id')->where('product_categories.cat_id', $cid)
        ->where('products.active', 1)
        ->select('products.id', 'products.product_code')->get();
}

function outlet_products() {
    $cid = Category::where('alias', 'the-outlet')->value('id');

    return Product::join('product_categories', 'product_categories.product_id', '=', 'products.id')->where('product_categories.cat_id', $cid)
        ->where('products.active', 1)
        ->select('products.id', 'products.product_code')->get();
}

function get_fonts() {
    return Font::select('name', 'path')->get();
}
