<?php

namespace App\Http\Controllers\API;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Facades\Storage; 
use Illuminate\Support\Facades\Hash;
use App\Helpers\Common\Functions;

use Auth;
use Mail;
use Illuminate\Support\Facades\URL; 

class ConversationController extends Controller
{
    private function _error_string($errArray)
    {
        $error_string = '';
        foreach ($errArray as $key) {
            $error_string.= $key."\n";
        }
        return $error_string;
    }
    public function update_request_status(Request $request){
        $validator = Validator::make($request->all(), [          
            'user_id'         => 'required',           
            'app_token'       => 'required',
            'request_id'         => 'required',           
            'status'       => 'required',
           
        ],[         
        	'user_id.required'	  	=> 'User Id is required',
        	'app_token.required'	=> 'App Token is required',
        	'status.required'	=> 'Status is required',
        	'request_id.required'	=> 'Request ID is required',
        	
        ]);

    	if (!$validator->passes()) {
            return response()->json(['status'=>'error','msg'=> $this->_error_string($validator->errors()->all()) ]);
        }else{
            $functions = new Functions();
            $token_res = $functions->validate_token($request->user_id, $request->app_token);
    		if($token_res>0){
    			$up_data['status'] = $request->status;
    			$up_data['action_on'] = date("Y-m-d H:i:s");
    			DB::table('chat_requests')->where('to_id',$request->user_id)->where('request_id',$request->request_id)->update($up_data);
    			if($request->status=="R"){
					$action_label = "rejected";
				}else{
					$action_label = "accepted";
				}

                $res=DB::table('users as u')
                	->join("chat_requests as r", "r.from_id","u.user_id")
                    ->select(DB::raw('u.player_id, u.user_id'))
                    ->where('r.request_id', $request->request_id)
                    ->first();
    			

                $res_from=DB::table('users')
                    ->select(DB::raw('username'))
                    ->where('user_id', $request->user_id)
                    ->first();
				
                $not_data['created_on'] = date("Y-m-d H:i:s");
                $not_data['sent_to'] = $res->user_id;
                $not_data['title'] = $res_from->username." $action_label your chat request";
                $not_data['page_name'] = "sent-requests";
                $not_data['post_id'] = "0";
                $not_data['sent_by'] = $request->user_id;
                DB::table('notifications')->insert($not_data);
                if($res->player_id!=""){
	                $functions = new Functions();
	                $functions->send_notification_both($res->player_id, $res_from->username." $action_label your chat request","CHAT REQUEST ".strtoupper($action_label));
	            }				
				
    		}else{
		        $response = array("status" => "error",'msg'=>'Sorry! Unauthorized access');
		        return response()->json($response);
			}
        }
		
	}
    public function chat_request_list(Request $request){
        if (!auth()->guard('api')->user()) {
            return response()->json([
                "status" => false, "msg" => "Unauthorized user!"
            ]);
        }else{
            $login_id = auth()->guard('api')->user()->user_id;
            
            $res=DB::table('users as u')
            //->leftJoin('categories as c','u.cat_id','=','c.cat_id')
            ->leftjoin("categories as c",\DB::raw("FIND_IN_SET(c.cat_id, u.cat_id)"),">",\DB::raw("'0'"))
            ->join('chat_requests as r', 'r.from_id', 'u.user_id')
            ->select(DB::raw('u.user_id as user_id,u.app_token as app_token,u.username as username,GROUP_CONCAT(c.category) as cat,round(DATEDIFF(CURRENT_DATE(),u.dob) / 365) as age,u.gender as gender,u.city as city,u.state as state,u.country as country,u.address1 as address1,u.profile_pic as profile_pic,r.request_id as request_id'))
            ->where('r.status','P')
            ->where('r.to_id',$login_id);
            if(!isset($request->page) && $request->page==""){
                $page=1;
            }else{
                $page=$request->page;
            }
            $limit=10;
            $offset=($page-1)*$limit;
            $where_key="";
            if(isset($request->keyword) && $request->keyword!=""){
                $key_arr=explode(",",$request->keyword);
                foreach ($key_arr as $val){
                $where_key=$where_key.' or (u.first_name like "%'.$val.'%") or (u.last_name like "%'.$val.'%") or (c.category like "%'.$val.'%") or (u.state like "%'.$val.'%") or (u.country like "%'.$val.'%")';
                }
                $where_key=$res->whereRaw("(".substr($where_key,3).")");
                $res=$where_key;
            }
            $res=$res->groupBy('u.user_id','u.username','u.gender','u.city','u.state','u.country','u.address1','u.profile_pic','r.request_id')->orderBy('r.request_id','desc')
            ->paginate($limit);
            $total_records=$res->total();
            $data=array();
            if (!$res->isEmpty()){
                foreach($res as $r){
                    if($r->profile_pic==""){
							if($r->gender=="M"){
							    $p=secure_asset('assets/images/avatar-man.png');
							}else if($r->gender=="F"){
							    $p=secure_asset('assets/images/avatar-woman.png');
							}else{
							    $p=secure_asset('assets/images/profile.png');
							}
					}else{
						$p=Storage::url("profile_pic/".$r->user_id."/".$r->profile_pic);
					}
					if($r->gender=='F'){
						$gender='Female';
					}else{
						$gender='Male';
					}
                    $s = array('id'=>$r->user_id,'username'=>$r->username,'cat_name'=>$r->cat,'age'=>$r->age,'gender'=>$gender,'city'=>$r->city,'state'=>$r->state,'country'=>$r->country,'address'=>$r->address1,'profile_pic' => $p,'request_id'=>$r->request_id);
                    array_push($data,$s);
            	}
            }else{
               $data=array('warning'=>'Sorry..! No record found.');
            }
            $response = array("status" => "success",'msg'=>'Chat Request List filtered successfully' ,'content' => $data,'total_records'=> $total_records);
            return response()->json($response); 
        }		
	}
    public function sent_requests(Request $request){
        if (!auth()->guard('api')->user()) {
            return response()->json([
                    "status" => false, "msg" => "Unauthorized user!"
                ]);
        }else{
            $login_id=auth()->guard('api')->user()->user_id;
            $res=DB::table('users as u')
                //->leftJoin('categories as c','u.cat_id','=','c.cat_id')
                ->leftjoin("categories as c",\DB::raw("FIND_IN_SET(c.cat_id, u.cat_id)"),">",\DB::raw("'0'"))
                ->join('chat_requests as r', 'r.to_id', 'u.user_id')
                ->select(DB::raw('u.user_id as user_id,u.app_token as app_token,u.username as username,GROUP_CONCAT(c.category) as cat,round(DATEDIFF(CURRENT_DATE(),u.dob) / 365) as age,u.gender as gender,u.city as city,u.state as state,u.country as country,u.address1 as address1,u.profile_pic as profile_pic,r.request_id as request_id, r.status'))
                ->where('r.from_id',$login_id);
                
                if(!isset($request->page) && $request->page==""){
                    $page=1;
                }else{
                    $page=$request->page;
                }
                $limit=10;
                $offset=($page-1)*$limit;
            $where_key="";
            if(isset($request->keyword) && $request->keyword!=""){
                $key_arr=explode(",",$request->keyword);
                foreach ($key_arr as $val){
                $where_key=$where_key.' or (u.first_name like "%'.$val.'%") or (u.last_name like "%'.$val.'%") or (c.category like "%'.$val.'%") or (u.state like "%'.$val.'%") or (u.country like "%'.$val.'%")';
                }
                $where_key=$res->whereRaw("(".substr($where_key,3).")");
                $res=$where_key;
            }
             $res=$res->groupBy('u.user_id','u.app_token','u.username','u.gender','u.city','u.state','u.country','u.address1','u.profile_pic','r.request_id');
             if(isset($request->src)){
                 $res=$res->orderByRaw(DB::raw("r.action_on desc, r.request_id desc"));
             }else{
				$res=$res->orderByRaw(DB::raw("r.request_id desc"));
			 }
             $res=$res->paginate($limit);
             
            $total_records=$res->total();
                
            
            $data=array();
            if (!$res->isEmpty()){
                foreach($res as $r){
                     if($r->profile_pic==""){
						if($r->gender=="M"){
						    $p=secure_asset('assets/images/avatar-man.png');
						}else if($r->gender=="F"){
						    $p=secure_asset('assets/images/avatar-woman.png');
						}else{
						    $p=secure_asset('assets/images/profile.png');
						}
					}else{
						$p=Storage::url("profile_pic/".$r->user_id."/".$r->profile_pic);
					}
					if($r->gender=='F'){
						$gender='Female';
					}else{
						$gender='Male';
					}
					if($r->status=='P'){
						$status='P';
					}elseif($r->status=='A'){
						$status='A';
					}else{
						$status='R';
					}
                    $s = array('id'=>$r->user_id,'app_token'=>$r->app_token,'username'=>$r->username,'cat_name'=>$r->cat,'age'=>$r->age,'gender'=>$gender,'city'=>$r->city,'state'=>$r->state,'country'=>$r->country,'address'=>$r->address1,'profile_pic' => $p,'request_id'=>$r->request_id, 'status'=>$status);
                    array_push($data,$s);
            	}
            }else{
               $data=array('warning'=>'Sorry..! No record found.');
            }
            
            $response = array("status" => "success",'msg'=>'Chat Request List filtered successfully' ,'content' => $data,'total_records'=> $total_records);
           
           /* }  else{
                $response = array("status" => "error",'msg'=>'Invalid Token');
            }   */ 
            return response()->json($response); 
        
        }		
	}
    public function show_interest(Request $request){
        $validator = Validator::make($request->all(), [
            'user_id'          => 'required',              
            'app_token'        => 'required',    
            'candidate_id'     => 'required', 
        ],[ 
            'user_id.required'   => 'Id is required',
            'app_token.required'   => 'App Token is required',
            'candidate_id.required'  => 'Candidate id is required',
        ]);

        if (!$validator->passes()) {
            return response()->json(['status'=>'error','msg'=> $this->_error_string($validator->errors()->all()) ]);
        }else{
            $functions = new Functions();
            $token_res = $functions->validate_token($request->user_id, $request->app_token);
    		if($token_res>0){
    			$ins_data['request_on'] = date("Y-m-d H:i:s");
    			$ins_data['from_id'] = $request->user_id;
    			$ins_data['to_id'] = $request->candidate_id;
    			$ins_data['status'] = "P";
    			DB::table('chat_requests')->insert($ins_data);

                $res=DB::table('users')
                    ->select(DB::raw('player_id'))
                    ->where('user_id', $request->candidate_id)
                    ->first();
    			

                $res_from=DB::table('users')
                    ->select(DB::raw('username'))
                    ->where('user_id', $request->user_id)
                    ->first();

    			
                $not_data['created_on'] = date("Y-m-d H:i:s");
                $not_data['sent_to'] = $request->candidate_id;
                $not_data['title'] = $res_from->username." showed interest in your profile";
                $not_data['page_name'] = "chat-requests";
                $not_data['post_id'] = "0";
                $not_data['sent_by'] = $request->user_id;
                DB::table('notifications')->insert($not_data);
                if($res->player_id!=""){
	                $functions = new Functions();
	                $functions->send_notification_both($res->player_id, $res_from->username." showed interest in your profile","NEW INTEREST RECEIVED");
	            }

    			
    		}else{
		        $response = array("status" => "error",'msg'=>'Sorry! Unauthorized access');
		        return response()->json($response);
			}
    	}
	}
    public function chat_request(Request $request){
        $validator = Validator::make($request->all(), [ 
            'user_id'          => 'required',              
            'app_token'        => 'required',    
            'candidate_id'               => 'required', 
        ],[ 
            'user_id.required'   => 'Id is required',
            'app_token.required'   => 'App Token is required',
            'candidate_id.required'  => 'Candidate id is required',
        ]);

        if (!$validator->passes()) {
            return response()->json(['status'=>'error','msg'=> $this->_error_string($validator->errors()->all()) ]);
        }else{
            $functions = new Functions();
            $token_res = $functions->validate_token($request->user_id, $request->app_token);
    		if($token_res>0){
				$res=DB::table('chat_requests')
		            ->select(DB::raw('status'))
	            	->where("to_id", $request->candidate_id)
	            	->where("from_id", $request->user_id)
		        	->first();
		        if($res){
					$response = array("status" => "success",'chat_status'=>$res->status);
				}else{
					$response = array("status" => "success",'chat_status'=>'');
				}
		        return response()->json($response);    			
    		}else{
		        $response = array("status" => "error",'msg'=>'Sorry! Unauthorized access');
		        return response()->json($response);
			}
        }
	}
   	public function message_count(Request $request){
        $validator = Validator::make($request->all(), [ 
          	'user_id'          => 'required',              
            'app_token'          => 'required',              
        ],[ 
            'user_id.required'   => 'User Id is required',
            'app_token.required'   => 'App Token is required',
        ]);

        if (!$validator->passes()) {
            return response()->json(['status'=>'error','msg'=> $this->_error_string($validator->errors()->all()) ]);
        }else{
            $functions = new Functions();
            $token_res= $functions->validate_token($request->user_id,$request->app_token);
    		if($token_res>0){
		        $res=DB::table('message')
		            ->select(DB::raw('count(*) as tot_msg'))
	            	->whereRaw(DB::raw("is_read=0 and to_id=".$request->user_id));
		        $res = $res->first();
		        if($res){
					$tot_msg = $res->tot_msg;
				}
		        $response = array("status" => "success",'total_count'=>$tot_msg);
		        return response()->json($response);
    		}else{
		        $response = array("status" => "error",'msg'=>'Sorry! Unauthorized access');
		        return response()->json($response);
			}
    	}
		
	}
    public function candidate_message(Request $request){
        
        $validator = Validator::make($request->all(), [ 
            'user_id'          => 'required',              
            'app_token'        => 'required',    
            'candidate_id'               => 'required', 
            'user_name'               => 'required',
            'msg'              => 'required',    
        ],[ 
            'user_id.required'   => 'Id is required',
            'app_token.required'   => 'App Token is required',
            'candidate_id.required'  => 'Candidate id is required',
            'user_name.required'  => 'User name is required',
            'msg.required'  => 'Cannot send empty Message'
        ]);

        if (!$validator->passes()) {
            return response()->json(['status'=>'error','msg'=> $this->_error_string($validator->errors()->all()) ]);
        }else{
            $functions = new Functions();
           /* $token_res= $functions->validate_token($request->user_id,$request->app_token,'C');
            $string="";
            if($token_res>0){
                $user_res= $functions->valid_candidate($request->user_id,'C');
                if($user_res==0){
                    $response = array("status" => "error",'msg'=>'Invalid Candidate');
                }else{*/
                $data =array(
                    'from_id'       => $request->user_id,
                    'to_id'         => $request->candidate_id,
                    'msg'           => $request->msg,
                  
                ); 
                DB::table('message')->insert($data);
                
                $res_from=DB::table('users')
                    ->select(DB::raw('username'))
                    ->where('user_id', $request->user_id)
                    ->first();
                    
                $res=DB::table('users')
                    ->select(DB::raw('player_id'))
                    ->where('user_id', $request->candidate_id)
                    ->first();
					
                $not_data['created_on'] = date("Y-m-d H:i:s");
                $not_data['sent_to'] = $request->candidate_id;
                $not_data['title'] = $res_from->username." sent you a message";
                $not_data['page_name'] = "candidate-messages";
                $not_data['post_id'] = "0";
                $not_data['sent_by'] = $request->user_id;
                DB::table('notifications')->insert($not_data);
                if($res->player_id!=""){
	                $functions = new Functions();
	                $functions->send_notification_both($res->player_id, $res_from->username." sent you a message","NEW MESSAGE RECEIVED");
	            }

				/*                  
               $functions = new Functions();
                    $res= $functions->send_notification($res->player_id,$request->msg,env('APP_ID'),"",$request->user_name,"candidate-message","u_id,u_name,c_id,c_name",$request->user_id.",".$request->user_name.",".$request->candidate_id.",".$request->candidate_name);
                    */
                    
                $response = array("status" => "success",'msg'=>'message sent' ,'content' => $data);
            /*}
            }  else{
                $response = array("status" => "error",'msg'=>'Invalid Token');
            }  */  
        
            return response()->json($response); 
        }
    }

}   