<?php

namespace App\Http\Controllers\API;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\Validator;
use AmrShawky\LaravelCurrency\Facade\Currency;

class ChallengesController extends Controller
{
    public function _error_string($errArray)
    {
        $error_string = '';
        foreach ($errArray as $key) {
            $error_string .= $key . "\n";
        }
        return $error_string;
    }

    public function create(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'title' => 'required',
            'cat_ids'     => 'required',
            'description' => 'required',
            'start_date' => 'required',
            'end_date' => 'required',
            'file' => 'mimes:mp4,jpg,jpeg'
        ], [
            'title.required' => 'You can\'t leave title field empty',
            'cat_ids.required'    => 'You can\'t leave categories field empty',
            'description.required'    => 'You can\'t leave description field empty',
            'start_date.required'    => 'You can\'t leave start date field empty',
            'end_date.required'    => 'You can\'t leave end date field empty',
        ]);

        if (!$validator->passes()) {
            return response()->json(['status' => 'error', 'msg' => $this->_error_string($validator->errors()->all())]);
        } else {
            $cat_ids = '';
            if (count($request->cat_ids) > 0) {
                $cat_ids = implode(',', $request->cat_ids);
            }

            $postData = array(
                'title'         => $request->title,
                'cat_ids'       => $cat_ids,
                'description'   => $request->description,
                'terms'   => isset($request->terms) ? $request->terms : '',
                'start_date'    => $request->start_date,
                'end_date'      => $request->end_date
            );

            if ($request->hasFile('file')) {
                $path = 'challenges';
                $ext = $request->file('file')->getClientOriginalExtension();
                $filenametostore = $request->file('file')->store($path);
                Storage::setVisibility($filenametostore, 'public');
                $fileArray = explode('/', $filenametostore);
                $image = array_pop($fileArray);
                $postData['file'] = $image;
                if ($ext == 'mp4') {
                    $type = 'V';
                } else {
                    $type = 'I';
                }
                $postData['file_type'] = $type;
            }
            $user_id = auth()->guard('api')->user()->user_id;
            $postData['user_id'] = $user_id;

            if (isset($request->price)) {
                $postData['price'] = $request->price;
            }

            if (isset($request->id)) {
                if (date('Y-m-d', strtotime($request->start_date)) > date('Y-m-d')) {
                    $title = str_replace(' ', '',  $request->title);
                    $tag = $title;
                    while (DB::table("challenges")->select("tag")->where("tag", $tag)->where('id', '<>', $request->id)->first()) {
                        $cat_ids = 0;
                        if (count($request->cat_ids) > 0) {
                            $cat_ids = $request->cat_ids[0];
                        }
                        $tag = $title . $cat_ids;
                    }
                    $postData['tag'] = $tag;
                }
                DB::table('challenges')->where('id', $request->id)->where('user_id', $user_id)->update($postData);
                return response()->json(['status' => true, 'msg' => 'Challenge Updated!']);
            } else {
                $title = str_replace(' ', '',  $request->title);
                $tag = $title;
                while (DB::table("challenges")->select("tag")->where("tag", $tag)->first()) {
                    $cat_ids = 0;
                    if (count($request->cat_ids) > 0) {
                        $cat_ids = $request->cat_ids[0];
                    }
                    $tag = $title . $cat_ids;
                }
                $postData['tag'] = $tag;

                DB::table('challenges')->insert($postData);
                return response()->json(['status' => true, 'msg' => 'Challenge Created!']);
            }
        }
    }

    public function challengesList(Request $request)
    {
        $limit = 10;
        $user_id = 0;
        $isIndia = 0;
        if (auth()->guard('api')->user()) {
            $user_id = auth()->guard('api')->user()->user_id;

            if (strtolower(auth()->guard('api')->user()->country) == 'india') {
                $isIndia = 1;
            }
        }
        config()->set('database.connections.mysql.strict', false);
        DB::reconnect();
        $default = secure_asset('assets/images/profile.png');
        $userDpPath = Storage::url("profile_pic");
        $data = array();
        $totalChallenges = 0;
        $fetchRecord = false;
        $setting = DB::table('settings')->first();
        
        if (isset($request->is_android)) {
            $app_version = $request->app_version;
            if ($request->is_android == 1) {
                if ($app_version >= $setting->android_version) {
                    $fetchRecord = true;
                }
            } else {
                if ($app_version >= $setting->ios_version) {
                    $fetchRecord = true;
                }
            }
        }

        // if ($fetchRecord) {
            // if (in_array($user_id, array(46, 79, 110, 120, 16609, 23510, 16611, 16674, 17582,24425))) {
            $challenges = DB::table('challenges as c')
                //     ->select(DB::raw('c.*,w.id as w_id, CASE WHEN w.id > 0 THEN 1 ELSE 0 END as joined,CASE WHEN p.post_id > 0 THEN 1 ELSE 0 END as posted,substring_index(group_concat(case when u.profile_pic !="" THEN case when INSTR(u.profile_pic,"https://") > 0 THEN u.profile_pic ELSE 
                // 	concat("' . $userDpPath . '/",u.user_id,"/",u.profile_pic)  END ELSE "' . $default . '" END),",",5) as profile_pic,count(u.user_id) as total_members'))
                ->select(DB::raw('c.*,w.id as w_id, CASE WHEN w.id > 0 THEN 1 ELSE 0 END as joined,CASE WHEN p.post_id > 0 THEN 1 ELSE 0 END as posted'))
                ->leftJoin('wallet_history as w', function ($q) use ($user_id) {
                    $q->on('w.challenge_id', 'c.id')
                        ->where('w.type', 'D')
                        ->where('w.user_id', $user_id)
                        ->limit(1);
                    // ->whereRaw("w.id = (SELECT id FROM wallet_history WHERE wallet_history.user_id = $user_id and type='D' order by id desc LIMIT 1)");
                    // ->where('w.type','D');
                })
                ->leftJoin('posts as p', function ($q) use ($user_id) {
                    $q->on('p.challenge_id', 'c.id')->where('p.user_id', $user_id);
                });
            //  ->leftJoin('posts as ps', function ($q) use ($user_id) {
            //     $q->on('ps.challenge_id', 'c.id');
            // })
            // ->leftJoin('users as u', function ($q) use ($user_id) {
            //     $q->on('u.user_id', 'ps.user_id');
            // });
            if (isset($request->search)) {
                $challenges = $challenges->whereRaw('((c.title like "%' . $request->search . '%") or (c.description like "%' . $request->search . '%") or (c.tag like "%' . $request->search . '%"))');
            }
            $challenges = $challenges->where('c.active', 1);
            $challenges = $challenges->orderBy('id', 'desc');
            // $challenges = $challenges->groupBy('ps.challenge_id');
            // dd($challenges->tosql());
            $totalChallenges = $challenges->get()->count();
            $challenges = $challenges->paginate($limit);
            // dd($challenges);
            config()->set('database.connections.mysql.strict', true);
            DB::reconnect();

            $filePath = asset(Storage::url('challenges')) . '/';
            foreach ($challenges as $challenge) {
                $posts = DB::table('challenges as c')
                    ->select(DB::raw('substring_index(group_concat(case when u.profile_pic !="" THEN case when INSTR(u.profile_pic,"https://") > 0 THEN u.profile_pic ELSE 
    			 	concat("' . $userDpPath . '/",u.user_id,"/",u.profile_pic)  END ELSE "' . $default . '" END),",",5) as profile_pic,count(u.user_id) as total_members'))

                    ->leftJoin('posts as ps', function ($q) use ($user_id) {
                        $q->on('ps.challenge_id', 'c.id');
                    })
                    ->leftJoin('users as u', function ($q) use ($user_id) {
                        $q->on('u.user_id', 'ps.user_id');
                    })
                    ->where('ps.challenge_id', $challenge->id)
                    ->groupBy('ps.challenge_id')
                    ->first();

                if($fetchRecord){
                    $description=$challenge->description;
                }else{
                    $description="The Show Your Talent Challenge invites participants to showcase their unique skills in a fun and engaging way from 11th October to 21th October. 
                    Whether it's singing, dancing, cooking, painting, or any other talent, this challenge encourages creativity and self-expression. To participate, select a talent, 
                    record a short video (1-3 minutes) highlighting it, and share it on social media using the hashtag #ShowYourTalentChallenge, while nominating at least three friends to join in. 
                    Judging will be based on creativity, presentation quality, and enthusiasm, with exciting prizes such as gift cards and features on our platform for winners. 
                    Join us in celebrating diverse talents and inspiring one another! 
                    This challenge is currently available only in India. Participants from other countries, stay tuned!";
                }

                $challengeData = array();
                $challengeData['id'] = $challenge->id;
                $challengeData['title'] = $challenge->title;
                // $challengeData['description'] = strip_tags($challenge->description);
                $challengeData['description'] = $description;
                $challengeData['terms'] = $challenge->terms;
                $challengeData['file'] = ($challenge->file != "") ? $filePath . $challenge->file : '';
                $challengeData['file_type'] = ($challenge->file != "") ? $challenge->file_type : '';
                $challengeData['start_date'] = date('d M Y', strtotime($challenge->start_date));
                $challengeData['end_date'] = date('d M Y', strtotime($challenge->end_date));
                $challengeData['created_at'] = $challenge->created_at;
                $challengeData['tag'] = $challenge->tag;
                $challengeData['min_required_users'] = $challenge->min_required_users;

                $price = $challenge->price;
                // $challengeData['price'] = isset($price) ? number_format((float) $price, 2, '.', '') : '';
                $challengeData['price'] = isset($price) ? $price : 0;

                $first_price = $challenge->first_price;
                $challengeData['first_price'] = isset($first_price) ? $first_price : 0;

                $second_price = $challenge->second_price;
                $challengeData['second_price'] = isset($second_price) ? $second_price : 0;

                $third_price = $challenge->third_price;
                $challengeData['third_price'] = isset($third_price) ? $third_price : 0;

                $isStarted = 0;
                if ($challenge->start_date <= date('Y-m-d 00:00:00')) {
                    $isStarted = 1;
                }

                $active = 1;
                if ($challenge->end_date < date('Y-m-d 59:59:59')) {
                    $active = 0;
                }

                if ($challenge->result_declared == 2) {
                    $active = 2;
                }



                $challengeData['active'] = $active;
                $challengeData['isStarted'] = $isStarted;
                $challengeData['isIndia'] = $isIndia;

                $challengeData['joined'] = $challenge->joined;
                $challengeData['posted'] = $challenge->posted;

                $users = [];
                $total_members = 0;
                if ($posts) {
                    $users = explode(',', $posts->profile_pic);
                    $total_members = $posts->total_members;
                }
                $challengeData['users'] = $users;
                $challengeData['total_members'] = $total_members;

                $challengeData['tie'] = 0;
                $tieMsg = '';
                if ($challenge->tie == 1 && $challenge->result_declared == 0) {
                    $challengeData['tie'] = $challenge->tie;
                    $tieMsg = $challenge->title . ": challenge has been tied, due to this the deadline has been extended by one day.";
                } else if ($challenge->tie == 2 && $challenge->result_declared == 0) {
                    $challengeData['tie'] = $challenge->tie;
                    $tieMsg = $challenge->title . ": challenge has been tied again, result will be announced by admin as soon as possible.";
                }
                $challengeData['tie_msg'] = $tieMsg;
                array_push($data, $challengeData);
            }
        // }
        // }
        return response()->json(['status' => true, 'total' => $totalChallenges, 'data' => $data]);
    }

    public function challengeDetail(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'id' => 'required'
        ], [
            'id.required' => 'You can\'t leave id field empty'
        ]);

        if (!$validator->passes()) {
            return response()->json(['status' => 'error', 'msg' => $this->_error_string($validator->errors()->all())]);
        } else {
            $filePath = asset(Storage::url('challenges')) . '/';
            $wallet_amount = 0;
            $user_id = 0;
            $isIndia=0;
            if (auth()->guard('api')->user()) {
                $user_id = auth()->guard('api')->user()->user_id;
                $wallet_amount = auth()->guard('api')->user()->wallet_amount;
                if(strtolower(auth()->guard('api')->user()->country)=='india'){
                    $isIndia=1;
                }
            }
             $fetchRecord = false;
            $setting = DB::table('settings')->first();
            
            if (isset($request->is_android)) {
                $app_version = $request->app_version;
                if ($request->is_android == 1) {
                    if ($app_version >= $setting->android_version) {
                        $fetchRecord = true;
                    }
                } else {
                    if ($app_version >= $setting->ios_version) {
                        $fetchRecord = true;
                    }
                }
            }
        
            config()->set('database.connections.mysql.strict', false);
            DB::reconnect();
            $default = secure_asset('assets/images/profile.png');
            $userDpPath = Storage::url("profile_pic");
            $challenge = DB::table('challenges as c')
                ->select(DB::raw('c.*, CASE WHEN w.id > 0 THEN 1 ELSE 0 END as joined,CASE WHEN p.post_id > 0 THEN 1 ELSE 0 END as posted, substring_index(group_concat(case when u.profile_pic !="" THEN case when INSTR(u.profile_pic,"https://") > 0 THEN u.profile_pic ELSE 
    					concat("' . $userDpPath . '/",u.user_id,"/",u.profile_pic)  END ELSE "' . $default . '" END),",",5) as profile_pic,count(u.user_id) as total_members'))

                ->leftJoin('wallet_history as w', function ($q) use ($user_id) {
                    $q->on('w.challenge_id', 'c.id')
                        ->whereRaw("w.id = (SELECT id FROM wallet_history WHERE wallet_history.user_id = $user_id and type='D' order by id desc LIMIT 1)");
                    // ->where('w.type','D');
                })
                ->leftJoin('posts as p', function ($q) use ($user_id) {
                    $q->on('p.challenge_id', 'c.id')->where('p.user_id', $user_id);
                })
                ->leftJoin('posts as ps', function ($q) use ($user_id) {
                    $q->on('ps.challenge_id', 'c.id');
                })
                ->leftJoin('users as u', function ($q) use ($user_id) {
                    $q->on('u.user_id', 'ps.user_id');
                });
            $challenge = $challenge->where('c.id', $request->id);
            $challenge = $challenge->groupBy('ps.challenge_id');
            $challenge = $challenge->first();
            config()->set('database.connections.mysql.strict', true);
            DB::reconnect();
            if ($challenge) {

                if($fetchRecord){
                    $description=$challenge->description;
                }else{
                    $description="The Show Your Talent Challenge invites participants to showcase their unique skills in a fun and engaging way from 11th October to 21th October. 
                    Whether it's singing, dancing, cooking, painting, or any other talent, this challenge encourages creativity and self-expression. To participate, select a talent, 
                    record a short video (1-3 minutes) highlighting it, and share it on social media using the hashtag #ShowYourTalentChallenge, while nominating at least three friends to join in. 
                    Judging will be based on creativity, presentation quality, and enthusiasm, with exciting prizes such as gift cards and features on our platform for winners. 
                    Join us in celebrating diverse talents and inspiring one another! 
                    This challenge is currently available only in India. Participants from other countries, stay tuned!";
                }
                
                $challengeData['id'] = $challenge->id;
                $challengeData['title'] = $challenge->title;
                // $challengeData['description'] = strip_tags($challenge->description);
                $challengeData['description'] = $description;
                $challengeData['terms'] = $challenge->terms;
                $challengeData['file'] = ($challenge->file != "") ? $filePath . $challenge->file : '';
                $challengeData['file_type'] = ($challenge->file != "") ? $challenge->file_type : '';
                $challengeData['start_date'] = date('d M Y', strtotime($challenge->start_date));
                $challengeData['end_date'] = date('d M Y', strtotime($challenge->end_date));
                $challengeData['created_at'] = $challenge->created_at;
                $challengeData['tag'] = $challenge->tag;
                $challengeData['min_required_users'] = $challenge->min_required_users;
                $price = $challenge->price;
                // $challengeData['price'] = isset($price) ? number_format((float) $price, 2, '.', '') : '';
                $challengeData['price'] = isset($price) ?  $price : 0;

                $first_price = $challenge->first_price;
                $challengeData['first_price'] = isset($first_price) ? $first_price : 0;

                $second_price = $challenge->second_price;
                $challengeData['second_price'] = isset($second_price) ? $second_price : 0;

                $third_price = $challenge->third_price;
                $challengeData['third_price'] = isset($third_price) ? $third_price : 0;

                $isStarted=0;
                if ($challenge->start_date <= date('Y-m-d 00:00:00')) {
                    $isStarted=1;
                }

                $active = 1;
                if ($challenge->end_date < date('Y-m-d 59:59:59')) {
                    $active = 0;
                }

                if ($challenge->result_declared == 2) {
                    $active = 2;
                }
                $challengeData['active'] = $active;
                $challengeData['isStarted'] = $isStarted;
                $challengeData['isIndia'] = $isIndia;

                $challengeData['joined'] = $challenge->joined;
                $challengeData['posted'] = $challenge->posted;

                $users = explode(',', $challenge->profile_pic);
                $challengeData['users'] = $users;
                $challengeData['total_members'] = $challenge->total_members;

                $challengeData['tie'] = 0;
                $tieMsg = '';
                if ($challenge->tie == 1 && $challenge->result_declared == 0) {
                    $challengeData['tie'] = $challenge->tie;
                    $tieMsg = $challenge->title . ": challenge has been tied, due to this the deadline has been extended by one day.";
                } else if ($challenge->tie == 2 && $challenge->result_declared == 0) {
                    $challengeData['tie'] = $challenge->tie;
                    $tieMsg = $challenge->title . ": challenge has been tied again, result will be announced by admin as soon as possible.";
                }
                $challengeData['tie_msg'] = $tieMsg;

                // fd_newuser_200_coins
                $new_user_coin = 0;
                $payment = DB::table('payment_history')->where('user_id', $user_id)->where('product_id', 'fd_newuser_200_coins')->exists();
                if ($payment) {
                    $new_user_coin = 1;
                }

                return response()->json(['status' => true, 'data' => $challengeData, 'wallet_amount' => $wallet_amount, 'new_user_coin' => $new_user_coin,'show_challenge_actions'=>$setting->show_challenge_actions,'show_challenge_points' => $setting->show_challenge_points]);
            }
            return response()->json(['status' => false, 'msg' => 'Record not found!', 'data' => []]);
        }
    }
    public function deleteChallenge(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'id' => 'required'
        ], [
            'id.required' => 'You can\'t leave id field empty'
        ]);

        if (!$validator->passes()) {
            return response()->json(['status' => 'error', 'msg' => $this->_error_string($validator->errors()->all())]);
        } else {

            $id = $request->id;
            $user_id = auth()->guard('api')->user()->user_id;

            $challenge = DB::table('challenges')->where('id', $id)->where('user_id', $user_id)->exist();
            if ($challenge) {
                DB::table('challenges')->where('id', $id)->where('user_id', $user_id)->delete();
                return response()->json(['status' => true, 'msg' => 'Challenge deleted successfully!']);
            }
            return response()->json(['status' => false, 'msg' => 'No record found!']);
        }
    }

    public function challengeVideos(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'id' => 'required'
        ], [
            'id.required' => 'You can\'t leave id field empty'
        ]);

        if (!$validator->passes()) {
            return response()->json(['status' => 'error', 'msg' => $this->_error_string($validator->errors()->all())]);
        } else {
            config()->set('database.connections.mysql.strict', false);
            DB::reconnect();
            $user_id = 0;
            if (auth()->guard('api')->user()) {
                $user_id = auth()->guard('api')->user()->user_id;
            }
            $default = secure_asset('assets/images/profile.png');
            $userDpPath = Storage::url("profile_pic");
            $videoPath = Storage::url("videos");
            $posts = DB::table('posts as p')
                ->select(DB::raw('p.post_id as post_id,
                concat("' . $videoPath . '/",u.user_id,"/",p.file) as file,
                concat("' . $videoPath . '/",u.user_id,"/thumb/",REPLACE(p.file,".mp4",".jpg")) as thumb,
                p.title as title,p.added_on as added_on,p.likes as likes,p.views as views,
    					p.comments as comments,p.shares as shares,p.type as type,
    					u.user_id as user_id,u.username as username,u.gender,
    					case when u.profile_pic !="" THEN case when INSTR(u.profile_pic,"https://") > 0 THEN u.profile_pic ELSE 
    					concat("' . $userDpPath . '/",u.user_id,"/",u.profile_pic)  END ELSE "' . $default . '" END as profile_pic, p.aspect_ratio,
                CASE WHEN p.shares > 0 THEN p.shares * 4 ELSE 0 END AS total_shares,
                CASE WHEN p.likes > 0 THEN p.likes * 3 ELSE 0 END AS total_likes,
                CASE WHEN p.views > 0 THEN p.views * 2 ELSE 0 END AS total_views,
                CASE WHEN p.comments > 0 THEN p.comments * 1 ELSE 0 END AS total_comments,
             ((CASE WHEN count(DISTINCT ps.user_id) > 0 THEN count(DISTINCT ps.user_id) * 4 ELSE 0 END) +
            (CASE WHEN count(DISTINCT pl.user_id) > 0 THEN count(DISTINCT pl.user_id) * 2 ELSE 0 END) +
            (CASE WHEN count(DISTINCT pv.user_id) > 0 THEN count(DISTINCT pv.user_id) * 1 ELSE 0 END) +
            (CASE WHEN count(DISTINCT pc.user_id) > 0 THEN count(DISTINCT pc.user_id) * 3 ELSE 0 END)) as total,
            l.like_id as like_id, CASE WHEN cw.challenge_id IS NOT NULL THEN 1 ELSE 0 END AS is_winner
                '))->leftJoin('users as u', 'u.user_id', 'p.user_id')
                ->leftJoin('challenge_winners as cw', function ($q) {
                    $q->on('cw.challenge_id', 'p.challenge_id');
                    $q->on("cw.user_id", 'u.user_id');
                })

                ->join('challenges as c', 'c.id', 'p.challenge_id')

                ->leftJoin('post_comments as pc', function ($q) {
                    $q->on('pc.post_id', 'p.post_id');
                    $q->on("pc.comment_on", '<=', 'c.end_date');
                })

                ->leftJoin('post_shares as ps', function ($q) {
                    $q->on('ps.post_id', 'p.post_id');
                    $q->on("ps.share_on", '<=', 'c.end_date');
                })

                ->leftJoin('post_likes as pl', function ($q) {
                    $q->on('pl.post_id', 'p.post_id');
                    $q->on("pl.like_on", '<=', 'c.end_date');
                })

                ->leftJoin('post_views as pv', function ($q) {
                    $q->on('pv.post_id', 'p.post_id');
                    $q->on("pv.view_on", '<=', 'c.end_date');
                })

                ->leftJoin('post_likes as l', function ($q) use ($user_id) {
                    $q->on('l.post_id', 'p.post_id');
                    $q->where("l.user_id", $user_id);
                })


                ->where('p.challenge_approved', 1)
                ->where('p.challenge_id', $request->id);

            if (isset($request->search)) {
                $posts = $posts->whereRaw("((p.title like '%" . $request->search . "%') or (u.username like '%" . $request->search . "%') or (u.first_name like '%" . $request->search . "%') or (u.last_name like '%" . $request->search . "%'))");
            }

            $posts = $posts->groupBy('p.post_id');
            $totalRecord = $posts->get()->count();

            $posts->orderBy('is_winner', 'desc')
                ->orderBy('cw.position', 'asc')
                ->orderBy('total', 'desc')
                ->paginate(9);
            // dd($posts);
            config()->set('database.connections.mysql.strict', true);
            DB::reconnect();
            return response()->json(['status' => true, 'total' => $totalRecord, 'data' => $posts->items()]);
        }
    }

    public function updateChallengeTerm(Request $request)
    {
        $user_id = auth()->guard('api')->user()->user_id;
        DB::table('users')->where('user_id', $user_id)->update(['challenge_term' => 1]);
        return response()->json(['status' => true, 'msg' => 'Term Updated!']);
    }


    public function userChallengesWinningList(Request $request)
    {
        if (auth()->guard('api')->user()) {
            $user_id = auth()->guard('api')->user()->user_id;
            $records = DB::table('challenges as c')
                ->select(DB::raw("c.id as id,c.title,w.position,w.win_amount,LOWER(DATE_FORMAT(w.created_at,'%d %b %Y %l:%m %p')) as created_at"))
                ->join('challenge_winners as w', 'w.challenge_id', 'c.id')
                ->where('w.user_id', $user_id);
            if (isset($request->search)) {
                $records = $records->whereRaw('(c.title like "%' . $request->search . '%")');
            }

            $totalRecord = $records->get()->count();

            $records = $records->paginate(10);

            return response()->json(['status' => true, 'total' => $totalRecord, 'data' => $records->items()]);
        } else {
            return response()->json(['status' => false, 'msg' => 'Unauthorized user']);
        }
    }
}
