<?php

namespace App\Http\Controllers\API;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Facades\Storage; 
use Illuminate\Support\Facades\Hash;
use App\Helpers\Common\Functions;

use Auth;
use Mail;
use Illuminate\Support\Facades\URL; 

class MyProfileController extends Controller
{
    private function _error_string($errArray)
    {
        $error_string = '';
        foreach ($errArray as $key) {
            $error_string.= $key."\n";
        }
        return $error_string;
    }    

    public function my_profile(Request $request){
        
        $validator = Validator::make($request->all(), [ 
        	 'user_id'         => 'required',           
            'app_token'       => 'required',
           
        ],[         
        	'user_id.required'	  	=> 'User Id is required',
        	'app_token.required'	=> 'App Token is required',

        ]);

        if (!$validator->passes()) {
            return response()->json(['status'=>'error','msg'=> $this->_error_string($validator->errors()->all()) ]);
        }else{
             $functions = new Functions();
                $token_res= $functions->validate_token($request->user_id,$request->app_token);
                if($token_res>0){
        
        			$follower_res=DB::table('followers')
		                ->where('user_id',$request->user_id)
		                ->count();
		            
		            $following_res=DB::table('followers')
		                ->where('following_id',$request->user_id)
		                ->count();
		            
		           $likes_res=DB::table('post_likes as l')
		            	->leftJoin('posts as p','p.post_id','=','l.post_id')
		                ->where('p.user_id',$request->user_id)
		                ->count();
		                
		            $views_res=DB::table('post_views as v')
		            	->leftJoin('posts as p','p.post_id','=','v.post_id')
		                ->where('p.user_id',$request->user_id)
		                ->count();
                  
                        
                        $data = array('followers'=>$follower_res,'followings'=>$following_res,'likes'=>$likes_res,'views'=>$views_res);
                        
                        $response = array("status" => "success",'msg'=>'Candidate Profile View' ,'content' => $data);
                }  else{
                    $response = array("status" => "error",'msg'=>'Invalid Token');
                }   
            return response()->json($response); 
        }
    }
    
    public function get_photos(Request $request){
    	$validator = Validator::make($request->all(), [ 
			            'user_id'          => 'required',              
                        'app_token'        => 'required',                   
			        ],[ 
			            'user_id.required'   => 'Id is required',
                        'app_token.required'   => 'App Token is required',

			        ]);

	        if (!$validator->passes()) {
	            return response()->json(['status'=>'error','msg'=> $this->_error_string($validator->errors()->all()) ]);
	        }else{
	        	if(!isset($request->page) && $request->page==""){
                        $page=1;
                    }else{
                        $page=$request->page;
                    }
                    $limit=10;
                    $offset=($page-1)*$limit;
	            $functions = new Functions();
                $token_res= $functions->validate_token($request->user_id,$request->app_token);
                if($token_res>0){
    	        	 $photo_res=DB::table('posts')
    	                        ->select(DB::raw('post_id,file,title'))
    	                        ->where('user_id',$request->user_id)
    	                        ->where('type','P')
    	                        ->orderBy('post_id','desc')
    	                         ->paginate($limit);
    	            $total_records=$photo_res->total();
    	            	if (!$photo_res->isEmpty()){
    		               foreach($photo_res as $r){
    		               	 		$file=Storage::url("photos/".$request->user_id."/".$r->file);
    						        $data['photos'][] = array("post_id" => $r->post_id,"title"=>$r->title,'file'=>$file);  
    		                     }
    	                }else{
    						$data['photo_warning'] = '<br/><br/><br/><br/>No photo(s) uploaded yet.<br/><br/<br/><br/><br/><br/>';
    					}
    					$response = array("status" => "success",'msg'=>'Candidate Photos' ,'content' => $data,'total_records'=> $total_records);
                
    	        
    	        }  else{
                    $response = array("status" => "error",'msg'=>'Invalid Token');
                }   
	        	return response()->json($response); 
            }
    }	
    public function get_videos(Request $request){
    	$validator = Validator::make($request->all(), [ 
			            'user_id'          => 'required',              
                        'app_token'        => 'required',                   
			        ],[ 
			            'user_id.required'   => 'Id is required',
                        'app_token.required'   => 'App Token is required',

			        ]);

	        if (!$validator->passes()) {
	            return response()->json(['status'=>'error','msg'=> $this->_error_string($validator->errors()->all()) ]);
	        }else{
	        	if(!isset($request->page) && $request->page==""){
                        $page=1;
                    }else{
                        $page=$request->page;
                    }
                    $limit=10;
                    $offset=($page-1)*$limit;
	             $functions = new Functions();
                $token_res= $functions->validate_token($request->user_id,$request->app_token);
                if($token_res>0){
    	        	 $video_res=DB::table('posts')
                            ->select(DB::raw('post_id,file,title'))
                            ->where('user_id',$request->user_id)
                            ->where('type','V')
                            ->orderBy('post_id','desc')
                            ->paginate($limit);
    	            $total_records=$video_res->total();
                    if (!$video_res->isEmpty()){
    	               foreach($video_res as $r){
								$thumb=explode(".",$r->file);
								$thum=$thumb[0].".jpg";
								//$thum=substr($r->file, 0, -3)."jpg";
								$thumb_file=Storage::url("videos/".$request->user_id."/thumb/".$thum);
    	               			$file=Storage::url("videos/".$request->user_id."/".$r->file);
    	                        $data['videos'][] = array("post_id" => $r->post_id,"title"=>$r->title,'file'=>$file,'thumb'=>$thumb_file);
    	                     }
                    }else{
						$data['video_warning'] = '<br/><br/><br/><br/>No video(s) uploaded yet.<br/><br/<br/><br/><br/><br/>';
					}
            	$response = array("status" => "success",'msg'=>'Candidate Videos' ,'content' => $data,'total_records'=> $total_records);
                }  else{
                    $response = array("status" => "error",'msg'=>'Invalid Token');
                }   
	        	return response()->json($response); 
            }
    	}
    


}   