<?php
namespace App\Http\Controllers\API;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Facades\Storage; 
use Illuminate\Support\Facades\Hash;
use App\Helpers\Common\Functions;
use Intervention\Image\ImageManagerStatic as Image;
use Auth;
use Mail;
use Illuminate\Support\Facades\URL; 

class NotificationController extends Controller
{
    private function _error_string($errArray)
    {
        $error_string = '';
        foreach ($errArray as $key) {
            $error_string.= $key."\n";
        }
        return $error_string;
    }
    public function update_last_visited(Request $request){
        $validator = Validator::make($request->all(), [ 
          	'user_id'          => 'required',              
            'app_token'          => 'required',              
        ],[ 
            'user_id.required'   => 'User Id is required',
            'app_token.required'   => 'App Token is required',
        ]);

        if (!$validator->passes()) {
            return response()->json(['status'=>'error','msg'=> $this->_error_string($validator->errors()->all()) ]);
        }else{
            $functions = new Functions();
            $token_res= $functions->validate_token($request->user_id,$request->app_token);
    		if($token_res>0){
                 DB::table('users')
                    ->where('user_id',$request->user_id)
                    ->update(['last_visited' => date("Y-m-d H:i:s")]);

    		}else{
		        $response = array("status" => "error",'msg'=>'Sorry! Unauthorized access');
		        return response()->json($response);
			}
		}
    }
   	public function notification_count(Request $request){
        $validator = Validator::make($request->all(), [ 
          	'user_id'          => 'required',              
            'app_token'          => 'required',              
        ],[ 
            'user_id.required'   => 'User Id is required',
            'app_token.required'   => 'App Token is required',
        ]);

        if (!$validator->passes()) {
            return response()->json(['status'=>'error','msg'=> $this->_error_string($validator->errors()->all()) ]);
        }else{
            $functions = new Functions();
            $token_res= $functions->validate_token($request->user_id,$request->app_token);
    		if($token_res>0){
		        $res=DB::table('notifications')
		            ->select(DB::raw('count(*) as tot_notice'))
	            	->whereRaw(DB::raw( "concat(',',IFNULL(read_by,''),',') not like ',%".$request->user_id."%,' and sent_to=".$request->user_id));
		        $res = $res->first();
		        if($res){
					$tot_notice = $res->tot_notice;
				}
		        $response = array("status" => "success",'total_count'=>$tot_notice);
		        return response()->json($response);
    		}else{
		        $response = array("status" => "error",'msg'=>'Sorry! Unauthorized access');
		        return response()->json($response);
			}
    	}
		
	}
    public function notification_list(Request $request){
        if(auth()->guard('api')->user()){
            $user_id=auth()->guard('api')->user()->user_id;
	        $res=DB::table('notifications as n')
	            ->select(DB::raw('n.*, p.file, p.type, u.profile_pic, u.username'))
	            ->leftJoin("posts as p", "p.post_id","=","n.post_id")
	            ->leftJoin("users as u", "u.user_id","=","n.sent_by")
	            ->where('n.sent_to',$user_id)
	            ->orderBy('n.created_on','desc');
			
	        $res = $res->paginate(15);

			DB::statement("UPDATE notifications SET read_by = concat(IFNULL(read_by,''),',',".$user_id.") where concat(',',IFNULL(read_by,''),',') not like ',%".$user_id."%,' and sent_to=".$user_id);
			
	        $data=array();
	        foreach($res as $r){
				if($r->profile_pic==""){
					$user_pic = asset('assets/images/profile.png');
				}else{
				    if (stripos($r->profile_pic, 'https://') !== false) {
						$user_pic=$r->profile_pic;
					}else{
						$user_pic=Storage::url("profile_pic/".$r->sent_by."/".$r->profile_pic);
					}
							
				// 	$user_pic=Storage::url("profile_pic/".$r->sent_by."/".$r->profile_pic);
				}

				if($r->type=="V"){
                    $thumb=explode(".",$r->file);
                    $thum=$thumb[0].".jpg";
					//$thum=substr($r->file, 0, -3)."jpg";
					$file=Storage::url("videos/".$r->sent_to."/thumb/".$thum);
				}else{
					$file=Storage::url("photos/".$r->sent_to."/".$r->file);
				}

	        	if(strpos(",".$r->read_by.",", ",".$user_id.",")===false){
					$class_name = "unread";
				}else{
					$class_name = "read";
				}
	        	
	        	$created_on = date("d, M Y h:i a", strtotime($r->created_on));
	            $s = array('user_pic'=>$user_pic,'post_thumb'=>$file,'class_name'=>$class_name,'created_on'=>$created_on,'title'=>$r->title,'message'=>$r->message,'page_name'=>$r->page_name,'post_id'=>$r->post_id,'sent_by'=>$r->sent_by,'username'=>$r->username);
	            array_push($data,$s);
	        } 
	        $response = array("status" => "success",'msg'=>'Notification List','page_total'=>$res->count(), 'total_count'=>$res->total(),'data' => $data);
	        return response()->json($response);
	         
		}else{
	        $response = array("status" => "error",'msg'=>'Sorry! Unauthorized access');
	        return response()->json($response);
		}
    }

        
}   