<?php

namespace App\Http\Controllers\API;

use Auth;
use Mail;
use FFMpeg;
use Notification;
use App\Models\User;
use FFProbe as FFProbe;
use Illuminate\Http\Request;
use App\Jobs\UpdateAspectRatios;
use App\Helpers\Common\Functions;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\URL;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Hash;
use App\Notifications\UserNotification;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\Validator;
use Intervention\Image\ImageManagerStatic as Image;

class PostController extends Controller
{
    public $ffprobe;

    private function _error_string($errArray)
    {
        $error_string = '';
        foreach ($errArray as $key) {
            $error_string .= $key . "\n";
        }
        return $error_string;
    }

    //single post
    public function fetchPost(Request $request)
    {

        $validator = Validator::make($request->all(), [

            'post_id'          => 'required',
        ], [

            'post_id.required'   => 'Post Id is required.',
        ]);

        if (!$validator->passes()) {
            return response()->json(['status' => 'error', 'msg' => $this->_error_string($validator->errors()->all())]);
        } else {
            // if (auth()->guard('api')->user()) {
            if (auth()->guard('api')->user()) {
                $login_id = auth()->guard('api')->user()->user_id;
            } else {
                $login_id = 0;
            }

            $strSql = "select l.like_id as like_id, u.user_id as user_id,u.username as username,u.gender,u.profile_pic as profile_pic,p.aspect_ratio,p2.aspect_ratio as aspect_ratio2,GROUP_CONCAT(c.cat_id) as cat_id,GROUP_CONCAT(c.category) as cat_name,u2.user_id as user_id2, u2.username as username2, u2.profile_pic as profile_pic2,u2.gender as gender2, p.shared_post_id, p2.post_id as post_id2, p2.type as type2, p2.file as file2,p2.title as title2, p.post_id as post_id,p.file as file,p.title as title,p.added_on as added_on,p2.added_on as shared_added_on,p.likes as likes,p.views as views,p.comments as comments,p.shares as shares,p.type as type ,case when f.follower_id IS NULL then 0 else 1 end as isFollowing,case when fav.fav_id IS NULL then 0 else 1 end as isFav
        		from users as u
        		join posts as p on u.user_id = p.user_id 
        		left join post_likes as l on l.post_id = p.post_id and l.user_id = " . $login_id . "
        		left join followers as f on f.user_id=u.user_id and f.following_id = " . $login_id . "
        		left join favorite_users as fav on fav.user_id=u.user_id and fav.added_by = " . $login_id . "
        		left join posts as p2 on p2.post_id  = p.shared_post_id
        		left join users as u2 on p2.user_id = u2.user_id
        		left join categories as c on FIND_IN_SET(c.cat_id, u.cat_id) > 0
        		where u.deleted = 0 and p.show_on_wall=1  and p.active=1 and p.post_id = " . $request->post_id;
            $strSql = $strSql . " group by fav.fav_id,f.follower_id,u2.user_id, u2.gender,u.gender,u2.username, u2.profile_pic, p.shared_post_id, p2.post_id, p2.type, p2.file, p2.title, like_id, u.user_id, u.username, u.profile_pic, p.post_id, p.file, p.title, p.added_on, p2.added_on, p.likes, p.views, p.comments, p.shares, p.type,p.aspect_ratio,p2.aspect_ratio";

            $res = DB::select(DB::raw($strSql));
            $total_records = 0;
            $data = array();
            if ($res) {
                $total_records = count($res);
                $i = 0;
                foreach ($res as $r) {
                    if ($r->profile_pic == "") {
                        if ($r->gender == "M") {
                            $p = secure_asset('assets/images/avatar-man.png');
                        } else if ($r->gender == "F") {
                            $p = secure_asset('assets/images/avatar-woman.png');
                        } else {
                            $p = secure_asset('assets/images/profile.png');
                        }
                    } else {
                        if (stripos($r->profile_pic, 'https://') !== false) {
                            $p = $r->profile_pic;
                        } else {
                            $p = Storage::url("profile_pic/" . $r->user_id . "/" . $r->profile_pic);
                        }
                    }
                    $p2 = "";
                    if ($r->shared_post_id > 0) {
                        if ($r->profile_pic2 == "") {
                            if ($r->gender2 == "M") {
                                $p2 = secure_asset('assets/images/avatar-man.png');
                            } else if ($r->gender2 == "F") {
                                $p2 = secure_asset('assets/images/avatar-woman.png');
                            } else {
                                $p2 = secure_asset('assets/images/profile.png');
                            }
                        } else {
                            if (stripos($r->profile_pic2, 'https://') !== false) {
                                $p2 = $r->profile_pic2;
                            } else {
                                $p2 = Storage::url("profile_pic/" . $r->user_id2 . "/" . $r->profile_pic2);
                            }
                        }
                    }
                    if ($r->type == "V") {
                        $thumb = explode(".", $r->file);
                        $thum = $thumb[0] . ".jpg";
                        //$thum=substr($r->file, 0, -3)."jpg";
                        $file = Storage::url("videos/" . $r->user_id . "/" . $r->file);
                        $thumb_file = Storage::url("videos/" . $r->user_id . "/thumb/" . $thum);
                    } else {
                        $file = Storage::url("photos/" . $r->user_id . "/" . $r->file);
                        $thumb_file = "";
                    }
                    $file2 = "";
                    $thumb_file2 = "";
                    if ($r->shared_post_id > 0) {
                        if ($r->type2 == "V") {
                            $thumb2 = explode(".", $r->file2);
                            $thum2 = $thumb2[0] . ".jpg";
                            //$thum=substr($r->file, 0, -3)."jpg";
                            $file2 = Storage::url("videos/" . $r->user_id2 . "/" . $r->file2);
                            $thumb_file2 = Storage::url("videos/" . $r->user_id2 . "/thumb/" . $thum2);
                        } else {
                            $file2 = Storage::url("photos/" . $r->user_id2 . "/" . $r->file2);
                            $thumb_file2 = "";
                        }
                    }
                    $added_on = $r->added_on;
                    $data_liked_users['users'] = array();
                    if ($r->likes > 0) {
                        $rs_liked_users = DB::table('post_likes as l')
                            ->Join('users as u', 'l.user_id', '=', 'u.user_id')
                            ->select(DB::raw('u.user_id as user_id,u.username as username,u.gender,u.profile_pic as profile_pic,l.like_on,l.like_id,l.post_id'))
                            ->where('l.post_id', $r->post_id);
                        // ->orderBy('comment_id','desc');

                        $rs_liked_users = $rs_liked_users->orderBy('like_id', 'desc')
                            //->skip($offset) 
                            ->paginate(2);
                        //->get();
                        //print_r($res);
                        $total_liked_users = $rs_liked_users->total();

                        if (!$rs_liked_users->isEmpty()) {

                            foreach ($rs_liked_users as $l) {
                                if ($l->profile_pic == "") {
                                    if ($l->gender == "M") {
                                        $p_liked = secure_asset('assets/images/avatar-man.png');
                                    } else if ($l->gender == "F") {
                                        $p_liked = secure_asset('assets/images/avatar-woman.png');
                                    } else {
                                        $p_liked = secure_asset('assets/images/profile.png');
                                    }
                                } else {
                                    $p_liked = Storage::url("profile_pic/" . $l->user_id . "/" . $l->profile_pic);
                                }

                                $liked_on = ($l->like_on);

                                $data_liked_users['users'][] = array("post_id" => $l->post_id, "like_id" => $l->like_id, "user_id" => $l->user_id, "username" => $l->username, "liked_on" => $liked_on, "profile_pic" => $p_liked);
                            }
                        }
                    }

                    $data_comment['comment'] = array();

                    if ($r->comments > 0) {

                        $rs_comments = DB::table('post_comments as c')
                            ->Join('users as u', 'c.user_id', '=', 'u.user_id')
                            ->select(DB::raw('u.user_id as user_id,u.username as username,u.gender,u.profile_pic as profile_pic,c.comment as comment,c.comment_id as comment_id,c.comment_on as comment_on,c.parent_id as parent_id'))
                            ->where('c.post_id', $r->post_id)
                            ->where('c.parent_id', 0);
                        // ->orderBy('comment_id','desc');

                        $rs_comments = $rs_comments->orderBy('comment_id', 'desc')
                            ->offset(0)
                            ->limit(2)
                            ->get();
                        //->get();
                        //print_r($res);

                        foreach ($rs_comments as $c) {
                            if ($c->profile_pic == "") {
                                if ($c->gender == "M") {
                                    $p_comment = secure_asset('assets/images/avatar-man.png');
                                } else if ($c->gender == "F") {
                                    $p_comment = secure_asset('assets/images/avatar-woman.png');
                                } else {
                                    $p_comment = secure_asset('assets/images/profile.png');
                                }
                            } else {
                                $p_comment = Storage::url("profile_pic/" . $c->user_id . "/" . $c->profile_pic);
                            }

                            $comment_on = $c->comment_on;


                            $data_comment['comment'][] = array("comment_id" => $c->comment_id, "user_id" => $c->user_id, "username" => $c->username, "comment" => $c->comment, "comment_on" => $comment_on, "profile_pic" => $p_comment, "parent_id" => $c->parent_id, "post_id" => $r->post_id);
                        }
                    }
                    $data_comment['comment'] = array_reverse($data_comment['comment']);
                    if ($r->shared_post_id == 0) {
                        $aspect_ratio = $r->aspect_ratio;
                        $sig = md5($r->post_id . "*FilmsDream@1290");
                    } else {
                        $aspect_ratio = $r->aspect_ratio2;
                        $sig = md5($r->post_id2 . "*FilmsDream@1290");
                    }
                    $s = array('shared_post_id' => $r->shared_post_id, 'liked_users' => $data_liked_users['users'], 'user_comments' => $data_comment['comment'], 'like_id' => $r->like_id, 'user_id' => $r->user_id, 'user_id2' => $r->user_id2, 'file1' => $r->file, 'username' => $r->username, 'username2' => $r->username2, 'file' => $file, 'file2' => $file2, 'thumb' => $thumb_file, 'thumb2' => $thumb_file2, 'title' => $r->title, 'title2' => $r->title2, 'added_on' => $added_on, 'shared_added_on' => $r->shared_added_on, 'likes' => $r->likes, 'comments' => $r->comments, 'shares' => $r->shares, 'views' => $r->views, 'profile_pic' => $p, 'profile_pic2' => $p2, 'type' => $r->type, 'type2' => $r->type2, 'cat_id' => $r->cat_id, 'cat_name' => $r->cat_name, 'post_id' => $r->post_id, 'post_id2' => $r->post_id2, 'sig' => $sig, 'aspect_ratio' => number_format($aspect_ratio, 1), 'isFollowing' => $r->isFollowing, 'isFav' => $r->isFav);
                    $data = $s;


                    if ($login_id > 0) {
                        $user = DB::table("users")
                            ->select(DB::raw('*'))
                            ->where("user_id", $login_id)
                            ->first();
                        $country = $user->country;
                        $state = $user->state;
                        if (strtolower($country) == "usa") {
                            $country = "United States";
                        }
                    } else {
                        $country = "United States";
                        $state = '';
                    }
                }
            }
            $response = array("status" => "success", 'content' => $data);
            return response()->json($response);
            // }else{
            //     return response()->json([
            //         "status" => false, "msg" => "Unauthorized user!"
            //     ]);
            // }
        }
    }

    // views
    public function view(Request $request)
    {

        $validator = Validator::make($request->all(), [

            'post_id'          => 'required',
            'unique_id'          => 'required',

        ], [

            'post_id.required'   => 'Post Id is required.',
            'unique_id.required'   => 'Unique Id is required.',

        ]);

        if (!$validator->passes()) {
            return response()->json(['status' => 'error', 'msg' => $this->_error_string($validator->errors()->all())]);
        } else {
            if (auth()->guard('api')->user()) {
                $login_id = auth()->guard('api')->user()->user_id;

                $post_view = DB::table('post_views')
                    ->where('user_id', $login_id)
                    ->where('unique_id', $request->unique_id)
                    ->where('post_id', $request->post_id)
                    ->count();
                if ($post_view > 0) {
                    $response = array("status" => "warning", "msg" => "already viewed");
                } else {
                    $data = array(
                        'post_id' => $request->post_id,
                        'user_id' => $login_id,

                    );
                    DB::table('post_views')->insert($data);

                    DB::table('posts')
                        ->where('post_id', $request->post_id)
                        ->update(['views' => DB::raw('views + 1')]);
                    //$response = $file_path;

                    $response = array("status" => true, "msg" => "viewed");
                }
                //exit();

                return response()->json($response);
            } else {
                return response()->json([
                    "status" => false, "msg" => "Unauthorized user!"
                ]);
            }
        }
    }

    // likes
    public function like(Request $request)
    {

        $validator = Validator::make($request->all(), [
            'post_id'          => 'required',

        ], [
            'post_id.required'   => 'Post Id is required.',

        ]);

        if (!$validator->passes()) {
            return response()->json(['status' => 'error', 'msg' => $this->_error_string($validator->errors()->all())]);
        } else {
            if (auth()->guard('api')->user()) {
                $login_id = auth()->guard('api')->user()->user_id;

                $res = DB::table('post_likes')
                    ->select(DB::raw('like_id'))
                    ->where('post_id', $request->post_id)
                    ->where('user_id', $login_id)
                    ->get();
                if ($res->isEmpty()) {
                    $data = array(
                        'post_id' => $request->post_id,
                        'user_id' => $login_id,

                    );
                    DB::table('post_likes')->insert($data);

                    DB::table('posts')
                        ->where('post_id', $request->post_id)
                        ->update(['likes' => DB::raw('likes + 1')]);

                    //Last Post Like
                    $rs_last_like = DB::table('last_post_likes')
                        ->select(DB::raw('last_post_like_id'))
                        ->where('post_id', $request->post_id)
                        ->first();

                    if ($rs_last_like) {
                        DB::table('last_post_likes')
                            ->where('last_post_like_id', $rs_last_like->last_post_like_id)
                            ->update(['post_id' => $request->post_id, 'user_id' => $login_id]);
                    } else {
                        DB::table('last_post_likes')->insert($data);
                    }
                    //Last Post Like

                    $rs_user =     DB::table('users')
                        ->select(DB::raw('username'))
                        ->where('user_id', $login_id)
                        ->first();

                    $rs_post =     DB::table('posts as p')
                        ->join("users as u", "u.user_id", "=", "p.user_id")
                        ->select(DB::raw('u.fcm_token, u.user_id, u.username'))
                        ->where('p.post_id', $request->post_id)
                        ->first();
                    if ($rs_post) {
                        if ($rs_post->user_id != $login_id) {
                            $not_data['created_on'] = date("Y-m-d H:i:s");
                            $not_data['sent_to'] = $rs_post->user_id;
                            $not_data['title'] = $rs_user->username . " liked your post";
                            $not_data['page_name'] = "post-detail";
                            $not_data['post_id'] = $request->post_id;
                            $not_data['sent_by'] = $login_id;

                            DB::table('notifications')->insert($not_data);
                            try{
                                if ($rs_post->fcm_token != "") {
                                    $title = "NEW LIKE ON POST";
                                    $message = $rs_user->username . " liked your post";
                                    $fcmTokens = [$rs_post->fcm_token];
                                    $image='';
                                    $param = ['id' => strval($request->post_id), 'type' => 'like'];
                                    // Notification::send(null, new UserNotification($title, $message, null, $param, $fcmTokens));
                                    $user=User::where('user_id',$rs_post->user_id)->first();  
                                    $user->notify(new UserNotification($title, $message, $image, $param));
                                }
                            } catch (\Exception $e) {
                            }
                        }
                    }

                    $response = array("status" => true, "msg" => "Liked", "like" => '1');
                } else {
                    DB::table('post_likes')->where('post_id', $request->post_id)->where('user_id', $login_id)->delete();
                    DB::table('posts')
                        ->where('post_id', $request->post_id)
                        ->update(['likes' => DB::raw('likes - 1')]);

                    $response = array("status" => true, "msg" => "Unliked", "like" => '0');
                }

                //exit();
                //DB::table('user_photos')->where('photo_id', $photo_id)->where('user_id', $user_id)->delete();          
                return response()->json($response);
            } else {
                return response()->json([
                    "status" => false, "msg" => "Unauthorized user!"
                ]);
            }
        }
    }
    // comments
    public function comment(Request $request)
    {

        $validator = Validator::make($request->all(), [
            'post_id'          => 'required',
            'comment'            => 'required',
            'parent_id'      => 'required'
        ], [
            'post_id.required'   => 'Post Id is required.',
            'comment.required'   => 'Comment is required.',
            'parent_id.required'   => 'Parent Id is required.',
        ]);

        if (!$validator->passes()) {
            return response()->json(['status' => 'error', 'msg' => $this->_error_string($validator->errors()->all())]);
        } else {

            if (auth()->guard('api')->user()) {
                $user = auth()->guard('api')->user();
                $login_id = $user->user_id;
                if ($user->profile_pic == "") {
                    if ($user->gender == "M") {
                        $p = secure_asset('assets/images/avatar-man.png');
                    } else if ($user->gender == "F") {
                        $p = secure_asset('assets/images/avatar-woman.png');
                    } else {
                        $p = secure_asset('assets/images/profile.png');
                    }
                } else {
                    if (stripos($user->profile_pic, 'https://') !== false) {
                        $p = $user->profile_pic;
                    } else {
                        $p = Storage::url("profile_pic/" . $user->user_id . "/" . $user->profile_pic);
                    }

                    // $p=Storage::url("profile_pic/".$user->user_id."/".$user->profile_pic);
                }
                $data = array(
                    'post_id' => $request->post_id,
                    'user_id' => $login_id,
                    'comment' => $request->comment,
                    'parent_id' => $request->parent_id,
                    'comment_on' => date('Y-m-d H:i:s')
                );

                $comment_id = DB::table('post_comments')->insertGetId($data);

                if ($request->parent_id == 0) {

                    //Last Post Comment
                    $rs_last_comment = DB::table('last_post_comments')
                        ->select(DB::raw('last_post_comment_id'))
                        ->where('post_id', $request->post_id)
                        ->first();

                    $update_data = array(
                        'post_id' => $request->post_id,
                        'user_id' => $login_id,
                        'comment' => $request->comment,
                        'comment_id' => $comment_id,
                        'comment_on' => date('Y-m-d H:i:s')
                    );

                    if ($rs_last_comment) {
                        DB::table('last_post_comments')
                            ->where('last_post_comment_id', $rs_last_comment->last_post_comment_id)
                            ->update($update_data);
                    } else {
                        DB::table('last_post_comments')->insert($update_data);
                    }
                    //Last Post Comment

                }


                $data = array(
                    'post_id' => (int) $request->post_id,
                    'user_id' => $login_id,
                    'username' => auth()->guard('api')->user()->username,
                    // 'username' => auth()->guard('api')->user()->first_name.' '.auth()->guard('api')->user()->last_name,
                    'comment' => $request->comment,
                    'parent_id' => (int) $request->parent_id,
                    "comment_id" => $comment_id,
                    "profile_pic" => $p,
                    'comment_on' => date('Y-m-d H:i:s')
                );

                $rs_user =     DB::table('users')
                    ->select(DB::raw('username'))
                    ->where('user_id', $login_id)
                    ->first();
                DB::table('posts')
                    ->where('post_id', $request->post_id)
                    ->update(['comments' => DB::raw('comments + 1')]);
                $rs_post =     DB::table('posts as p')
                    ->join("users as u", "u.user_id", "=", "p.user_id")
                    ->select(DB::raw('u.fcm_token, u.user_id, u.username'))
                    ->where('p.post_id', $request->post_id)
                    ->first();
                if ($rs_post) {
                    if ($rs_post->user_id != $login_id) {
                        $not_data['created_on'] = date("Y-m-d H:i:s");
                        $not_data['sent_to'] = $rs_post->user_id;
                        $not_data['title'] = $rs_user->username . " commented your post";
                        $not_data['page_name'] = "post-detail";
                        $not_data['post_id'] = $request->post_id;
                        $not_data['sent_by'] = $login_id;
                        DB::table('notifications')->insert($not_data);
                        try{
                            if ($rs_post->fcm_token != "") {
                                $title = "NEW COMMENT ON POST";
                                $message = $rs_user->username . " commented your post";
                                $fcmTokens = [$rs_post->fcm_token];
                                $image='';
                                $param = ['id' => strval($request->post_id), 'type' => 'comment'];
                                // Notification::send(null, new UserNotification($title, $message, null, $param, $fcmTokens));
                                $user=User::where('user_id',$rs_post->user_id)->first();  
                                $user->notify(new UserNotification($title, $message, $image, $param));
                            }
                        } catch (\Exception $e) {
                        }
                    }
                }
                //$response = $file_path;
                $response = array("status" => true, "msg" => "upload comment successfully", 'data' => $data);
                //exit();

                return response()->json($response);
            } else {
                return response()->json([
                    "status" => false, "msg" => "Unauthorized user!"
                ]);
            }
        }
    }

    public function comments_list(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'post_id'          => 'required',
        ], [
            'post_id.required'   => 'Post Id is required.',

        ]);

        if (!$validator->passes()) {
            return response()->json(['status' => 'error', 'msg' => $this->_error_string($validator->errors()->all())]);
        } else {
            $login_id = 0;
            if (auth()->guard('api')->user()) {
                $login_id = auth()->guard('api')->user()->user_id;
            }
            if (!isset($request->page) && $request->page == "") {
                $page = 1;
            } else {
                $page = $request->page;
            }
            $limit = 10;
            $offset = ($page - 1) * $limit;
            $res = DB::table('post_comments as c')
                ->Join('users as u', 'c.user_id', '=', 'u.user_id')
                ->leftJoin("post_comments as rc", 'c.comment_id', 'rc.parent_id');
            if ($request->from_notification == "1") {
                $res = $res->leftJoin('post_comments as rc2', function ($join) use ($login_id) {
                    $join->on('c.comment_id', 'rc2.comment_id')
                        ->where('c.user_id', $login_id);
                });
            }
            $res = $res->select(DB::raw('u.user_id as user_id,u.username as username,u.profile_pic as profile_pic,u.gender,c.comment as comment,c.comment_id as comment_id,c.comment_on as comment_on,c.parent_id as parent_id,count(rc.comment_id) as replies'))
                ->where('c.post_id', $request->post_id)
                ->where('c.parent_id', 0);
            // ->orderBy('comment_id','desc');
            if ($request->from_notification == "1") {
                $res = $res->orderBy('rc2.comment_id', 'desc');
            } else {
                $res = $res->orderBy('rc.comment_id', 'desc');
            }
            $res = $res->orderBy('c.comment_id', 'desc');
            $res = $res->groupBy(DB::raw('u.user_id,u.username,u.profile_pic,u.gender,c.comment,c.comment_id,c.comment_on,c.parent_id'));
            //->skip($offset) 
            $res = $res->paginate($limit);
            //->get();
            // print_r($res);
            $total_records = $res->total();

            if (!$res->isEmpty()) {

                foreach ($res as $r) {
                    if ($r->profile_pic == "") {
                        if ($r->gender == "M") {
                            $p = secure_asset('assets/images/avatar-man.png');
                        } else if ($r->gender == "F") {
                            $p = secure_asset('assets/images/avatar-woman.png');
                        } else {
                            $p = secure_asset('assets/images/profile.png');
                        }
                    } else {
                        if (stripos($r->profile_pic, 'https://') !== false) {
                            $p = $r->profile_pic;
                        } else {
                            $p = Storage::url("profile_pic/" . $r->user_id . "/" . $r->profile_pic);
                        }

                        // $p=Storage::url("profile_pic/".$r->user_id."/".$r->profile_pic);
                    }



                    $data['comment'][] = array("comment_id" => $r->comment_id, "user_id" => $r->user_id, "username" => $r->username, "comment" => $r->comment, "comment_on" => $r->comment_on, "profile_pic" => $p, "parent_id" => $r->parent_id, 'replies' => $r->replies);
                }
            } else {
                $data['warning'] = array('warning' => 'Sorry..! No record found.');
            }

            $response = array("status" => true, 'msg' => 'comments', 'data' => $data['comment'], 'total_records' => $total_records);
            return response()->json($response);
        }
    }

    public function comment_delete(Request $request)
    {

        $validator = Validator::make($request->all(), [
            'post_id'          => 'required',
            'comment_id'            => 'required'

        ], [
            'post_id.required'   => 'Post Id is required.',
            'comment.required'   => 'Comment is required.'
        ]);

        if (!$validator->passes()) {
            return response()->json(['status' => 'error', 'msg' => $this->_error_string($validator->errors()->all())]);
        } else {

            if (auth()->guard('api')->user()) {
                $login_id = auth()->guard('api')->user()->user_id;
                DB::table('post_comments')->where('post_id', $request->post_id)->where('user_id', $login_id)->where('comment_id', $request->comment_id)->delete();
                if ($request->parent_id == 0) {
                    DB::table('posts')
                        ->where('post_id', $request->post_id)
                        ->update(['comments' => DB::raw('comments - 1')]);
                }
                //$response = $file_path;
                $response = array("status" => true, "msg" => "delete comment successfully");
                //exit();

                return response()->json($response);
            } else {
                return response()->json([
                    "status" => false, "msg" => "Unauthorized user!"
                ]);
            }
        }
    }

    // delete
    public function delete_post(Request $request)
    {

        $validator = Validator::make($request->all(), [
            'post_id'               => 'required',
        ], [
            'post_id.required'  => 'Post Id is id required',
        ]);

        if (!$validator->passes()) {
            return response()->json(['status' => 'error', 'msg' => $this->_error_string($validator->errors()->all())]);
        } else {
            if (auth()->guard('api')->user()) {
                $login_id = auth()->guard('api')->user()->user_id;
                DB::table('posts')->where('post_id', $request->post_id)->where('user_id', $login_id)->delete();
                $response = array("status" => true, 'msg' => 'Post deleted Successfully');
                return response()->json($response);
            } else {
                return response()->json([
                    "status" => false, "msg" => "Unauthorized user!"
                ]);
            }
        }
    }

    // edit
    public function edit_post(Request $request)
    {

        $validator = Validator::make($request->all(), [
            'post_id'               => 'required',
            'title'               => 'required'
        ], [
            'post_id.required'  => 'Post Id is required',
            'title.required'  => 'Title is required',
        ]);

        if (!$validator->passes()) {
            return response()->json(['status' => 'error', 'msg' => $this->_error_string($validator->errors()->all())]);
        } else {
            if (auth()->guard('api')->user()) {
                $login_id = auth()->guard('api')->user()->user_id;
                DB::table('posts')->where('post_id', $request->post_id)->where('user_id', $login_id)->update(['title' => $request->title, 'show_on_wall' => $request->show_on_wall]);
                $response = array("status" => true, 'msg' => 'Post updated Successfully');
                return response()->json($response);
            } else {
                return response()->json([
                    "status" => false, "msg" => "Unauthorized user!"
                ]);
            }
        }
    }

    // comments replies
    // comments replies
    public function reply(Request $request)
    {

        $validator = Validator::make($request->all(), [
            'post_id'          => 'required',
            'comment'            => 'required',
            'parent_id'      => 'required'
        ], [
            'post_id.required'   => 'Post Id is required.',
            'comment.required'   => 'Comment is required.',
            'parent_id.required'   => 'Parent Id is required.',
        ]);

        if (!$validator->passes()) {
            return response()->json(['status' => 'error', 'msg' => $this->_error_string($validator->errors()->all())]);
        } else {
            if (auth()->guard('api')->user()) {
                $user = auth()->guard('api')->user();
                $login_id = $user->user_id;
                if ($user->profile_pic == "") {
                    if ($user->gender == "M") {
                        $p = secure_asset('assets/images/avatar-man.png');
                    } else if ($user->gender == "F") {
                        $p = secure_asset('assets/images/avatar-woman.png');
                    } else {
                        $p = secure_asset('assets/images/profile.png');
                    }
                } else {
                    if (stripos($user->profile_pic, 'https://') !== false) {
                        $p = $user->profile_pic;
                    } else {
                        $p = Storage::url("profile_pic/" . $user->user_id . "/" . $user->profile_pic);
                    }
                    // $p=Storage::url("profile_pic/".$user->user_id."/".$user->profile_pic);
                }

                $data = array(
                    'post_id' => $request->post_id,
                    'user_id' => $login_id,
                    'comment' => $request->comment,
                    'parent_id' => $request->parent_id,
                    'comment_on' => date('Y-m-d H:i:s')
                );

                $comment_id =  DB::table('post_comments')->insertGetId($data);

                $data = array(
                    'post_id' => (int) $request->post_id,
                    'user_id' => $login_id,
                    'username' => auth()->guard('api')->user()->first_name . ' ' . auth()->guard('api')->user()->first_name,
                    'comment' => $request->comment,
                    'parent_id' => (int) $request->parent_id,
                    "comment_id" => $comment_id,
                    "profile_pic" => $p,
                    'comment_on' => date('Y-m-d H:i:s')
                );
                //replied on yuor comment
                //a replies on b comment on your post
                $rs_user =     DB::table('users')
                    ->select(DB::raw('username'))
                    ->where('user_id', $login_id)
                    ->first();
                DB::table('posts')
                    ->where('post_id', $request->post_id)
                    ->update(['comments' => DB::raw('comments + 1')]);
                $rs_post =     DB::table('posts as p')
                    ->join("users as u", "u.user_id", "=", "p.user_id")
                    ->select(DB::raw('u.fcm_token, u.user_id, u.username'))
                    ->where('p.post_id', $request->post_id)
                    ->first();

                $rs_comment = DB::table('post_comments as c')
                    ->join("users as u", "u.user_id", "=", "c.user_id")
                    ->select(DB::raw('u.fcm_token, u.user_id, u.username'))
                    ->where('c.comment_id', $request->parent_id)
                    ->first();

                if ($rs_post) {
                    if ($rs_post->user_id != $login_id) {

                        if($rs_comment->user_id!=$rs_post->user_id){
                            $not_data['created_on'] = date("Y-m-d H:i:s");
                            $not_data['sent_to'] = $rs_comment->user_id;
                            $not_data['title'] = $rs_user->username . " replied on your comment";
                            $not_data['page_name'] = "post-detail";
                            $not_data['post_id'] = $request->post_id;
                            $not_data['sent_by'] = $login_id;
                            DB::table('notifications')->insert($not_data);
                            try{
                                if ($rs_comment->fcm_token != "") {
                                    $title = "NEW COMMENT ON POST";
                                    $message = $rs_user->username . " replied on your comment";
                                    $fcmTokens = [$rs_comment->fcm_token];
                                    $image='';
                                    $param = ['id' => strval($request->post_id), 'type' => 'comment'];
                                    // Notification::send(null, new UserNotification($title, $message, null, $param, $fcmTokens));
                                    $user=User::where('user_id',$rs_comment->user_id)->first();  
                                    $user->notify(new UserNotification($title, $message, $image, $param));
                                }
                            } catch (\Exception $e) {
                            }
                        }
                        $not_data['created_on'] = date("Y-m-d H:i:s");
                        $not_data['sent_to'] = $rs_post->user_id;
                        $not_data['title'] = $rs_user->username . " replied on your post's comment";
                        $not_data['page_name'] = "post-detail";
                        $not_data['post_id'] = $request->post_id;
                        $not_data['sent_by'] = $login_id;
                        DB::table('notifications')->insert($not_data);
                        try{
                            if ($rs_post->fcm_token != "") {
                                $title = "NEW COMMENT ON POST";
                                $message = $rs_user->username . " replied on your post's comment";
                                $fcmTokens = [$rs_post->fcm_token];
                                $image='';
                                $param = ['id' => strval($request->post_id), 'type' => 'comment'];
                                // Notification::send(null, new UserNotification($title, $message, null, $param, $fcmTokens));
                                $user=User::where('user_id',$rs_post->user_id)->first();  
                                $user->notify(new UserNotification($title, $message, $image, $param));
                            }
                        } catch (\Exception $e) {
                        }
                    }
                }
                $response = array("status" => true, "msg" => "upload comment successfully", 'data' => $data);
                return response()->json($response);
            } else {
                return response()->json([
                    "status" => false, "msg" => "Unauthorized user!"
                ]);
            }
        }
    }

    public function replies_list(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'post_id'          => 'required',
            'comment_id'          => 'required',
        ], [
            'post_id.required'   => 'Post Id is required.',
            'comment_id.required'   => 'Comment Id is required.',

        ]);

        if (!$validator->passes()) {
            return response()->json(['status' => 'error', 'msg' => $this->_error_string($validator->errors()->all())]);
        } else {

            $login_id = 0;
            if (auth()->guard('api')->user()) {
                $login_id = auth()->guard('api')->user()->user_id;
            }
            if (!isset($request->page) && $request->page == "") {
                $page = 1;
            } else {
                $page = $request->page;
            }
            $limit = 10;
            $offset = ($page - 1) * $limit;


            $res = DB::table('post_comments as c')
                ->Join('users as u', 'c.user_id', '=', 'u.user_id')
                ->leftJoin("post_comments as rc", 'c.comment_id', 'rc.parent_id')
                ->select(DB::raw('u.user_id as user_id,u.username as username,u.profile_pic as profile_pic,u.gender,c.comment as comment,c.comment_id as comment_id,c.comment_on as comment_on,c.parent_id as parent_id,count(rc.comment_id) as replies'))
                ->where('c.post_id', $request->post_id)
                ->where('c.parent_id', $request->comment_id);
            // ->orderBy('comment_id','desc');

            $res = $res->orderBy('comment_id', 'desc');
            $res = $res->groupBy(DB::raw('u.user_id,u.username,u.profile_pic,u.gender,c.comment,c.comment_id,c.comment_on,c.parent_id'));
            //->skip($offset) 
            $res = $res->paginate($limit);
            //->get();
            //print_r($res);
            $total_records = $res->total();

            if (!$res->isEmpty()) {

                foreach ($res as $r) {
                    if ($r->profile_pic == "") {
                        if ($r->gender == "M") {
                            $p = secure_asset('assets/images/avatar-man.png');
                        } else if ($r->gender == "F") {
                            $p = secure_asset('assets/images/avatar-woman.png');
                        } else {
                            $p = secure_asset('assets/images/profile.png');
                        }
                    } else {
                        if (stripos($r->profile_pic, 'https://') !== false) {
                            $p = $r->profile_pic;
                        } else {
                            $p = Storage::url("profile_pic/" . $r->user_id . "/" . $r->profile_pic);
                        }
                        // $p=Storage::url("profile_pic/".$r->user_id."/".$r->profile_pic);
                    }



                    $data['comment'][] = array("comment_id" => $r->comment_id, "user_id" => $r->user_id, "username" => $r->username, "comment" => $r->comment, "comment_on" => $r->comment_on, "profile_pic" => $p, "parent_id" => $r->parent_id, 'replies' => $r->replies);
                }
            } else {
                $data['warning'] = array('warning' => 'Sorry..! No record found.');
            }

            $response = array("status" => true, 'msg' => 'comments', 'data' => $data['comment'], 'total_records' => $total_records);
            return response()->json($response);
        }
    }
    // share
    public function sharePost(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'post_id'          => 'required',
        ], [
            'post_id.required'   => 'Post Id is required.',
        ]);
        if (!$validator->passes()) {
            return response()->json(['status' => 'error', 'msg' => $this->_error_string($validator->errors()->all())]);
        } else {
            $functions = new Functions();
            if (auth()->guard('api')->user()) {
                $login_id = auth()->guard('api')->user()->user_id;
                $data = array(
                    'post_id' => $request->post_id,
                    'user_id' => $login_id,
                );
                DB::table('post_shares')->insert($data);

                DB::table('posts')
                    ->where('post_id', $request->post_id)
                    ->update(['shares' => DB::raw('shares + 1')]);

                $post_data['user_id'] = $login_id;
                $post_data['type'] = "S";
                $post_data['added_on'] = date("Y-m-d H:i:s");
                $post_data['title'] = $request->title;
                $post_data['shared_post_id'] = $request->post_id;
                $s_post_id = DB::table('posts')->insertGetId($post_data);
                //$response = $file_path;

                $rs_user =     DB::table('users')
                    ->select(DB::raw('username'))
                    ->where('user_id', $login_id)
                    ->first();

                $rs_post =     DB::table('posts as p')
                    ->join("users as u", "u.user_id", "=", "p.user_id")
                    ->select(DB::raw('u.player_id, u.fcm_token, u.user_id, u.username'))
                    ->where('p.post_id', $request->post_id)
                    ->first();

                if ($rs_post) {
                    $not_data['created_on'] = date("Y-m-d H:i:s");
                    $not_data['sent_to'] = $rs_post->user_id;
                    $not_data['title'] = $rs_user->username . " shared your post";
                    $not_data['page_name'] = "post-detail";
                    $not_data['post_id'] = $request->post_id;
                    $not_data['sent_by'] = $login_id;
                    DB::table('notifications')->insert($not_data);
                    try{
                        if ($rs_post->fcm_token != "") {
                            $title = "NEW SHARING ON POST";
                            $message = $rs_post->username . " shared your post";
                            $fcmTokens = [$rs_post->fcm_token];
                            $image='';
                            $param = ['id' => strval($request->post_id), 'type' => 'share'];
                            // Notification::send(null, new UserNotification($title, $message, null, $param, $fcmTokens));
                            $user=User::where('user_id',$rs_post->user_id)->first();  
                            $user->notify(new UserNotification($title, $message, $image, $param));
                        }
                    } catch (\Exception $e) {
                    }
                    /*if($rs_post->player_id!=""){
                        $functions = new Functions();
                        $functions->send_notification_both($rs_post->player_id, $rs_user->username." shared your post","NEW SHARING ON POST");
                    }*/
                }

                $response = array("status" => true, "msg" => "shared");

                return response()->json($response);
            } else {
                return response()->json([
                    "status" => false, "msg" => "Unauthorized user!"
                ]);
            }
        }
    }
    public function share(Request $request)
    {

        $validator = Validator::make($request->all(), [

            'post_id'          => 'required',

        ], [

            'post_id.required'   => 'Post Id is required.',

        ]);

        if (!$validator->passes()) {
            return response()->json(['status' => 'error', 'msg' => $this->_error_string($validator->errors()->all())]);
        } else {
            if (auth()->guard('api')->user()) {
                $login_id = auth()->guard('api')->user()->user_id;
                $data = array(
                    'post_id' => $request->post_id,
                    'user_id' => $login_id,

                );
                DB::table('post_shares')->insert($data);
                DB::table('posts')
                    ->where('post_id', $request->post_id)
                    ->update(['shares' => DB::raw('shares + 1')]);
                //$response = $file_path;

                $rs_post =     DB::table('posts as p')
                    ->join("users as u", "u.user_id", "=", "p.user_id")
                    ->select(DB::raw('u.player_id, u.fcm_token, u.user_id, u.username'))
                    ->where('p.post_id', $request->post_id)
                    ->first();
                if ($rs_post) {

                    $not_data['created_on'] = date("Y-m-d H:i:s");
                    $not_data['sent_to'] = $rs_post->user_id;
                    $not_data['title'] = $rs_post->username . " shared your post";
                    $not_data['page_name'] = "post-detail";
                    $not_data['post_id'] = $request->post_id;
                    $not_data['sent_by'] = $login_id;
                    DB::table('notifications')->insert($not_data);
                    try{
                        if ($rs_post->fcm_token != "") {
                            $title = "NEW SHARING ON POST";
                            $message = $rs_post->username . " shared your post";
                            $fcmTokens = [$rs_post->fcm_token];
                            $image='';
                            $param = ['id' => strval($request->post_id), 'type' => 'share'];
                            // Notification::send(null, new UserNotification($title, $message, null, $param, $fcmTokens));
                            $user=User::where('user_id',$rs_post->user_id)->first();  
                            $user->notify(new UserNotification($title, $message, $image, $param));
                        }
                    } catch (\Exception $e) {
                    }
                    // if($rs_post->player_id!=""){
                    //     $functions = new Functions();
                    //     $functions->send_notification_both($rs_post->player_id, ,"");
                    // }
                }


                $response = array("status" => true, "msg" => "shared");
                //exit();

                return response()->json($response);
            } else {
                return response()->json([
                    "status" => false, "msg" => "Unauthorized user!"
                ]);
            }
        }
    }
    public function liked_user_listing(Request $r)
    {
        $picPath = Storage::url("profile_pic/");
        $login_id = 0;
        if (auth()->guard('api')->user()) {
            $login_id = auth()->guard('api')->user()->user_id;
        }
        $rs_liked_users = DB::table('post_likes as l')
            ->Join('users as u', 'l.user_id', '=', 'u.user_id')
            ->leftJoin('followers as f', function ($join) use ($login_id) {
                $join->on('f.following_id', '=', 'u.user_id')
                    ->where('f.user_id', $login_id);
            })
            ->select(DB::raw('u.user_id as user_id,u.username as username,case when u.profile_pic="" then case when u.gender="M" then "' . secure_asset('assets/images/avatar-man.png') . '" else "' . secure_asset('assets/images/avatar-man.png') . '" end else concat("' . $picPath . '",u.user_id,"/",u.profile_pic) end as profile_pic,l.like_on as liked_on,l.like_id,l.post_id,case when f.follower_id IS NULL then 0 else 1 end as isFollowing'))
            ->where('l.post_id', $r->post_id);
        // ->orderBy('comment_id','desc');
        $rs_liked_users = $rs_liked_users->orderBy('like_id', 'desc')
            ->paginate(20);
        $data_liked_users = $rs_liked_users->items();
        $total = $rs_liked_users->total();
        if ($rs_liked_users) {

            $response = array("status" => true, "data" => $data_liked_users, "total" => $total);
        } else {
            $response = array("status" => false, "msg" => "No Users");
        }
        return response()->json($response);
    }

    public function createPost(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'post_type'      => 'required',
            'post'          => $request->post_type == 'V' ? 'required|mimes:mp4,mov,ogg,qt' : 'required|image|mimes:jpeg,png,jpg,gif,svg',
        ], [
            'post_type.required'   => 'Post type is required',
            'post.required' => 'Post is required',
            'post.mimes' => $request->post_type == 'V' ? 'Invalid video format' : 'Invalid photo format',
        ]);

        if (!$validator->passes()) {
            return response()->json(['status' => false, 'msg' => $this->_error_string($validator->errors()->all())]);
        } else {
            $login_id = 0;
            // dd(auth()->guard('api')->user());
            if (auth()->guard('api')->user()) {
                $added_on = date('Y-m-d H:i:s');
                $user_info = auth()->guard('api')->user();
                $login_id = $user_info->user_id;
                if ($user_info->profile_pic == "") {
                    if ($user_info->gender == "M") {
                        $p = secure_asset('assets/images/avatar-man.png');
                    } else if ($user_info->gender == "F") {
                        $p = secure_asset('assets/images/avatar-woman.png');
                    } else {
                        $p = secure_asset('assets/images/profile.png');
                    }
                } else {
                    if (stripos($user_info->profile_pic, 'https://') !== false) {
                        $p = $user_info->profile_pic;
                    } else {
                        if (stripos($user_info->profile_pic, 'https://') !== false) {
                            $p = $user_info->profile_pic;
                        } else {
                            $p = Storage::url("profile_pic/" . $user_info->user_id . "/" . $user_info->profile_pic);
                        }
                        // 			$p=Storage::url("profile_pic/".$user_info->user_id."/".$user_info->profile_pic);
                    }

                    // $p=Storage::url("profile_pic/".$user_info->user_id."/".$user_info->profile_pic);
                }

                $functions = new Functions();
                if ($request->post_type == "V") {
                    $path = "videos/" . $login_id;
                    $t_path = "videos/" . $login_id . "/thumb";
                    $filenametostore = $request->file('post')->store($path);
                    Storage::setVisibility($filenametostore, 'public');
                    $fileArray = explode('/', $filenametostore);
                    $fileName = array_pop($fileArray);
                    $thumb = explode(".", $fileName);
                    $thumb_name = $thumb[0] . ".jpg";
                    $file_path = Storage::url("videos/" . $login_id . "/" . $fileName);
                    //$thumb_path = Storage::url("videos/".$request->user_id."/thumb");
                    $thumb_path = storage_path("thumb");
                    $thumb_storage_path = $thumb_path . '/' . $thumb_name;
                    $ffmpeg = FFMpeg\FFMpeg::create();
                    $video = $ffmpeg->open($file_path);
                    $frame = $video->frame(FFMpeg\Coordinate\TimeCode::fromSeconds(0));
                    $frame->save($thumb_storage_path);
                    $this->ffprobe = FFMpeg\FFProbe::create(array(
                        'ffmpeg.binaries'  => config('app.ffmpeg'),
                        'ffprobe.binaries' => config('app.ffprobe'),
                        'timeout'          => 3600, // The timeout for the underlying process
                        'ffmpeg.threads'   => 12, // The number of threads that FFMpeg should use
                    ));
                    $post_dimensions = $this->ffprobe
                        ->streams($file_path)   // extracts streams informations
                        ->videos()                      // filters post streams
                        ->first()                       // returns the first post stream
                        ->getDimensions();
                    // dd($post_dimensions);
                    $width = $post_dimensions->getWidth();
                    $height = $post_dimensions->getHeight();

                    $aspectRatio = round($width / $height, 1);
                    try {
                        Storage::put("videos/" . $login_id . "/thumb/" . $thumb_name, file_get_contents($thumb_storage_path));
                    } catch (\Exception $e) {
                        dd($e);
                    }

                    unlink(storage_path("thumb/" . $thumb_name));
                    $thumb = Storage::url("videos/" . $login_id . "/thumb/" . $thumb_name);
                    Storage::setVisibility("videos/" . $login_id . "/thumb/" . $thumb_name, 'public');
                    /*$data =array(
                        'user_id'    => $request->user_id,
                        'video'      => $fileName,
                        'title'      => $title,
                        
                    ); 
                    DB::table('user_videos')->insert($data);*/
                    if ($request->title == '') {
                        $title = '';
                    } else {
                        $title = $request->title;
                    }
                    $data = array(
                        'user_id'    => $login_id,
                        'file'      => $fileName,
                        'title'      => $title,
                        'aspect_ratio' => $aspectRatio,
                        'type'           => 'V',
                        'added_on' => $added_on,
                        'challenge_id' => isset($request->challenge_id) ? $request->challenge_id : 0,
                        'challenge_approved' => (isset($request->challenge_id) && $request->challenge_id > 0) ? 1 : 0
                    );
                    $id = DB::table('posts')->insertGetId($data);
                    $thumb = explode(".", $fileName);
                    $thum = $thumb[0] . ".jpg";
                    //$thum=substr($r->file, 0, -3)."jpg";
                    $file = Storage::url("videos/" . $login_id . "/" . $fileName);
                    $thumb_file = Storage::url("videos/" . $login_id . "/thumb/" . $thum);

                    // 	dd($aspectRatio);
                    $challenge_id = 0;
                    $challenge_tag = '';
                    if (isset($request->challenge_id) && $request->challenge_id > 0) {
                        $challenge_id = (int)$request->challenge_id;
                        $challenge = DB::table('challenges')->where('id', $challenge_id)->first();
                        if ($challenge) {
                            $challenge_tag = $challenge->tag;
                        }
                    }
                    $post = array('shared_post_id' => 0, 'like_id' => 0, 'user_id' => $login_id, 'user_id2' => 0, 'file1' => '', 'username' => $user_info->first_name . ' ' . $user_info->last_name, 'username2' => "", 'file' => $file, 'file2' => "", 'thumb' => $thumb_file, 'thumb2' => "", 'title' => $request->title, 'title2' => "", 'added_on' => $added_on, 'likes' => 0, 'comments' => 0, 'shares' => 0, 'views' => 0, 'profile_pic' => $p, 'profile_pic2' => "", 'type' => $request->post_type, 'type2' => "", 'cat_id' => "0", 'cat_name' => "", 'post_id' => $id, 'post_id2' => 0, 'sig' => md5($id . "*FilmsDream@1290"), 'aspect_ratio' => number_format($aspectRatio, 1), 'isFollowing' => 0, 'challenge_id' => $challenge_id, 'challenge_tag' => $challenge_tag);

                    $response = array("status" => true, "msg" => "Post Uploaded Successfully", "post" => $post);
                } else {
                    if ($request->hasFile('post')) {
                        $path = "photos/" . $login_id;
                        $filenametostore = $request->file('post')->store($path);

                        Storage::setVisibility($filenametostore, 'public');
                        $fileArray = explode('/', $filenametostore);
                        $fileName = array_pop($fileArray);
                        $img = Image::make(Storage::get($filenametostore));
                        $width = $img->width();
                        $height = $img->height();
                        $aspectRatio = round($width / $height, 1);
                        $functions->_createThumb(Storage::url($filenametostore), 400, 300, $path . '/small', $fileName);
                        $functions->_createThumb(Storage::url($filenametostore), 1200, 900, $path . '/', $fileName);
                        $file_path = Storage::url("photos/" . $login_id . "/" . $fileName);

                        //Storage::delete($filenametostore);  
                        /*$data =array(
                            'user_id' => $request->user_id,
                            'photo'    => $fileName,
                            'title'     => $title,
                            
                        ); 
                        DB::table('user_photos')->insert($data);*/
                        if ($request->title == '') {
                            $title = '';
                        } else {
                            $title = $request->title;
                        }

                        if (!isset($request->show_on_wall)) {
                            $show_on_wall = 1;
                        } else {
                            $show_on_wall = $request->show_on_wall;
                        }

                        $data = array(
                            'user_id' => $login_id,
                            'file'    => $fileName,
                            'title'   => $title,
                            'type'       => 'P',
                            'aspect_ratio'       => $aspectRatio,
                            'show_on_wall'       => $show_on_wall,
                            'added_on' => $added_on,
                            'challenge_id' => isset($request->challenge_id) ? $request->challenge_id : 0,
                            'challenge_approved' => (isset($request->challenge_id) && $request->challenge_id > 0) ? 1 : 0
                        );
                    }
                    DB::table('posts')->insert($data);
                    $id = DB::getPdo()->lastInsertId();

                    $file = Storage::url("photos/" . $login_id . "/" . $fileName);
                    $thumb_file = "";

                    $challenge_id = 0;
                    $challenge_tag = '';
                    if (isset($request->challenge_id) && $request->challenge_id > 0) {
                        $challenge_id = (int)$request->challenge_id;
                        $challenge = DB::table('challenges')->where('id', $challenge_id)->first();
                        $challenge_tag = $challenge->tag;
                    }

                    $post = array(
                        'shared_post_id' => 0,
                        'like_id' => 0,
                        'user_id' => $login_id,
                        'user_id2' => 0,
                        'file1' => '',
                        'username' => $user_info->first_name . ' ' . $user_info->last_name,
                        'username2' => "",
                        'file' => $file,
                        'file2' => "",
                        'thumb' => $thumb_file,
                        'thumb2' => "",
                        'title' => $request->title,
                        'title2' => "",
                        'added_on' => $added_on,
                        'likes' => 0,
                        'comments' => 0,
                        'shares' => 0,
                        'views' => 0,
                        'profile_pic' => $p,
                        'profile_pic2' => "",
                        'type' => $request->post_type,
                        'type2' => "",
                        'cat_id' => "0",
                        'cat_name' => "",
                        'post_id' => $id,
                        'post_id2' => 0,
                        'sig' => md5($id . "*FilmsDream@1290"),
                        'aspect_ratio' => number_format($aspectRatio, 1), 'isFollowing' => 0,
                        'challenge_id' => $challenge_id,
                        'challenge_tag' => $challenge_tag
                    );

                    $response = array("status" => true, "msg" => "Post Uploaded Successfully", "post" => $post);
                }
                return response()->json($response);
            } else {
                return response()->json([
                    "status" => false, "msg" => "Unauthorized user!"
                ]);
            }
        }
    }
    public function getUserPosts(Request $request)
    {
        $validator = Validator::make(
            $request->all(),
            [
                'user_id'          => 'required',
            ],
            [
                'user_id.required'   => 'User Id is required.',
            ]
        );

        if (!$validator->passes()) {
            return response()->json(['status' => 'error', 'msg' => $this->_error_string($validator->errors()->all())]);
        } else {
            $login_id = 0;
            if (auth()->guard('api')->user()) {
                $login_id = auth()->guard('api')->user()->user_id;
            }
            $user_id = $request->user_id;

            $posts = DB::table('users as u')
                ->select(DB::raw("l.like_id as like_id, u.user_id as user_id,u.gender,u.username as username,u.profile_pic as profile_pic,p.aspect_ratio,GROUP_CONCAT(c.cat_id) as cat_id,GROUP_CONCAT(c.category) as cat_name,u2.user_id as user_id2, u2.username as username2, u2.profile_pic as profile_pic2, p.show_on_wall,p.shared_post_id, p2.post_id as post_id2, p2.type as type2, p2.file as file2,p2.title as title2, p.post_id as post_id,p.file as file,p.title as title,p.added_on as added_on,p.likes as likes,p.views as views,p.comments as comments,p.shares as shares,p.type as type,
            ch.tag as challenge_tag,p.challenge_id"))
                ->join('posts as p', function ($join) use ($user_id, $request) {
                    $join->on('u.user_id', 'p.user_id');
                    $join->where('p.user_id', '=', $user_id);
                    if ($request->new == "true") {
                        $join->where('p.type', '=', $request->post_type);
                    }
                })
                ->leftJoin('post_likes as l', function ($join) use ($login_id) {
                    $join->on('l.post_id', '=', 'p.post_id');
                    $join->where('l.user_id', '=', $login_id);
                })
                ->leftJoin('posts as p2', 'p2.post_id', 'p.shared_post_id')
                ->leftJoin('challenges as ch', 'ch.id', 'p.challenge_id')
                ->leftJoin('users as u2', 'p2.user_id', 'u2.user_id')
                ->leftJoin('categories as c', function ($join) {
                    $join->on(DB::raw("FIND_IN_SET(c.cat_id, u.cat_id)"), ">", DB::raw("0"));
                })
                ->where('u.deleted', 0)
                ->where('p.type', '!=', 'S')
                ->where('p.show_on_wall', 1);
            $posts = $posts->groupBy(DB::raw('u2.user_id, u2.username,u.gender, u2.profile_pic,p.show_on_wall, p.shared_post_id, p2.post_id, p2.type, p2.file, p2.title, like_id, u.user_id, u.username, u.profile_pic, p.post_id, p.file, p.title, p.added_on, p.likes, p.views, p.comments, p.shares, p.type,p.aspect_ratio,ch.tag,p.challenge_id'));
            $posts = $posts->orderBy("post_id", "desc");
            $posts = $posts->skip($request->posts_count)->take(21)->get();
            $data = array();
            if ($posts) {
                $i = 0;
                foreach ($posts as $r) {
                    $i++;
                    if ($r->profile_pic == "") {
                        if ($r->gender == "M") {
                            $p = secure_asset('assets/images/avatar-man.png');
                        } else if ($r->gender == "F") {
                            $p = secure_asset('assets/images/avatar-woman.png');
                        } else {
                            $p = secure_asset('assets/images/profile.png');
                        }
                    } else {
                        $p = Storage::url("profile_pic/" . $r->user_id . "/" . $r->profile_pic);
                    }
                    $p2 = "";
                    if ($r->shared_post_id > 0) {
                        if ($r->profile_pic2 == "") {
                            $p2 = secure_asset('assets/images/profile.png');
                        } else {
                            $p2 = Storage::url("profile_pic/" . $r->user_id2 . "/" . $r->profile_pic2);
                        }
                    }
                    if ($r->type == "V") {
                        $thumb = explode(".", $r->file);
                        $thum = $thumb[0] . ".jpg";
                        //$thum=substr($r->file, 0, -3)."jpg";
                        $file = Storage::url("videos/" . $r->user_id . "/" . $r->file);
                        $thumb_file = Storage::url("videos/" . $r->user_id . "/thumb/" . $thum);
                    } else {
                        $file = Storage::url("photos/" . $r->user_id . "/" . $r->file);
                        $thumb_file = "";
                    }
                    $file2 = "";
                    $thumb_file2 = "";
                    if ($r->shared_post_id > 0) {
                        if ($r->type2 == "V") {
                            $thumb2 = explode(".", $r->file2);
                            $thum2 = $thumb2[0] . ".jpg";
                            //$thum=substr($r->file, 0, -3)."jpg";
                            $file2 = Storage::url("videos/" . $r->user_id2 . "/" . $r->file2);
                            $thumb_file2 = Storage::url("videos/" . $r->user_id2 . "/thumb/" . $thum2);
                        } else {
                            $file2 = Storage::url("photos/" . $r->user_id2 . "/" . $r->file2);
                            $thumb_file2 = "";
                        }
                    }

                    $added_on = $r->added_on;


                    $data_liked_users['users'] = array();

                    if ($r->likes > 0) {
                        $rs_liked_users = DB::table('post_likes as l')
                            ->Join('users as u', 'l.user_id', '=', 'u.user_id')
                            ->select(DB::raw('u.user_id as user_id,u.username as username,u.profile_pic as profile_pic,l.like_on,l.like_id,l.post_id'))
                            ->where('l.post_id', $r->post_id);
                        // ->orderBy('comment_id','desc');

                        $rs_liked_users = $rs_liked_users->orderBy('like_id', 'desc')
                            //->skip($offset) 
                            ->paginate(2);
                        //->get();
                        //print_r($res);
                        $total_liked_users = $rs_liked_users->total();

                        if (!$rs_liked_users->isEmpty()) {

                            foreach ($rs_liked_users as $l) {
                                if ($l->profile_pic == "") {
                                    $p_liked = asset('assets/images/profile.png');
                                } else {
                                    $p_liked = Storage::url("profile_pic/" . $l->user_id . "/" . $l->profile_pic);
                                }

                                $liked_on = ($l->like_on);

                                $data_liked_users['users'][] = array("post_id" => $l->post_id, "like_id" => $l->like_id, "user_id" => $l->user_id, "username" => $l->username, "liked_on" => $liked_on, "profile_pic" => $p_liked);
                            }
                        }
                    }

                    $data_comment['comment'] = array();

                    if ($r->comments > 0) {

                        $rs_comments = DB::table('post_comments as c')
                            ->Join('users as u', 'c.user_id', '=', 'u.user_id')
                            ->select(DB::raw('u.user_id as user_id,u.username as username,u.profile_pic as profile_pic,c.comment as comment,c.comment_id as comment_id,c.comment_on as comment_on,c.parent_id as parent_id'))
                            ->where('c.post_id', $r->post_id)
                            ->where('c.parent_id', 0);
                        // ->orderBy('comment_id','desc');

                        $rs_comments = $rs_comments->orderBy('comment_id', 'desc')
                            ->offset(0)
                            ->limit(2)
                            ->get();
                        //->get();
                        //print_r($res);

                        foreach ($rs_comments as $c) {
                            if ($c->profile_pic == "") {
                                $p_comment = "secure_asset('assets/images/profile.png')";
                            } else {
                                $p_comment = Storage::url("profile_pic/" . $c->user_id . "/" . $c->profile_pic);
                            }

                            $comment_on = $c->comment_on;


                            $data_comment['comment'][] = array("comment_id" => $c->comment_id, "user_id" => $c->user_id, "username" => $c->username, "comment" => $c->comment, "comment_on" => $comment_on, "profile_pic" => $p_comment, "parent_id" => $c->parent_id, "post_id" => $r->post_id);
                        }
                    }
                    $data_comment['comment'] = array_reverse($data_comment['comment']);
                    $s = array('shared_post_id' => $r->shared_post_id, 'liked_users' => $data_liked_users['users'], 'user_comments' => $data_comment['comment'], 'like_id' => $r->like_id, 'user_id' => $r->user_id, 'user_id2' => $r->user_id2, 'file1' => $r->file, 'username' => $r->username, 'username2' => $r->username2, 'file' => $file, 'file2' => $file2, 'thumb' => $thumb_file, 'thumb2' => $thumb_file2, 'title' => $r->title, 'title2' => $r->title2, 'added_on' => $added_on, 'likes' => $r->likes, 'comments' => $r->comments, 'shares' => $r->shares, 'views' => $r->views, 'profile_pic' => $p, 'profile_pic2' => $p2, 'type' => $r->type, 'type2' => $r->type2, 'cat_id' => $r->cat_id, 'cat_name' => $r->cat_name, 'post_id' => $r->post_id, 'post_id2' => $r->post_id2, 'sig' => md5($r->post_id . "*FilmsDream@1290"), 'aspect_ratio' => number_format($r->aspect_ratio, 1), 'show_on_wall' => $r->show_on_wall, 'challenge_id' => $r->challenge_id, 'challenge_tag' => $r->challenge_tag);
                    array_push($data, $s);
                }
                return response()->json([
                    "status" => true, "data" => $data
                ]);
            }
            return response()->json($response);
        }
    }

    public function submitReport(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'post_id'        => 'required',
        ], [
            'post_id.required'    => 'Post Id is required',
        ]);

        if (!$validator->passes()) {
            return response()->json(['status' => 'error', 'msg' => $this->_error_string($validator->errors()->all())]);
        } else {

            if (auth()->guard('api')->user()) {
                $user_id = auth()->guard('api')->user()->user_id;
                $insertData = array();
                $insertData['user_id'] = $user_id;
                $insertData['post_id'] = $request->post_id;
                $insertData['type'] = isset($request->type) ? $request->type : '';
                $insertData['description'] = strip_tags(is_null($request->description) ? '' : $request->description);
                $insertData['report_on'] = date("Y-m-d H:i:s");
                DB::table("reports")->insert($insertData);

                $videoTotalReport = DB::table("posts")
                    ->select(DB::raw("total_report"))
                    ->where("post_id", $request->post_id)
                    ->first();
                $total_report = 0;
                if ($videoTotalReport) {
                    $total_report = $videoTotalReport->total_report;
                }
                $total_report = $total_report + 1;
                DB::table("posts")->where('post_id', $request->post_id)->update(['total_report' => $total_report]);
                $response = array("status" => "success", 'msg' => 'Thanks for reporting.If we find this content to be in violation of our Guidelines, we will remove it.');
            } else {
                return response()->json([
                    "status" => "error", "msg" => "Unauthorized user!"
                ]);
            }
        }
        return response()->json($response);
    }
}
