<?php

namespace App\Http\Controllers\API;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Facades\Storage; 
use Illuminate\Support\Facades\Hash;
use App\Helpers\Common\Functions;
use App\User;
use Auth;
use Mail;
use Illuminate\Support\Facades\URL; 
use Carbon\Carbon;

class ProfileController extends Controller
{
    private function _error_string($errArray)
    {
        $error_string = '';
        foreach ($errArray as $key) {
            $error_string.= $key."\n";
        }
        return $error_string;
    }    
    
    public function profile(Request $request){
        $validator = Validator::make($request->all(), [
            'user_id'          => 'required',                     
        ],[ 
            'user_id.required'   => 'Id is required',
        ]);
        if (!$validator->passes()) {
            return response()->json(['status'=>'error','msg'=> $this->_error_string($validator->errors()->all()) ]);
        }else{
            return $this->respondWithUserData($request->user_id,isset($request->new) ? true : false);
        }
    }
    protected function  respondWithUserData($user_id,$new=false){
        $user_data = array();
        if (auth()->guard('api')->user()) {
            $login_id = auth()->guard('api')->user()->user_id;
        } else {
            $login_id = 0;
        }
        $user_data = User::find($user_id);
        $file_path = '';
        $small_file_path = '';
        if ($user_data->profile_pic != '' && $user_data->profile_pic != null) {
            if (stripos($user_data->profile_pic, 'https://') !== false) {
                $file_path = $user_data->profile_pic;
                $small_file_path = $user_data->profile_pic;
            } else {
                $file_path = asset(Storage::url('profile_pic/' . $user_data->user_id . "/" . $user_data->profile_pic));
                $small_file_path = asset(Storage::url('profile_pic/' . $user_data->user_id . "/small/" . $user_data->profile_pic));
                if ($file_path == "") {
                    $file_path = asset('default/default.png');
                }
                if ($small_file_path == "") {
                    $small_file_path = asset('default/default.png');
                }
            }
        }else{
            if($user_data->gender=="M"){
                $file_path=secure_asset('assets/images/avatar-man.png');    
            }else if($user_data->gender=="F"){
                $file_path=secure_asset('assets/images/avatar-woman.png');    
            }else{
                $file_path=secure_asset('assets/images/profile.png');
            }
        }
        $follower_res=DB::table('followers')
        ->where('user_id',$user_data->user_id)
        ->count();
        $isFollowing=DB::table('followers')
        ->where('user_id',$user_data->user_id)
        ->where('following_id',$login_id)
        ->first();
        
        $following_res=DB::table('followers')
        ->where('following_id',$user_data->user_id)
        ->count();
        
        $likes_res=DB::table('post_likes as l')
        ->leftJoin('posts as p','p.post_id','=','l.post_id')
        ->where('p.user_id',$user_data->user_id)
        ->count();
        
        $views_res=DB::table('post_views as v')
        ->leftJoin('posts as p','p.post_id','=','v.post_id')
        ->where('p.user_id',$user_data->user_id)
        ->count();
        $categories = \DB::table("categories")
        ->select(\DB::raw("GROUP_CONCAT(category) as cat_name"))
        ->whereIn("cat_id", explode(",",$user_data->cat_id))
        ->first();
        $videoStoragePath = asset(Storage::url('videos'));
        $photoStoragePath = asset(Storage::url('photos'));
        ini_set("serialize_precision", 1);
        if (auth()->guard('api')->user()) {
            $login_id = auth()->guard('api')->user()->user_id;
        } else {
            $login_id = 0;
        }
        $data=null;
        $videos_data=null;
        $photos_data=null;
        
        if($new=="true"){
            $videos_data = array();
            $photos_data = array();
            $video_posts = DB::table('users as u')
            ->select(DB::raw("l.like_id as like_id, u.user_id as user_id,u.gender,u.username as username,u.profile_pic as profile_pic,p.aspect_ratio,GROUP_CONCAT(c.cat_id) as cat_id,GROUP_CONCAT(c.category) as cat_name,u2.user_id as user_id2, u2.username as username2, u2.profile_pic as profile_pic2, p.shared_post_id, p2.post_id as post_id2, p2.type as type2, p2.file as file2,p2.title as title2, p.post_id as post_id,p.file as file,p.title as title,p.added_on as added_on,p.likes as likes,p.views as views,p.comments as comments,p.shares as shares,p.type as type,case when f.follower_id IS NULL then 0 else 1 end as isFollowing,
            ch.tag as challenge_tag,p.challenge_id"))
            ->join('posts as p', function ($join) use ($user_id){
                $join->on('u.user_id','p.user_id'); 
                $join->where('p.user_id','=',$user_id); 
                $join->where('p.type','=',"V"); 
            })
            ->leftJoin('followers as f', function ($join)use ($login_id){
                $join->on('f.following_id','=','u.user_id')
                ->where('f.user_id',$login_id);
            })
            ->leftJoin('post_likes as l', function ($join) use ($login_id){
                $join->on('l.post_id','=','p.post_id'); 
                $join->where('l.user_id','=',$login_id); 
            })
            ->leftJoin('posts as p2','p2.post_id','p.shared_post_id')
            ->leftJoin('challenges as ch','ch.id','p.challenge_id')
            ->leftJoin('users as u2','p2.user_id','u2.user_id')
            ->leftJoin('categories as c', function($join){
                $join->on(DB::raw("FIND_IN_SET(c.cat_id, u.cat_id)"), ">",DB::raw("0"));
            })
            
            ->leftJoin('reports as rp', function ($join)use ($login_id){
                $join->on('p.post_id','=','rp.post_id');
                $join->whereRaw(DB::raw(" ( rp.user_id=".$login_id." )" ));
            })
            ->whereRaw( DB::Raw(' rp.id is null '))
            ->where('u.deleted',0)
            //  ->where('p.show_on_wall',1)
            ->where('p.active',1)
            ->where('p.type','!=','S');
            $video_posts=$video_posts->groupBy(DB::raw('u2.user_id, u2.username,u.gender, u2.profile_pic, p.shared_post_id, p2.post_id, p2.type, p2.file, p2.title, f.follower_id, like_id, u.user_id, u.username, u.profile_pic, p.post_id, p.file, p.title, p.added_on, p.likes, p.views, p.comments, p.shares, p.type,p.aspect_ratio,ch.tag,p.challenge_id'));
            $video_posts=$video_posts->orderBy("post_id","desc");
            $video_posts=$video_posts->paginate(21);
            // dd($video_posts);
            $total_records = $video_posts->total();
            $page=1;
            // $total_records = 0;
            
            if ($video_posts) {
                $i = 0;
                foreach ($video_posts as $r) {
                    $i++;
                    if ($r->profile_pic == "") {
                        if($r->gender=="M"){
                            $p=secure_asset('assets/images/avatar-man.png');    
                        }else if($r->gender=="F"){
                            $p=secure_asset('assets/images/avatar-woman.png');    
                        }else{
                            $p=secure_asset('assets/images/profile.png');
                        }
                    } else {
                        
                        if (stripos($r->profile_pic, 'https://') !== false) {
                            $p=$r->profile_pic;
                        }else{
                            $p=Storage::url("profile_pic/".$r->user_id."/".$r->profile_pic);
                        }
                        
                        //$p = Storage::url("profile_pic/" . $r->user_id . "/" . $r->profile_pic);
                    }
                    $p2 = "";
                    if ($r->shared_post_id > 0) {
                        if ($r->profile_pic2 == "") {
                            $p2 = secure_asset('assets/images/profile.png');
                        } else {
                            
                            if (stripos($r->profile_pic2, 'https://') !== false) {
                                $p=$r->profile_pic2;
                            }else{
                                $p=Storage::url("profile_pic/".$r->user_id2."/".$r->profile_pic2);
                            }
                            
                            //$p2 = Storage::url("profile_pic/" . $r->user_id2 . "/" . $r->profile_pic2);
                        }
                    }
                    if ($r->type == "V") {
                        $thumb = explode(".", $r->file);
                        $thum = $thumb[0] . ".jpg";
                        //$thum=substr($r->file, 0, -3)."jpg";
                        $file = Storage::url("videos/" . $r->user_id . "/" . $r->file);
                        $thumb_file = Storage::url("videos/" . $r->user_id . "/thumb/" . $thum);
                    } else {
                        $file = Storage::url("photos/" . $r->user_id . "/" . $r->file);
                        $thumb_file = "";
                    }
                    $file2 = "";
                    $thumb_file2 = "";
                    if ($r->shared_post_id > 0) {
                        if ($r->type2 == "V") {
                            $thumb2 = explode(".", $r->file2);
                            $thum2 = $thumb2[0] . ".jpg";
                            //$thum=substr($r->file, 0, -3)."jpg";
                            $file2 = Storage::url("videos/" . $r->user_id2 . "/" . $r->file2);
                            $thumb_file2 = Storage::url("videos/" . $r->user_id2 . "/thumb/" . $thum2);
                        } else {
                            $file2 = Storage::url("photos/" . $r->user_id2 . "/" . $r->file2);
                            $thumb_file2 = "";
                        }
                    }
                    
                    $added_on = $r->added_on;
                    
                    
                    $data_liked_users['users'] = array();
                    
                    if ($r->likes > 0) {
                        $rs_liked_users = DB::table('post_likes as l')
                        ->Join('users as u', 'l.user_id', '=', 'u.user_id')
                        ->select(DB::raw('u.user_id as user_id,u.username as username,u.profile_pic as profile_pic,l.like_on,l.like_id,l.post_id'))
                        ->where('l.post_id', $r->post_id);
                        // ->orderBy('comment_id','desc');
                        
                        $rs_liked_users = $rs_liked_users->orderBy('like_id', 'desc')
                        //->skip($offset) 
                        ->paginate(2);
                        //->get();
                        //print_r($res);
                        $total_liked_users = $rs_liked_users->total();
                        
                        if (!$rs_liked_users->isEmpty()) {
                            
                            foreach ($rs_liked_users as $l) {
                                if ($l->profile_pic == "") {
                                    $p_liked = asset('assets/images/profile.png');
                                } else {
                                    
                                    if (stripos($l->profile_pic, 'https://') !== false) {
                                        $p_liked=$l->profile_pic;
                                    }else{
                                        $p_liked=Storage::url("profile_pic/".$l->user_id."/".$l->profile_pic);
                                    }
                                    
                                    // $p_liked = Storage::url("profile_pic/" . $l->user_id . "/" . $l->profile_pic);
                                }
                                
                                $liked_on = ($l->like_on);
                                
                                $data_liked_users['users'][] = array("post_id" => $l->post_id, "like_id" => $l->like_id, "user_id" => $l->user_id, "username" => $l->username, "liked_on" => $liked_on, "profile_pic" => $p_liked);
                            }
                        }
                    }
                    
                    $data_comment['comment'] = array();
                    
                    if ($r->comments > 0) {
                        
                        $rs_comments = DB::table('post_comments as c')
                        ->Join('users as u', 'c.user_id', '=', 'u.user_id')
                        ->select(DB::raw('u.user_id as user_id,u.username as username,u.profile_pic as profile_pic,c.comment as comment,c.comment_id as comment_id,c.comment_on as comment_on,c.parent_id as parent_id'))
                        ->where('c.post_id', $r->post_id)
                        ->where('c.parent_id', 0);
                        // ->orderBy('comment_id','desc');
                        
                        $rs_comments = $rs_comments->orderBy('comment_id', 'desc')
                        ->offset(0)
                        ->limit(2)
                        ->get();
                        //->get();
                        //print_r($res);
                        
                        foreach ($rs_comments as $c) {
                            if ($c->profile_pic == "") {
                                $p_comment =  asset('assets/images/profile.png');
                            } else {
                                
                                if (stripos($c->profile_pic, 'https://') !== false) {
                                    $p_comment=$c->profile_pic;
                                }else{
                                    $p_comment=Storage::url("profile_pic/".$c->user_id."/".$c->profile_pic);
                                }
                                
                                // $p_comment = Storage::url("profile_pic/" . $c->user_id . "/" . $c->profile_pic);
                            }
                            
                            $comment_on = $c->comment_on;
                            
                            $data_comment['comment'][] = array("comment_id" => $c->comment_id, "user_id" => $c->user_id, "username" => $c->username, "comment" => $c->comment, "comment_on" => $comment_on, "profile_pic" => $p_comment, "parent_id" => $c->parent_id,"post_id"=>$r->post_id);
                        }
                    }
                    $data_comment['comment'] = array_reverse($data_comment['comment']);
                    $s = array('shared_post_id' => $r->shared_post_id, 'liked_users' => $data_liked_users['users'], 'user_comments' => $data_comment['comment'], 'like_id' => $r->like_id, 'user_id' => $r->user_id, 'user_id2' => $r->user_id2, 'file1' => $r->file, 'username' => $r->username, 'username2' => $r->username2, 'file' => $file, 'file2' => $file2, 'thumb' => $thumb_file, 'thumb2' => $thumb_file2, 'title' => $r->title, 'title2' => $r->title2, 'added_on' => $added_on, 'likes' => $r->likes, 'comments' => $r->comments, 'shares' => $r->shares, 'views' => $r->views, 'profile_pic' => $p, 'profile_pic2' => $p2, 'type' => $r->type, 'type2' => $r->type2, 'cat_id' => $r->cat_id, 'cat_name' => $r->cat_name, 'post_id' => $r->post_id, 'post_id2' => $r->post_id2, 'sig' => md5($r->post_id . "*FilmsDream@1290"), 'aspect_ratio' => number_format($r->aspect_ratio, 1),'challenge_id'=>$r->challenge_id,'challenge_tag'=>$r->challenge_tag);
                    array_push($videos_data, $s);
                }
                
                $photo_posts = DB::table('users as u')
                ->select(DB::raw("l.like_id as like_id, u.user_id as user_id,u.gender,u.username as username,u.profile_pic as profile_pic,p.aspect_ratio,GROUP_CONCAT(c.cat_id) as cat_id,GROUP_CONCAT(c.category) as cat_name,u2.user_id as user_id2, u2.username as username2, u2.profile_pic as profile_pic2, p.shared_post_id, p2.post_id as post_id2, p2.type as type2, p2.file as file2,p2.title as title2, p.post_id as post_id,p.file as file,p.title as title,p.added_on as added_on,p.likes as likes,p.views as views,p.comments as comments,p.shares as shares,p.type as type,case when f.follower_id IS NULL then 0 else 1 end as isFollowing,
                ch.tag as challenge_tag,p.challenge_id"))
                ->join('posts as p', function ($join) use ($user_id){
                    $join->on('u.user_id','p.user_id'); 
                    $join->where('p.type','=',"P"); 
                    $join->where('p.user_id','=',$user_id); 
                })
                ->leftJoin('followers as f', function ($join)use ($login_id){
                    $join->on('f.following_id','=','u.user_id')
                    ->where('f.user_id',$login_id);
                })
                ->leftJoin('post_likes as l', function ($join) use ($login_id){
                    $join->on('l.post_id','=','p.post_id'); 
                    $join->where('l.user_id','=',$login_id); 
                })
                ->leftJoin('posts as p2','p2.post_id','p.shared_post_id')
                ->leftJoin('challenges as ch','ch.id','p.challenge_id')
                ->leftJoin('users as u2','p2.user_id','u2.user_id')
                ->leftJoin('categories as c', function($join){
                    $join->on(DB::raw("FIND_IN_SET(c.cat_id, u.cat_id)"), ">",DB::raw("0"));
                })
                
                ->leftJoin('reports as rp', function ($join)use ($login_id){
                    $join->on('p.post_id','=','rp.post_id');
                    $join->whereRaw(DB::raw(" ( rp.user_id=".$login_id." )" ));
                })
                ->whereRaw( DB::Raw(' rp.id is null '))
                ->where('u.deleted',0)
                //  ->where('p.show_on_wall',1)
                ->where('p.active',1)
                ->where('p.type','!=','S');
                $photo_posts=$photo_posts->groupBy(DB::raw('u2.user_id, u2.username,u.gender, u2.profile_pic, p.shared_post_id, p2.post_id, p2.type, p2.file, p2.title, f.follower_id, like_id, u.user_id, u.username, u.profile_pic, p.post_id, p.file, p.title, p.added_on, p.likes, p.views, p.comments, p.shares, p.type,p.aspect_ratio,ch.tag,p.challenge_id'));
                $photo_posts=$photo_posts->orderBy("post_id","desc");
                $photo_posts=$photo_posts->paginate(21);
                // dd($photo_posts);
                $total_records = $photo_posts->total();
            }
            $page=1;
            // $total_records = 0;
            if ($photo_posts) {
                $i = 0;
                foreach ($photo_posts as $r) {
                    $i++;
                    if ($r->profile_pic == "") {
                        if($r->gender=="M"){
                            $p=secure_asset('assets/images/avatar-man.png');    
                        }else if($r->gender=="F"){
                            $p=secure_asset('assets/images/avatar-woman.png');    
                        }else{
                            $p=secure_asset('assets/images/profile.png');
                        }
                    } else {
                        
                        if (stripos($r->profile_pic, 'https://') !== false) {
                            $p=$r->profile_pic;
                        }else{
                            $p=Storage::url("profile_pic/".$r->user_id."/".$r->profile_pic);
                        }
                        
                        //$p = Storage::url("profile_pic/" . $r->user_id . "/" . $r->profile_pic);
                    }
                    $p2 = "";
                    if ($r->shared_post_id > 0) {
                        if ($r->profile_pic2 == "") {
                            $p2 = secure_asset('assets/images/profile.png');
                        } else {
                            
                            if (stripos($r->profile_pic2, 'https://') !== false) {
                                $p=$r->profile_pic2;
                            }else{
                                $p=Storage::url("profile_pic/".$r->user_id2."/".$r->profile_pic2);
                            }
                            
                            //$p2 = Storage::url("profile_pic/" . $r->user_id2 . "/" . $r->profile_pic2);
                        }
                    }
                    if ($r->type == "V") {
                        $thumb = explode(".", $r->file);
                        $thum = $thumb[0] . ".jpg";
                        //$thum=substr($r->file, 0, -3)."jpg";
                        $file = Storage::url("videos/" . $r->user_id . "/" . $r->file);
                        $thumb_file = Storage::url("videos/" . $r->user_id . "/thumb/" . $thum);
                    } else {
                        $file = Storage::url("photos/" . $r->user_id . "/" . $r->file);
                        $thumb_file = "";
                    }
                    $file2 = "";
                    $thumb_file2 = "";
                    if ($r->shared_post_id > 0) {
                        if ($r->type2 == "V") {
                            $thumb2 = explode(".", $r->file2);
                            $thum2 = $thumb2[0] . ".jpg";
                            //$thum=substr($r->file, 0, -3)."jpg";
                            $file2 = Storage::url("videos/" . $r->user_id2 . "/" . $r->file2);
                            $thumb_file2 = Storage::url("videos/" . $r->user_id2 . "/thumb/" . $thum2);
                        } else {
                            $file2 = Storage::url("photos/" . $r->user_id2 . "/" . $r->file2);
                            $thumb_file2 = "";
                        }
                    }
                    
                    $added_on = $r->added_on;
                    
                    $data_liked_users['users'] = array();
                    
                    if ($r->likes > 0) {
                        $rs_liked_users = DB::table('post_likes as l')
                        ->Join('users as u', 'l.user_id', '=', 'u.user_id')
                        ->select(DB::raw('u.user_id as user_id,u.username as username,u.profile_pic as profile_pic,l.like_on,l.like_id,l.post_id'))
                        ->where('l.post_id', $r->post_id);
                        // ->orderBy('comment_id','desc');
                        $rs_liked_users = $rs_liked_users->orderBy('like_id', 'desc')
                        //->skip($offset) 
                        ->paginate(2);
                        //->get();
                        //print_r($res);
                        
                        $total_liked_users = $rs_liked_users->total();
                        
                        if (!$rs_liked_users->isEmpty()) {
                            
                            foreach ($rs_liked_users as $l) {
                                if ($l->profile_pic == "") {
                                    $p_liked = asset('assets/images/profile.png');
                                } else {
                                    
                                    if (stripos($l->profile_pic, 'https://') !== false) {
                                        $p_liked=$l->profile_pic;
                                    }else{
                                        $p_liked=Storage::url("profile_pic/".$l->user_id."/".$l->profile_pic);
                                    }
                                    
                                    // $p_liked = Storage::url("profile_pic/" . $l->user_id . "/" . $l->profile_pic);
                                }
                                
                                $liked_on = ($l->like_on);
                                
                                $data_liked_users['users'][] = array("post_id" => $l->post_id, "like_id" => $l->like_id, "user_id" => $l->user_id, "username" => $l->username, "liked_on" => $liked_on, "profile_pic" => $p_liked);
                            }
                        }
                    }
                    
                    $data_comment['comment'] = array();
                    
                    if ($r->comments > 0) {
                        
                        $rs_comments = DB::table('post_comments as c')
                        ->Join('users as u', 'c.user_id', '=', 'u.user_id')
                        ->select(DB::raw('u.user_id as user_id,u.username as username,u.profile_pic as profile_pic,c.comment as comment,c.comment_id as comment_id,c.comment_on as comment_on,c.parent_id as parent_id'))
                        ->where('c.post_id', $r->post_id)
                        ->where('c.parent_id', 0);
                        // ->orderBy('comment_id','desc');
                        
                        $rs_comments = $rs_comments->orderBy('comment_id', 'desc')
                        ->offset(0)
                        ->limit(2)
                        ->get();
                        //->get();
                        //print_r($res);
                        
                        foreach ($rs_comments as $c) {
                            if ($c->profile_pic == "") {
                                $p_comment =  asset('assets/images/profile.png');
                            } else {
                                
                                if (stripos($c->profile_pic, 'https://') !== false) {
                                    $p_comment=$c->profile_pic;
                                }else{
                                    $p_comment=Storage::url("profile_pic/".$c->user_id."/".$c->profile_pic);
                                }
                                
                                // $p_comment = Storage::url("profile_pic/" . $c->user_id . "/" . $c->profile_pic);
                            }
                            
                            $comment_on = $c->comment_on;
                            
                            
                            $data_comment['comment'][] = array("comment_id" => $c->comment_id, "user_id" => $c->user_id, "username" => $c->username, "comment" => $c->comment, "comment_on" => $comment_on, "profile_pic" => $p_comment, "parent_id" => $c->parent_id,"post_id"=>$r->post_id);
                        }
                    }
                    $data_comment['comment'] = array_reverse($data_comment['comment']);
                    $s = array('shared_post_id' => $r->shared_post_id, 'liked_users' => $data_liked_users['users'], 'user_comments' => $data_comment['comment'], 'like_id' => $r->like_id, 'user_id' => $r->user_id, 'user_id2' => $r->user_id2, 'file1' => $r->file, 'username' => $r->username, 'username2' => $r->username2, 'file' => $file, 'file2' => $file2, 'thumb' => $thumb_file, 'thumb2' => $thumb_file2, 'title' => $r->title, 'title2' => $r->title2, 'added_on' => $added_on, 'likes' => $r->likes, 'comments' => $r->comments, 'shares' => $r->shares, 'views' => $r->views, 'profile_pic' => $p, 'profile_pic2' => $p2, 'type' => $r->type, 'type2' => $r->type2, 'cat_id' => $r->cat_id, 'cat_name' => $r->cat_name, 'post_id' => $r->post_id, 'post_id2' => $r->post_id2, 'sig' => md5($r->post_id . "*FilmsDream@1290"), 'aspect_ratio' => number_format($r->aspect_ratio, 1),'challenge_id'=>$r->challenge_id,'challenge_tag'=>$r->challenge_tag);
                    array_push($photos_data, $s);
                }
            }
        }else{
            $data = array();
            $posts = DB::table('users as u')
            ->select(DB::raw("l.like_id as like_id, u.user_id as user_id,u.gender,u.username as username,u.profile_pic as profile_pic,p.aspect_ratio,GROUP_CONCAT(c.cat_id) as cat_id,GROUP_CONCAT(c.category) as cat_name,u2.user_id as user_id2, u2.username as username2, u2.profile_pic as profile_pic2, p.shared_post_id, p2.post_id as post_id2, p2.type as type2, p2.file as file2,p2.title as title2, p.post_id as post_id,p.file as file,p.title as title,p.added_on as added_on,p.likes as likes,p.views as views,p.comments as comments,p.shares as shares,p.type as type,case when f.follower_id IS NULL then 0 else 1 end as isFollowing,
            ch.tag as challenge_tag,p.challenge_id"))
            ->join('posts as p', function ($join) use ($user_id){
                $join->on('u.user_id','p.user_id'); 
                $join->where('p.user_id','=',$user_id); 
            })
            ->leftJoin('followers as f', function ($join)use ($login_id){
                $join->on('f.following_id','=','u.user_id')
                ->where('f.user_id',$login_id);
            })
            ->leftJoin('post_likes as l', function ($join) use ($login_id){
                $join->on('l.post_id','=','p.post_id'); 
                $join->where('l.user_id','=',$login_id); 
            })
            ->leftJoin('posts as p2','p2.post_id','p.shared_post_id')
            ->leftJoin('users as u2','p2.user_id','u2.user_id')
            ->leftJoin('challenges as ch','ch.id','p.challenge_id')
            ->leftJoin('categories as c', function($join){
                $join->on(DB::raw("FIND_IN_SET(c.cat_id, u.cat_id)"), ">",DB::raw("0"));
            })
            
            ->leftJoin('reports as rp', function ($join)use ($login_id){
                $join->on('p.post_id','=','rp.post_id');
                $join->whereRaw(DB::raw(" ( rp.user_id=".$login_id." )" ));
            })
            ->whereRaw( DB::Raw(' rp.id is null '))
            ->where('u.deleted',0)
            //  ->where('p.show_on_wall',1)
            ->where('p.active',1)
            ->where('p.type','!=','S');
            $posts=$posts->groupBy(DB::raw('u2.user_id, u2.username,u.gender, u2.profile_pic, p.shared_post_id, p2.post_id, p2.type, p2.file, p2.title, f.follower_id, like_id, u.user_id, u.username, u.profile_pic, p.post_id, p.file, p.title, p.added_on, p.likes, p.views, p.comments, p.shares, p.type,p.aspect_ratio,ch.tag,p.challenge_id'));
            $posts=$posts->orderBy("post_id","desc");
            $posts=$posts->paginate(21);
            // dd($posts);
            $total_records = $posts->total();
            
            $page=1;
            // $total_records = 0;
            if ($posts) {
                $i = 0;
                foreach ($posts as $r) {
                    $i++;
                    if ($r->profile_pic == "") {
                        if($r->gender=="M"){
                            $p=secure_asset('assets/images/avatar-man.png');    
                        }else if($r->gender=="F"){
                            $p=secure_asset('assets/images/avatar-woman.png');    
                        }else{
                            $p=secure_asset('assets/images/profile.png');
                        }
                    } else {
                        
                        if (stripos($r->profile_pic, 'https://') !== false) {
                            $p=$r->profile_pic;
                        }else{
                            $p=Storage::url("profile_pic/".$r->user_id."/".$r->profile_pic);
                        }
                        
                        //$p = Storage::url("profile_pic/" . $r->user_id . "/" . $r->profile_pic);
                    }
                    $p2 = "";
                    if ($r->shared_post_id > 0) {
                        if ($r->profile_pic2 == "") {
                            $p2 = secure_asset('assets/images/profile.png');
                        } else {
                            
                            if (stripos($r->profile_pic2, 'https://') !== false) {
                                $p=$r->profile_pic2;
                            }else{
                                $p=Storage::url("profile_pic/".$r->user_id2."/".$r->profile_pic2);
                            }
                            
                            //$p2 = Storage::url("profile_pic/" . $r->user_id2 . "/" . $r->profile_pic2);
                        }
                    }
                    if ($r->type == "V") {
                        $thumb = explode(".", $r->file);
                        $thum = $thumb[0] . ".jpg";
                        //$thum=substr($r->file, 0, -3)."jpg";
                        $file = Storage::url("videos/" . $r->user_id . "/" . $r->file);
                        $thumb_file = Storage::url("videos/" . $r->user_id . "/thumb/" . $thum);
                    } else {
                        $file = Storage::url("photos/" . $r->user_id . "/" . $r->file);
                        $thumb_file = "";
                    }
                    $file2 = "";
                    $thumb_file2 = "";
                    if ($r->shared_post_id > 0) {
                        if ($r->type2 == "V") {
                            $thumb2 = explode(".", $r->file2);
                            $thum2 = $thumb2[0] . ".jpg";
                            //$thum=substr($r->file, 0, -3)."jpg";
                            $file2 = Storage::url("videos/" . $r->user_id2 . "/" . $r->file2);
                            $thumb_file2 = Storage::url("videos/" . $r->user_id2 . "/thumb/" . $thum2);
                        } else {
                            $file2 = Storage::url("photos/" . $r->user_id2 . "/" . $r->file2);
                            $thumb_file2 = "";
                        }
                    }
                    
                    $added_on = $r->added_on;
                    
                    
                    $data_liked_users['users'] = array();
                    
                    if ($r->likes > 0) {
                        $rs_liked_users = DB::table('post_likes as l')
                        ->Join('users as u', 'l.user_id', '=', 'u.user_id')
                        ->select(DB::raw('u.user_id as user_id,u.username as username,u.profile_pic as profile_pic,l.like_on,l.like_id,l.post_id'))
                        ->where('l.post_id', $r->post_id);
                        // ->orderBy('comment_id','desc');
                        
                        $rs_liked_users = $rs_liked_users->orderBy('like_id', 'desc')
                        //->skip($offset) 
                        ->paginate(2);
                        //->get();
                        //print_r($res);
                        $total_liked_users = $rs_liked_users->total();
                        
                        if (!$rs_liked_users->isEmpty()) {
                            
                            foreach ($rs_liked_users as $l) {
                                if ($l->profile_pic == "") {
                                    $p_liked = asset('assets/images/profile.png');
                                } else {
                                    
                                    if (stripos($l->profile_pic, 'https://') !== false) {
                                        $p_liked=$l->profile_pic;
                                    }else{
                                        $p_liked=Storage::url("profile_pic/".$l->user_id."/".$l->profile_pic);
                                    }
                                    
                                    // $p_liked = Storage::url("profile_pic/" . $l->user_id . "/" . $l->profile_pic);
                                }
                                
                                $liked_on = ($l->like_on);
                                
                                $data_liked_users['users'][] = array("post_id" => $l->post_id, "like_id" => $l->like_id, "user_id" => $l->user_id, "username" => $l->username, "liked_on" => $liked_on, "profile_pic" => $p_liked);
                            }
                        }
                    }
                    
                    $data_comment['comment'] = array();
                    
                    if ($r->comments > 0) {
                        
                        $rs_comments = DB::table('post_comments as c')
                        ->Join('users as u', 'c.user_id', '=', 'u.user_id')
                        ->select(DB::raw('u.user_id as user_id,u.username as username,u.profile_pic as profile_pic,c.comment as comment,c.comment_id as comment_id,c.comment_on as comment_on,c.parent_id as parent_id'))
                        ->where('c.post_id', $r->post_id)
                        ->where('c.parent_id', 0);
                        // ->orderBy('comment_id','desc');
                        
                        $rs_comments = $rs_comments->orderBy('comment_id', 'desc')
                        ->offset(0)
                        ->limit(2)
                        ->get();
                        //->get();
                        //print_r($res);
                        
                        foreach ($rs_comments as $c) {
                            if ($c->profile_pic == "") {
                                $p_comment =  asset('assets/images/profile.png');
                            } else {
                                
                                if (stripos($c->profile_pic, 'https://') !== false) {
                                    $p_comment=$c->profile_pic;
                                }else{
                                    $p_comment=Storage::url("profile_pic/".$c->user_id."/".$c->profile_pic);
                                }
                                
                                // $p_comment = Storage::url("profile_pic/" . $c->user_id . "/" . $c->profile_pic);
                            }
                            
                            $comment_on = $c->comment_on;
                            
                            
                            $data_comment['comment'][] = array("comment_id" => $c->comment_id, "user_id" => $c->user_id, "username" => $c->username, "comment" => $c->comment, "comment_on" => $comment_on, "profile_pic" => $p_comment, "parent_id" => $c->parent_id,"post_id"=>$r->post_id);
                        }
                    }
                    $data_comment['comment'] = array_reverse($data_comment['comment']);
                    $s = array('shared_post_id' => $r->shared_post_id, 'liked_users' => $data_liked_users['users'], 'user_comments' => $data_comment['comment'], 'like_id' => $r->like_id, 'user_id' => $r->user_id, 'user_id2' => $r->user_id2, 'file1' => $r->file, 'username' => $r->username, 'username2' => $r->username2, 'file' => $file, 'file2' => $file2, 'thumb' => $thumb_file, 'thumb2' => $thumb_file2, 'title' => $r->title, 'title2' => $r->title2, 'added_on' => $added_on, 'likes' => $r->likes, 'comments' => $r->comments, 'shares' => $r->shares, 'views' => $r->views, 'profile_pic' => $p, 'profile_pic2' => $p2, 'type' => $r->type, 'type2' => $r->type2, 'cat_id' => $r->cat_id, 'cat_name' => $r->cat_name, 'post_id' => $r->post_id, 'post_id2' => $r->post_id2, 'sig' => md5($r->post_id . "*FilmsDream@1290"), 'aspect_ratio' => number_format($r->aspect_ratio, 1),'challenge_id'=>$r->challenge_id,'challenge_tag'=>$r->challenge_tag);
                    array_push($data, $s);
                    
                }
            }
            
            
            
        }
        
        return response()->json([
            'status' =>true,
            'msg' => 'User login successfully!',
            'data' => array(
                'user_id'           => $user_data->user_id,
                'username'          => $user_data->username,
                'fname'             => $user_data->first_name,
                'lname'             => $user_data->last_name,
                'email'             => $user_data->email,
                'mobile'            => $user_data->mobile1,
                'dob'               => $user_data->dob,
                'gender'            => $user_data->gender,
                'country'           => $user_data->country,
                'state'           => $user_data->state,
                'city'           => $user_data->city,
                'user_dp'     => $file_path,
                'bio'        => ($user_data->bio == null) ? '' : $user_data->bio,
                'categories' => $categories->cat_name,
                'posts'  => $data,
                'videos' => $videos_data,
                'photos' => $photos_data,
                'total_posts'=>$total_records,
                "views"=>$user_data->views,
                "type"=> $user_data->user_type,
                "isFollowing"=> $isFollowing ? 1:0,
                "active"=> $user_data->active,
                "deleted"=> $user_data->deleted,
                "age"=> $user_data->show_age ==1 ? Carbon::parse($user_data->dob)->age : "",
                "language"=> $user_data->language,
                "education"=> $user_data->education,
                'total_followers'=>$follower_res,
                'total_following'=>$following_res,
                'total_likes'=>$likes_res,
                'total_views'=>$views_res,
            ),
        ]);
    }   
}