<?php
namespace App\Http\Controllers\Admin;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Facades\Storage; 
use Illuminate\Support\Facades\DB; 

class AdsController extends Controller
{   

    var $column_order = array(null,null, 'title','added_on','expiry_date','banner'); //set column field database for datatable orderable

    var $column_search = array('title','added_on','expiry_date','banner'); //set column field database for datatable searchable

    var $order = array('added_on' => 'desc'); // default order

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function __construct()
    {
        $this->middleware('auth');
    }
    public function index($active=1)
    {
        $viewers = DB::table('top_ads')
        ->select(DB::raw('*'))
        ->orderBy('added_on','DESC')
        ->get();
        return view("admin.top_ads",compact('top_ads','active'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */


    private function _form_validation($request, $is_edit){
    	if($is_edit==1){
	        $rules = [
	            'title' => 'required',
	            'start_date'     => 'required',
	            'expiry_date'     => 'required',
	            //'password' => 'required',
	            'active'     => 'required',
	            'banner'          => 'image|mimes:jpeg,png,jpg,gif',              
	            //'zipcode'     => 'required',
	        ];
	        $messages = [
	            'tilte.required' => 'You can\'t leave Title field empty',
	            'start_date.required'    => 'You can\'t leave Start Date field empty',
	            'expiry_date.required'    => 'You can\'t leave End Date field empty',
	            //'password.required'    => 'You can\'t leave Password field empty',
	            'active.required'    => 'You can\'t leave Active field empty',
	            //'zipcode.required'    => 'You can\'t leave Zipcode field empty',
	        ]; 
	        $this->validate($request,$rules,$messages);
	        
		}else{
			
	        $rules = [
	            'title' => 'required',
	            'start_date'     => 'required',
	            'expiry_date'     => 'required',
	            //'password' => 'required',
	            'active'     => 'required',
	            'banner'          => 'required|image|mimes:jpeg,png,jpg,gif',              
	            //'zipcode'     => 'required',
	        ];
	        $messages = [
	            'tilte.required' => 'You can\'t leave Title field empty',
	            'start_date.required'    => 'You can\'t leave Start Date field empty',
	            'expiry_date.required'    => 'You can\'t leave End Date field empty',
	            //'password.required'    => 'You can\'t leave Password field empty',
	            'active.required'    => 'You can\'t leave Active field empty',
	            'banner.required'    => 'You can\'t leave banner field empty',
	            //'zipcode.required'    => 'You can\'t leave Zipcode field empty',
	        ]; 
	        $this->validate($request,$rules,$messages);
	        
		}
		if(is_array($request->state)){
			$state = implode(",", $request->state);
		}else{
			$state = "";
		}

		if(is_array($request->country)){
			$country = implode(",", $request->country);
		}else{
			$country = "";
		}
		
        $postData = array(
            'title' => $request->title,
            'start_date'     => $request->start_date,
            'expiry_date'  => $request->expiry_date,
            'link'     => $request->link,
            //'password'     => Hash::make($request->password),
            'countries' => $country,
            'states' => $state,
            'active'     => $request->active,
            'added_on'     => date("Y-m-d H:i:s"),
            
        ); 			
		
        return $postData;
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $data = $this->_form_validation($request, 0); 
		if($request->hasFile('banner')) {
            $path = "banners";
            $filenametostore = $request->file('banner')->store($path);
          
            Storage::setVisibility($filenametostore, 'public');
            $fileArray = explode('/',$filenametostore);
            $fileName = array_pop($fileArray); 
            $data['banner'] = $fileName;
		}
        DB::table('top_ads')->insert($data);
        return redirect( config('app.admin_url').'/top_ads')->with('success','Ad submitted successfully');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($active=1){
        $viewers = DB::table('top_ads')
        ->select(DB::raw('*'))
        ->orderBy('added_on','DESC')
        ->get();
        return view("admin.top_ads",compact('active','viewers'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id){
        $action = 'edit';
        $countryRS = DB::table('countries')->select(DB::raw("*"))->get();
        $stateRS = DB::table('states')->select(DB::raw("*"))->get();
        $viewer = DB::table('top_ads')->select(DB::raw("*"))->where('ad_id','=',$id)->first();
        // dd($category);
        return view('admin.top_ad_create',compact('viewer','id','action', 'countryRS', 'stateRS'));
    }

    public function add(){
        $action = 'add';
        $id = 0;
        $countryRS = DB::table('countries')->select(DB::raw("*"))->get();
        $stateRS = DB::table('states')->select(DB::raw("*"))->get();
        // dd($category);
        return view('admin.top_ad_create',compact('id','action','countryRS', 'stateRS'));
    }

    public function view($id){
        $action = 'view';
        $viewer = DB::table('top_ads')->select(DB::raw("*"))->where('ad_id','=',$id)->first();
        $countryRS = DB::table('countries')->select(DB::raw("*"))->get();
         //dd($candidate);
        return view('admin.top_ad_create',compact('viewer','id','action','countryRS'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $data = $this->_form_validation($request, 1);
		if($request->hasFile('banner')) {
            $path = "banners";
            $filenametostore = $request->file('banner')->store($path);
          
            Storage::setVisibility($filenametostore, 'public');
            $fileArray = explode('/',$filenametostore);
            $fileName = array_pop($fileArray); 
            $data['banner'] = $fileName;
		}
        
        DB::table('top_ads')->where('ad_id',$id)->update($data);
        return redirect( env('ADMIN_URL').'/top_ads')->with('success','Ad details updated successfully');
    }

    public function inactive($id)
    {   
        DB::table('top_ads')->where('ad_id',$id)->update(array('active' => '0'));
        return redirect( env('ADMIN_URL').'/top_ads')->with('success','Ad Inactivated');
    }

    public function active($id)
    {   
        DB::table('top_ads')->where('ad_id',$id)->update(array('active' => '1'));
        return redirect( env('ADMIN_URL').'/top_ads')->with('success','Ad Activated');
    }


    public function serverProcessing(Request $request)
    {
        $currentPath = url(config('app.admin_url')).'/top_ads/';
        $list = $this->get_datatables($request);

        $data = array();
        $no = $request->start;
        foreach ($list as $viewer) {
            $no++;
            $row = array();
            // $row[] = '<a class="view" href="'.$currentPath.'view/'.$viewer->ad_id.'"><i class="fa fa-search"></i></a><a class="edit" href="'.$currentPath.$viewer->ad_id.'/edit"><i class="fa fa-edit"></i></a><a class="copy" href="'.$currentPath.'copy/'.$viewer->ad_id.'"><i class="fa fa-copy"></i></a><a class="delete deleteSelSingle" style="cursor:pointer;" data-val="'.$viewer->ad_id.'"><i class="fa fa-trash"></i></a>';
            $row[] = '<a class="view" href="'.$currentPath.'view/'.$viewer->ad_id.'"><i class="fa fa-search"></i></a><a class="edit" href="'.$currentPath.'edit/'.$viewer->ad_id.'"><i class="fa fa-edit"></i></a><a class="delete deleteSelSingle" style="cursor:pointer;" data-val="'.$viewer->ad_id.'"><i class="fa fa-trash"></i></a>';
            $row[] = '<div class="align-center"><input id="cb'.$no.'" name="key_m[]" class="delete_box blue-check" type="checkbox" data-val="'.$viewer->ad_id.'"><label for="cb'.$no.'"></label></div>';
            $row[] = $viewer->title;
            // $row[] = $producer->last_name;
            $row[] = $viewer->added_on;
            $row[] = $viewer->start_date;
            $row[] = $viewer->expiry_date;
            $row[] = $viewer->countries;
            $row[] = $viewer->states;
            $row[] = '<img height="50" src="'.Storage::url("banners/".$viewer->banner).'">';
            $row[] = $viewer->views;
            $row[] = $viewer->clicks;
            //$row[] = $producer->city;
            //$row[] = $viewer->zipcode;
            if($viewer->active==1){
                $row[] = '<a class="btn btn-success" href="'.$currentPath.'inactive/'.$viewer->ad_id.'" onclick="return confirm(\'Are you sure, you want to inactivate this ad?\')">Active</a>';
            }else{
                $row[] = '<a class="btn btn-danger" href="'.$currentPath.'active/'.$viewer->ad_id.'" onclick="return confirm(\'Are you sure, you want to activate this ad?\')">Inactive</a>';
            }
            //$row[] = '<a href="#" class="btn btn-primary">Change Password</a>';
            $data[] = $row;
        }

        $output = array(
            "draw" => $request->draw,
            "recordsTotal" => $this->count_all($request),
            "recordsFiltered" => $this->count_filtered($request),
            "data" => $data,
        );
        echo json_encode($output);
    }

    private function _get_datatables_query($request)
    {            
        $keyword = $request->search['value'];
        $order = $request->order;
        $viewerRS = DB::table('top_ads')
        ->select(DB::raw("*"));
        $strWhere = " 1=1 ";
        
        $strWhereOr = "";
        $i = 0;

        foreach ($this->column_search as $item) // loop column
        {
            if($keyword) // if datatable send POST for search{
            	$strWhereOr = $strWhereOr." $item like '%".$keyword."%' or ";
                //$candidateRS = $candidateRS->orWhere($item, 'like', '%' . $keyword . '%') ;
        }
        $strWhereOr = trim($strWhereOr, "or ");
        if($strWhereOr!=""){
	        $viewerRS = $viewerRS->whereRaw(DB::raw($strWhere." and (".$strWhereOr.")"));
	    }else{
			$viewerRS = $viewerRS->whereRaw(DB::raw($strWhere	));
		}

        
        if(isset($order)) // here order processing
        {
            $viewerRS = $viewerRS->orderBy($this->column_order[$request->order['0']['column']], $request->order['0']['dir']);
        } 
        else if(isset($this->order))
        {
            $orderby = $this->order;
            $viewerRS = $viewerRS->orderBy(key($orderby),$orderby[key($orderby)]);
        }
        return $viewerRS;
    }

    function get_datatables($request)
    {
        $viewerRS = $this->_get_datatables_query($request);
        if($request->length != -1){
            $viewerRS = $viewerRS->limit($request->length);
            if($request->start != -1){
                $viewerRS = $viewerRS->offset($request->start);
            }
        }
        
        $viewers = $viewerRS->get();
        return $viewers;
    }

    function count_filtered($request)
    {
        $viewerRS = $this->_get_datatables_query($request);
        return $viewerRS->count();
    }

    public function count_all($request)
    {
        $viewerRS = DB::table('top_ads')->select(DB::raw("count(*) as total"))->first();
        return $viewerRS->total;
    }

    public function delete(Request $request){
        $rec_exists = array();
        $del_error = '';
        $ids = explode(',',$request->ids);
        foreach ($ids as $id) {
            DB::table('top_ads')->where('ad_id', $id)->delete();
        }
        
        if($del_error == 'error'){
            $request->session()->put('error',$msg );
            return response()->json(['status' => 'error',"rec_exists"=>$rec_exists]);
        }else{
            if( count($ids) > 1){
                $msg = "Ad deleted successfully";
            }else{
                $msg = "Ad deleted successfully";
            }
            $request->session()->put('success', $msg);
            return response()->json(['status' => 'success',"rec_exists"=>$rec_exists]);
        }

    }

}
