<?php

namespace App\Http\Controllers\Admin;

use DateTime;
use Carbon\Carbon;
use App\Models\User;
use App\Models\Appointment;
use Illuminate\Http\Request;
use App\Models\AppointmentSlot;
use Yajra\DataTables\DataTables;
use App\Models\AppointmentService;
use App\Http\Controllers\Controller;
use App\Models\BookedAppointmentSlot;
use App\Models\AppointmentServiceStaff;
use Illuminate\Support\Facades\Validator;
use App\Models\AppointmentServiceCategory;

class AppointmentController extends Controller
{
    public function index(Request $request)
    {
        $title = 'Appointments';

        if ($request->ajax()) {
            $data = Appointment::with(['user', 'payment','slot'])->has('booked_appointment')->latest()->get();

            return DataTables::of($data)
                ->addIndexColumn()
                ->addColumn('action', function ($row) {
                    $actionBtn = "<button class='btn btn-sm btn-warning' data-bs-toggle='modal'  data-bs-target='#staffModalCenter' data-bs-id='$row->id'>Assign Staff</button>";
                    $actionBtn .= " <a class='btn btn-sm btn-primary' href='".route('admin.edit-appointment',$row->id)."'>Edit</a>";
                    return $actionBtn;
                })
                ->addColumn('time', function ($row) {
                    $time = '';
                    if ($row->slot) {
                        $time = "<span class='badge bg-info text-dark'>" . date('h:i A', strtotime($row->slot->from_time)) . ' - ' . date('h:i A', strtotime($row->slot->to_time)) . '</span>';
                    }
                    return $time;
                })
                ->addColumn('customer', function ($row) {
                    return $row->user->first_name . ' ' . $row->user->last_name;;
                })
                ->addColumn('staff', function ($row) {
                    $staff = '-';
                    if ($row->booked_appointment) {
                        if ($row->booked_appointment->user) {
                            $staff = $row->booked_appointment->user->first_name . ' ' . $row->booked_appointment->user->last_name;
                        }
                    }
                    return $staff;
                })
                ->addColumn('price', function ($row) {
                    $price = '';
                    if ($row->price == 0) {
                        $price = 'Free';
                    } else {
                        $price = '$' . number_format($row->price, 2);
                    }
                    return $price;
                })
                ->addColumn('payment_status', function ($row) {
                    if ($row->price == 0) {
                        $status = '-';
                    } else {
                        $status = "<span class='badge bg-warning '>Pending</span>";
                        if($row->payment){
                            if ($row->payment->status == 'S') {
                                $status = "<span class='badge bg-success '>Success</span>";
                            } else if ($row->payment->status == 'C') {
                                $status = "<span class='badge bg-danger '>Canceled</span>";
                            } else if ($row->payment->status == 'F') {
                                $status = "<span class='badge bg-danger'>Failed</span>";
                            }
                        }
                    }
                    return $status;
                })
                ->addColumn('paid', function ($row) {
                    $paid = '';
                    if ($row->price == 0) {
                        $paid = '-';
                    } else {
                        if ($row->payment) {
                            $paid = '$' . number_format($row->payment->amount, 2);
                        } else {
                            $paid = "<span class='badge bg-warning text-dark'>Pending</span>";
                        }
                    }
                    return $paid;
                })

                ->addColumn('status', function ($row) {
                    // P for Pending,A:approved, C for Cancelled, R for Rejected
                    $status = "<span class='badge bg-warning '>Pending</span>";
                    if ($row->status == 'A') {
                        $status = "<span class='badge bg-success '>Approved</span>";
                    } else if ($row->status == 'C') {
                        $status = "<span class='badge bg-danger '>Canceled</span>";
                    } else if ($row->status == 'R') {
                        $status = "<span class='badge bg-danger'>Rejected</span>";
                    }
                    return $status;
                })
                ->rawColumns(['action', 'time', 'staff', 'status', 'price', 'paid','payment_status'])
                ->make(true);
        }

        return view('admin.appointment.index', compact('title'));
    }

    public function staff(Request $request)
    {
        $appointment_id = $request->appointment_id;
        $appointment = Appointment::find($appointment_id);
        if ($appointment) {
            $date = $appointment->date;
            $service_id = $appointment->service_id;
            $slot_id = $appointment->slot_id;
            $slot = AppointmentSlot::find($slot_id);

            $day = date('N', strtotime($date));
            $assigned_user_id = 0;
            $assignedUser = BookedAppointmentSlot::where('appointment_id', $appointment_id)->first();
            if ($assignedUser) {
                $assigned_user_id = $assignedUser->user_id;
            }

            $staff = User::doesnthave('booked_appointment_slots', 'or', function ($query) use ($date, $slot_id, $appointment_id,$service_id) {
                $query->where('date',  $date);
                $query->where('slot_id',  $slot_id);
                $query->where('appointment_id', '<>', $appointment_id);
                $query->where('service_id',$service_id);
            })->whereDoesntHave('holidays', function ($query) use ($date) {
                $query->where('date',  $date);
            })->whereHas('working_days', function ($q) use ($day) {
                $q->where('day_id', $day);
            })->with(['services','working_days' => function ($q) use ($day) {
                $q->where('day_id', $day);
            }])
            ->whereHas('services',function($q) use($service_id){
                $q->where('service_id',$service_id);
            })
            ->get();


            $html = view('admin.appointment.staff', ['staff' => $staff, 'assigned_user_id' => $assigned_user_id])->render();
            return response()->json(['status' => true, 'appointment_no' => $appointment->quote_number, 'html' => $html]);
        }
    }

    public function assignStaff(Request $request)
    {
        $rules = array(
            'staff_id' => 'required',
            'appointment_id' => 'required'
        );
        $validator = Validator::make($request->all(), $rules);

        // Validate the input and return correct response
        if ($validator->fails()) {
            return response()->json(array(
                'success' => false,
                'errors' => $validator->getMessageBag()->toArray()
            ), 400);
        }

        $appointment_id = $request->appointment_id;
        $appointment = Appointment::find($appointment_id);
        $appointment->status='A';
        $appointment->save();

        BookedAppointmentSlot::where('appointment_id', $appointment_id)->delete();
        $bookAppoinment = new BookedAppointmentSlot();
        $bookAppoinment->user_id = $request->staff_id;
        $bookAppoinment->appointment_id = $appointment_id;
        $bookAppoinment->service_id = $appointment->service_id;
        $bookAppoinment->slot_id = $appointment->slot_id;
        $bookAppoinment->date = $appointment->date;
        $bookAppoinment->save();

        session()->flash('success', 'Staff assigned to appointment ' . $appointment->quote_number);

        return response()->json(['status' => true]);
    }

    public function appointment_form($date = NULL)
    {
        $categories = AppointmentServiceCategory::select('id', 'name')->get();
        $slots = AppointmentSlot::get();
        $users = User::select('id', 'first_name', 'last_name', 'email', 'phone')->where('active', 1)->get();

        return view('admin.appointment.appointment-form', compact('categories', 'slots', 'users', 'date'));
    }

    public function edit_appointment_form($id, Request $request)
    {
        $categories = AppointmentServiceCategory::select('id', 'name')->get();
        $slots = AppointmentSlot::get();
        $users = User::select('id', 'first_name', 'last_name', 'email', 'phone')->where('active', 1)->get();
        $appointment = Appointment::with(['user', 'service', 'booked_appointment', 'slot'])->find($id);

        return view('admin.appointment.appointment-form', compact('categories', 'slots', 'users', 'appointment', 'id'));
    }

    public function get_appointment_services(AppointmentServiceCategory $category, Request $request)
    {
        $services = AppointmentService::where('cat_id', $category->id)->get();

        $str = '<option disabled>---</option>';

        foreach ($services as $service) {
            $selected = '';
            if ($service->id == $request->selected_service_id) {
                $selected = 'selected';
            }
            $str .= '<option value="' . $service->id . '" ' . $selected . '>' . $service->name . '</option>';
        }

        return $str;
    }

    public function get_appointment_service_staff(AppointmentService $service, Request $request)
    {
        $staff = User::distinct()->select('users.id', 'users.first_name', 'users.last_name')
            ->join('appointment_service_staff', 'appointment_service_staff.user_id', '=', 'users.id')
            ->where('appointment_service_staff.service_id', $service->id)
            ->get();

        $str = '<option>---</option>';

        foreach ($staff as $x) {
            $selected = '';
            if ($x->id == $request->selected_staff_id) {
                $selected = 'selected';
            }
            $str .= '<option value="' . $x->id . '" ' . $selected . '>' . $x->first_name . ' ' . $x->last_name . '</option>';
        }

        return $str;
    }

    public function get_customers()
    {
        $customers = User::select('id', 'first_name', 'last_name', 'email', 'phone')->get();

        $str = '<option selected disabled>---</option>';

        foreach ($customers as $x) {
            $str .= '<option value="' . $x->id . '">' . $x->first_name . ' ' . $x->last_name . '</option>';
        }

        return $str;
    }

    public function save_customer(Request $request)
    {
        $request->validate([
            'first_name' => 'required|string|max:50',
            'last_name' => 'required|string|max:50',
            'email' => 'required|email|unique:App\Models\User,email',
            'phone' => 'required|string|unique:App\Models\User,email',
        ]);

        $user = new User();
        $user->first_name = $request->first_name;
        $user->last_name = $request->last_name;
        $user->email = $request->email;
        $user->phone = $request->phone;
        $user->save();

        echo 'done';
        exit;
    }

    function store_appointment(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'service' => 'required',
            'staff' => 'required|exists:App\Models\User,id',
            'date' => 'required',
            'slot_id' => 'required',
            'customer_id' => 'required',
            'status' => 'required',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $appointment = new Appointment;
        $appointment->user_id = $request->customer_id;
        $appointment->date = $request->date;
        $appointment->slot_id = $request->slot_id;
        $appointment->status = $request->status;
        $appointment->service_id = $request->service;
        $appointment->save();

        $bookedAppointmentSlot = new BookedAppointmentSlot;
        $bookedAppointmentSlot->user_id = $request->staff;
        $bookedAppointmentSlot->slot_id = $request->slot_id;
        $bookedAppointmentSlot->service_id = $request->service;
        $bookedAppointmentSlot->date = $request->date;
        $bookedAppointmentSlot->appointment_id = $appointment->id;
        $bookedAppointmentSlot->save();

        return to_route('admin.appointments');
    }

    function update_appointment($id, Request $request)
    {
        $request->validate([
            'service' => 'required',
            'staff' => 'required',
            'date' => 'required',
            'slot_id' => 'required',
            'customer_id' => 'required',
        ]);

        $appointment = Appointment::find($id);
        if ($appointment) {
            $appointment->user_id = $request->customer_id;
            $appointment->date = $request->date;
            $appointment->slot_id = $request->slot_id;
            $appointment->status = $request->status;
            $appointment->service_id = $request->service;
            $appointment->save();

            $bookedAppointmentSlot = BookedAppointmentSlot::where('appointment_id', $appointment->id)->first();
            if ($bookedAppointmentSlot) {
                $bookedAppointmentSlot->user_id = $request->staff;
                $bookedAppointmentSlot->slot_id = $request->slot_id;
                $bookedAppointmentSlot->date = $request->date;
                $bookedAppointmentSlot->appointment_id = $appointment->id;
                $bookedAppointmentSlot->service_id = $request->service;
                $bookedAppointmentSlot->save();
            }
        }
        return to_route('admin.appointments');
    }

    public function calendar()
    {
        $appointments = Appointment::select('id', 'date', 'user_id')->get();

        return view('admin.appointment.calendar', compact('appointments'));
    }

    public function appointments(Request $request)
    {
        $start = new DateTime($request->start);
        $end = new DateTime($request->end);

        $start = $start->format('Y-m-d');
        $end = $end->format('Y-m-d');

        $appointments = Appointment::select('appointments.*', 'appointments.id as appointmentId',
            'staff.first_name as fn', 'staff.last_name as ln', 'staff.image as dp',
            'u.*',
            'appointment_slots.from_time', 'appointment_slots.to_time',
            'appointment_services.name as service_name')
            ->join('booked_appointment_slots', 'booked_appointment_slots.appointment_id', '=', 'appointments.id')
            ->join('appointment_slots', 'appointment_slots.id', '=', 'appointments.slot_id')
            ->join('appointment_services', 'appointment_services.id', '=', 'appointments.service_id')
            ->join('users as staff', 'staff.id', '=', 'booked_appointment_slots.user_id')
            ->join('users as u', 'u.id', '=', 'appointments.user_id')
            ->where('appointments.date', '>=', $start)
            ->where('appointments.date', '<=', $end)
            ->get();

        return response()->json($appointments);
    }

    public function appointment_details(Appointment $appointment)
    {
        return view('admin.appointment.details', compact('appointment'));
    }

    public function dashboard(Request $request)
    {
        $appointments = NULL;

        $dt = Carbon::now()->format('Y-m-d');

        $pending = Appointment::where('date', $dt)->where('status', 'P')->count();
        $approved = Appointment::where('date', $dt)->where('status', 'A')->count();
        $cancelled = Appointment::where('date', $dt)->where('status', 'C')->count();
        $rejected = Appointment::where('date', $dt)->where('status', 'R')->count();

        $total_appointments = $pending + $approved + $cancelled + $rejected;
        $total_duration = $approved;
        $total_revenue = Appointment::where('date', $dt)->sum('price');
        $new_customers = 0;

        if ($request->filled('duration')) {
            switch ($request->duration) {
                case 'today':
                    $dt = Carbon::now()->format('Y-m-d');
                    $appointments = Appointment::where('date', $dt)->get();

                    $pending = Appointment::where('date', $dt)->where('status', 'P')->count();
                    $approved = Appointment::where('date', $dt)->where('status', 'A')->count();
                    $cancelled = Appointment::where('date', $dt)->where('status', 'C')->count();
                    $rejected = Appointment::where('date', $dt)->where('status', 'R')->count();

                    $total_appointments = $pending + $approved + $cancelled + $rejected;
                    $total_duration = $approved;
                    $total_revenue = Appointment::where('date', $dt)->sum('price');
                    $new_customers = User::where('created_at', Carbon::createFromFormat('Y-m-d', $dt))->count();
                    break;
                case 'yesterday':
                    $dt = Carbon::yesterday()->format('Y-m-d');
                    $appointments = Appointment::where('date', $dt)->get();

                    $pending = Appointment::where('date', $dt)->where('status', 'P')->count();
                    $approved = Appointment::where('date', $dt)->where('status', 'A')->count();
                    $cancelled = Appointment::where('date', $dt)->where('status', 'C')->count();
                    $rejected = Appointment::where('date', $dt)->where('status', 'R')->count();

                    $total_appointments = $pending + $approved + $cancelled + $rejected;
                    $total_duration = $approved;
                    $total_revenue = Appointment::where('date', $dt)->sum('price');
                    $new_customers = User::where('created_at', Carbon::createFromFormat('Y-m-d', $dt))->count();
                    break;
                case 'tomorrow':
                    $dt = Carbon::tomorrow()->format('Y-m-d');
                    $appointments = Appointment::where('date', $dt)->get();

                    $pending = Appointment::where('date', $dt)->where('status', 'P')->count();
                    $approved = Appointment::where('date', $dt)->where('status', 'A')->count();
                    $cancelled = Appointment::where('date', $dt)->where('status', 'C')->count();
                    $rejected = Appointment::where('date', $dt)->where('status', 'R')->count();

                    $total_appointments = $pending + $approved + $cancelled + $rejected;
                    $total_duration = $approved;
                    $total_revenue = Appointment::where('date', $dt)->sum('price');
                    $new_customers = User::where('created_at', Carbon::createFromFormat('Y-m-d', $dt))->count();
                    break;
                case 'last-week':
                    $endOfWeek = Carbon::now()->startOfWeek()->subDay()->format('Y-m-d');
                    $startOfWeek = Carbon::now()->startOfWeek()->subDays(8)->format('Y-m-d');
                    $appointments = Appointment::whereBetween('date', [$startOfWeek, $endOfWeek])->get();

                    $pending = Appointment::whereBetween('date', [$startOfWeek, $endOfWeek])->where('status', 'P')->count();
                    $approved = Appointment::whereBetween('date', [$startOfWeek, $endOfWeek])->where('status', 'A')->count();
                    $cancelled = Appointment::whereBetween('date', [$startOfWeek, $endOfWeek])->where('status', 'C')->count();
                    $rejected = Appointment::whereBetween('date', [$startOfWeek, $endOfWeek])->where('status', 'R')->count();

                    $total_appointments = $pending + $approved + $cancelled + $rejected;
                    $total_duration = $approved;
                    $total_revenue = Appointment::whereBetween('date', [$startOfWeek, $endOfWeek])->sum('price');
                    $new_customers = User::whereBetween('created_at', [Carbon::createFromFormat('Y-m-d', $startOfWeek), Carbon::createFromFormat('Y-m-d', $endOfWeek)])->count();
                    break;
                case 'this-week':
                    $startOfWeek = Carbon::now()->startOfWeek()->format('Y-m-d');
                    $endOfWeek = Carbon::now()->endOfWeek()->format('Y-m-d');
                    $appointments = Appointment::whereBetween('date', [$startOfWeek, $endOfWeek])->get();

                    $pending = Appointment::whereBetween('date', [$startOfWeek, $endOfWeek])->where('status', 'P')->count();
                    $approved = Appointment::whereBetween('date', [$startOfWeek, $endOfWeek])->where('status', 'A')->count();
                    $cancelled = Appointment::whereBetween('date', [$startOfWeek, $endOfWeek])->where('status', 'C')->count();
                    $rejected = Appointment::whereBetween('date', [$startOfWeek, $endOfWeek])->where('status', 'R')->count();

                    $total_appointments = $pending + $approved + $cancelled + $rejected;
                    $total_duration = $approved;
                    $total_revenue = Appointment::whereBetween('date', [$startOfWeek, $endOfWeek])->sum('price');
                    $new_customers = User::whereBetween('created_at', [Carbon::createFromFormat('Y-m-d', $startOfWeek), Carbon::createFromFormat('Y-m-d', $endOfWeek)])->count();
                    break;
                case 'next-week':
                    $startOfNextWeek = Carbon::now()->startOfWeek()->addWeek()->format('Y-m-d');
                    $endOfNextWeek = Carbon::now()->endOfWeek()->addWeek()->format('Y-m-d');
                    $appointments = Appointment::whereBetween('date', [$startOfNextWeek, $endOfNextWeek])->get();

                    $pending = Appointment::whereBetween('date', [$startOfNextWeek, $endOfNextWeek])->where('status', 'P')->count();
                    $approved = Appointment::whereBetween('date', [$startOfNextWeek, $endOfNextWeek])->where('status', 'A')->count();
                    $cancelled = Appointment::whereBetween('date', [$startOfNextWeek, $endOfNextWeek])->where('status', 'C')->count();
                    $rejected = Appointment::whereBetween('date', [$startOfNextWeek, $endOfNextWeek])->where('status', 'R')->count();

                    $total_appointments = $pending + $approved + $cancelled + $rejected;
                    $total_duration = $approved;
                    $total_revenue = Appointment::whereBetween('date', [$startOfNextWeek, $endOfNextWeek])->sum('price');
                    $new_customers = User::whereBetween('created_at', [Carbon::createFromFormat('Y-m-d', $startOfNextWeek), Carbon::createFromFormat('Y-m-d', $endOfNextWeek)])->count();
                    break;
                case 'this-month':
                    $startOfMonth = Carbon::now()->startOfMonth()->format('Y-m-d');
                    $endOfMonth = Carbon::now()->endOfMonth()->format('Y-m-d');
                    $appointments = Appointment::whereBetween('date', [$startOfMonth, $endOfMonth])->get();

                    $pending = Appointment::whereBetween('date', [$startOfMonth, $endOfMonth])->where('status', 'P')->count();
                    $approved = Appointment::whereBetween('date', [$startOfMonth, $endOfMonth])->where('status', 'A')->count();
                    $cancelled = Appointment::whereBetween('date', [$startOfMonth, $endOfMonth])->where('status', 'C')->count();
                    $rejected = Appointment::whereBetween('date', [$startOfMonth, $endOfMonth])->where('status', 'R')->count();

                    $total_appointments = $pending + $approved + $cancelled + $rejected;
                    $total_duration = $approved;
                    $total_revenue = Appointment::whereBetween('date', [$startOfMonth, $endOfMonth])->sum('price');
                    $new_customers = User::whereBetween('created_at', [Carbon::createFromFormat('Y-m-d', $startOfMonth), Carbon::createFromFormat('Y-m-d', $endOfMonth)])->count();
                    break;
                case 'this-year':
                    $currentYear = Carbon::now()->year;
                    $startDate = Carbon::create($currentYear, 1, 1)->startOfDay()->format('Y-m-d');
                    $endDate = Carbon::create($currentYear, 12, 31)->endOfDay()->format('Y-m-d');
                    $appointments = Appointment::whereBetween('date', [$startDate, $endDate])->get();

                    $pending = Appointment::whereBetween('date', [$startDate, $endDate])->where('status', 'P')->count();
                    $approved = Appointment::whereBetween('date', [$startDate, $endDate])->where('status', 'A')->count();
                    $cancelled = Appointment::whereBetween('date', [$startDate, $endDate])->where('status', 'C')->count();
                    $rejected = Appointment::whereBetween('date', [$startDate, $endDate])->where('status', 'R')->count();

                    $total_appointments = $pending + $approved + $cancelled + $rejected;
                    $total_duration = $approved;
                    $total_revenue = Appointment::whereBetween('date', [$startDate, $endDate])->sum('price');
                    $new_customers = User::whereBetween('created_at', [Carbon::createFromFormat('Y-m-d', $startDate), Carbon::createFromFormat('Y-m-d', $endDate)])->count();
                    break;
            }
        }

        return view('admin.appointment.dashboard', compact(
                                                                'appointments',
                                                                'pending',
                                                                'approved',
                                                                'cancelled',
                                                                'rejected',
                                                                'total_appointments',
                                                                'total_duration',
                                                                'total_revenue',
                                                                'new_customers'
                                                            ));
    }
}
