<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\AppointmentServiceCategory;
use Illuminate\Http\Request;
use Yajra\DataTables\DataTables;

class AppointmentServiceCategoryController extends Controller
{
    public function index(Request $request)
    {
        $title = 'Appointment Service Categories';
        if ($request->ajax()) {
            $data = AppointmentServiceCategory::latest()->get();
            return DataTables::of($data)
                ->addIndexColumn()
                ->addColumn('action', function ($row) {
                    $actionBtn = ' <ul class="list-inline me-auto mb-0">
                    <li class="list-inline-item align-bottom" data-bs-toggle="tooltip" title="Edit">
                    <a href="' . route('admin.appointment.categories.edit', $row->id) . '" class="edit avtar avtar-xs btn-link-success btn-pc-default"><i class="ti ti-edit-circle f-18"></i></a> 
                    </li>
                    <li class="list-inline-item align-bottom" data-bs-toggle="tooltip" title="Edit">
                    <a href="javascript:void(0)" class="deleteSelSingle delete avtar avtar-xs btn-link-danger btn-pc-default" data-val=' . $row->id . '> <i class="ti ti-trash f-18"></i></a>
                    </li>';
                    return $actionBtn;
                })
                // ->addColumn('image', function ($row) {
                //     $image = "";
                //     if ($row->image != "") {
                //         $image = asset(Storage::url('categories')) . '/' . $row->image;
                //         return "<img src='" . $image . "' width='100'>";
                //     }
                //     return $image;
                // })
                ->addColumn('active', function ($row) {
                    $checked = "";
                    if ($row->active == 1) {
                        $checked = 'checked';
                    }
                    return '<div class="form-check form-switch custom-switch-v1 mb-2">
                        <input type="checkbox" class="form-check-input input-success active_item" data-name="' . $row->title . '" data-value="' . $row->active . '" data-id="' . $row->id . '" ' . $checked . '>
                    </div>';
                })
                ->rawColumns(['action', 'active'])
                ->make(true);
        }
        return view('admin.appointment.category.index', compact('title'));
    }

    public function create()
    {
        $action = 'Create';
        $title = 'Appointment Service Category';
        $categories = AppointmentServiceCategory::where('parent_id', 0)->get();
        return view('admin.appointment.category.category', compact('action', 'title', 'categories'));
    }

    public function edit($id)
    {
        $action = 'Edit';
        $title = 'Appointment Service Category';
        $record = AppointmentServiceCategory::find($id);
        $categories = AppointmentServiceCategory::where('parent_id', 0)->where('id', '<>', $id)->get();
        return view('admin.appointment.category.category', compact('action', 'title', 'record', 'categories'));
    }

    private function _form_validation($request)
    {
        // dd($request->all());
        $rules = [
            'name' => 'required',
            'parent_id' => 'nullable',
            'rank' => 'nullable',
            'description' => 'nullable',
            'image' => 'nullable'
        ];
        $messages = [
            'name.required' => 'Name is required',

        ];
        $request->validate($rules, $messages);

        $postData = array(
            'name' => $request->name,
            'parent_id' => isset($request->parent_id) ? $request->parent_id : 0,
            'rank' => isset($request->rank) ? $request->rank : 0,
            'description' => isset($request->description) ? $request->description : '',
            'active' => isset($request->active) ? $request->active : 0
        );

        return $postData;
    }

    public function store(Request $request)
    {
        $data = $this->_form_validation($request);
        $data['created_at'] = date('Y-m-d H:i:s');
        AppointmentServiceCategory::insertGetId($data);

        return redirect()->route('admin.appointment.categories')->with('success', 'Data submitted successfully');
    }

    public function update($id, Request $request)
    {
        $data = $this->_form_validation($request);
        $data['updated_at'] = date('Y-m-d H:i:s');
        AppointmentServiceCategory::where('id', $id)->update($data);

        return redirect()->route('admin.appointment.categories')->with('success', 'Data updated successfully');
    }

    public function updateActive(Request $request)
    {
        $id = $request->id;
        $active = ($request->value == 0) ? 1 : 0;
        AppointmentServiceCategory::where('id', $id)->update(['active' => $active]);
        $msg = 'Record has been deactivated';
        if ($active == 1) {
            $msg = 'Record has been activated';
        }
        return response()->json(['status' => true, 'msg' => $msg]);
    }

    public function destroy(Request $request)
    {
        $ids = $request->ids;
        $ids = explode(",", $ids);

        AppointmentServiceCategory::whereIn('id', $ids)->delete();
        if (count($ids) > 1) {
            $msg = "Records deleted successfully";
        } else {
            $msg = "Record deleted successfully";
        }
        $request->session()->put('success', $msg);
        return response(['status' => true, 'msg' => $msg]);
    }
}
