<?php

namespace App\Http\Controllers\Admin;

use Illuminate\Support\Str;
use App\Models\Brand;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\Validator;

class BrandController extends Controller
{
    public function index()
    {
        return view('admin.brand.index', [
            'data' => Brand::orderBy('updated_at','desc')->get(),
        ]);
    }

    public function create()
    {
        return view('admin.brand.add');
    }

    public function store(Request $request) {
        $validator = Validator::make($request->all(), [
            'name' => 'required|string|max:191|unique:App\Models\Brand,name',
            'alias' => 'nullable|string|max:191|unique:App\Models\Brand,alias',
            'image' => 'nullable|file|max:1024000|mimes:jpg,jpeg,png,webp',
            'active' => 'nullable|boolean',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $brand = new Brand;
        $brand->name = $request->name;
        $brand->alias = $request->alias ? $request->alias : Str::slug($request->name, '-');
        $brand->active = $request->active == NULL ? 0 : 1;

        if ($request->file('image') != NULL) {
            $image = $request->file('image');
            $uploadPath = "public/uploads/brand";
            $brand->image = $image->store($uploadPath);
        }

        $brand->save();

        session()->flash('message', 'Brand added successfully.');

        return to_route('admin.designers');
    }

    public function edit(Brand $brand)
    {
        if ($brand->image != NULL) {
            if (Storage::exists($brand->image)) {
                $brand->image = asset(Storage::url($brand->image));
            }
        }

        return view('admin.brand.edit', [
            'brand' => $brand,
        ]);
    }

    public function update(Request $request) {
        $validator = Validator::make($request->all(), [
            'name' => 'required|string|max:191|unique:App\Models\Brand,name,' . $request->id,
            'alias' => 'nullable|string|max:191|unique:App\Models\Brand,alias,' . $request->id,
            'image' => 'nullable|file|max:1024000|mimes:jpg,jpeg,png,webp',
            'active' => 'nullable|boolean',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $brand = Brand::where('id', $request->id)->first();
        $brand->name = $request->name;
        $brand->alias = $request->alias ? $request->alias : Str::slug($request->name, '-');
        $brand->active = $request->active == NULL ? 0 : 1;

        if ($request->file('image') != NULL) {
            $old_file = $brand->image;

            $image = $request->file('image');
            $uploadPath = "public/uploads/brand";
            $brand->image = $image->store($uploadPath);

            if ($old_file != NULL) {
                if (Storage::exists($old_file)) {
                    Storage::delete($old_file);
                }
            }
        }

        $brand->save();

        session()->flash('message', 'Brand details updated successfully.');

        return to_route('admin.designers');
    }

    public function delete(Brand $brand)
    {
        if ($brand->delete()) {
            echo 'done';
        }

        exit;
    }
}
