<?php
namespace App\Http\Controllers\Admin;

use Mail;
use Illuminate\Http\Request;
use App\Jobs\UpdateAspectRatios;
use Illuminate\Support\Facades\DB; 
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\Validator;

class CandidateController extends Controller
{   

    var $column_order = array(null,null, 'first_name','last_name','email','dob','mobile1','mobile2','address1','country','state','city','zipcode'); //set column field database for datatable orderable

    var $column_search = array('first_name','last_name','email','dob','mobile1','address1','country','state','city','zipcode'); //set column field database for datatable searchable

    var $order = array('user_id' => 'asc'); // default order
    
    
    public function __construct() {
        // $this->middleware('admin', ['except' => [
        //     'UpdateVideosAspectRatios'
        // ]]);
    }
    
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index($active=1)
    {
        return view("admin.candidates",compact('active'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $action = 'add';
        return view('admin.candidates-create',compact('action'));
    }

    private function _form_validation($request){
        $rules = [
            'first_name' => 'required',
            'last_name'     => 'required',
            'email'     => 'required',
            'mobile1'     => 'required',
            'dob'     => 'required',
            'gender' => 'required',
            'address1'     => 'required',
            'language'     => 'required',
            'country'     => 'required',
            'state'     => 'required',
            'city'     => 'required',
            //'zipcode'     => 'required',
        ];
        $messages = [
            'first_name.required' => 'You can\'t leave First Name field empty',
            'last_name.required'    => 'You can\'t leave Last Name field empty',
            'email.required'    => 'You can\'t leave Email field empty',
            'dob.required'    => 'You can\'t leave DOB field empty',
            'gender.required'    => 'You can\'t leave Gender field empty',
            'mobile1.required'    => 'You can\'t leave Mobile field empty',
            'address1.required'    => 'You can\'t leave Address field empty',
            'country.required'    => 'You can\'t leave Country field empty',
            'state.required'    => 'You can\'t leave State field empty',
            'city.required'    => 'You can\'t leave City field empty',
            'language.required'    => 'You can\'t leave Language field empty',
            //'zipcode.required'    => 'You can\'t leave Zipcode field empty',
        ]; 
        $type='C';
        $this->validate($request,$rules,$messages);
        $postData = array(
            'first_name' => $request->first_name,
            'last_name'     => $request->last_name,
            'username' => $request->first_name." ".$request->last_name,
            'email'     => $request->email,
            'dob'     => $request->dob,
            'gender' => $request->gender,
            'language' => implode(",",$request->language),
            'mobile1'     => $request->mobile1,
            'mobile2'     => $request->mobile2,
            'address1'     => $request->address1,
            'country'     => $request->country,
            'state'     => $request->state,
            'city'     => $request->city,
            //'zipcode'     => $request->zipcode,
            'user_type'     => $request->user_type,
            'active'     => $request->active,
            
        ); 
        return $postData;
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $data = $this->_form_validation($request); 
        DB::table('users')->insert($data);
        return redirect( config('app.admin_url').'/candidates')->with('success','Candidate details submitted successfully');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($active=1)
    {   
        $candidates = DB::table('users')
        ->select(DB::raw('user_id,first_name,last_name,email,mobile1,mobile2,address1,country,state,city,zipcode,user_type,language,active,can_move_abroad'))
        ->where('user_type','C')
        ->where('active',$active)
        ->orderBy('user_id','DESC')
        ->get();
        return view("admin.candidates",compact('candidates','active'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $action = 'edit';
        $candidate = DB::table('users')->select(DB::raw("*"))->where('user_id','=',$id)->first();
        $language = DB::table('languages')->select(DB::raw("*"))->get();
         //dd($candidate);
        return view('admin.candidates-create',compact('candidate','id','action','language'));
    }

    public function view($id)
    {
        $action = 'view';
        $candidate = DB::table('users')->select(DB::raw("*"))->where('user_id','=',$id)->first();
        $language = DB::table('languages')->select(DB::raw("*"))->get();
         //dd($candidate);
        return view('admin.candidates-create',compact('candidate','id','action','language'));
    }

    public function photos($action,$id)
    {   
        $photos_total_count = DB::table('posts')->select(DB::raw("*"))->where('user_id','=',$id)->where('type','P')->count();
        $photos = DB::table('posts')->select(DB::raw("*"))->where('user_id','=',$id)->where('type','P')->orderBy('post_id','desc')->limit(env('LIMIT'))->get();
         //dd($photos);
        return view('admin.candidates-photos',compact('photos','id','action','photos_total_count'));
    }

    public function loadMore(Request $request)
    {   
        $offset=$request->input('offset');
        $id=$request->input('id');
        $action = 'view';
        $imageUpload=env('AWS_URL')."photos/".$id."/";
        // '/../bollywood/public/assets/images/';
        $photos = DB::table('posts')->select(DB::raw("*"))->where('user_id','=',$id)->where('type','P')->orderBy('post_id','desc')->offset($offset)->limit(env('LIMIT'))->get();
        foreach($photos as $photo) {  
        echo  '<div class="col-md-3 inner_pics">';
        echo '<div class="photo_div">';
        echo  '<a data-fancybox="gallery" href="'.$imageUpload.$photo->file.'"><img src="'.$imageUpload.$photo->file.'" class="img-responsive img-fluid m-b-10"></a>';
        echo  '</div>';
        echo  '</div>';
            }
    }

    public function loadMoreVideos(Request $request)
    {   
        $offset=$request->input('offset');
        $id=$request->input('id');
        $action = 'view';
        $videoUpload=env('AWS_URL')."videos/".$id."/";
        $videos = DB::table('posts')->select(DB::raw("*"))->where('user_id','=',$id)->where('type','V')->orderBy('post_id','desc')->offset($offset)->limit(env('VIDEO_LIMIT'))->get();
        foreach($videos as $video) {  
        echo  '<div class="col-md-4 inner_video">';
        echo '<div class="video_div">';
        echo   '<video width="100%" height="100%" controls>';
        echo  '<source src="'.$videoUpload.$video->file.'" type="video/mp4">';
        echo  '</video>';
       // echo '<div class="title_heading">'.$video->title.'</div>';
        echo '</div>';
        echo '</div>';
            }
    }

    public function loadMoreAudios(Request $request)
    {   
        $offset=$request->input('offset');
        $id=$request->input('id');
        $action = 'view';
        $audioUpload='/../bollywood/public/assets/audios/';
        $audios = DB::table('user_audios')->select(DB::raw("*"))->where('user_id','=',$id)->orderBy('post_id','desc')->offset($offset)->limit(env('LIMIT'))->get();
        foreach($audios as $audio) {  
        echo  '<div class="col-md-4 align-center">';
        echo   '<audio width="100%" height="auto" controls>';
        echo  '<source src="'.$audioUpload.$audio->audio.'" type="audio/mpeg">';
        echo  '</audio>';
        echo '<div class="title_heading">'.$audio->title.'</div>';
        echo '</div>';
            }
    }

    public function videos($action,$id)
    {
        $videos_total_count = DB::table('posts')->select(DB::raw("*"))->where('user_id','=',$id)->count();
        $videos = DB::table('posts')->select(DB::raw("*"))->where('user_id','=',$id)->where('type','V')->orderBy('post_id','desc')->limit(env('VIDEO_LIMIT'))->get();
         //dd($candidate);
        return view('admin.candidates-videos',compact('videos','id','action','videos_total_count'));
    }

    public function audios($action,$id)
    {
        $audios_total_count = DB::table('user_audios')->select(DB::raw("*"))->where('user_id','=',$id)->count();
        $audios = DB::table('user_audios')->select(DB::raw("*"))->where('user_id','=',$id)->limit(env('VIDEO_LIMIT'))->get();
         //dd($candidate);
        return view('admin.candidates-audios',compact('audios','id','action','audios_total_count'));
    }

    public function documents($action,$id)
    {
        $documents = DB::table('users')->select(DB::raw("*"))->where('user_id','=',$id)->first();
         //dd($candidate);
        return view('admin.candidates-documents',compact('documents','id','action'));
    }

    
    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $data = $this->_form_validation($request);
        DB::table('users')->where('user_id',$id)->update($data);
        return redirect( env('ADMIN_URL').'/candidates')->with('success','Candidate details updated successfully');
    }

    public function inactive($id)
    {   
        DB::table('users')->where('user_id',$id)->update(array('active' => '0'));
        return redirect( env('ADMIN_URL').'/candidates')->with('success','Candidate Inactivated');
    }

    public function active($id)
    {   
        $users = DB::table('users')->select(DB::raw("username,email"))->where('user_id','=',$id)->first();
        $mailBody ='<b>Dear,'.$users->username.'<b><br /> <br />
        We have reviewed your account. We are happy to announce that your account is active now. You can login in your account and post your Pictures, Videos, Audios. Your profile is now searchable by producers waiting to hire new candidates.<br /><br />
        BEST OF LUCK WITH YOUR DREAMS<br />< br/>
        Thanks <br />'.env('COMPANY_NAME');
        $array = array('subject'=>'Hurrey! You account is active at Films Dream','view'=>'emails.email','body' => $mailBody);
           Mail::to($users->email)->send(new SendMail($array)); 
        DB::table('users')->where('user_id',$id)->update(array('active' => '1'));
        return redirect( env('ADMIN_URL').'/candidates')->with('success','Candidate Activated');
    }

    public function changePassword($id)
    {   
        $action="changePassword";
        $users = DB::table('users')->select(DB::raw("*"))->where('user_id','=',$id)->first();
         //dd($candidate);
        return view('admin.candidates-changePassword',compact('user','id'));
    }

    public function updatePassword(Request $request,$id)
    {   
        $rules = [
            'password' => 'required',
            'confirm_password' => 'required|same:password',

            
        ];
        $messages = [
            'password.required' => 'You can\'t leave Password field empty',
            'confirm_password.required'    => 'You can\'t leave Confirm Password field empty',
           
        ]; 
        $this->validate($request,$rules,$messages);
        
        $password=Hash::make($request->password);
       
        DB::table('users')->where('user_id',$id)->update(array('password' => $password));
        return redirect( env('ADMIN_URL').'/candidates')->with('success','Candidate Password updated successfully');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }
    public function serverProcessing(Request $request)
    {
        $currentPath = url(config('app.admin_url')).'/candidates/';

        $list = $this->get_datatables($request);

        $data = array();
        $no = $request->start;
        foreach ($list as $candidates) {
            $no++;
            $row = array();
            $row[] = '<a class="view" href="'.$currentPath.'view/'.$candidates->user_id.'"><i class="fa fa-search"></i></a><a class="edit" href="'.$currentPath.'edit/'.$candidates->user_id.'"><i class="fa fa-edit"></i></a><a class="delete deleteSelSingle" style="cursor:pointer;" data-val="'.$candidates->user_id.'"><i class="fa fa-trash"></i></a>';
            $row[] = '<div class="align-center"><input id="cb'.$no.'" name="key_m[]" class="delete_box blue-check" type="checkbox" data-val="'.$candidates->user_id.'"><label for="cb'.$no.'"></label></div>';
            $row[] = $candidates->username;
            // $row[] = $candidates->last_name;
            $row[] = $candidates->email;
            // $row[] = $candidates->dob;
            $row[] = $candidates->mobile1;
            $row[] = $candidates->address1;
            $row[] = $candidates->country;
            $row[] = $candidates->state;
            // $row[] = $candidates->city;
            //$row[] = $candidates->zipcode;
            if($candidates->active==1){
                $row[] = '<a class="btn btn-danger" href="'.$currentPath.'inactive/'.$candidates->user_id.'" onclick="return confirm(\'Are you sure ?\')">Inactive</a> <a href="'.$currentPath.'changePassword/'.$candidates->user_id.'" class="btn btn-primary">Change Password</a>';
            }else{
                $row[] = '<a class="btn btn-success" href="'.$currentPath.'active/'.$candidates->user_id.'" onclick="return confirm(\'Are you sure ?\')">Active</a> <a href="'.$currentPath.'changePassword/'.$candidates->user_id.'" class="btn btn-primary">Change Password</a>';
            }
           // $row[] = '<a href="#" data-toggle="modal" data-target="#modal1" class="btn btn-primary process" data-val="'.$candidates->user_id.'">Visible</a>';
            $data[] = $row;
        }

        $output = array(
            "draw" => $request->draw,
            "recordsTotal" => $this->count_all($request),
            "recordsFiltered" => $this->count_filtered($request),
            "data" => $data,
        );
        echo json_encode($output);
    }

    private function _get_datatables_query($request)
    {            
        $keyword = $request->search['value'];
        $order = $request->order;
        $candidateRS = DB::table('users')
        ->select(DB::raw("*"));
        
        $strWhere = "user_type='C' and active='".$request->active."'";
        $strWhereOr = "";
        $i = 0;

        foreach ($this->column_search as $item) // loop column
        {
            if($keyword) // if datatable send POST for search{
            	$strWhereOr = $strWhereOr." $item like '%".$keyword."%' or ";
                //$candidateRS = $candidateRS->orWhere($item, 'like', '%' . $keyword . '%') ;
        }
        $strWhereOr = trim($strWhereOr, "or ");
        if($strWhereOr!=""){
	        $candidateRS = $candidateRS->whereRaw(DB::raw($strWhere." and (".$strWhereOr.")"));
	    }else{
			$candidateRS = $candidateRS->whereRaw(DB::raw($strWhere	));
		}
        

        if(isset($order)) // here order processing
        {
            $candidateRS = $candidateRS->orderBy($this->column_order[$request->order['0']['column']], $request->order['0']['dir']);
        } 
        else if(isset($this->order))
        {
            $orderby = $this->order;
            $candidateRS = $candidateRS->orderBy(key($orderby),$orderby[key($orderby)]);
        }
        return $candidateRS;
    }

    function get_datatables($request)
    {
        $candidateRS = $this->_get_datatables_query($request);
        if($request->length != -1){
            $candidateRS = $candidateRS->limit($request->length);
            if($request->start != -1){
                $candidateRS = $candidateRS->offset($request->start);
            }
        }
        
        $candidates = $candidateRS->get();
        return $candidates;
    }

    function count_filtered($request)
    {
        $candidateRS = $this->_get_datatables_query($request);
        return $candidateRS->count();
    }

    public function count_all($request)
    {
        $candidateRS = DB::table('users')->select(DB::raw("count(*) as total"))->where('user_type','C')->where('active',$request->active)->first();
        return $candidateRS->total;
    }

    public function delete(Request $request){
        $rec_exists = array();
        $del_error = '';
        $ids = explode(',',$request->ids);
        foreach ($ids as $id) {
            DB::table('users')->where('user_id', $id)->delete();
        }
        
        if($del_error == 'error'){
            $request->session()->put('error',$msg );
            return response()->json(['status' => 'error',"rec_exists"=>$rec_exists]);
        }else{
            if( count($ids) > 1){
                $msg = "Candidate deleted successfully";
            }else{
                $msg = "Candidate deleted successfully";
            }
            $request->session()->put('success', $msg);
            return response()->json(['status' => 'success',"rec_exists"=>$rec_exists]);
        }
    }

    public function copyContent($id)
    {
        $action = 'copy';
        $candidate = DB::table('users')->select(DB::raw("*"))->where('user_id','=',$id)->first();
        // dd($category);
        return view('admin.candidates-create',compact('id','candidate','action'));
    
    }

    public function UpdateVideosAspectRatios(){
        ini_set('max_execution_time', 0);
        ini_set('memory_limit', '18048M');
        $storage_path=config('app.filesystem_driver');
        $posts = DB::table("posts")->select(DB::raw("post_id,user_id,file,type"))->where('aspect_ratio',0)->orderBy('post_id','desc')->get();
        foreach($posts as $post){
            if($post->type=="V"){
                $postPath = 'videos/'.$post->user_id;
            }else{
                $postPath = 'photos/'.$post->user_id;
            }
            $file_path= $postPath.'/'. $post->file;
            $currentVideo = array(
                'disk'         => $storage_path,
                'path'         => $file_path,
                'post_id'      => $post->post_id,
                'type'         => $post->type,
                'user_id'      => $post->user_id
            );
            echo $file_path."<br/>";
            echo asset(Storage::url($file_path))."<br/>";
            UpdateAspectRatios::dispatch($currentVideo);
            echo $post->post_id."<br/>";
        }
        // return redirect()->back();
    }

    
}
