<?php
namespace App\Http\Controllers\Admin;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Facades\DB; 
use Mail;

class CategoryController extends Controller
{   

     var $column_order = array(null,null, 'category','rank'); //set column field database for datatable orderable

    var $column_search = array('category'); //set column field database for datatable searchable

    var $order = array('cat_id' => 'asc'); // default order

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index($type='C')
    {
        return view("admin.categories",compact('type'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create($type='C')
    {
        $action = 'add';
        return view('admin.categories-create',compact('action','type'));
    }

    private function _form_validation($request){
        $rules = [
            'category' => 'required',
            'rank'     => 'required',
            'type' => 'required'
        ];
        $messages = [
            'category.required' => 'You can\'t leave category field empty',
            'rank.required'    => 'You can\'t leave rank field empty',
            'type.required'    => 'You can\'t leave type field empty',
        ]; 
        $this->validate($request,$rules,$messages);
        $postData = array(
            'category' => $request->category,
            'rank'     => $request->rank,
            'type'     => $request->type
        ); 
        return $postData;
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $data = $this->_form_validation($request); 
        DB::table('categories')->insert($data);
        return redirect( config('app.admin_url').'/categories')->with('success','Category details submitted successfully');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($type='C')
    {   
        $categories = DB::table('categories')
        ->select(DB::raw('cat_id,category'))
        ->where('type',$type)
        ->orderBy('cat_id','DESC')
        ->orderBy('rank','DESC')
        ->get();
        return view("admin.categories",compact('categories','type'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id,$type='C')
    {
        $action = 'edit';
        $category = DB::table('categories')->select(DB::raw("*"))->where('cat_id','=',$id)->first();
        return view('admin.categories-create',compact('category','id','action','type'));
    }

    public function view($id,$type='C')
    {
        $action = 'view';
        $category = DB::table('categories')->select(DB::raw("*"))->where('cat_id','=',$id)->first();
                 //dd($candidate);
        return view('admin.categories-create',compact('category','id','action','type'));
    }

   
    
    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $data = $this->_form_validation($request);
        DB::table('categories')->where('cat_id',$id)->update($data);
        return redirect( env('ADMIN_URL').'/categories')->with('success','categorie details updated successfully');
    }

  
    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
   
     public function serverProcessing(Request $request)
    {
        $currentPath = url(config('app.admin_url')).'/categories/';

        $list = $this->get_datatables($request);
		
        $data = array();
        $no = $request->start;
        foreach ($list as $category) {
            $no++;
            $row = array();
            $row[] = '<a class="view" href="'.$currentPath.$category->cat_id.'/'.$category->type.'/'.'view"><i class="fa fa-search"></i></a><a class="edit" href="'.$currentPath.$category->cat_id.'/'.$category->type.'/edit"><i class="fa fa-edit"></i></a><a class="copy" href="'.$currentPath.$category->cat_id.'/'.$category->type.'/copy"><i class="fa fa-copy"></i></a><a class="delete deleteSelSingle" style="cursor:pointer;" data-val="'.$category->cat_id.'"><i class="fa fa-trash"></i></a>';
            $row[] = '<div class="align-center"><input id="cb'.$no.'" name="key_m[]" class="delete_box blue-check" type="checkbox" data-val="'.$category->cat_id.'"><label for="cb'.$no.'"></label></div>';
            $row[] = $category->category;
            $row[] = $category->rank;
            
            $row[] = '<a href="#" data-toggle="modal" data-target="#modal1" class="btn btn-primary process" data-val="'.$category->cat_id.'">Visible</a>';
            $data[] = $row;
        }

        $output = array(
            "draw" => $request->draw,
            "recordsTotal" => $this->count_all($request),
            "recordsFiltered" => $this->count_filtered($request),
            "data" => $data,
        );
        echo json_encode($output);
    }

	private function _get_datatables_query($request)
    {            
        $keyword = $request->search['value'];
        $order = $request->order;
        $candidateRS = DB::table('categories')
        ->select(DB::raw("*"));
        
        $strWhere = "type='".$request->type."'";
        $strWhereOr = "";
        $i = 0;

        foreach ($this->column_search as $item) // loop column
        {
            if($keyword) // if datatable send POST for search{
            	$strWhereOr = $strWhereOr." $item like '%".$keyword."%' or ";
                //$candidateRS = $candidateRS->orWhere($item, 'like', '%' . $keyword . '%') ;
        }
        $strWhereOr = trim($strWhereOr, "or ");
        if($strWhereOr!=""){
	        $candidateRS = $candidateRS->whereRaw(DB::raw($strWhere." and (".$strWhereOr.")"));
	    }else{
			$candidateRS = $candidateRS->whereRaw(DB::raw($strWhere	));
		}
        

        if(isset($order)) // here order processing
        {
            $candidateRS = $candidateRS->orderBy($this->column_order[$request->order['0']['column']], $request->order['0']['dir']);
        } 
        else if(isset($this->order))
        {
            $orderby = $this->order;
            $candidateRS = $candidateRS->orderBy(key($orderby),$orderby[key($orderby)]);
        }
        return $candidateRS;
    }
    
  

    function get_datatables($request)
    {
        $categoryRS = $this->_get_datatables_query($request);
        if($request->length != -1){
            $categoryRS = $categoryRS->limit($request->length);
            if($request->start != -1){
                $categoryRS = $categoryRS->offset($request->start);
            }
        }
        
        $categories = $categoryRS->get();
        return $categories;
    }

    function count_filtered($request)
    {
        $categoryRS = $this->_get_datatables_query($request);
        return $categoryRS->count();
    }

    public function count_all($request)
    {
        $categoryRS = DB::table('categories')->select(DB::raw("count(*) as total"))->where('type',$request->type)->first();
        return $categoryRS->total;
    }

    public function delete(Request $request){
        $rec_exists = array();
        $del_error = '';
        $ids = explode(',',$request->ids);
        foreach ($ids as $id) {
            DB::table('categories')->where('cat_id', $id)->delete();
        }
        
        if($del_error == 'error'){
            $request->session()->put('error',$msg );
            return response()->json(['status' => 'error',"rec_exists"=>$rec_exists]);
        }else{
            if( count($ids) > 1){
                $msg = "Category deleted successfully";
            }else{
                $msg = "Category deleted successfully";
            }
            $request->session()->put('success', $msg);
            return response()->json(['status' => 'success',"rec_exists"=>$rec_exists]);
        }
        return redirect()->back();
    }

    public function copyContent($id,$type='C')
    {
        $action = 'copy';
        $category = DB::table('categories')->select(DB::raw("*"))->where('cat_id','=',$id)->first();
        // dd($category);
        return view('admin.categories-create',compact('id','category','action','type'));
    }
}
