<?php

namespace App\Http\Controllers\Admin;

use Mail;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\Validator;

class ChallengeVideosController extends Controller
{

    var $column_order = array(null, 'challenge_name', 'username', 'file', 'created_at'); //set column field database for datatable orderable

    var $column_search = array('c.title', 'u.username', 'p.file', 'p.created_at'); //set column field database for datatable searchable

    // var $order = array('total' => 'desc'); // default order

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index($id)
    {
        $challenge = DB::table('challenges')->find($id);
        return view("admin.challenge_videos.index", compact('id', 'challenge'));
    }


    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */

    public function serverProcessing(Request $request, $id)
    {
        $currentPath = url(config('app.admin_url')) . '/challenge-videos/' . $id;

        $list = $this->get_datatables($request, $id);

        $data = array();
        $no = $request->start;
        foreach ($list as $category) {
            $no++;
            $row = array();
            if ($category->challenge_approved == 0) {
            $row[] = '<a class="btn btn-sm btn-primary text-light approve" data-val="' . $category->post_id . '" >Approve</a>';
            }else{
                $row[] = '<a class="btn btn-sm btn-primary text-light disapprove" data-val="' . $category->post_id . '" >Disapprove</a>';
            }
            // $row[] = '<div class="align-center"><input id="cb' . $no . '" name="key_m[]" class="delete_box blue-check" type="checkbox" data-val="' . $category->post_id . '"><label for="cb' . $no . '"></label></div>';
            $row[] = $category->challenge_name;
            $row[] = $category->username;
            // $row[] = $category->file;
            $html = "<i class='fa fa-play-circle-o video_play' aria-hidden='true'></i>";
            $row[] = "<div style='position:relative;text-align:center;'>" . $html . "<img src=" . $category->thumb . " height=200 data-toggle='modal' data-target='#homeVideo' class='video_thumb' id='" . $category->file . "'/></div>";

            $status = '<span class="badge badge-success">Approved</span>';
            if ($category->challenge_approved == 0) {
                $status = '<span class="badge badge-danger">Disapproved</span>';
            }
            $row[] = $status;
            $row[] = $category->total;
            $row[] = ($category->position>0) ? $category->position : '-';

            // $row[] = '<a href="#" data-toggle="modal" data-target="#modal1" class="btn btn-primary process" data-val="' . $category->post_id . '">Visible</a>';
            $data[] = $row;
        }

        $output = array(
            "draw" => $request->draw,
            "recordsTotal" => $this->count_all($request, $id),
            "recordsFiltered" => $this->count_filtered($request, $id),
            "data" => $data,
        );
        echo json_encode($output);
             config()->set('database.connections.mysql.strict', true);
        DB::reconnect();
    }

    private function _get_datatables_query($request, $id)
    {
        config()->set('database.connections.mysql.strict', false);
        DB::reconnect();
        $keyword = $request->search['value'];
        $order = $request->order;
        // $candidateRS = DB::table('challenges')
        //     ->select(DB::raw("*,DATE_FORMAT(start_date, '%Y-%m-%d') as start_date,DATE_FORMAT(end_date, '%Y-%m-%d') as end_date"));
        $videoPath = Storage::url("videos");
        $candidateRS = 
        // DB::table('posts')
        //     ->select(DB::raw('posts.*,concat("' . $videoPath . '/",u.user_id,"/",posts.file) as file,
        //         concat("' . $videoPath . '/",u.user_id,"/thumb/",REPLACE(posts.file,".mp4",".jpg")) as thumb,
        //         posts.title as title,c.title as challenge_name,u.username as username'))
        //     ->where('posts.challenge_id', $id)
        //     ->join('challenges as c', 'c.id', 'posts.challenge_id')
        //     ->join('users as u', 'u.user_id', 'posts.user_id')
        //     ->where('posts.active', 1);


        DB::table('posts as p')
            ->select(DB::raw('p.post_id as post_id,
            concat("'.$videoPath.'/",u.user_id,"/",p.file) as file,
            concat("'.$videoPath.'/",u.user_id,"/thumb/",REPLACE(p.file,".mp4",".jpg")) as thumb,
            p.title as title,p.added_on as added_on,p.likes as likes,p.views as views,c.title as challenge_name,
                    p.comments as comments,p.shares as shares,p.type as type,p.challenge_approved,
                    u.user_id as user_id,u.username as username,
            CASE WHEN p.shares > 0 THEN p.shares * 4 ELSE 0 END AS total_shares,
            CASE WHEN p.likes > 0 THEN p.likes * 3 ELSE 0 END AS total_likes,
            CASE WHEN p.views > 0 THEN p.views * 2 ELSE 0 END AS total_views,
            CASE WHEN p.comments > 0 THEN p.comments * 1 ELSE 0 END AS total_comments,
            ((CASE WHEN count(DISTINCT ps.user_id) > 0 THEN count(DISTINCT ps.user_id) * 4 ELSE 0 END) +
            (CASE WHEN count(DISTINCT pl.user_id) > 0 THEN count(DISTINCT pl.user_id) * 2 ELSE 0 END) +
            (CASE WHEN count(DISTINCT pv.user_id) > 0 THEN count(DISTINCT pv.user_id) * 1 ELSE 0 END) +
            (CASE WHEN count(DISTINCT pc.user_id) > 0 THEN count(DISTINCT pc.user_id) * 3 ELSE 0 END)) as total,
             CASE WHEN cw.challenge_id IS NOT NULL THEN 1 ELSE 0 END AS is_winner,cw.position
            '))
            ->join('users as u','u.user_id','p.user_id')
            ->leftJoin('challenge_winners as cw', function ($q) {
                $q->on('cw.challenge_id', 'p.challenge_id');
                $q->on("cw.user_id", 'u.user_id');
            })
            ->join('challenges as c', 'c.id', 'p.challenge_id')
               ->leftJoin('post_comments as pc', function($q){
                    $q->on('pc.post_id', 'p.post_id');
                    $q->on("pc.comment_on",'<=','c.end_date');
                    // $q->groupBy('pc.user_id');
                })
    
                ->leftJoin('post_shares as ps', function($q){
                    $q->on('ps.post_id', 'p.post_id');
                    $q->on("ps.share_on",'<=','c.end_date');
                    // $q->groupBy('ps.user_id');
                })
    
                ->leftJoin('post_likes as pl', function($q){
                    $q->on('pl.post_id', 'p.post_id');
                    $q->on("pl.like_on",'<=','c.end_date');
                    // $q->groupBy('pl.user_id');
                })
    
                ->leftJoin('post_views as pv', function($q){
                    $q->on('pv.post_id', 'p.post_id');
                    $q->on("pv.view_on",'<=','c.end_date');
                    // $q->groupBy('pv.user_id');
                })

            ->where('p.challenge_id',$id);
           

        $strWhere = "p.active = 1";
        $strWhereOr = "";
        $i = 0;

        foreach ($this->column_search as $item) // loop column
        {
            if ($keyword) // if datatable send POST for search{
                $strWhereOr = $strWhereOr . " $item like '%" . $keyword . "%' or ";
            //$candidateRS = $candidateRS->orWhere($item, 'like', '%' . $keyword . '%') ;
        }
        $strWhereOr = trim($strWhereOr, "or ");
        if ($strWhereOr != "") {
            $candidateRS = $candidateRS->whereRaw(DB::raw($strWhere . " and (" . $strWhereOr . ")"));
        } else {
            $candidateRS = $candidateRS->whereRaw(DB::raw($strWhere));
        }
        $candidateRS=$candidateRS->groupBy('p.post_id');
        // $candidateRS = $candidateRS->groupBy('p.post_id','u.user_id','p.file','p.title','p.added_on','p.likes','p.comments','p.shares','p.views','c.title','ps.post_id',
        // 'p.type','p.challenge_approved','u.username','pv.post_id','pc.post_id','pl.post_id');
        // if (isset($order)) // here order processing
        // {
        //     $candidateRS = $candidateRS->orderBy($this->column_order[$request->order['0']['column']], $request->order['0']['dir']);
        // } else if (isset($this->order)) {
        //     $orderby = $this->order;
        //     $candidateRS = $candidateRS->orderBy(key($orderby), $orderby[key($orderby)]);
        // }
        $candidateRS = $candidateRS->orderBy(DB::raw("(CASE WHEN cw.challenge_id IS NOT NULL THEN 1 ELSE 0 END )"),'desc')
                ->orderBy('cw.position', 'asc');
                $candidateRS = $candidateRS->orderBy(DB::raw("  ((CASE WHEN count(DISTINCT ps.user_id) > 0 THEN count(DISTINCT ps.user_id) * 4 ELSE 0 END) +
            (CASE WHEN count(DISTINCT pl.user_id) > 0 THEN count(DISTINCT pl.user_id) * 2 ELSE 0 END) +
            (CASE WHEN count(DISTINCT pv.user_id) > 0 THEN count(DISTINCT pv.user_id) * 1 ELSE 0 END) +
            (CASE WHEN count(DISTINCT pc.user_id) > 0 THEN count(DISTINCT pc.user_id) * 3 ELSE 0 END))"),'desc');
        // dd($candidateRS->get());
        return $candidateRS;
    }



    function get_datatables($request, $id)
    {
        $categoryRS = $this->_get_datatables_query($request, $id);
        if ($request->length != -1) {
            $categoryRS = $categoryRS->limit($request->length);
            if ($request->start != -1) {
                $categoryRS = $categoryRS->offset($request->start);
            }
        }

        $categories = $categoryRS->get();
        return $categories;
    }

    function count_filtered($request, $id)
    {
        $categoryRS = $this->_get_datatables_query($request, $id);
        return $categoryRS->get()->count();
    }

    public function count_all($request,$id)
    {
        $categoryRS = DB::table('posts')->select(DB::raw("count(*) as total"))
        ->where('challenge_id',$id)->first();
        return $categoryRS->total;
    }

    public function disapprove(Request $request)
    {
        $ids = explode(',', $request->ids);
        foreach ($ids as $id) {
            DB::table('posts')->where('post_id', $id)->update(['challenge_approved' => 0]);
        }
            $msg = "Post disapproved!";
        
        $request->session()->put('success', $msg);
        return response()->json(['status' => 'success']);
    }

    public function approve(Request $request)
    {
        $ids = explode(',', $request->ids);
        foreach ($ids as $id) {
            DB::table('posts')->where('post_id', $id)->update(['challenge_approved' => 1]);
        }
            $msg = "Post approved!";
        
        $request->session()->put('success', $msg);
        return response()->json(['status' => 'success']);
    }

    public function copyContent($id)
    {
        $action = 'copy';
        $challenge = DB::table('challenges')->select(DB::raw("*"))->where('id', '=', $id)->first();
        // dd($category);
        return view('admin.challenges-create', compact('id', 'challenge', 'action', 'type'));
    }
}
