<?php

namespace App\Http\Controllers\Admin;

use Mail;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Hash;
use App\Notifications\UserNotification;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\Validator;
use Notification;

class ChallengesController extends Controller
{

    var $column_order = array(null, null, 'title', 'start_date', 'end_date', 'created_at'); //set column field database for datatable orderable

    var $column_search = array('title', 'start_date', 'end_date'); //set column field database for datatable searchable

    var $order = array('id' => 'asc'); // default order

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        return view("admin.challenges.index");
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $action = 'add';
        $categories = DB::table('categories')->orderBy('category', 'asc')->get();
        return view('admin.challenges.create', compact('action', 'categories'));
    }

    private function _form_validation($request)
    {
        // dd($request->all());
        $rules = [
            'title' => 'required',
            'cat_ids'     => 'required',
            'description' => 'required',
            'start_date' => 'required',
            'end_date' => 'required',
            'min_required_users' => 'required',
            'file' => 'mimes:mp4,jpg,jpeg'
        ];
        $messages = [
            'title.required' => 'You can\'t leave title field empty',
            'cat_ids.required'    => 'You can\'t leave categories field empty',
            'description.required'    => 'You can\'t leave description field empty',
            'start_date.required'    => 'You can\'t leave start date field empty',
            'end_date.required'    => 'You can\'t leave end date field empty',
            'min_required_users.required'    => 'You can\'t leave Min required users field empty',
        ];
        $this->validate($request, $rules, $messages);
        $cat_ids = '';
        if (count($request->cat_ids) > 0) {
            $cat_ids = implode(',', $request->cat_ids);
        }

        $countries = '';
        if (isset($request->countries) && count($request->countries) > 0) {
            $countries = implode(',', $request->countries);
        }

        $postData = array(
            'title'         => $request->title,
            'cat_ids'       => $cat_ids,
            'countries'     => $countries,
            'description'   => $request->description,
            'terms'         => isset($request->terms) ? $request->terms : '',
            'start_date'    => date('Y-m-d H:i:s', strtotime($request->start_date)),
            'end_date'      => date('Y-m-d H:i:s', strtotime($request->end_date)),
            'min_required_users'      => $request->min_required_users,
            'active'     => isset($request->active) ? $request->active : 0,
        );

        if ($request->hasFile('file')) {
            $path = 'challenges';
            $ext = $request->file('file')->getClientOriginalExtension();
            $filenametostore = $request->file('file')->store($path);
            Storage::setVisibility($filenametostore, 'public');
            $fileArray = explode('/', $filenametostore);
            $image = array_pop($fileArray);
            $postData['file'] = $image;
            if ($ext == 'mp4') {
                $type = 'V';
            } else {
                $type = 'I';
            }
            $postData['file_type'] = $type;
        }

        if (isset($request->price)) {
            $postData['price'] = $request->price;
        }

        if (isset($request->first_price)) {
            $postData['first_price'] = $request->first_price;
        }
        if (isset($request->second_price)) {
            $postData['second_price'] = $request->second_price;
        }
        if (isset($request->third_price)) {
            $postData['third_price'] = $request->third_price;
        }
        return $postData;
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $data = $this->_form_validation($request);

        $title = str_replace(' ', '',  $data['title']);
        $tag = $title;


        while (DB::table("challenges")->select("tag")->where("tag", $tag)->first()) {
            $cat_ids = 0;
            if (count($request->cat_ids) > 0) {
                $cat_ids = $request->cat_ids[0];
            }
            $tag = $title . $cat_ids;
        }

        $data['tag'] = $tag;
        $data['created_at'] = date('Y-m-d H:i:s');
        $data['updated_at'] = date('Y-m-d H:i:s');
        DB::table('challenges')->insert($data);
        return redirect(config('app.admin_url') . '/challenges')->with('success', 'Challenge details submitted successfully');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show()
    {
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $action = 'edit';
        $categories = DB::table('categories')->orderBy('category', 'asc')->get();
        $challenge = DB::table('challenges')->select(DB::raw("*"))->where('id', $id)->first();
        return view('admin.challenges.create', compact('challenge', 'id', 'action', 'categories'));
    }

    public function view($id)
    {
        $action = 'view';
        $challenge = DB::table('challenges')->select(DB::raw("*"))->where('id', $id)->first();
        $categories = DB::table('categories')->orderBy('category', 'asc')->get();
        //dd($candidate);
        return view('admin.challenges.create', compact('challenge', 'id', 'action', 'categories'));
    }


    // get Countries
    public function getCountries(Request $request)
    {
        $search = $request->searchTerm;
        $countries = DB::table('countries')->where('country_id', '<>', 0);

        if ($search != '') {
            $countries = $countries->where('country', 'like', '%' . $search . '%');
        }
        $countries = $countries->limit(5)->get();
        $response = array(); // select2 wants id and text so we declare $response array otherwise no need

        foreach ($countries as $country) {
            $response[] = array(
                "id" => $country->country,
                "text" => $country->country
            );
        }
        return response()->json($response);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $data = $this->_form_validation($request);
        $title = str_replace(' ', '',  $data['title']);
        $tag = $title;

        while (DB::table("challenges")->select("tag")->where("tag", $tag)->first()) {
            $cat_ids = 0;
            if (count($request->cat_ids) > 0) {
                $cat_ids = $request->cat_ids[0];
            }
            $tag = $title . $cat_ids;
        }

        $data['tag'] = $tag;
        $data['updated_at'] = date('Y-m-d H:i:s');
        DB::table('challenges')->where('id', $id)->update($data);
        return redirect(config('app.admin_url') . '/challenges')->with('success', 'Challenge details updated successfully');
    }


    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */

    public function serverProcessing(Request $request)
    {
        $currentPath = url(config('app.admin_url')) . '/challenges/';
        $currentChallengePath = url(config('app.admin_url')) . '/challenge-videos/';

        $list = $this->get_datatables($request);

        $data = array();
        $no = $request->start;
        foreach ($list as $category) {
            $no++;
            $row = array();
            $row[] = '<a class="view" href="' . $currentPath . $category->id . '/' . 'view"><i class="fa fa-search"></i></a><a class="edit" href="' . $currentPath . $category->id . '/edit"><i class="fa fa-edit"></i></a> <a class="delete deleteSelSingle" style="cursor:pointer;" data-val="' . $category->id . '"><i class="fa fa-trash"></i></a>';
            $row[] = '<div class="align-center"><input id="cb' . $no . '" name="key_m[]" class="delete_box blue-check" type="checkbox" data-val="' . $category->id . '"><label for="cb' . $no . '"></label></div>';
            $row[] = $category->title;
            $row[] = $category->price;
            $row[] = $category->start_date;
            $row[] = $category->end_date;
            $row[] = $category->created_at;
            // 0:no, 1:yes, 2:canceled	
            $status = '';
            if ($category->result_declared == 0) {
                $status = 'Pending';
            } else if ($category->result_declared == 1) {
                $status = 'Declared';
            } else if ($category->result_declared == 2) {
                $status = 'Canceled';
            }

            if ($category->tie == 2 && $category->result_declared == 0) {
                $status = 'Tied';
            }
            $row[] = $status;

            $btn = '';
            if ($category->tie == 2  && $category->result_declared == 0) {
                $btn = ' <a class="videos btn btn-primary" href="' . route('admin.challenges_announce_result', $category->id) . '">Announce Result</a> ';
            }
            $btn .= ' <a class="videos btn btn-primary" href="' . $currentChallengePath . $category->id . '">Detail</a> ';
            $row[] = $btn;
            $data[] = $row;
        }

        $output = array(
            "draw" => $request->draw,
            "recordsTotal" => $this->count_all($request),
            "recordsFiltered" => $this->count_filtered($request),
            "data" => $data,
        );
        echo json_encode($output);
    }

    private function _get_datatables_query($request)
    {
        $keyword = $request->search['value'];
        $order = $request->order;
        $candidateRS = DB::table('challenges')
            ->select(DB::raw("*,DATE_FORMAT(start_date, '%Y-%m-%d') as start_date,DATE_FORMAT(end_date, '%Y-%m-%d') as end_date"));

        $strWhere = "id > 0";
        $strWhereOr = "";
        $i = 0;

        foreach ($this->column_search as $item) // loop column
        {
            if ($keyword) // if datatable send POST for search{
                $strWhereOr = $strWhereOr . " $item like '%" . $keyword . "%' or ";
            //$candidateRS = $candidateRS->orWhere($item, 'like', '%' . $keyword . '%') ;
        }
        $strWhereOr = trim($strWhereOr, "or ");
        if ($strWhereOr != "") {
            $candidateRS = $candidateRS->whereRaw(DB::raw($strWhere . " and (" . $strWhereOr . ")"));
        } else {
            $candidateRS = $candidateRS->whereRaw(DB::raw($strWhere));
        }


        if (isset($order)) // here order processing
        {
            $candidateRS = $candidateRS->orderBy($this->column_order[$request->order['0']['column']], $request->order['0']['dir']);
        } else if (isset($this->order)) {
            $orderby = $this->order;
            $candidateRS = $candidateRS->orderBy(key($orderby), $orderby[key($orderby)]);
        }
        return $candidateRS;
    }

    function get_datatables($request)
    {
        $categoryRS = $this->_get_datatables_query($request);
        if ($request->length != -1) {
            $categoryRS = $categoryRS->limit($request->length);
            if ($request->start != -1) {
                $categoryRS = $categoryRS->offset($request->start);
            }
        }

        $categories = $categoryRS->get();
        return $categories;
    }

    function count_filtered($request)
    {
        $categoryRS = $this->_get_datatables_query($request);
        return $categoryRS->count();
    }

    public function count_all($request)
    {
        $categoryRS = DB::table('challenges')->select(DB::raw("count(*) as total"))->first();
        return $categoryRS->total;
    }

    public function announceResult(Request $request, $id)
    {
        config()->set('database.connections.mysql.strict', false);
        DB::reconnect();
        $videoPath = Storage::url("videos");
        $posts = DB::table('posts as p')
            ->select(DB::raw('p.post_id as post_id,
            concat("' . $videoPath . '/",u.user_id,"/",p.file) as file,0 as position,
            concat("' . $videoPath . '/",u.user_id,"/thumb/",REPLACE(p.file,".mp4",".jpg")) as thumb,
            p.title as title,p.added_on as added_on,p.likes as likes,p.views as views,c.title as challenge_name,
                    p.comments as comments,p.shares as shares,p.type as type,p.challenge_approved,
                    u.user_id as user_id,u.username as username,
            CASE WHEN p.shares > 0 THEN p.shares * 4 ELSE 0 END AS total_shares,
            CASE WHEN p.likes > 0 THEN p.likes * 3 ELSE 0 END AS total_likes,
            CASE WHEN p.views > 0 THEN p.views * 2 ELSE 0 END AS total_views,
            CASE WHEN p.comments > 0 THEN p.comments * 1 ELSE 0 END AS total_comments,
            ((CASE WHEN count(DISTINCT ps.user_id) > 0 THEN count(DISTINCT ps.user_id) * 4 ELSE 0 END) +
            (CASE WHEN count(DISTINCT pl.user_id) > 0 THEN count(DISTINCT pl.user_id) * 2 ELSE 0 END) +
            (CASE WHEN count(DISTINCT pv.user_id) > 0 THEN count(DISTINCT pv.user_id) * 1 ELSE 0 END) +
            (CASE WHEN count(DISTINCT pc.user_id) > 0 THEN count(DISTINCT pc.user_id) * 3 ELSE 0 END)) as total
            '))
            ->join('users as u', 'u.user_id', 'p.user_id')
            ->join('challenges as c', 'c.id', 'p.challenge_id')
            ->leftJoin('post_comments as pc', function ($q) {
                $q->on('pc.post_id', 'p.post_id');
                $q->on("pc.comment_on", '<=', 'c.end_date');
                // $q->groupBy('pc.user_id');
            })

            ->leftJoin('post_shares as ps', function ($q) {
                $q->on('ps.post_id', 'p.post_id');
                $q->on("ps.share_on", '<=', 'c.end_date');
                // $q->groupBy('ps.user_id');
            })

            ->leftJoin('post_likes as pl', function ($q) {
                $q->on('pl.post_id', 'p.post_id');
                $q->on("pl.like_on", '<=', 'c.end_date');
                // $q->groupBy('pl.user_id');
            })

            ->leftJoin('post_views as pv', function ($q) {
                $q->on('pv.post_id', 'p.post_id');
                $q->on("pv.view_on", '<=', 'c.end_date');
                // $q->groupBy('pv.user_id');
            })

            ->where('p.challenge_id', $id)
            ->where('p.active', 1)
            ->groupBy('p.post_id')
            ->orderBy(DB::raw("  ((CASE WHEN count(DISTINCT ps.user_id) > 0 THEN count(DISTINCT ps.user_id) * 4 ELSE 0 END) +
            (CASE WHEN count(DISTINCT pl.user_id) > 0 THEN count(DISTINCT pl.user_id) * 2 ELSE 0 END) +
            (CASE WHEN count(DISTINCT pv.user_id) > 0 THEN count(DISTINCT pv.user_id) * 1 ELSE 0 END) +
            (CASE WHEN count(DISTINCT pc.user_id) > 0 THEN count(DISTINCT pc.user_id) * 3 ELSE 0 END))"), 'desc');
        $records = $posts->get();
        // dd($posts);
        $ranks = array_unique($posts->pluck('total')->toArray());
        $firstRank = isset($ranks[0]) ? $ranks[0] : 0;
        $secondRank = isset($ranks[1]) ? $ranks[1] : 0;
        $thirdRank = isset($ranks[2]) ? $ranks[2] : 0;
        // $firstRank=
        $first = $records->where('total', $firstRank);
        // dd($first->count());
        config()->set('database.connections.mysql.strict', true);
        DB::reconnect();
        $result = [];
        $totalFirst = $first->count();

        $x = 0;
        if ($totalFirst > 0) {
            $pos = 0;
            if ($totalFirst == 1) {
                $pos = 1;
            }
            foreach ($first as $key => $val) {
                if (isset($records[$key]) && $x < $totalFirst) {
                    $item = $records[$key];
                    $item->position = $pos;
                    $result[] = $item;
                }
                $x++;
            }
        }

        // if ($totalFirst > 0 && $totalFirst <= 3) {
        //     $pos = 0;
        //     if ($totalFirst == 1) {
        //         $pos = 1;
        //     }
        //     for ($x = 0; $x < 3; $x++) {
        //         if (isset($first[$x])) {
        //             $item = $first[$x];
        //             $item->position = $pos;
        //             $result[] = $item;
        //         }
        //     }
        // }

        $totalRecord = count($result);
        if ($totalRecord < 3) {
            $second = $records->where('total', $secondRank);
            $totalSecond = $second->count();

            $x = 0;
            if ($totalSecond > 0) {
                $pos = 0;
                if ($totalSecond == 1) {
                    $pos = 2;
                }
                foreach ($second as $key => $val) {
                    if (isset($records[$key]) && $x < $totalSecond) {
                        $item = $records[$key];
                        $item->position = $pos;
                        $result[] = $item;
                    }
                    $x++;
                }
            }

            // if ($totalSecond > 0 && $totalSecond <= 2) {
            //     $pos = 0;
            //     if ($totalSecond == 1 && $totalRecord == 1) {
            //         $pos = 2;
            //     }
            //     for ($x = 0; $x < 2; $x++) {
            //         if (isset($second[$x])) {
            //             $item = $second[$x];
            //             $item->position = $pos;
            //             $result[] = $item;
            //         }
            //     }
            // }
        }

        $totalRecord = count($result);
        if ($totalRecord < 3) {
            $third = $records->where('total', $thirdRank);
            $totalThird = $third->count();
            $x = 0;
            if ($totalThird > 0) {
                $pos = 0;
                if ($totalThird == 1) {
                    $pos = 3;
                }
                foreach ($third as $key => $val) {
                    if (isset($records[$key]) && $x < $totalThird) {
                        $item = $records[$key];
                        $item->position = $pos;
                        $result[] = $item;
                    }
                    $x++;
                }
            }
            // if ($totalThird > 0) {
            //     $pos = 0;
            //     if ($totalThird == 1) {
            //         $pos = 3;
            //     }
            //     for ($x = 0; $x < $totalThird; $x++) {
            //         dd($third);
            //         if (isset($third[$x])) {
            //             $item = $third[$x];
            //             $item->position = $pos;
            //             $result[] = $item;
            //         }
            //     }
            // }
        }

        $records = collect($result);
        $challenge = DB::table('challenges')->find($id);
        return view('admin.challenges.announce-result', ['records' => $records, 'challenge' => $challenge]);
    }

    public function announcedResultSubmit(Request $request, $id)
    {
        $challenge = DB::table('challenges')->find($id);
        $price[0] = $challenge->first_price;
        $price[1] = $challenge->second_price;
        $price[2] = $challenge->third_price;
        $posts = $request->post_id;
        $winner_data = [];
        for ($x = 0; $x < 3; $x++) {
            if (isset($posts[$x])) {
                $post = DB::table('posts')->where("post_id", $posts[$x])->first();

                $data1['user_id'] = $post->user_id;
                $data1['challenge_id'] = $id;
                $data1['position'] = $x + 1;
                $data1['win_amount'] = $price[$x];
                $data1['created_at'] = date('Y-m-d H:i:s');
                $data1['updated_at'] = date('Y-m-d H:i:s');

                array_push($winner_data, $data1);

                DB::table('wallet_history')->insert([
                    'challenge_id' => $id,
                    'coins' => $price[$x],
                    'amount' => 0,
                    'raw_amount' => '',
                    'type' => 'C',
                    'status' => 'Credited',
                    'user_id' => $post->user_id,
                    'created_at' => date('Y-m-d H:i:s'),
                    'updated_at' => date('Y-m-d H:i:s')
                ]);
                $pos = '';
                if ($x == 0) {
                    $pos = 'first';
                } elseif ($x == 1) {
                    $pos = 'second';
                } elseif ($x = 2) {
                    $pos = 'third';
                }
                $user = User::where('user_id', $post->user_id)->first();

                $title =  $challenge->title . ": You won " . $pos . " price.";
                $message = $challenge->title . " result declared.";
                $fcmTokens = [$user->fcm_token];

                $not_data['created_on'] = date("Y-m-d H:i:s");
                $not_data['sent_to'] = $user->user_id;
                $not_data['title'] = $title;
                $not_data['page_name'] = "challenge-detail";
                $not_data['post_id'] = $post->post_id;
                $not_data['sent_by'] = 0;
                DB::table('notifications')->insert($not_data);
                try {
                    $image = '';
                    // $image = asset(Storage::url('gifts')) . '/' . $gift->icon;
                    $param = ['id' => $id, 'type' => 'challenge', 'page' => '/challenge-detail', 'image' => $image, 'to_id' => $user->user_id, 'from_id' => 0];
                    // Notification::send(null, new UserNotification($title, $message, $image, $param, $fcmTokens));
                    $user->notify(new UserNotification($title, $message, $image, $param));
                } catch (\Exception $e) {
                }
            }
        }

        if (count($winner_data) > 0) {
            DB::table('challenge_winners')->insert($winner_data);
        }
        DB::table('challenges')->where('id', $id)->update(['result_declared' => 1]);

        return redirect(route('admin.challenges.index'))->with('success', 'Challenge result announced.');
    }

    public function delete(Request $request)
    {
        $ids = explode(',', $request->ids);
        foreach ($ids as $id) {
            DB::table('challenges')->where('id', $id)->delete();
        }


        if (count($ids) > 1) {
            $msg = "Challenges deleted successfully";
        } else {
            $msg = "Challenge deleted successfully";
        }
        $request->session()->put('success', $msg);
        return response()->json(['status' => 'success']);
    }

    public function copyContent($id)
    {
        $action = 'copy';
        $challenge = DB::table('challenges')->select(DB::raw("*"))->where('id', '=', $id)->first();
        // dd($category);
        return view('admin.challenges-create', compact('id', 'challenge', 'action', 'type'));
    }
}
