<?php

namespace App\Http\Controllers\Admin;

use App\Models\City;
use App\Models\State;
use App\Models\Country;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Validator;

class CityController extends Controller
{
    public function index()
    {
        return view('admin.city.index', [
            'data' => City::orderBy('updated_at','desc')->get(),
        ]);
    }

    public function create()
    {
        $countries = Country::get();
        $states = State::get();

        return view('admin.city.add', compact('countries', 'states'));
    }

    public function store(Request $request) {
        $validator = Validator::make($request->all(), [
            'name' => 'required|string|max:100|unique:App\Models\City,name',
            'code' => 'required|string|max:10|unique:App\Models\City,code',
            'state_id' => 'required|exists:App\Models\State,id',
            'country_id' => 'required|exists:App\Models\Country,id',
            'active' => 'nullable',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $city = new City;
        $city->name = $request->name;
        $city->code = $request->code;
        $city->state_id = $request->state_id;
        $city->country_id = $request->country_id;
        $city->active = $request->active == NULL ? 0 : 1;
        $city->save();

        session()->flash('message', 'City added successfully.');

        return to_route('admin.cities');
    }

    public function edit(City $city)
    {
        return view('admin.city.edit', [
            'city' => $city,
            'states' => State::get(),
            'countries' => Country::get(),
        ]);
    }

    public function update(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'name' => 'required|string|max:191|unique:App\Models\City,name,' . $request->id,
            'code' => 'required|string|max:10|unique:App\Models\City,code,' . $request->id,
            'state_id' => 'nullable|exists:App\Models\state,id',
            'country_id' => 'required|exists:App\Models\Country,id',
            'active' => 'nullable',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $city = City::where('id', $request->id)->first();

        $city->name = $request->name;
        $city->code = $request->code;
        $city->state_id = $request->state_id ? $request->state_id : $city->state_id;
        $city->country_id = $request->country_id ? $request->country_id : $city->country_id;
        $city->active = $request->active == NULL ? 0 : 1;
        $city->update();

        session()->flash('message', 'City details updated successfully.');

        return to_route('admin.cities');
    }

    public function delete(City $city)
    {
        $city->delete();
        
        echo 'done';

        exit;
    }
}
