<?php

namespace App\Http\Controllers\Admin;

use App\Models\Coming;
use Illuminate\Support\Str;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Models\ComingCrud;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\Validator;

class ComingController extends Controller
{
    public function index()
    {
        $crud = ComingCrud::first();

        $top_content = '';
        $bottom_content = '';

        if ($crud != NULL) {
            $top_content = $crud->top_content;
            $bottom_content = $crud->bottom_content;
        }

        return view('admin.coming.index', [
            'data' => Coming::orderBy('updated_at','desc')->get(),
            'top_content' => $top_content,
            'bottom_content' => $bottom_content,
        ]);
    }

    public function create()
    {
        return view('admin.coming.add');
    }

    public function update_crud(Request $request) {
        $validator = Validator::make($request->all(), [
            'top_content' => 'nullable',
            'bottom_content' => 'nullable',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $crud = ComingCrud::first();

        if ($crud == NULL) {
            $r = new ComingCrud;
            $r->top_content = $request->top_content;
            $r->bottom_content = $request->bottom_content;
            $r->save();
        } else {
            $crud->top_content = $request->top_content;
            $crud->bottom_content = $request->bottom_content;
            $crud->save();
        }

        session()->flash('message', 'Coming CRUD updated successfully.');

        return to_route('admin.comingsoon');
    }

    public function store(Request $request) {
        $validator = Validator::make($request->all(), [
            'title' => 'required|string|max:191|unique:App\Models\Coming,title',
            'image' => 'required|file|max:10240|mimes:jpg,jpeg,png,webp',
            'description' => 'nullable',
            'rank' => 'nullable',
            'active' => 'boolean',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $r = new Coming;
        $r->title = $request->title;
        $r->alias = Str::slug($request->title, '-');
        $r->description = $request->description;
        $r->rank = $request->rank ? $request->rank : 0;
        $r->active = $request->active == NULL ? 0 : 1;

        if ($request->file('image') != NULL) {
            $image = $request->file('image');
            $uploadPath = "public/uploads/coming";
            $r->image = $image->store($uploadPath);
        }

        $r->save();

        session()->flash('message', 'Coming soon added successfully.');

        return to_route('admin.comingsoon');
    }

    public function edit(Coming $coming)
    {
        if ($coming->image != NULL) {
            if (Storage::exists($coming->image)) {
                $coming->image = asset(Storage::url($coming->image));
            }
        }

        return view('admin.coming.edit', compact('coming'));
    }

    public function update(Request $request) {

        $validator = Validator::make($request->all(), [
            'title' => 'required|string|max:191|unique:App\Models\Coming,title,' . $request->id,
            'image' => 'nullable|file|max:1024000|mimes:jpg,jpeg,png,webp',
            'description' => 'nullable',
            'rank' => 'nullable',
            'active' => 'boolean',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $r = Coming::where('id', $request->id)->first();

        $r->title =  $request->title;
        $r->alias = Str::slug($request->title, '-');
        $r->description = $request->description;
        $r->rank = $request->rank ? $request->rank : 0;
        $r->active = $request->active == NULL ? 0 : 1;

        if ($request->file('image') != NULL) {
            if ($r->image != NULL) {
                Storage::delete($r->image);
            }

            $image = $request->file('image');
            $uploadPath = "public/uploads/coming";
            $r->image = $image->store($uploadPath);
        }

        $r->update();

        session()->flash('message', 'Coming soon details updated successfully.');

        return to_route('admin.comingsoon');
    }

    public function delete(Coming $coming)
    {
        if ($coming->delete()) {
            echo 'done';
        }

        exit;
    }
}
