<?php

namespace App\Http\Controllers\Admin;

use App\Models\City;
use App\Models\State;
use App\Models\Country;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Validator;

class CountryController extends Controller
{
    public function index()
    {
        return view('admin.country.index', [
            'data' => Country::orderBy('updated_at','desc')->get(),
        ]);
    }

    public function create()
    {
        return view('admin.country.add');
    }

    public function store(Request $request) {
        $validator = Validator::make($request->all(), [
            'name' => 'required|string|max:100|unique:App\Models\Country,name',
            'code' => 'required|string|max:10|unique:App\Models\Country,code',
            'active' => 'nullable',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $country = new Country;
        $country->name = $request->name;
        $country->code = $request->code;
        $country->active = $request->active == NULL ? 0 : 1;
        $country->save();

        session()->flash('message', 'Country added successfully.');

        return to_route('admin.countries');
    }

    public function edit(Country $country)
    {
        return view('admin.country.edit', [
            'country' => $country,
        ]);
    }

    public function update(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'name' => 'required|string|max:100|unique:App\Models\Country,name,' . $request->id,
            'code' => 'required|string|max:10|unique:App\Models\Country,code,' . $request->id,
            'active' => 'nullable',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $country = Country::where('id', $request->id)->first();

        $country->name = $request->name;
        $country->code = $request->code;
        $country->active = $request->active == NULL ? 0 : 1;
        $country->update();

        session()->flash('message', 'Country details updated successfully.');

        return to_route('admin.countries');
    }

    public function delete(Country $country)
    {
        $state_ids = State::where('country_id', $country->id)->pluck('id');

        City::whereIn('state_id', $state_ids)->delete();
        State::where('country_id', $country->id)->delete();

        $country->delete();

        echo 'done';

        exit;
    }

    public function get_states(Country $country)
    {
        $states = State::where('country_id', $country->id)->get();

        $str = '<option selected disabled>--Not Selected--</option>';

        foreach ($states as $state) {
            $str .= '<option value="'. $state->id .'">'. $state->name .'</option>';
        }

        return $str;
    }

    public function get_cities(Country $country, State $state)
    {
        $cities = City::where('country_id', $country->id)->where('state_id', $state->id)->get();

        $str = '<option selected disabled>--Not Selected--</option>';

        foreach ($cities as $city) {
            $str .= '<option value="'. $city->id .'">'. $city->name .'</option>';
        }

        return $str;
    }
}
