<?php

namespace App\Http\Controllers\Admin;

use App\Models\User;
use App\Models\Country;
use App\Models\Appointment;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\Validator;

class CustomerController extends Controller
{
    public function index()
    {
        return view('admin.customer.index', [
            'users' => User::where('utype', 'U')->latest()->get(),
        ]);
    }

    public function create()
    {
        $countries = Country::get();

        return view('admin.customer.add', compact('countries'));
    }

    public function store(Request $request) {
        $validator = Validator::make($request->all(), [
            'first_name' => 'required|string|max:50',
            'last_name' => 'required|string|max:50',
            'email' => 'required|email|max:50|unique:App\Models\User,email',
            'phone' => 'required|string|max:20|unique:App\Models\User,phone',
            'address' => 'required|string|max:191',
            'zipcode' => 'required|string|max:10',
            'city_id' => 'required|exists:App\Models\City,id',
            'state_id' => 'required|exists:App\Models\State,id',
            'country_id' => 'required|exists:App\Models\Country,id',
            'image' => 'required|file|max:1024000|mimes:jpg,jpeg,png,webp',
            'active' => 'nullable',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $user = new User;
        $user->first_name = $request->first_name;
        $user->last_name = $request->last_name;
        $user->email = $request->email;
        $user->phone = $request->phone;
        $user->address = $request->address;
        $user->zipcode = $request->zipcode;
        $user->city_id = $request->city_id;
        $user->state_id = $request->state_id;
        $user->country_id = $request->country_id;
        $user->active = $request->active == NULL ? 0 : 1;

        if ($request->file('image') != NULL) {
            $image = $request->file('image');
            $uploadPath = "public/uploads/customer";
            $user->image = $image->store($uploadPath);
        }

        $user->save();

        session()->flash('message', 'Customer details saved successfully.');

        return to_route('admin.customers');
    }

    public function edit(User $customer)
    {
        $countries = Country::get();

        if ($customer->image != NULL) {
            if (Storage::exists($customer->image)) {
                $customer->image = asset(Storage::url($customer->image));
            }
        }

        return view('admin.customer.edit', compact('customer', 'countries'));
    }

    public function update(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'first_name' => 'required|string|max:50',
            'last_name' => 'required|string|max:50',
            'email' => 'required|email|max:50|unique:App\Models\User,email,' . $request->id,
            'phone' => 'required|string|max:20|unique:App\Models\User,phone,' . $request->id,
            'address' => 'required|string|max:191',
            'zipcode' => 'required|string|max:10',
            'city_id' => 'required|exists:App\Models\City,id',
            'state_id' => 'required|exists:App\Models\State,id',
            'country_id' => 'required|exists:App\Models\Country,id',
            'image' => 'nullable|file|max:1024000|mimes:jpg,jpeg,png,webp',
            'active' => 'nullable',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $user = User::where('id', $request->id)->first();

        $user->first_name = $request->first_name;
        $user->last_name = $request->last_name;
        $user->email = $request->email;
        $user->phone = $request->phone;
        $user->address = $request->address;
        $user->zipcode = $request->zipcode;
        $user->city_id = $request->city_id;
        $user->state_id = $request->state_id;
        $user->country_id = $request->country_id;
        $user->active = $request->active == NULL ? 0 : 1;

        if ($request->file('image') != NULL) {
            if ($user->image != NULL) {
                Storage::delete($user->image);
            }

            $image = $request->file('image');
            $uploadPath = "public/uploads/customer";
            $user->image = $image->store($uploadPath);
        }

        $user->save();

        session()->flash('message', 'Customer details updated successfully.');

        return to_route('admin.customers');
    }

    public function delete(User $customer)
    {
        Appointment::where('user_id', $customer->id)->delete();

        $customer->delete();

        echo 'done';

        exit;
    }
}
