<?php

namespace App\Http\Controllers\Admin;

use Carbon\Carbon;
use App\Models\User;
use App\Models\Payment;
use App\Models\Appointment;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use App\Http\Controllers\Controller;

class DashboardController extends Controller
{
    public function index(Request $request)
    {
        $dt1 = Carbon::now()->startOfMonth();
        $dt2 = Carbon::now()->endOfMonth();

        // Start - Top 4 charts.
        // Staff chart
        $arr = User::where('utype', 'S')->select(
                DB::raw("(COUNT(*)) as count"),
                DB::raw('MONTH(created_at) as month'),
            )->groupBy('month')->get()->toArray();

        $staffGraphTop = array_fill(0, 12, 0);

        foreach ($arr as $item) {
            $staffGraphTop[$item['month']] = $item['count'];
        }

        // Customers chart
        $arr = User::where('utype', 'U')->select(
                DB::raw("(COUNT(*)) as count"),
                DB::raw('MONTH(created_at) as month'),
            )->groupBy('month')->get()->toArray();

        $usersGraphTop = array_fill(0, 12, 0);

        foreach ($arr as $item) {
            $usersGraphTop[$item['month']] = $item['count'];
        }

        // Appointments chart
        $arr = Appointment::select(
                DB::raw("(COUNT(*)) as count"),
                DB::raw('MONTH(date) as month'),
            )->groupBy('month')->get()->toArray();

        $appointmentsGraphTop = array_fill(0, 12, 0);

        foreach ($arr as $item) {
            $appointmentsGraphTop[$item['month']] = $item['count'];
        }

        // Payments chart
        $arr = Payment::select(
                DB::raw("(COUNT(*)) as count"),
                DB::raw('MONTH(created_at) as month'),
            )->groupBy('month')->get()->toArray();

        $paymentsGraphTop = array_fill(0, 12, 0);

        foreach ($arr as $item) {
            $paymentsGraphTop[$item['month']] = $item['count'];
        }

        // End - Top 4 charts.

        // appointments graph
        $appointmentsGraph = [];
        $arr = Appointment::select(
            DB::raw("(COUNT(*)) as count"),
            DB::raw('UNIX_TIMESTAMP(date) as ts'),
            DB::raw("MONTHNAME(date) as month_name")
        )
        ->groupBy('month_name')
        ->groupBy('ts')
        ->orderBy('ts')
        ->get()->toArray();

        if (count($arr)) {
            foreach ($arr as $item) {
                array_push($appointmentsGraph, [(int)($item['ts'] . '000'), $item['count']]);
            }
        }
        // End

        // payments graph
        $paymentsGraph = [];

        $arr = Payment::where('status', 'S')->select(
                DB::raw("(SUM(amount)) as total"),
                DB::raw('UNIX_TIMESTAMP(created_at) as ts'),
                DB::raw("MONTHNAME(created_at) as month_name")
            )
            ->groupBy('month_name')
            ->groupBy('ts')
            ->orderBy('ts')
            ->get()->toArray();

        if (count($arr)) {
            foreach ($arr as $item) {
                array_push($paymentsGraph, [(int)($item['ts'] . '000'), $item['total']]);
            }
        }
        // End

        $totalPayments = 100;
        $pendingPayments = 100;
        $completedPayments = 100;
        $cancelledPayments = 100;

        $currentMonth = now()->month;
        $currentYear = now()->year;


        // Appointments
        $totalAppointments = Appointment::whereMonth('created_at', $currentMonth)->whereYear('created_at', $currentYear)->count();
        $pendingAppointments = Appointment::where('status', 'P')->whereMonth('created_at', $currentMonth)->whereYear('created_at', $currentYear)->count();
        $completedAppointments = Appointment::where('status', 'S')->whereMonth('created_at', $currentMonth)->whereYear('created_at', $currentYear)->count();
        $cancelledAppointments = Appointment::where('status', 'C')->whereMonth('created_at', $currentMonth)->whereYear('created_at', $currentYear)->count();;

        // Payments
        $totalPayments = Payment::count('id');
        $pendingPayments = Payment::where('status', 'P')->count('id');
        $completedPayments = Payment::where('status', 'S')->count('id');
        $cancelledPayments = Payment::where('status', 'F')->count('id');

        $totalPaymentsSum = Payment::sum('amount');
        $pendingPaymentsSum = Payment::where('status', 'P')->sum('amount');
        $completedPaymentsSum = Payment::where('status', 'S')->sum('amount');
        $cancelledPaymentsSum = Payment::where('status', 'F')->sum('amount');

        return view('admin.dashboard', [
            'staffGraphTop' => $staffGraphTop,
            'usersGraphTop' => $usersGraphTop,
            'appointmentsGraphTop' => $appointmentsGraphTop,
            'paymentsGraphTop' => $paymentsGraphTop,

            'staffCount' => User::where('utype', 'S')->count(),
            'usersCount' => User::where('utype', 'U')->count(),
            'appointmentsCount' => Appointment::count(),
            'paymentsCount' => Payment::count(),

            'staffCountNew' => User::where('utype', 'S')->whereBetween('created_at', [$dt1, $dt2])->count(),
            'usersCountNew' => User::where('utype', 'U')->whereBetween('created_at', [$dt1, $dt2])->count(),
            'appointmentsCountNew' => Appointment::whereBetween('created_at', [$dt1, $dt2])->count(),
            'paymentsCountNew' => Payment::whereBetween('created_at', [$dt1, $dt2])->count(),

            'staff' => User::where('utype', 'S')->latest()->take(5)->get(),
            'appointments' => Appointment::latest()->take(5)->get(),
            'payments' => Payment::latest()->take(5)->get(),

            'appointmentsGraph' => $appointmentsGraph,
            'paymentsGraph' => $paymentsGraph,

            'totalAppointments' => $totalAppointments,
            'pendingAppointments' => $pendingAppointments,
            'completedAppointments' => $completedAppointments,
            'cancelledAppointments' => $cancelledAppointments,

            'totalPayments' => $totalPayments,
            'pendingPayments' => $pendingPayments,
            'completedPayments' => $completedPayments,
            'cancelledPayments' => $cancelledPayments,

            'totalPaymentsSum' => number_format($totalPaymentsSum, 2),
            'pendingPaymentsSum' => number_format($pendingPaymentsSum, 2),
            'completedPaymentsSum' => number_format($completedPaymentsSum, 2),
            'cancelledPaymentsSum' => number_format($cancelledPaymentsSum, 2),

            'users' => User::where('utype', 'U')->latest()->take(5)->get(),
            'staff' => User::where('utype', 'S')->latest()->take(5)->get(),

            'active_staff_count' => User::where('utype', 'S')->where('active', 1)->count(),
            'inactive_staff_count' => User::where('utype', 'S')->where('active', 0)->count(),
            'active_users_count' => User::where('utype', 'U')->where('active', 1)->count(),
            'inactive_users_count' => User::where('utype', 'U')->where('active', 0)->count(),

            'today_appointments_count' => Appointment::where('date', Carbon::today())->where('status', 'P')->count(),
            'today_payments_count' => Payment::where('created_at', Carbon::today())->where('status', 'S')->count(),
        ]);

        return view('admin.dashboard');
    }




    public function uploadFile(Request $request)
    {
        if($request->hasFile('upload')) {
            $fileNameWithExtension = $request->file('upload')->getClientOriginalName();
            $fileName = pathinfo($fileNameWithExtension, PATHINFO_FILENAME);
            $extension = $request->file('upload')->getClientOriginalExtension();
            $fileNameToStore = $fileName.'_'.time().'.'.$extension;
            $request->file('upload')->storeAs('public/uploads', $fileNameToStore);
            $CKEditorFuncNum = $request->input('CKEditorFuncNum') ? $request->input('CKEditorFuncNum') : 0;

            if($CKEditorFuncNum > 0) {
                $url = asset('storage/uploads/'.$fileNameToStore);
                $msg = 'Image successfully uploaded';
                $renderHtml = "<script>window.parent.CKEDITOR.tools.callFunction($CKEditorFuncNum, '$url', '$msg')</script>";

                @header('Content-type: text/html; charset=utf-8');
                echo $renderHtml;
            } else {
                $url = asset('storage/uploads/'.$fileNameToStore);
                $msg = 'Image successfully uploaded';
                $renderHtml = "<script>window.parent.CKEDITOR.tools.callFunction($CKEditorFuncNum, '$url', '$msg')</script>";
                return response()->json([
                    'uploaded' => '1',
                    'fileName' => $fileNameToStore,
                    'url' => $url
                ]);
            }
        }
    }

    public function appointment_chart(Request $request)
    {
        $dt1 = Carbon::now()->subDays(7)->toDateString();
        $dt2 = Carbon::now()->addDays(31)->toDateString();

        $appointments = Appointment::join('appointment_services', 'appointments.service_id', '=', 'appointment_services.id')
            ->join('appointment_service_staff', 'appointment_service_staff.service_id', '=', 'appointment_services.id')
            ->join('users', 'appointment_service_staff.user_id', '=', 'users.id')
            ->where('date', '>=', $dt1)
            ->where('date', '<=', $dt2)
            ->get();

        $groupedAppointments = $appointments->groupBy('date');

        $data = [];

        $colors = [
            '#1a5276', '#922b21', '#2e4053', '#154360', '#641e16',
            '#1e8449', '#2874a6', '#7b241c', '#148f77', '#b9770e',
            '#5d6d7e', '#2c3e50', '#0e6251', '#1f618d', '#7d6608',
            '#34495e', '#273746', '#117864', '#5b2c6f', '#4d5656'
        ];

        foreach ($groupedAppointments as $date => $appointments) {
            $randomColorIndex = array_rand($colors);
            $color = $colors[$randomColorIndex];

            $data[] = [
                'x' => $date,
                'y' => $appointments->count(),
                'color' => $color,
            ];

            unset($colors[$randomColorIndex]);
        }

        return response()->json($data);
    }

    public function payments_chart(Request $request)
    {
        $dt1 = Carbon::now()->subDays(7)->toDateString();
        $dt2 = Carbon::now()->addDays(31)->toDateString();

        $appointments = Appointment::join('appointment_services', 'appointments.service_id', '=', 'appointment_services.id')
            ->join('appointment_service_staff', 'appointment_service_staff.service_id', '=', 'appointment_services.id')
            ->join('users', 'appointment_service_staff.user_id', '=', 'users.id')
            ->where('date', '>=', $dt1)
            ->where('date', '<=', $dt2)
            ->get();

        $groupedAppointments = $appointments->groupBy('date');
        $data = [];
        $colors = [
            '#1a5276', '#922b21', '#2e4053', '#154360', '#641e16',
            '#1e8449', '#2874a6', '#7b241c', '#148f77', '#b9770e',
            '#5d6d7e', '#2c3e50', '#0e6251', '#1f618d', '#7d6608',
            '#34495e', '#273746', '#117864', '#5b2c6f', '#4d5656'
        ];

        foreach ($groupedAppointments as $date => $appointments) {
            $randomColorIndex = array_rand($colors);
            $color = $colors[$randomColorIndex];

            $data[] = [
                'x' => $date,
                'y' => $appointments->count(),
                'color' => $color,
            ];

            unset($colors[$randomColorIndex]);
        }

        return response()->json($data);
    }
}
