<?php

namespace App\Http\Controllers\Admin;

use App\Models\Fabric;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Validator;

class FabricController extends Controller
{
    public function index()
    {
        return view('admin.fabric.index', [
            'data' => Fabric::orderBy('updated_at','desc')->get(),
        ]);
    }

    public function create()
    {
        return view('admin.fabric.add');
    }

    public function store(Request $request) {
        $validator = Validator::make($request->all(), [
            'name' => 'required|string|max:191|unique:App\Models\Fabric,name',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $fabric = new Fabric;
        $fabric->name = $request->name;
        $fabric->save();

        session()->flash('message', 'Fabric added successfully.');

        return to_route('admin.fabrics');
    }

    public function edit(Fabric $fabric)
    {
        return view('admin.fabric.edit', [
            'fabric' => $fabric,
        ]);
    }

    public function update(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'name' => 'required|string|max:191|unique:App\Models\Fabric,name,' . $request->id,
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $fabric = Fabric::where('id', $request->id)->first();
        $fabric->name = $request->name;
        $fabric->update();

        session()->flash('message', 'Fabric details updated successfully.');

        return to_route('admin.fabrics');
    }

    public function delete(Fabric $fabric)
    {
        if ($fabric->delete()) {
            echo 'done';
        }

        exit;
    }
}
