<?php

namespace App\Http\Controllers\Admin;

use App\Models\Faq;
use App\Models\PageFont;
use Illuminate\Support\Str;
use Illuminate\Http\Request;
use Yajra\DataTables\DataTables;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Validator;

class FaqController extends Controller
{
    public function index(Request $request)
    {
        $fonts = PageFont::where('page', 'faq')->first();

        $title = 'FAQs';
        if ($request->ajax()) {
            $data = Faq::latest()->get();
            return DataTables::of($data)
                ->addIndexColumn()
                ->addColumn('action', function ($row) {
                    $actionBtn = ' <ul class="list-inline me-auto mb-0">
                    <li class="list-inline-item align-bottom" data-bs-toggle="tooltip" title="Edit">
                    <a href="' . route('admin.edit-faq', $row->id) . '" class="edit avtar avtar-xs btn-link-success btn-pc-default"><i class="ti ti-edit-circle f-18"></i></a>
                    </li>
                    <li class="list-inline-item align-bottom" data-bs-toggle="tooltip" title="Edit">
                    <a href="javascript:void(0)" class="deleteSelSingle delete avtar avtar-xs btn-link-danger btn-pc-default" data-val=' . $row->id . '> <i class="ti ti-trash f-18"></i></a>
                    </li>';
                    return $actionBtn;
                })
                ->editColumn('answer', function ($row) {
                    return Str::limit($row->answer, 100);
                })
                ->editColumn('created_at', function ($row) {
                    return date('Y-m-d H:i:s', strtotime($row->created_at));
                })
                ->rawColumns(['answer', 'action'])
                ->make(true);
        }
        return view('admin.faq.index', compact('title', 'fonts'));
    }

    public function create()
    {
        return view('admin.faq.add');
    }

    public function store(Request $request) {
        $validator = Validator::make($request->all(), [
            'question' => 'required|string|max:191',
            'answer' => 'required',
            'sort_order' => 'nullable',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $faq = new Faq;
        $faq->question = $request->question;
        $faq->answer = $request->answer;
        $faq->sort_order = $request->sort_order;
        $faq->save();

        session()->flash('message', 'FAQ added successfully.');

        return to_route('admin.faqs');
    }

    public function edit(Faq $faq)
    {
        return view('admin.faq.edit', [
            'faq' => $faq,
        ]);
    }

    public function update(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'question' => 'required|string|max:191',
            'answer' => 'required',
            'sort_order' => 'nullable',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $faq = Faq::where('id', $request->id)->first();

        $faq->question = $request->question;
        $faq->answer = $request->answer;
        $faq->sort_order = $request->sort_order;
        $faq->update();

        session()->flash('message', 'FAQ details updated successfully.');

        return to_route('admin.faqs');
    }

    public function destroy(Request $request)
    {
        $ids = $request->ids;
        $ids = explode(",", $ids);

        Faq::whereIn('id', $ids)->delete();
        if (count($ids) > 1) {
            $msg = "Records deleted successfully";
        } else {
            $msg = "Record deleted successfully";
        }
        $request->session()->put('success', $msg);
        return response(['status' => true, 'msg' => $msg]);
    }
}
