<?php

namespace App\Http\Controllers\Admin;

use App\Models\Product;
use Illuminate\Http\Request;
use App\Models\HomepageSection;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\Validator;

class HomepageSectionsController extends Controller
{
    /**
     * List sections.
     */
    public function index()
    {
        $sections = HomepageSection::orderBy('order')->get();

        return view('admin.homepage_sections.index', compact('sections'));
    }

    /**
     * Open form to edit section details.
     */
    public function edit(HomepageSection $section)
    {
        return view('admin.homepage_sections.' . $section->name, compact('section'));
    }

    /**
     * Update section.
     * This function served as a common interface that forwards request to corresponding section specific update function.
     */
    public function update(Request $request, HomepageSection $section)
    {
        $x = 'update_' . $section->name;

        $v = $this->$x($request, $section);

        return back()->withErrors($v)->withInput();
    }

    public function update_cover(Request $request, HomepageSection $section)
    {
        $validator = Validator::make($request->all(), [
            'heading' => 'required|string|max:191',
            'sub_heading_1' => 'required|string|max:191',
            'button_text_1' => 'required|string|max:191',
            'button_url_1' => 'required|string|max:191',
            'cover_video' => 'nullable|file|max:20480|mimes:mp4,avi,mov,mkv',
            'cover_image' => 'nullable|file|max:10240|mimes:jpg,jpeg,png,webp',
            'image_1' => 'nullable|file|max:1024|mimes:jpg,jpeg,png,webp',
            'video_or_image' => 'required',
            'font1' => 'nullable',
            'font2' => 'nullable',
            'font3' => 'nullable',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        // Update section attributes
        $section->heading = $request->heading;
        $section->sub_heading_1 = $request->sub_heading_1;
        $section->button_text_1 = $request->button_text_1;
        $section->button_url_1 = $request->button_url_1;
        $section->video_or_image = $request->video_or_image;

        $section->font1 = $request->font1 ? $request->font1 : '';
        $section->font2 = $request->font2 ? $request->font2 : '';
        $section->font3 = $request->font3 ? $request->font3 : '';

        // Handle cover video upload
        if ($request->hasFile('cover_video')) {
            if ($section->cover_video) {
                Storage::delete($section->cover_video);
            }
            $video = $request->file('cover_video');
            $uploadPath = "public/uploads/homepage/" . $section->id;
            $section->cover_video = $video->store($uploadPath);
        }

        // Handle cover image upload
        if ($request->hasFile('cover_image')) {
            if ($section->cover_image) {
                Storage::delete($section->cover_image);
            }
            $image = $request->file('cover_image');
            $uploadPath = "public/uploads/homepage/" . $section->id;
            $section->cover_image = $image->store($uploadPath);
        }

        // Handle image_1 upload
        if ($request->hasFile('image_1')) {
            if ($section->image_1) {
                Storage::delete($section->image_1);
            }
            $image = $request->file('image_1');
            $uploadPath = "public/uploads/homepage/" . $section->id;
            $section->image_1 = $image->store($uploadPath);
        }

        // Save the section
        $section->save();

        // Set success message
        session()->flash('message', 'Section details updated successfully.');
    }

    public function update_promo_page(Request $request, HomepageSection $section)
    {
        $validator = Validator::make($request->all(), [
            'image_1' => 'nullable|file|max:10240|mimes:jpg,jpeg,png,webp',
            'image_2' => 'nullable|file|max:10240|mimes:jpg,jpeg,png,webp',
            'image_3' => 'nullable|file|max:10240|mimes:jpg,jpeg,png,webp',
            'image_4' => 'nullable|file|max:10240|mimes:jpg,jpeg,png,webp',
            'image_url_1' => 'nullable|max:191',
            'image_url_2' => 'nullable|max:191',
            'image_url_3' => 'nullable|max:191',
            'image_url_4' => 'nullable|max:191',
            'heading' => 'required|string|max:191',
            'sub_heading_1' => 'required|string|max:191',
            'button_text_1' => 'required|string|max:191',
            'button_url_1' => 'required|string|max:191',
            'font1' => 'nullable',
            'font2' => 'nullable',
            'font3' => 'nullable',
        ]);

        if ($validator->fails()) {
            return $validator;
        }

        if ($request->file('image_1') != NULL)
        {
            if ($section->image_1 != NULL) {
                Storage::delete($section->image_1);
            }

            $image = $request->file('image_1');
            $uploadPath = "public/uploads/homepage/" . $section->id;
            $section->image_1 = $image->store($uploadPath);
        }

        if ($request->file('image_2') != NULL)
        {
            if ($section->image_2 != NULL) {
                Storage::delete($section->image_2);
            }

            $image = $request->file('image_2');
            $uploadPath = "public/uploads/homepage/" . $section->id;
            $section->image_2 = $image->store($uploadPath);
        }

        if ($request->file('image_3') != NULL)
        {
            if ($section->image_3 != NULL) {
                Storage::delete($section->image_3);
            }

            $image = $request->file('image_3');
            $uploadPath = "public/uploads/homepage/" . $section->id;
            $section->image_3 = $image->store($uploadPath);
        }

        if ($request->file('image_4') != NULL)
        {
            if ($section->image_4 != NULL) {
                Storage::delete($section->image_4);
            }

            $image = $request->file('image_4');
            $uploadPath = "public/uploads/homepage/" . $section->id;
            $section->image_4 = $image->store($uploadPath);
        }

        $section->image_url_1 = $request->image_url_1;
        $section->image_url_2 = $request->image_url_2;
        $section->image_url_3 = $request->image_url_3;
        $section->image_url_4 = $request->image_url_4;
        $section->heading = $request->heading;
        $section->sub_heading_1 = $request->sub_heading_1;
        $section->button_text_1 = $request->button_text_1;
        $section->button_url_1 = $request->button_url_1;

        $section->font1 = $request->font1 ? $request->font1 : '';
        $section->font2 = $request->font2 ? $request->font2 : '';
        $section->font3 = $request->font3 ? $request->font3 : '';

        $section->save();

        session()->flash('message', 'Section details updated successfully.');
    }

    public function update_welcome(Request $request, HomepageSection $section)
    {
        $validator = Validator::make($request->all(), [
            'image_1' => 'nullable|file|max:10240|mimes:jpg,jpeg,png,webp',
            'image_2' => 'nullable|file|max:10240|mimes:jpg,jpeg,png,webp',
            'logo' => 'nullable|file|max:10240|mimes:jpg,jpeg,png,webp',
            'heading' => 'required|string|max:190',
            'button_text_1' => 'required|string|max:190',
            'button_url_1' => 'required|string|max:190',
            'content' => 'required',
            'font1' => 'nullable',
            'font2' => 'nullable',
            'font3' => 'nullable',
        ]);

        if ($validator->fails()) {
            return $validator;
        }

        if ($request->file('image_1') != NULL) {
            if ($section->image_1 != NULL) {
                Storage::delete($section->image_1);
            }

            $image = $request->file('image_1');
            $uploadPath = "public/uploads/homepage/" . $section->id;
            $section->image_1 = $image->store($uploadPath);
        }

        if ($request->file('image_2') != NULL) {
            if ($section->image_2 != NULL) {
                Storage::delete($section->image_2);
            }
                $image = $request->file('image_2');
            $uploadPath = "public/uploads/homepage/" . $section->id;
            $section->image_2 = $image->store($uploadPath);
        }

        if ($request->file('logo') != NULL) {
            if ($section->logo != NULL) {
                Storage::delete($section->logo);
            }
                $image = $request->file('logo');
            $uploadPath = "public/uploads/homepage/" . $section->id;
            $section->logo = $image->store($uploadPath);
        }

        $section->heading = $request->heading;
        $section->button_text_1 = $request->button_text_1;
        $section->button_url_1 = $request->button_url_1;
        $section->content = $request->content;
        $section->font1 = $request->font1 ? $request->font1 : '';
        $section->font2 = $request->font2 ? $request->font2 : '';
        $section->font3 = $request->font3 ? $request->font3 : '';
        $section->save();

        session()->flash('message', 'Section details updated successfully.');
    }

    public function update_outlet(Request $request, HomepageSection $section)
    {
        $validator = Validator::make($request->all(), [
            'heading' => 'required|string|max:191',
            'sub_heading_1' => 'required|string|max:191',
            'button_text_1' => 'required|string|max:191',
            'button_url_1' => 'required|string|max:191',
            'font1' => 'nullable',
            'font2' => 'nullable',
            'font3' => 'nullable',
            'font4' => 'nullable',
            'font5' => 'nullable',
        ]);

        if ($validator->fails()) {
            return $validator;
        }

        $product_codes = Product::pluck('product_code');
        $variations = [];

        foreach ($product_codes as $pc) {
            if ($request->filled($pc)) {
                $variations[] = $request->$pc[0];
            }
        }

        $variations = implode(",", $variations);

        $section->heading = $request->heading;
        $section->sub_heading_1 = $request->sub_heading_1;
        $section->products = $variations;
        $section->button_text_1 = $request->button_text_1;
        $section->button_url_1 = $request->button_url_1;
        $section->font1 = $request->font1 ? $request->font1 : '';
        $section->font2 = $request->font2 ? $request->font2 : '';
        $section->font3 = $request->font3 ? $request->font3 : '';
        $section->font4 = $request->font4 ? $request->font4 : '';
        $section->font5 = $request->font5 ? $request->font5 : '';
        $section->save();

        session()->flash('message', 'Section details updated successfully.');
    }

    public function update_seasonal_highlights(Request $request, HomepageSection $section)
    {
        $validator = Validator::make($request->all(), [
            'heading' => 'required|string|max:191',
            'sub_heading_1' => 'required|string|max:191',
            'font1' => 'nullable',
            'font2' => 'nullable',
            'font3' => 'nullable',
        ]);

        if ($validator->fails()) {
            return $validator;
        }

        $product_codes = Product::pluck('product_code');
        $variations = [];

        foreach ($product_codes as $pc) {
            if ($request->filled($pc)) {
                $variations[] = $request->$pc[0];
            }
        }

        $variations = implode(",", $variations);

        $section->heading = $request->heading;
        $section->sub_heading_1 = $request->sub_heading_1;
        $section->products = $variations;
        $section->font1 = $request->font1 ? $request->font1 : '';
        $section->font2 = $request->font2 ? $request->font2 : '';
        $section->font3 = $request->font3 ? $request->font3 : '';
        $section->save();

        session()->flash('message', 'Section details updated successfully.');
    }

    public function update_services(Request $request, HomepageSection $section)
    {
        $validator = Validator::make($request->all(), [
            'image_1' => 'nullable|file|max:1024000|mimes:jpg,jpeg,png,webp',
            'image_url_1' => 'nullable|max:190',
            'heading' => 'required|string|max:190',
            'sub_heading_1' => 'nullable|string|max:191',
            'service' => 'required',
            'font1' => 'nullable',
            'font2' => 'nullable',
            'font3' => 'nullable',
        ]);

        if ($validator->fails()) {
            return $validator;
        }

        if ($request->file('image_1') != NULL)
        {
            if ($section->image_1 != NULL) {
                Storage::delete($section->image_1);
            }

            $image = $request->file('image_1');
            $uploadPath = "public/uploads/homepage/" . $section->id;
            $section->image_1 = $image->store($uploadPath);
        }

        $section->image_url_1 = $request->image_url_1;
        $section->heading = $request->heading;
        $section->sub_heading_1 = $request->sub_heading_1 ? $request->sub_heading_1 : '';
        $section->services = implode(',', $request->service);
        $section->font1 = $request->font1 ? $request->font1 : '';
        $section->font2 = $request->font2 ? $request->font2 : '';
        $section->font3 = $request->font3 ? $request->font3 : '';
        $section->save();

        session()->flash('message', 'Section details updated successfully.');
    }

    public function update_bookings(Request $request, HomepageSection $section)
    {
        $validator = Validator::make($request->all(), [
            'heading' => 'required|string|max:190',
            'tagline' => 'required|string|max:190',
            'sub_heading_1' => 'required|string|max:190',
            'sub_heading_2' => 'required|string|max:190',
            'sub_heading_3' => 'required|string|max:190',
            'sub_heading_4' => 'required|string|max:190',
            'sub_content_1' => 'required',
            'sub_content_2' => 'required',
            'sub_content_3' => 'required',
            'sub_content_4' => 'required',
            'image_1' => 'nullable|file|max:10240|mimes:jpg,jpeg,png,webp',
            'image_2' => 'nullable|file|max:10240|mimes:jpg,jpeg,png,webp',
            'image_3' => 'nullable|file|max:10240|mimes:jpg,jpeg,png,webp',
            'image_4' => 'nullable|file|max:10240|mimes:jpg,jpeg,png,webp',
            'url_1' => 'nullable',
            'url_2' => 'nullable',
            'url_3' => 'nullable',
            'url_4' => 'nullable',
            'font1' => 'nullable',
            'font2' => 'nullable',
            'font3' => 'nullable',
            'font4' => 'nullable',
            'font5' => 'nullable',
            'font6' => 'nullable',
            'font7' => 'nullable',
            'font8' => 'nullable',
            'font9' => 'nullable',
            'font10' => 'nullable',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $section->heading = $request->heading;
        $section->tagline = $request->tagline;
        $section->sub_heading_1 = $request->sub_heading_1;
        $section->sub_heading_2 = $request->sub_heading_2;
        $section->sub_heading_3 = $request->sub_heading_3;
        $section->sub_heading_4 = $request->sub_heading_4;
        $section->sub_content_1 = $request->sub_content_1;
        $section->sub_content_2 = $request->sub_content_2;
        $section->sub_content_3 = $request->sub_content_3;
        $section->sub_content_4 = $request->sub_content_4;
        $section->url_1 = $request->url_1;
        $section->url_2 = $request->url_2;
        $section->url_3 = $request->url_3;
        $section->url_4 = $request->url_4;
        $section->font1 = $request->font1 ? $request->font1 : '';
        $section->font2 = $request->font2 ? $request->font2 : '';
        $section->font3 = $request->font3 ? $request->font3 : '';
        $section->font4 = $request->font4 ? $request->font4 : '';
        $section->font5 = $request->font5 ? $request->font5 : '';
        $section->font6 = $request->font6 ? $request->font6 : '';
        $section->font7 = $request->font7 ? $request->font7 : '';
        $section->font8 = $request->font8 ? $request->font8 : '';
        $section->font9 = $request->font9 ? $request->font9 : '';
        $section->font10 = $request->font10 ? $request->font10 : '';

        if ($request->file('image_1') != NULL)
        {
            if ($section->image_1 != NULL) {
                Storage::delete($section->image_1);
            }

            $image = $request->file('image_1');
            $uploadPath = "public/uploads/homepage/" . $section->id;
            $section->image_1 = $image->store($uploadPath);
        }

        if ($request->file('image_2') != NULL)
        {
            if ($section->image_2 != NULL) {
                Storage::delete($section->image_2);
            }

            $image = $request->file('image_2');
            $uploadPath = "public/uploads/homepage/" . $section->id;
            $section->image_2 = $image->store($uploadPath);
        }

        if ($request->file('image_3') != NULL)
        {
            if ($section->image_3 != NULL) {
                Storage::delete($section->image_3);
            }

            $image = $request->file('image_3');
            $uploadPath = "public/uploads/homepage/" . $section->id;
            $section->image_3 = $image->store($uploadPath);
        }

        if ($request->file('image_4') != NULL)
        {
            if ($section->image_4 != NULL) {
                Storage::delete($section->image_4);
            }

            $image = $request->file('image_4');
            $uploadPath = "public/uploads/homepage/" . $section->id;
            $section->image_4 = $image->store($uploadPath);
        }

        $section->save();

        session()->flash('message', 'Section details updated successfully.');
    }

    public function update_testimonials(Request $request, HomepageSection $section)
    {
        $validator = Validator::make($request->all(), [
            'testimonial' => 'required',
            'image_1' => 'nullable|file|max:10240|mimes:jpg,jpeg,png,webp',
            'font1' => 'nullable',
            'font2' => 'nullable',
            'font3' => 'nullable',
        ]);

        if ($validator->fails()) {
            return $validator;
        }

        if ($request->file('image_1') != NULL)
        {
            if ($section->image_1 != NULL) {
                Storage::delete($section->image_1);
            }

            $image = $request->file('image_1');
            $uploadPath = "public/uploads/homepage/" . $section->id;
            $section->image_1 = $image->store($uploadPath);
        }

        $section->testimonials = implode(',', $request->testimonial);
        $section->font1 = $request->font1 ? $request->font1 : '';
        $section->font2 = $request->font2 ? $request->font2 : '';
        $section->font3 = $request->font3 ? $request->font3 : '';
        $section->save();

        session()->flash('message', 'Section details updated successfully.');
    }

    public function update_contact(Request $request, HomepageSection $section)
    {
        $validator = Validator::make($request->all(), [
            'button_text_1' => 'required|string|max:190',
            'button_url_1' => 'required|string|max:190',
            'logo' => 'nullable|file|max:10240|mimes:jpg,jpeg,png,webp',
            'font1' => 'nullable',
            'font2' => 'nullable',
            'font3' => 'nullable',
        ]);

        if ($validator->fails()) {
            return $validator;
        }

        $section->button_text_1 = $request->button_text_1;
        $section->button_url_1 = $request->button_url_1;
        $section->font1 = $request->font1 ? $request->font1 : '';
        $section->font2 = $request->font2 ? $request->font2 : '';
        $section->font3 = $request->font3 ? $request->font3 : '';

        if ($request->file('logo') != NULL) {
            if ($section->logo != NULL) {
                Storage::delete($section->logo);
            }
            $image = $request->file('logo');
            $uploadPath = "public/uploads/homepage/" . $section->id;
            $section->logo = $image->store($uploadPath);
        }

        $section->save();

        session()->flash('message', 'Section details updated successfully.');
    }

    /**
     * Mark given section active/in-active.
     */
    public function toggle_section(HomepageSection $section)
    {
        $section->active = $section->active ^ 1;
        $section->save();

        echo $section->active;

        exit;
    }

    public function update_sections_order(Request $request)
    {
        $i = 1;

        if ($request->filled('order')) {
            foreach ($request->order as $x) {
                HomepageSection::where('id', $x)->update(['order' => $i++]);
            }

            session()->flash('message', 'Section order updated successfully.');

            echo 'done';
        }

        exit;
    }

    public function reset_fonts(Request $request)
    {
        HomepageSection::where('name', 'cover')->update([
            'font1' => 'caslon540',
            'font2' => '',
            'font3' => ''
        ]);

        HomepageSection::where('name', 'welcome')->update([
            'font1' => '',
            'font2' => '',
            'font3' => ''
        ]);

        HomepageSection::where('name', 'promo_page')->update([
            'font1' => 'sloop',
            'font2' => '',
            'font3' => '',
        ]);

        HomepageSection::where('name', 'seasonal_highlights')->update([
            'font1' => 'caslon540',
            'font2' => '',
            'font3' => '',
        ]);

        HomepageSection::where('name', 'services')->update([
            'font1' => 'brittany',
            'font2' => '',
            'font3' => '',
        ]);

        HomepageSection::where('name', 'outlet')->update([
            'font1' => 'caslon540',
            'font2' => '',
            'font3' => 'britanny',
            'font4' => '',
            'font5' => '',
        ]);

        HomepageSection::where('name', 'testimonials')->update([
            'font1' => 'britanny',
            'font2' => '',
            'font3' => '',
        ]);

        HomepageSection::where('name', 'bookings')->update([
            'font1' => 'caslon540',
            'font2' => 'britanny',
            'font3' => 'caslon540',
            'font4' => '',
            'font5' => 'caslon540',
            'font6' => '',
            'font7' => 'caslon540',
            'font8' => '',
            'font9' => 'caslon540',
            'font10' => '',
        ]);

        HomepageSection::where('name', 'contact')->update([
            'font1' => 'britanny',
            'font2' => 'caslon540',
            'font3' => '',
        ]);

        echo 'done';
        exit;
    }
}
