<?php
namespace App\Http\Controllers\Admin;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Facades\DB; 

class MessageController extends Controller
{   

    var $column_order = array(null,null, 'msg','from_id','to_id','sent_on'); //set column field database for datatable orderable

    var $column_search = array( 'msg','f.username','t.username','sent_on'); //set column field database for datatable searchable

    var $order = array('msg_id' => 'asc'); // default order

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $messages = DB::table('message')
        ->leftJoin('users as f' , 'f.user_id','=','message.from_id')
        ->leftJoin('users as t' , 't.user_id','=','message.to_id')
        ->select(DB::raw('message.msg_id,f.username as from_id,t.username as to_id,message.sent_on'))
        ->orderBy('msg_id','DESC')
        ->get();
        //dd($messages);
        return view("admin.messages",compact('messages'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $action = 'add';
        return view('admin.messages-create',compact('action'));
    }

    private function _form_validation($request){
        $rules = [
            'msg' => 'required',
            'from_id' => 'required',
            'to_id'     => 'required',
            'sent_on'     => 'required',
          
        ];
        $messages = [
            'msg.required' => 'You can\'t leave Message field empty',
            'from_id.required' => 'You can\'t leave Message From field empty',
            'to_id.required'    => 'You can\'t leave Message To field empty',
            'sent_on.required'    => 'You can\'t leave Send On field empty',
            
        ]; 
        $type='P';
        $this->validate($request,$rules,$messages);
        $postData = array(
            'msg' => $request->msg,
            'from_id' => $request->from_id,
            'to_id'     => $request->to_id,
            'sent_on'     => $request->send_on,
      
            
        ); 
        return $postData;
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $data = $this->_form_validation($request); 
        DB::table('message')->insert($data);
        return redirect( config('app.admin_url').'/messages')->with('success','Message details submitted successfully');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $messages = DB::table('message')
        ->leftJoin('users as f' , 'f.user_id','=','message.from_id')
        ->leftJoin('users as t' , 't.user_id','=','message.to_id')
        ->select(DB::raw('message.*,f.username as from_id,t.username as to_id'))
        ->orderBy('msg_id','DESC')
        ->get();
        return view("admin.messages",compact('messages'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $action = 'edit';
        $message = DB::table('message')->select(DB::raw("*"))->where('msg_id','=',$id)->first();
        // dd($category);
        return view('admin.messages-create',compact('message','id','action'));
    }

    public function view($id)
    {
        $action = 'view';
        $message = DB::table('message')
        ->leftJoin('users as f' , 'f.user_id','=','message.from_id')
        ->leftJoin('users as t' , 't.user_id','=','message.to_id')
        ->select(DB::raw('message.*,f.username as from_id,t.username as to_id,message.sent_on'))
        ->where('message.msg_id',$id)
        ->first();
         //dd($candidate);
        return view('admin.messages-create',compact('message','id','action'));

    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $data = $this->_form_validation($request);
        DB::table('message')->where('msg_id',$id)->update($data);
        return redirect( env('ADMIN_URL').'/messages')->with('success','Message details updated successfully');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }
    public function serverProcessing(Request $request)
    {
        $currentPath = url(config('app.admin_url')).'/messages/';

        $list = $this->get_datatables($request);
       // dd($list);
        $data = array();
        $no = $request->start;
        foreach ($list as $message) {
            $no++;
            $row = array();
            $row[] = '<a class="view" href="'.$currentPath.'view/'.$message->msg_id.'"><i class="fa fa-search"></i></a><a class="delete deleteSelSingle" style="cursor:pointer;" data-val="'.$message->msg_id.'"><i class="fa fa-trash"></i></a>';
            $row[] = '<div class="align-center"><input id="cb'.$no.'" name="key_m[]" class="delete_box blue-check" type="checkbox" data-val="'.$message->msg_id.'"><label for="cb'.$no.'"></label></div>';
            $row[] = $message->msg;
            $row[] = $message->to_id;
            $row[] = $message->from_id;
            $row[] = $message->sent_on;
            $row[] = $message->is_read;
            $row[] = $message->read_on;
           
            $row[] = '<a href="#" data-toggle="modal" data-target="#modal1" class="btn btn-primary process" data-val="'.$message->msg_id.'">Visible</a>';
            $data[] = $row;
        }

        $output = array(
            "draw" => $request->draw,
            "recordsTotal" => $this->count_all($request),
            "recordsFiltered" => $this->count_filtered($request),
            "data" => $data,
        );
        echo json_encode($output);
    }

    private function _get_datatables_query($request)
    {            
        $keyword = $request->search['value'];
        $order = $request->order;
        $messageRS = DB::table('message')
        ->leftJoin('users as f' , 'f.user_id','=','message.from_id')
        ->leftJoin('users as t' , 't.user_id','=','message.to_id')
        ->select(DB::raw('message.*,f.username as from_id,t.username as to_id'));
        $i = 0;

        foreach ($this->column_search as $item) // loop column
        {
            if($keyword) // if datatable send POST for search
            {
                $messageRS = $messageRS->orWhere($item, 'like', '%' . $keyword . '%') ;
            }
        }

        if(isset($order)) // here order processing
        {
            $messageRS = $messageRS->orderBy($this->column_order[$request->order['0']['column']], $request->order['0']['dir']);
        } 
        else if(isset($this->order))
        {
            $orderby = $this->order;
            $messageRS = $messageRS->orderBy(key($orderby),$orderby[key($orderby)]);
        }
        return $messageRS;
    }

    function get_datatables($request)
    {
        $messageRS = $this->_get_datatables_query($request);
        if($request->length != -1){
            $messageRS = $messageRS->limit($request->length);
            if($request->start != -1){
                $messageRS = $messageRS->offset($request->start);
            }
        }
        
        $meassages = $messageRS->get();
        return $meassages;
    }

    function count_filtered($request)
    {
        $messageRS = $this->_get_datatables_query($request);
        return $messageRS->count();
    }

    public function count_all($request)
    {
        $messageRS = DB::table('message')->select(DB::raw("count(*) as total"))->first();
        return $messageRS->total;
    }

    public function delete(Request $request){
        $rec_exists = array();
        $del_error = '';
        $ids = explode(',',$request->ids);
        foreach ($ids as $id) {
            DB::table('message')->where('msg_id', $id)->delete();
        }
        
        if($del_error == 'error'){
            $request->session()->put('error',$msg );
            return response()->json(['status' => 'error',"rec_exists"=>$rec_exists]);
        }else{
            if( count($ids) > 1){
                $msg = "Message deleted successfully";
            }else{
                $msg = "Message deleted successfully";
            }
            $request->session()->put('success', $msg);
            return response()->json(['status' => 'success',"rec_exists"=>$rec_exists]);
        }
    }

    public function copyContent($id)
    {
        $action = 'copy';
        $message = DB::table('message')->select(DB::raw("*"))->where('msg_id','=',$id)->first();
        // dd($category);
        return view('admin.messages-create',compact('id','message','action'));
    }
}
