<?php

namespace App\Http\Controllers\Admin;

use App\Models\Neckline;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Validator;

class NecklineController extends Controller
{
    public function index()
    {
        return view('admin.neckline.index', [
            'data' => Neckline::orderBy('updated_at','desc')->get(),
        ]);
    }

    public function create()
    {
        return view('admin.neckline.add');
    }

    public function store(Request $request) {
        $validator = Validator::make($request->all(), [
            'name' => 'required|string|max:191|unique:App\Models\Neckline,name',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $neckline = new Neckline;
        $neckline->name = $request->name;
        $neckline->save();

        session()->flash('message', 'Neckline added successfully.');

        return to_route('admin.necklines');
    }

    public function edit(Neckline $neckline)
    {
        return view('admin.neckline.edit', [
            'neckline' => $neckline,
        ]);
    }

    public function update(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'name' => 'required|string|max:191|unique:App\Models\Neckline,name,' . $request->id,
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $neckline = Neckline::where('id', $request->id)->first();
        $neckline->name = $request->name;
        $neckline->update();

        session()->flash('message', 'Neckline details updated successfully.');

        return to_route('admin.necklines');
    }

    public function delete(Neckline $neckline)
    {
        if ($neckline->delete()) {
            echo 'done';
        }

        exit;
    }
}
