<?php

namespace App\Http\Controllers\Admin;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\DB;

class PopupBannerController extends Controller
{

    var $column_order = array(null, null, 'title', 'start_date', 'end_date', 'type_name', 'image'); //set column field database for datatable orderable

    var $column_search = array('title', 'start_date', 'end_date', 'type_name', 'image'); //set column field database for datatable searchable

    var $order = array('created_at' => 'desc'); // default order

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function __construct()
    {
        $this->middleware('auth');
    }
    public function index($active = 1)
    {

        return view("admin.popup_banners");
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */


    private function _form_validation($request)
    {
        $rules = [
            'title' => 'required',
            'start_date'     => 'required',
            'end_date'     => 'required',
            //'password' => 'required',
            'type_id'     => 'nullable',
            'type_name'     => 'required',
            'active'     => 'nullable',
            'route'     => 'nullable',
            'show_once' => 'nullable',
            'image'          => 'image|mimes:jpeg,png,jpg,gif'
            //'zipcode'     => 'required',
        ];

        $messages = [
            'tilte.required' => 'You can\'t leave Title field empty',
            'start_date.required'    => 'You can\'t leave Start Date field empty',
            'end_date.required'    => 'You can\'t leave End Date field empty',
            'type_name.required'    => 'You can\'t leave Type field empty'
        ];

        $this->validate($request, $rules, $messages);


        $postData = array(
            'title' => $request->title,
            'start_date'     => $request->start_date,
            'end_date' => $request->end_date,
            'type_id' => isset($request->type_id) ? $request->type_id : 0,
            'type_name'     => $request->type_name,
            'active'     => isset($request->active) ? $request->active : 0,
            'show_once'     => isset($request->show_once) ? $request->show_once : 0,
            'route' => isset($request->route) ? $request->route : ''
        );

        if ($request->hasFile('image')) {
            $path = "banners";
            $filenametostore = $request->file('image')->store($path);
            Storage::setVisibility($filenametostore, 'public');
            $fileArray = explode('/', $filenametostore);
            $fileName = array_pop($fileArray);
            $postData['image'] = $fileName;
        }

        return $postData;
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $data = $this->_form_validation($request);
        $data['created_at'] = date('Y-m-d H:i:s');
        $data['updated_at'] = date('Y-m-d H:i:s');
        DB::table('popup_banners')->insert($data);
        return redirect(config('app.admin_url') . '/popup_banners')->with('success', 'Banner submitted successfully');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($active = 1)
    {
        $popup_banners = DB::table('popup_banners')
            ->select(DB::raw('*'))
            ->orderBy('created_at', 'DESC')
            ->get();
        $challenges=DB::table('challenges')->where('end_date','>=',date('Y-m-d H:i:s'))->get();
        return view("admin.popup_banners", compact('active', 'popup_banners','challenges'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $action = 'edit';
        $popup_banner = DB::table('popup_banners')->select(DB::raw("*"))->where('id', '=', $id)->first();
        $challenges=DB::table('challenges')->where("active", 1)->where('end_date','>=',date('Y-m-d H:i:s'))->get();
        // dd($challenges);
        return view('admin.popup_banner_create', compact('popup_banner', 'id', 'action','challenges'));
    }

    public function add()
    {
        $action = 'add';
        $id = 0;
        $challenges=DB::table('challenges')->where("active", 1)->where('end_date','>=',date('Y-m-d H:i:s'))->get();
        return view('admin.popup_banner_create', compact('id', 'action','challenges'));
    }

    public function view($id)
    {
        $action = 'view';
        $popup_banner = DB::table('popup_banners')->select(DB::raw("*"))->where('id', '=', $id)->first();
        $challenges=DB::table('challenges')->where('end_date','>=',date('Y-m-d H:i:s'))->get();
        return view('admin.popup_banner_create', compact('popup_banner', 'id', 'action','challenges'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $data = $this->_form_validation($request);
        $data['updated_at'] = date('Y-m-d H:i:s');
        DB::table('popup_banners')->where('id', $id)->update($data);
        return redirect(env('ADMIN_URL') . '/popup_banners')->with('success', 'Banner details updated successfully');
    }

    public function inactive($id)
    {
        DB::table('popup_banners')->where('id', $id)->update(array('active' => '0'));
        return redirect()->route('admin.popup_banners')->with('success', 'Banner Inactivated');
    }

    public function active($id)
    {
        DB::table('popup_banners')->where('id', $id)->update(array('active' => '1'));
        return  redirect()->route('admin.popup_banners')->with('success', 'Banner Activated');
    }


    public function serverProcessing(Request $request)
    {
        $currentPath = url(config('app.admin_url')) . '/popup_banners/';
        $list = $this->get_datatables($request);

        $data = array();
        $no = $request->start;
        foreach ($list as $banner) {
            $no++;

            $row = array();
            // $row[] = '<a class="view" href="'.$currentPath.'view/'.$wall_ads->ad_id.'"><i class="fa fa-search"></i></a><a class="edit" href="'.$currentPath.$wall_ads->ad_id.'/edit"><i class="fa fa-edit"></i></a><a class="copy" href="'.$currentPath.'copy/'.$wall_ads->ad_id.'"><i class="fa fa-copy"></i></a><a class="delete deleteSelSingle" style="cursor:pointer;" data-val="'.$wall_ads->ad_id.'"><i class="fa fa-trash"></i></a>';
            $row[] = '<a class="view" href="' . $currentPath . 'view/' . $banner->id . '"><i class="fa fa-search"></i></a><a class="edit" href="' . $currentPath . 'edit/' . $banner->id . '"><i class="fa fa-edit"></i></a><a class="delete deleteSelSingle" style="cursor:pointer;" data-val="' . $banner->id . '"><i class="fa fa-trash"></i></a>';
            $row[] = '<div class="align-center"><input id="cb' . $no . '" name="key_m[]" class="delete_box blue-check" type="checkbox" data-val="' . $banner->id . '"><label for="cb' . $no . '"></label></div>';
            $row[] = $banner->title;
            $row[] = date('Y-m-d', strtotime($banner->start_date));
            $row[] = date('Y-m-d', strtotime($banner->end_date));
            $row[] = '<img height="50" src="' . asset(Storage::url("banners/" . $banner->image)) . '">';

            $row[] = $banner->type_name;
            //$row[] = $wall_ads->zipcode;
            if ($banner->active == 1) {
                $row[] = '<a class="btn btn-success" href="' . $currentPath . 'inactive/' . $banner->id . '" onclick="return confirm(\'Are you sure, you want to inactivate this ad?\')">Active</a>';
            } else {
                $row[] = '<a class="btn btn-danger" href="' . $currentPath . 'active/' . $banner->id . '" onclick="return confirm(\'Are you sure, you want to activate this ad?\')">Inactive</a>';
            }
            //$row[] = '<a href="#" class="btn btn-primary">Change Password</a>';
            $data[] = $row;
        }

        $output = array(
            "draw" => $request->draw,
            "recordsTotal" => $this->count_all($request),
            "recordsFiltered" => $this->count_filtered($request),
            "data" => $data,
        );
        echo json_encode($output);
    }

    private function _get_datatables_query($request)
    {
        $keyword = $request->search['value'];
        $order = $request->order;
        $bannerRS = DB::table('popup_banners')
            ->select(DB::raw("*"));
        $strWhere = " 1=1 ";

        $strWhereOr = "";
        $i = 0;

        foreach ($this->column_search as $item) // loop column
        {
            if ($keyword) // if datatable send POST for search{
                $strWhereOr = $strWhereOr . " $item like '%" . $keyword . "%' or ";
            //$candidateRS = $candidateRS->orWhere($item, 'like', '%' . $keyword . '%') ;
        }
        $strWhereOr = trim($strWhereOr, "or ");
        if ($strWhereOr != "") {
            $bannerRS = $bannerRS->whereRaw(DB::raw($strWhere . " and (" . $strWhereOr . ")"));
        } else {
            $bannerRS = $bannerRS->whereRaw(DB::raw($strWhere));
        }


        if (isset($order)) // here order processing
        {
            $bannerRS = $bannerRS->orderBy($this->column_order[$request->order['0']['column']], $request->order['0']['dir']);
        } else if (isset($this->order)) {
            $orderby = $this->order;
            $bannerRS = $bannerRS->orderBy(key($orderby), $orderby[key($orderby)]);
        }
        return $bannerRS;
    }

    function get_datatables($request)
    {
        $bannerRS = $this->_get_datatables_query($request);
        if ($request->length != -1) {
            $bannerRS = $bannerRS->limit($request->length);
            if ($request->start != -1) {
                $bannerRS = $bannerRS->offset($request->start);
            }
        }

        $bannerRS = $bannerRS->get();
        return $bannerRS;
    }

    function count_filtered($request)
    {
        $bannerRS = $this->_get_datatables_query($request);
        return $bannerRS->count();
    }

    public function count_all($request)
    {
        $bannerRS = DB::table('popup_banners')->select(DB::raw("count(*) as total"))->first();
        return $bannerRS->total;
    }

    public function delete(Request $request)
    {
        $rec_exists = array();
        $ids = explode(',', $request->ids);
        foreach ($ids as $id) {
            DB::table('popup_banners')->where('id', $id)->delete();
        }

        if (count($ids) > 1) {
            $msg = "Banners deleted successfully";
        } else {
            $msg = "Banner deleted successfully";
        }
        $request->session()->put('success', $msg);
        return response()->json(['status' => 'success', "rec_exists" => $rec_exists]);
    }
}
