<?php

namespace App\Http\Controllers\Admin;

use App\Models\Size;
use App\Models\Brand;
use App\Models\Color;
use App\Models\Fabric;
use App\Models\Season;
use App\Models\Product;
use App\Models\Category;
use App\Models\Neckline;
use App\Models\PageFont;
use App\Models\Silhouette;
use App\Models\ProductSize;
use Illuminate\Support\Str;
use Illuminate\Http\Request;
use App\Models\ProductSeason;
use App\Models\ProductCategory;
use App\Models\ProductVariation;
use Yajra\DataTables\DataTables;
use App\Http\Controllers\Controller;
use App\Models\ProductVariationImage;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\Validator;

class ProductController extends Controller
{
    public function index(Request $request)
    {
        $fonts = PageFont::where('page', 'product')->first();

        $title = 'Products';
        if ($request->ajax()) {
            $data = Product::latest()->get();
            return DataTables::of($data)
                ->addIndexColumn()
                ->addColumn('action', function ($row) {
                    $actionBtn = ' <ul class="list-inline me-auto mb-0">
                    <li class="list-inline-item align-bottom" data-bs-toggle="tooltip" title="Edit">
                    <a href="' . route('admin.products.edit', $row->id) . '" class="edit avtar avtar-xs btn-link-success btn-pc-default"><i class="ti ti-edit-circle f-18"></i></a>
                    </li>
                    <li class="list-inline-item align-bottom" data-bs-toggle="tooltip" title="Edit">
                    <a href="javascript:void(0)" class="deleteSelSingle delete avtar avtar-xs btn-link-danger btn-pc-default" data-val=' . $row->id . '> <i class="ti ti-trash f-18"></i></a>
                    </li>';
                    return $actionBtn;
                })
                ->addColumn('active', function ($row) {
                    $checked = "";
                    if ($row->active == 1) {
                        $checked = 'checked';
                    }
                    return '<div class="form-check form-switch custom-switch-v1 mb-2">
                        <input type="checkbox" class="form-check-input input-success active_item" data-name="' . $row->product_code . '" data-value="' . $row->active . '" data-id="' . $row->id . '" ' . $checked . '>
                    </div>';
                })
                ->rawColumns(['action', 'active'])
                ->make(true);
        }
        return view('admin.product.index', compact('title', 'fonts'));
    }

    public function create()
    {
        $action = 'Create';
        $title = 'Product';
        $categories = Category::where('active', 1)->get();
        $necklines = Neckline::get();
        $fabrics = Fabric::get();
        $silhouettes = Silhouette::get();
        $seasons = Season::get();
        $colors = Color::get();
        $sizes = Size::where('is_plus', 0)->get();
        $plus_sizes = Size::where('is_plus', 1)->get();
        $brands = Brand::get();
        return view('admin.product.product', compact('action', 'title', 'categories', 'necklines', 'fabrics', 'brands', 'silhouettes', 'seasons', 'colors', 'sizes', 'plus_sizes'));
    }

    public function edit($id)
    {
        $action = 'Edit';
        $title = 'Product';
        $record = Product::with(['categories', 'seasons', 'normal_sizes' => function ($q) {
            $q->where('is_plus', 0)->orderBy('id', 'asc');
        }, 'plus_sizes' => function ($q) {
            $q->where('is_plus', 1)->orderBy('id', 'asc');
        }, 'variations' => function ($q) {
            $q->with(['images']);
        }])->find($id);
        // dd( $record);
        $categories = Category::where('active', 1)->get();
        $necklines = Neckline::get();
        $fabrics = Fabric::get();
        $silhouettes = Silhouette::get();
        $seasons = Season::get();
        $colors = Color::get();
        $sizes = Size::where('is_plus', 0)->get();
        $plus_sizes = Size::where('is_plus', 1)->get();
        $brands = Brand::get();
        return view('admin.product.product', compact('action', 'title', 'record', 'colors', 'categories', 'necklines', 'fabrics', 'brands', 'silhouettes', 'seasons', 'sizes', 'plus_sizes'));
    }

    private function _form_validation($request)
    {
        // dd($request->all());

        $rules = [
            'product_code' => 'required|unique:App\Models\Product,product_code,' . $request->id,
            'cat_ids' => 'nullable',
            'season_ids' => 'nullable',
            'fabric_id' => 'nullable',
            'neckline_id' => 'nullable',
            'silhouette_id' => 'nullable',
            'color_id' => 'nullable',
            'brand_id' => 'nullable',
            'visible_type' => 'nullable',
            'price' => 'nullable',
            'discounted_price' => 'nullable',
            'active' => 'nullable',
            'images' => 'nullable',
            'videos' => 'nullable',
            'list_images' => 'nullable',
            'rank' => 'nullable',
            'description' => 'nullable',
            'meta_title' => 'nullable',
            'meta_keyword' => 'nullable',
            'meta_description' => 'nullable',
            'og_title' => 'nullable',
            'og_description' => 'nullable'
        ];
        $messages = [
            'product_code.required' => 'Product Code is required',

        ];
        $request->validate($rules, $messages);
        $product_id = isset($request->id) ? $request->id : 0;

        $product = Product::find($product_id);
        if (!$product) {
            $product = new Product();
        }
        $product->product_code = $request->product_code;
        $product->fabric_id = isset($request->fabric_id) ? $request->fabric_id : 0;
        $product->neckline_id = isset($request->neckline_id) ? $request->neckline_id : 0;
        $product->silhouette_id = isset($request->silhouette_id) ? $request->silhouette_id : 0;
        $product->brand_id = isset($request->brand_id) ? $request->brand_id : 0;

        // $product->alias = isset($request->alias) ? Str::slug($request->alias) : Str::slug($request->name);
        $product->rank = isset($request->rank) ? $request->rank : 0;
        $product->description = isset($request->summary) ? $request->summary : '';
        $product->meta_title = isset($request->meta_title) ? $request->meta_title : '';
        $product->meta_keywords = isset($request->meta_keywords) ? $request->meta_keywords : '';
        $product->meta_description = isset($request->meta_description) ? $request->meta_description : '';
        $product->og_title = isset($request->og_title) ? $request->og_title : '';
        $product->og_description = isset($request->og_description) ? $request->og_description : '';
        $product->active = isset($request->active) ? $request->active : 0;
        // dd($product);
        $product->save();
        $product_id = $product->id;

        $image_file_name = '';


        // product sizes
        ProductSize::where('product_id', $product_id)->delete();

        if (isset($request->from_size) && isset($request->to_size)) {
            $from_size_id = $request->from_size;
            $to_size_id = $request->to_size;
            $sizes = Size::where('id', '>=', $from_size_id)->where('id', '<=', $to_size_id)->get();
            foreach ($sizes as $size) {
                $productSize = new ProductSize();
                $productSize->product_id = $product_id;
                $productSize->size_id = $size->id;
                $productSize->save();
            }
        }

        // product plus sizes
        if (isset($request->from_plus_size) && isset($request->to_plus_size)) {
            $from_plus_size_id = $request->from_plus_size;
            $to_plus_size_id = $request->to_plus_size;
            $sizes = Size::where('id', '>=', $from_plus_size_id)->where('id', '<=', $to_plus_size_id)->get();
            foreach ($sizes as $size) {
                $productSize = new ProductSize();
                $productSize->product_id = $product_id;
                $productSize->size_id = $size->id;
                $productSize->save();
            }
        }

        //categories
        ProductCategory::where('product_id', $product_id)->delete();
        if ($request->cat_ids) {
            foreach ($request->cat_ids as $cat_id) {
                if ($cat_id != null) {
                    $category = new ProductCategory();
                    $category->product_id = $product_id;
                    $category->cat_id = $cat_id;
                    $category->save();

                    $category = Category::find($cat_id);
                    $image_file_name .= $category->name . '-';
                }
            }
        }
        // seasons
        ProductSeason::where('product_id', $product_id)->delete();
        if ($request->season_ids) {
            foreach ($request->season_ids as $season_id) {
                if ($season_id != null) {
                    $season = new ProductSeason();
                    $season->product_id = $product_id;
                    $season->season_id = $season_id;
                    $season->save();
                }
            }
        }
        // product variations
        // dd($request->all());
        $totalVariations = count($request->variation_id);
        for ($x = 0; $x < $totalVariations; $x++) {
            $variation_id = isset($request->variation_id[$x]) ? $request->variation_id[$x] : 0;

            $variation = ProductVariation::find($variation_id);
            if (!$variation) {
                $variation = new ProductVariation();
            }

            $color = Color::find($request->color_id[$x]);
            if ($color) {
                $color = $color->name;
            }

            $variation->product_id = $product_id;
            $variation->color_id = isset($request->color_id[$x]) ? $request->color_id[$x] : 0;
            $variation->visible_type = ($request->visible_type[$x] == 1) ? 'V' : 'I';
            $variation->description = $request->description[$x];
            $variation->price = $request->price[$x];
            $variation->discounted_price = $request->discounted_price[$x];
            $variation->rank = isset($request->variation_rank[$x]) ? $request->variation_rank[$x] : 0;
            $variation->active = $request->variation_active[$x];
            $variation->discounted_price = $request->discounted_price[$x];

            $path = "public/products/" . $product_id;
            $old_image = $request->old_image[$x];
            $image = isset($request->image[$x]) ? 'image' : '';

            if ($request->hasFile($image)) {
                $file = $request->file($image)[$x];
                $imagename = $image_file_name . $color . '-' . time() . '.' . $file->getClientOriginalExtension();
                $filenametostore = $file->storeAs($path, $imagename);
                // Storage::setVisibility($filenametostore, 'public');
                $variation->image = $imagename;
            } else if (isset($old_image)) {
                $variation->image = $old_image;
            }

            $old_video = $request->old_video[$x];
            $video = isset($request->video[$x]) ? 'video' : '';

            if ($request->hasFile($video)) {
                $file = $request->file($video)[$x];
                $videoname =  $image_file_name . $color . '-' . time() . '.' . $file->getClientOriginalExtension();
                $filenametostore = $file->storeAs($path, $videoname);
                // Storage::setVisibility($filenametostore, 'public');
                $variation->video = $videoname;
            } else if (isset($old_video)) {
                $variation->video = $old_video;
            }
            $variation->save();
            $variation_id = $variation->id;

            // $old_list_images = explode(',', $request->old_list_images[$x]);
            // ProductVariationImage::where('product_variation_id',$variation_id)->where('product_id',$product_id)->whereNotIn('image',$old_list_images)->delete();

            // variations multiple images
            $list_images = explode(',', $request->list_images[$x]);
            // dd($list_images);
            // $count=count($old_list_images);
            foreach ($list_images as $key => $img) {
                if ($img != "") {
                    if (Storage::exists('public/temp/' . $img)) {
                        $ext = explode('.', $img);
                        $extension = end($ext);
                        $fileName = $key . '-' . $image_file_name . '-' . $variation_id . '-' . time() . '.' . $extension;
                        $imgName = $path . '/' . $fileName;
                        Storage::move('public/temp/' . $img, $imgName);

                        $variationImages = new ProductVariationImage();
                        $variationImages->product_id = $product_id;
                        $variationImages->product_variation_id = $variation_id;
                        $variationImages->image = $fileName;
                        $variationImages->rank = $key;
                        $variationImages->save();
                    } else {
                        $variationImg = ProductVariationImage::where('image', $img)
                            ->where('product_id', $product_id)
                            ->where('product_variation_id', $variation_id)->first();
                        if ($variationImg) {
                            $variationImg->rank = $key;
                            $variationImg->save();
                        }
                    }
                }
            }
        }
    }

    public function store(Request $request)
    {
        $this->_form_validation($request);
        // $data['created_at'] = date('Y-m-d H:i:s');
        // Product::insertGetId($data);

        return redirect()->route('admin.products')->with('success', 'Data submitted successfully');
    }

    public function update($id, Request $request)
    {
        $this->_form_validation($request);
        // $data['updated_at'] = date('Y-m-d H:i:s');
        // Product::where('id', $id)->update($data);

        return redirect()->route('admin.products')->with('success', 'Data updated successfully');
    }

    public function uploadListImage(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'files.*' => 'image|mimes:jpeg,png,jpg,gif,webp'
        ]);

        if ($validator->fails()) {
            return redirect()->back()
                ->withErrors($validator)
                ->withInput();
        }
        if ($request->hasFile('files')) {
            $allowedfileExtension = ['jpg', 'jpeg', 'png','webp'];
            $files = $request->file('files');
            $list_images = '';
            $path = 'public/temp';
            foreach ($files as $file) {
                $filename = $file->getClientOriginalName();
                $extension = $file->getClientOriginalExtension();
                $check = in_array($extension, $allowedfileExtension);
                if ($check) {
                    $imagename = time() . '_' . $filename;
                    $file->storeAs($path, $imagename);
                    $list_images .= ',' . $imagename;
                }
            }
            return response()->json(['status' => true, 'images' => trim($list_images, ',')]);
        }
    }

    public function updateActive(Request $request)
    {
        $id = $request->id;
        $active = ($request->value == 0) ? 1 : 0;
        Product::where('id', $id)->update(['active' => $active]);
        $msg = 'Record has been deactivated';
        if ($active == 1) {
            $msg = 'Record has been activated';
        }
        return response()->json(['status' => true, 'msg' => $msg]);
    }

    public function destroy(Request $request)
    {
        $ids = $request->ids;
        $ids = explode(",", $ids);

        Product::whereIn('id', $ids)->delete();
        ProductVariation::whereIn('product_id', $ids)->delete();
        ProductVariationImage::whereIn('product_id', $ids)->delete();
        ProductCategory::whereIn('product_id', $ids)->delete();
        ProductSeason::whereIn('product_id', $ids)->delete();
        ProductSize::whereIn('product_id', $ids)->delete();

        if (count($ids) > 1) {
            $msg = "Records deleted successfully";
        } else {
            $msg = "Record deleted successfully";
        }
        $request->session()->put('success', $msg);
        return response(['status' => true, 'msg' => $msg]);
    }

    public function addMoreVariation(Request $request)
    {
        $colors = Color::get();
        $html = view('admin.product.product_variation', ['title' => 'New Variation', 'colors' => $colors])->render();
        return $html;
    }

    public function deleteListImage(Request $request)
    {
        $id = $request->id;
        if ($id > 0) {
            ProductVariationImage::where('id', $id)->delete();
        }
        return response()->json(['status' => true]);
    }


    public function removeFile(Request $request)
    {
        if ($request->type == 'I') {
            ProductVariation::where('id', $request->id)->update(['image' => '']);
            $msg = 'Image Removed!';
        } else if ($request->type == 'V') {
            ProductVariation::where('id', 1)->update(['video' => '']);
            $msg = 'Video Removed!';
        }

        $request->session()->put('success', $msg);
        return response(['status' => true, 'msg' => $msg]);
    }

    public function deleteVariation(Request $request)
    {
        $id = $request->id;
        ProductVariation::where('id', $id)->delete();
        ProductVariationImage::where('product_variation_id', $id)->delete();
        $msg = 'Variation removed!';
        $request->session()->put('success', $msg);

        return response(['status' => true, 'msg' => $msg]);
    }
}
