<?php

namespace App\Http\Controllers\Admin;

use App\Models\ProductModel;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Validator;

class ProductModelController extends Controller
{
    public function index()
    {
        return view('admin.product_model.index', [
            'data' => ProductModel::orderBy('updated_at','desc')->get(),
        ]);
    }

    public function create()
    {
        return view('admin.product_model.add');
    }

    public function store(Request $request) {
        $validator = Validator::make($request->all(), [
            'name' => 'required|string|max:191',
            'rank' => 'nullable|min:1',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $model = new ProductModel;
        $model->name = $request->name;
        $model->rank = $request->rank;
        $model->save();

        session()->flash('message', 'Model added successfully.');

        return to_route('admin.models');
    }

    public function edit(ProductModel $model)
    {
        return view('admin.product_model.edit', compact('model'));
    }

    public function update(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'name' => 'required|string|max:191|unique:App\Models\ProductModel,name,' . $request->id,
            'rank' => 'nullable|min:1',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $model = ProductModel::where('id', $request->id)->first();
        $model->name = $request->name;
        $model->rank = $request->rank;
        $model->update();

        session()->flash('message', 'Model details updated successfully.');

        return to_route('admin.models');
    }

    public function delete(ProductModel $model)
    {
        if ($model->delete()) {
            echo 'done';
        }

        exit;
    }
}
