<?php

namespace App\Http\Controllers\Admin;

use App\Models\Season;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Validator;

class SeasonController extends Controller
{
    public function index()
    {
        return view('admin.season.index', [
            'data' => Season::orderBy('updated_at','desc')->get(),
        ]);
    }

    public function create()
    {
        return view('admin.season.add');
    }

    public function store(Request $request) {
        $validator = Validator::make($request->all(), [
            'name' => 'required|string|max:191|unique:App\Models\Season,name',
            // 'show_color_option' => 'required|boolean',
            'rank' => 'nullable|min:1',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $season = new Season;
        $season->name = $request->name;
        // $season->show_color_option = $request->show_color_option;
        $season->rank = $request->rank;
        $season->save();

        session()->flash('message', 'Season added successfully.');

        return to_route('admin.seasons');
    }

    public function edit(Season $season)
    {
        return view('admin.season.edit', [
            'season' => $season,
        ]);
    }

    public function update(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'name' => 'required|string|max:191|unique:App\Models\Season,name,' . $request->id,
            // 'show_color_option' => 'required|boolean',
            'rank' => 'nullable|min:1',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $season = Season::where('id', $request->id)->first();
        $season->name = $request->name;
        // $season->show_color_option = $request->show_color_option;
        $season->rank = $request->rank;
        $season->update();

        session()->flash('message', 'Season details updated successfully.');

        return to_route('admin.seasons');
    }

    public function delete(Season $season)
    {
        if ($season->delete()) {
            echo 'done';
        }

        exit;
    }
}
