<?php

namespace App\Http\Controllers\Admin;

use App\Models\Service;
use App\Models\PageFont;
use Illuminate\Support\Str;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\Validator;
use Yajra\DataTables\DataTables;

class ServiceController extends Controller
{
    public function index(Request $request)
    {
        $fonts = PageFont::where('page', 'service')->first();

        $title = 'Services';
        if ($request->ajax()) {
            $data = Service::latest()->get();

            return DataTables::of($data)
                ->addIndexColumn()
                ->addColumn('action', function ($row) {
                    $actionBtn = ' <ul class="list-inline me-auto mb-0">
                    <li class="list-inline-item align-bottom" data-bs-toggle="tooltip" title="Edit">
                    <a href="' . route('admin.edit-service', $row->id) . '" class="edit avtar avtar-xs btn-link-success btn-pc-default"><i class="ti ti-edit-circle f-18"></i></a>
                    </li>
                    <li class="list-inline-item align-bottom" data-bs-toggle="tooltip" title="Edit">
                    <a href="javascript:void(0)" class="deleteSelSingle delete avtar avtar-xs btn-link-danger btn-pc-default" data-val=' . $row->id . '> <i class="ti ti-trash f-18"></i></a>
                    </li>';
                    return $actionBtn;
                })
                ->editColumn('name', function ($row) {
                    return Str::limit($row->name, 100);
                })
                ->editColumn('alias', function ($row) {
                    return Str::limit($row->alias, 100);
                })
                ->editColumn('created_at', function ($row) {
                    return date('Y-m-d H:i:s', strtotime($row->created_at));
                })
                ->rawColumns(['name', 'alias', 'action'])
                ->make(true);
        }
        return view('admin.service.index', compact('title', 'fonts'));
    }

    public function create()
    {
        return view('admin.service.add');
    }

    public function store(Request $request) {
        $validator = Validator::make($request->all(), [
            'name' => 'required|string|max:191|unique:App\Models\Service,name',
            'alias' => 'nullable|string|max:191|unique:App\Models\Service,alias',
            'image' => 'nullable|file|max:1024000|mimes:jpg,jpeg,png,webp',
            'description' => 'nullable',
            'rank' => 'nullable|min:1',
            'active' => 'boolean',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $service = new Service;
        $service->name = $request->name;
        $service->alias = $request->alias ? $request->alias : Str::slug($request->name, '-');
        $service->description = $request->description;
        $service->rank = $request->rank;
        $service->active = $request->active == NULL ? 0 : 1;

        if ($request->file('image') != NULL) {
            $image = $request->file('image');
            $uploadPath = "public/uploads/service";
            $service->image = $image->store($uploadPath);
        }

        $service->save();

        session()->flash('message', 'Service added successfully.');

        return to_route('admin.services');
    }

    public function edit(Service $service)
    {
        if ($service->image != NULL) {
            if (Storage::exists($service->image)) {
                $service->image = asset(Storage::url($service->image));
            }
        }

        return view('admin.service.edit', compact('service'));
    }

    public function update(Request $request) {

        $validator = Validator::make($request->all(), [
            'name' => 'required|string|max:191|unique:App\Models\Service,name,' . $request->id,
            'alias' => 'nullable|string|max:191|unique:App\Models\Service,alias,' . $request->id,
            'image' => 'nullable|file|max:1024000|mimes:jpg,jpeg,png,webp',
            'description' => 'nullable',
            'rank' => 'nullable|min:1',
            'active' => 'boolean',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $service = Service::where('id', $request->id)->first();

        $service->name = $request->name;
        $service->alias = $request->alias ? $request->alias : Str::slug($request->name, '-');
        $service->description = $request->description;
        $service->rank = $request->rank;
        $service->active = $request->active == NULL ? 0 : 1;

        if ($request->file('image') != NULL) {
            if ($service->image != NULL) {
                Storage::delete($service->image);
            }

            $image = $request->file('image');
            $uploadPath = "public/uploads/service";
            $service->image = $image->store($uploadPath);
        }

        $service->update();

        session()->flash('message', 'Service details updated successfully.');

        return to_route('admin.services');
    }

    public function destroy(Request $request)
    {
        $ids = $request->ids;
        $ids = explode(",", $ids);

        Service::whereIn('id', $ids)->delete();

        if (count($ids) > 1) {
            $msg = "Records deleted successfully";
        } else {
            $msg = "Record deleted successfully";
        }

        $request->session()->put('success', $msg);

        return response(['status' => true, 'msg' => $msg]);
    }
}
