<?php

namespace App\Http\Controllers\Admin;

use App\Models\Silhouette;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Validator;

class SilhouetteController extends Controller
{
    public function index()
    {
        return view('admin.silhouette.index', [
            'data' => Silhouette::orderBy('updated_at','desc')->get(),
        ]);
    }

    public function create()
    {
        return view('admin.silhouette.add');
    }

    public function store(Request $request) {
        $validator = Validator::make($request->all(), [
            'name' => 'required|string|max:191|unique:App\Models\Silhouette,name',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $silhouette = new Silhouette;
        $silhouette->name = $request->name;
        $silhouette->save();

        session()->flash('message', 'Silhouette added successfully.');

        return to_route('admin.silhouettes');
    }

    public function edit(Silhouette $silhouette)
    {
        return view('admin.silhouette.edit', [
            'silhouette' => $silhouette,
        ]);
    }

    public function update(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'name' => 'required|string|max:191|unique:App\Models\Silhouette,name,' . $request->id,
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $silhouette = Silhouette::where('id', $request->id)->first();
        $silhouette->name = $request->name;
        $silhouette->update();

        session()->flash('message', 'Silhouette details updated successfully.');

        return to_route('admin.silhouettes');
    }

    public function delete(Silhouette $silhouette)
    {
        if ($silhouette->delete()) {
            echo 'done';
        }

        exit;
    }
}
