<?php

namespace App\Http\Controllers\Admin;

use App\Models\Slider;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\Validator;

class SliderController extends Controller
{
    public function index()
    {
        return view('admin.slider.index', [
            'data' => Slider::orderBy('updated_at','desc')->get(),
        ]);
    }

    public function create()
    {
        return view('admin.slider.add');
    }

    public function store(Request $request) {
        $validator = Validator::make($request->all(), [
            'image' => 'required|file|max:1024000|mimes:jpg,jpeg,png,webp',
            'sub_image' => 'required|file|max:1024000|mimes:jpg,jpeg,png,webp',
            'title' => 'required|string|max:191',
            'subtitle' => 'nullable|string|max:191',
            'tagline' => 'nullable|string|max:191',
            'button_text' => 'nullable|string|max:50',
            'button_link' => 'nullable|string|max:191',
            'rank' => 'nullable|integer|max:9999',
            'active' => 'nullable|boolean',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $slider = new Slider;

        if ($request->file('image') != NULL) {
            $image = $request->file('image');
            $uploadPath = "public/uploads/slider";
            $slider->image = $image->store($uploadPath);
        }

        if ($request->file('sub_image') != NULL) {
            $image = $request->file('sub_image');
            $uploadPath = "public/uploads/slider";
            $slider->sub_image = $image->store($uploadPath);
        }

        $slider->title = $request->title;
        $slider->subtitle = $request->subtitle;
        $slider->tagline = $request->tagline;
        $slider->button_text = $request->button_text;
        $slider->button_link = $request->button_link;
        $slider->rank = $request->rank;
        $slider->button_link = $request->button_link;
        $slider->save();

        session()->flash('message', 'Image added to slider successfully.');

        return to_route('admin.slider');
    }

    public function edit(Slider $slider)
    {
        if ($slider->image != NULL) {
            if (Storage::exists($slider->image)) {
                $slider->image = asset(Storage::url($slider->image));
            }
        }

        if ($slider->sub_image != NULL) {
            if (Storage::exists($slider->sub_image)) {
                $slider->sub_image = asset(Storage::url($slider->sub_image));
            }
        }

        return view('admin.slider.edit', [
            'slider' => $slider,
        ]);
    }

    public function update(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'image' => 'nullable|file|max:1024000|mimes:jpg,jpeg,png,webp',
            'sub_image' => 'nullable|file|max:1024000|mimes:jpg,jpeg,png,webp',
            'title' => 'nullable|string|max:191',
            'subtitle' => 'nullable|string|max:191',
            'tagline' => 'nullable|string|max:191',
            'button_text' => 'nullable|string|max:50',
            'button_link' => 'nullable|string|max:191',
            'rank' => 'nullable|integer|max:9999',
            'active' => 'nullable|boolean',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $slider = Slider::where('id', $request->id)->first();

        if ($request->file('image') != NULL) {
            $image = $request->file('image');
            $uploadPath = "public/uploads/slider";
            $slider->image = $image->store($uploadPath);
        }

        if ($request->file('sub_image') != NULL) {
            $image = $request->file('sub_image');
            $uploadPath = "public/uploads/slider";
            $slider->sub_image = $image->store($uploadPath);
        }

        $slider->title = $request->title;
        $slider->subtitle = $request->subtitle;
        $slider->tagline = $request->tagline;
        $slider->button_text = $request->button_text;
        $slider->button_link = $request->button_link;
        $slider->rank = $request->rank;
        $slider->button_link = $request->button_link;
        $slider->update();

        session()->flash('message', 'Slider details updated successfully.');

        return to_route('admin.slider');
    }

    public function delete(Slider $slider)
    {
        if ($slider->delete()) {
            echo 'done';
        }

        exit;
    }
}
