<?php

namespace App\Http\Controllers\Admin;

use App\Models\Day;
use App\Models\City;
use App\Models\User;
use App\Models\State;
use App\Models\Country;
use App\Models\Service;
use App\Models\StaffService;
use Illuminate\Http\Request;
use App\Models\StaffWorkingDay;
use App\Models\AppointmentService;
use Illuminate\Support\Facades\DB;
use App\Http\Controllers\Controller;
use App\Models\AppointmentServiceStaff;
use Illuminate\Support\Facades\Storage;
use Yajra\DataTables\Facades\DataTables;
use App\Models\AppointmentServiceCategory;
use App\Models\AppointmentServiceTimeSheet;

class StaffController extends Controller
{
    public function index(Request $request)
    {
        $title = 'Staff';
        if ($request->ajax()) {
            $data = User::with(['services'])->where('utype', 'S')->latest()->get();

            return DataTables::of($data)
                ->addIndexColumn()
                ->addColumn('action', function ($row) {
                    $actionBtn = ' <ul class="list-inline me-auto mb-0">
                    <li class="list-inline-item align-bottom" data-bs-toggle="tooltip" title="Edit">
                    <a href="' . route('admin.staff.edit', $row->id) . '" class="edit avtar avtar-xs btn-link-success btn-pc-default"><i class="ti ti-edit-circle f-18"></i></a>
                    </li>
                    <li class="list-inline-item align-bottom" data-bs-toggle="tooltip" title="Edit">
                    <a href="javascript:void(0)" class="deleteSelSingle delete avtar avtar-xs btn-link-danger btn-pc-default" data-val=' . $row->id . '> <i class="ti ti-trash f-18"></i></a>
                    </li>';
                    return $actionBtn;
                })
                ->addColumn('image', function ($row) {
                    $image = "";
                    if ($row->image != "") {
                        $image = asset(Storage::url('staff')) . '/' . $row->image;
                        return "<img class='" . 'rounded rounded-circle' . "' src='" . $image . "' width='100'>";
                    }
                    return $image;
                })
                ->addColumn('services', function ($row) {
                    $services = "";
                    foreach ($row->services as $service) {
                        $services .= $service->name.',';
                    }
                    return trim($services,',');
                })
                ->addColumn('active', function ($row) {
                    $checked = "";
                    if ($row->active == 1) {
                        $checked = 'checked';
                    }
                    return '<div class="form-check form-switch custom-switch-v1 mb-2">
                        <input type="checkbox" class="form-check-input input-success active_item" data-name="' . $row->first_name . '" data-value="' . $row->active . '" data-id="' . $row->id . '" ' . $checked . '>
                    </div>';
                })
                ->rawColumns(['action', 'active', 'image','services'])
                ->make(true);
        }

        return view('admin.staff.index', compact('title'));
    }

    public function create()
    {
        $action = 'Create';
        $title = 'Staff';
        $countries = Country::get();
        $days = Day::get();
        $services = AppointmentServiceCategory::with(['services'])->get();
        return view('admin.staff.staff', compact('action', 'title', 'countries', 'days', 'services'));
    }

    public function edit($id)
    {
        $action = 'Edit';
        $title = 'Staff';
        $record = User::with(['working_days'])->find($id);
        $countries = Country::orderBy(DB::raw('id=' . $record->country_id), 'asc')->limit(5)->get();
        $state_id = $record->state_id;
        $city_id = $record->city_id;
        $state = State::find($state_id);
        $city = City::find($city_id);
        $days = Day::get();
        $services = AppointmentServiceCategory::with(['services'])->get();
        return view('admin.staff.staff', compact('action', 'title', 'countries', 'record', 'days', 'state', 'city', 'services'));
    }


    private function _form_validation($request)
    {
        // dd($request->all());
        $rules = [
            'first_name' => 'required',
            'last_name' => 'nullable',
            'email' => 'nullable',
            'phone' => 'nullable',
            'country_id' => 'nullable',
            'state_id' => 'nullable',
            'city_id' => 'nullable',
            'zipcode' => 'nullable',
            'address' => 'nullable',
            'in_time' => 'nullable',
            'out_time' => 'nullable',
            'days.*' => 'required',
            'services.*' => 'required',
        ];
        $messages = [
            'first_name.required' => 'Name is required',

        ];
        $request->validate($rules, $messages);

        $postData = array(
            'first_name' => $request->first_name,
            'last_name' => isset($request->last_name) ? $request->last_name : '',
            'utype' => 'S',
            'email' => $request->email,
            'phone' => isset($request->phone) ? $request->phone : '',
            'country_id' => isset($request->country_id) ? $request->country_id : 0,
            'state_id' => isset($request->state_id) ? $request->state_id : 0,
            'city_id' => isset($request->city_id) ? $request->city_id : 0,
            'zipcode' => isset($request->zipcode) ? $request->zipcode : '',
            'address' => isset($request->address) ? $request->address : '',
            'in_time' => isset($request->in_time) ? $request->in_time : null,
            'out_time' => isset($request->out_time) ? $request->out_time : null
        );

        $image = isset($request->image) ? 'image' : '';
        if ($request->hasFile($image)) {
            $path = "public/staff";
            $file = $request->file($image);
            // dd($request->file($image));
            $image = time() . '_' . $file->getClientOriginalName();
            $file->storeAs($path, $image);
            // Storage::setVisibility($filenametostore, 'public');
            $postData['image'] = $image;
        } else if (isset($request->old_image)) {
            $old_image = $request->old_image;
            $postData['image']  = $old_image;
        }

        return $postData;
    }

    public function store(Request $request)
    {
        $data = $this->_form_validation($request);
        $data['created_at'] = date('Y-m-d H:i:s');
        $id = User::insertGetId($data);

        AppointmentServiceStaff::where("user_id", $id)->delete();
        if($request->services){
            $data = [];
            foreach ($request->services as $service) {
                $data[] = [
                    'user_id' => $id,
                    'service_id' => $service,
                ];
            }
            AppointmentServiceStaff::insert($data);

            $servicesDay = AppointmentServiceTimeSheet::whereIn('service_id', $request->services)->where('active', 1)->get()->pluck('day_id')->unique()->toArray();
            StaffWorkingDay::where("user_id", $id)->delete();
            if (count($servicesDay) > 0) {
                foreach ($servicesDay as $day) {
                    $workingDay = new StaffWorkingDay();
                    $workingDay->user_id = $id;
                    $workingDay->day_id = $day;
                    $workingDay->save();
                }
            }
        }
        return redirect()->route('admin.staff')->with('success', 'Data submitted successfully');
    }

    public function update($id, Request $request)
    {
        $data = $this->_form_validation($request);
        $data['updated_at'] = date('Y-m-d H:i:s');
        User::where('id', $id)->update($data);

        AppointmentServiceStaff::where("user_id", $id)->delete();
        if($request->services){
            $data = [];
            foreach ($request->services as $service) {
                $data[] = [
                    'user_id' => $id,
                    'service_id' => $service,
                ];
            }
            AppointmentServiceStaff::insert($data);


            $servicesDay = AppointmentServiceTimeSheet::whereIn('service_id', $request->services)->where('active', 1)->get()->pluck('day_id')->unique()->toArray();
            StaffWorkingDay::where("user_id", $id)->delete();
            if (count($servicesDay) > 0) {
                foreach ($servicesDay as $day) {
                    $workingDay = new StaffWorkingDay();
                    $workingDay->user_id = $id;
                    $workingDay->day_id = $day;
                    $workingDay->save();
                }
            }
        }
        return redirect()->route('admin.staff')->with('success', 'Data updated successfully');
    }


    public function updateActive(Request $request)
    {
        $id = $request->id;
        $active = ($request->value == 0) ? 1 : 0;
        User::where('id', $id)->update(['active' => $active]);
        $msg = 'Record has been deactivated';
        if ($active == 1) {
            $msg = 'Record has been activated';
        }
        return response()->json(['status' => true, 'msg' => $msg]);
    }

    public function removeFile(Request $request)
    {
        User::where('id', $request->id)->update(['image' => '']);
        $msg = 'Image Removed!';

        $request->session()->put('success', $msg);
        return response(['status' => true, 'msg' => $msg]);
    }

    public function destroy(Request $request)
    {
        $ids = $request->ids;
        $ids = explode(",", $ids);

        User::whereIn('id', $ids)->delete();
        if (count($ids) > 1) {
            $msg = "Records deleted successfully";
        } else {
            $msg = "Record deleted successfully";
        }
        $request->session()->put('success', $msg);
        return response(['status' => true, 'msg' => $msg]);
    }
}
