<?php

namespace App\Http\Controllers\Admin;

use App\Models\City;
use App\Models\State;
use App\Models\Country;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Validator;

class StateController extends Controller
{
    public function index()
    {
        return view('admin.state.index', [
            'data' => State::orderBy('updated_at','desc')->get(),
        ]);
    }

    public function create()
    {
        $countries = Country::get();

        return view('admin.state.add', compact('countries'));
    }

    public function store(Request $request) {
        $validator = Validator::make($request->all(), [
            'name' => 'required|string|max:100|unique:App\Models\State,name',
            'code' => 'required|string|max:10|unique:App\Models\State,code',
            'country_id' => 'required|exists:App\Models\Country,id',
            'active' => 'nullable',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $state = new State;
        $state->name = $request->name;
        $state->code = $request->code;
        $state->country_id = $request->country_id;
        $state->active = $request->active == NULL ? 0 : 1;
        $state->save();

        session()->flash('message', 'State added successfully.');

        return to_route('admin.states');
    }

    public function edit(State $state)
    {
        return view('admin.state.edit', [
            'state' => $state,
            'countries' => Country::get(),
        ]);
    }

    public function update(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'name' => 'required|string|max:100|unique:App\Models\State,name,' . $request->id,
            'code' => 'required|string|max:10|unique:App\Models\State,code,' . $request->id,
            'country_id' => 'nullable|exists:App\Models\Country,id',
            'active' => 'nullable',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $state = State::where('id', $request->id)->first();

        $state->name = $request->name;
        $state->code = $request->code;
        $state->country_id = $request->country_id ? $request->country_id : $state->country_id;
        $state->active = $request->active == NULL ? 0 : 1;
        $state->update();

        session()->flash('message', 'State details updated successfully.');

        return to_route('admin.states');
    }

    public function delete(State $state)
    {
        City::where('state_id', $state->id)->delete();

        $state->delete();

        echo 'done';
        
        exit;
    }
}
