<?php

namespace App\Http\Controllers\Admin;

use App\Models\Testimonial;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Validator;

class TestimonialController extends Controller
{
    public function index()
    {
        return view('admin.testimonial.index', [
            'data' => Testimonial::orderBy('updated_at','desc')->get(),
        ]);
    }

    public function create()
    {
        return view('admin.testimonial.add');
    }

    public function store(Request $request) {
        $validator = Validator::make($request->all(), [
            'name' => 'required|string|max:190',
            'rating' => 'required',
            'content' => 'required',
            'active' => 'nullable',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $testimonial = new Testimonial;
        $testimonial->name = $request->name;
        $testimonial->content = $request->content;
        $testimonial->rating = $request->rating;
        $testimonial->active = $request->active == NULL ? 0 : 1;
        $testimonial->save();

        session()->flash('message', 'Testimonial added successfully.');

        return to_route('admin.testimonials');
    }

    public function edit(Testimonial $testimonial)
    {
        return view('admin.testimonial.edit', [
            'testimonial' => $testimonial,
        ]);
    }

    public function update(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'name' => 'required|string|max:190',
            'rating' => 'required',
            'content' => 'required',
            'active' => 'nullable',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $testimonial = Testimonial::where('id', $request->id)->first();

        $testimonial->name = $request->name;
        $testimonial->content = $request->content;
        $testimonial->rating = $request->rating;
        $testimonial->active = $request->active == NULL ? 0 : 1;
        $testimonial->update();

        session()->flash('message', 'Testimonial details updated successfully.');

        return to_route('admin.testimonials');
    }

    public function delete(Testimonial $testimonial)
    {
        if ($testimonial->delete()) {
            echo 'done';
        }

        exit;
    }
}
