<?php
namespace App\Http\Controllers\Admin;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Facades\DB; 

class ViewerController extends Controller
{   

    var $column_order = array(null,null, 'first_name','last_name','email','mobile1','address1','country','state','city','zipcode'); //set column field database for datatable orderable

    var $column_search = array('first_name','last_name','email','mobile1','address1','country','state','city','zipcode'); //set column field database for datatable searchable

    var $order = array('user_id' => 'asc'); // default order

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function __construct()
    {
        $this->middleware('auth');
    }
    public function index($active=1)
    {
        $viewers = DB::table('users')
        ->select(DB::raw('user_id,first_name,last_name,email,password,mobile1,mobile2,address1,country,state,city,zipcode'))
        ->where('user_type','V')
        ->where('active',$active)
        ->orderBy('first_name','DESC')
        ->get();
        return view("admin.viewers",compact('viewers','active'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $action = 'add';
        return view('admin.viewers-create',compact('action'));
    }

    private function _form_validation($request){
        $rules = [
            'first_name' => 'required',
            'last_name'     => 'required',
            'email'     => 'required',
            //'password' => 'required',
            'mobile1'     => 'required',
            'address1'     => 'required',
            'language'     => 'required',
            'country'     => 'required',
            'state'     => 'required',
            'city'     => 'required',
            //'zipcode'     => 'required',
        ];
        $messages = [
            'first_name.required' => 'You can\'t leave First Name field empty',
            'last_name.required'    => 'You can\'t leave Last Name field empty',
            'email.required'    => 'You can\'t leave Email field empty',
            //'password.required'    => 'You can\'t leave Password field empty',
            'mobile1.required'    => 'You can\'t leave Mobile field empty',
            'address1.required'    => 'You can\'t leave Address field empty',
            'language.required'    => 'You can\'t leave Language field empty',
            'country.required'    => 'You can\'t leave Country field empty',
            'state.required'    => 'You can\'t leave State field empty',
            'city.required'    => 'You can\'t leave City field empty',
            //'zipcode.required'    => 'You can\'t leave Zipcode field empty',
        ]; 
        $type='V';
        $this->validate($request,$rules,$messages);
        $postData = array(
            'first_name' => $request->first_name,
            'last_name'     => $request->last_name,
            'username'  => $request->first_name." ".$request->last_name,
            'email'     => $request->email,
            //'password'     => Hash::make($request->password),
            'language' => implode(",",$request->language),
            'mobile1'     => $request->mobile1,
            'mobile2'     => $request->mobile2,
            'address1'     => $request->address1,
            'country'     => $request->country,
            'state'     => $request->state,
            'city'     => $request->city,
            //'zipcode'     => $request->zipcode,
            'user_type'     => $request->user_type,
            'active'     => $request->active,
            
        ); 
       
        return $postData;
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $data = $this->_form_validation($request); 
        DB::table('users')->insert($data);
        return redirect( config('app.admin_url').'/viewers')->with('success','User details submitted successfully');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($active=1)
    {
        $viewers = DB::table('users')
        ->select(DB::raw('user_id,first_name,last_name,email,mobile1,address1,country,state,city,zipcode,user_type,active'))
        ->where('user_type','V')
        ->where('active',$active)
        ->orderBy('user_id','DESC')
        ->get();
        return view("admin.viewers",compact('active','viewers'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $action = 'edit';
        $viewer = DB::table('users')->select(DB::raw("*"))->where('user_id','=',$id)->first();
        $language = DB::table('languages')->select(DB::raw("*"))->get();
        // dd($category);
        return view('admin.viewers-create',compact('viewer','id','action','language'));
    }

    public function view($id)
    {
        $action = 'view';
        $viewer = DB::table('users')->select(DB::raw("*"))->where('user_id','=',$id)->first();
        $language = DB::table('languages')->select(DB::raw("*"))->get();
         //dd($candidate);
        return view('admin.viewers-create',compact('viewer','id','action','language'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $data = $this->_form_validation($request);
        DB::table('users')->where('user_id',$id)->update($data);
        return redirect( env('ADMIN_URL').'/viewers')->with('success','User details updated successfully');
    }

    public function inactive($id)
    {   
        DB::table('users')->where('user_id',$id)->update(array('active' => '0'));
        return redirect( env('ADMIN_URL').'/viewers')->with('success','User Inactivated');
    }

    public function active($id)
    {   
        DB::table('users')->where('user_id',$id)->update(array('active' => '1'));
        return redirect( env('ADMIN_URL').'/viewers')->with('success','User Activated');
    }
    public function changePassword($id)
    {   
        $action="changePassword";
        $users = DB::table('users')->select(DB::raw("*"))->where('user_id','=',$id)->first();
         //dd($candidate);
        return view('admin.viewers-changePassword',compact('user','id'));
    }

    public function updatePassword(Request $request,$id)
    {   
        $rules = [
            'password' => 'required',
            'confirm_password' => 'required|same:password',

            
        ];
        $messages = [
            'password.required' => 'You can\'t leave Password field empty',
            'confirm_password.required'    => 'You can\'t leave Confirm Password field empty',
           
        ]; 
        $this->validate($request,$rules,$messages);
        
        $password=Hash::make($request->password);
       
        DB::table('users')->where('user_id',$id)->update(array('password' => $password));
        return redirect( env('ADMIN_URL').'/viewers')->with('success','User Password updated successfully');
    }
    
    public function photos($action,$id)
    {   
        $photos_total_count = DB::table('posts')->select(DB::raw("*"))->where('user_id','=',$id)->where('type','P')->count();
        $photos = DB::table('posts')->select(DB::raw("*"))->where('user_id','=',$id)->where('type','P')->orderBy('post_id','desc')->limit(env('LIMIT'))->get();
        // dd($photos);
        return view('admin.viewers-photos',compact('photos','id','action','photos_total_count'));
    }

    public function loadMore(Request $request)
    {   
        $offset=$request->input('offset');
        $id=$request->input('id');
        $action = 'view';
        $imageUpload=env('AWS_URL')."photos/".$id."/";
        // '/../bollywood/public/assets/images/';
        $photos = DB::table('posts')->select(DB::raw("*"))->where('user_id','=',$id)->where('type','P')->orderBy('post_id','desc')->offset($offset)->limit(env('LIMIT'))->get();
        foreach($photos as $photo) {  
        echo  '<div class="col-md-3 inner_pics">';
        echo '<div class="photo_div">';
        echo  '<a data-fancybox="gallery" href="'.$imageUpload.$photo->file.'"><img src="'.$imageUpload.$photo->file.'" class="img-responsive img-fluid m-b-10"></a>';
        echo  '</div>';
        echo  '</div>';
            }
    }

    public function loadMoreVideos(Request $request)
    {   
        $offset=$request->input('offset');
        $id=$request->input('id');
        $action = 'view';
        $videoUpload=env('AWS_URL')."videos/".$id."/";
        $videos = DB::table('posts')->select(DB::raw("*"))->where('user_id','=',$id)->where('type','V')->orderBy('post_id','desc')->offset($offset)->limit(env('VIDEO_LIMIT'))->get();
        foreach($videos as $video) {  
        echo  '<div class="col-md-4 inner_video">';
        echo '<div class="video_div">';
        echo   '<video width="100%" height="100%" controls>';
        echo  '<source src="'.$videoUpload.$video->file.'" type="video/mp4">';
        echo  '</video>';
       // echo '<div class="title_heading">'.$video->title.'</div>';
        echo '</div>';
        echo '</div>';
            }
    }

    public function loadMoreAudios(Request $request)
    {   
        $offset=$request->input('offset');
        $id=$request->input('id');
        $action = 'view';
        $audioUpload='/../bollywood/public/assets/audios/';
        $audios = DB::table('user_audios')->select(DB::raw("*"))->where('user_id','=',$id)->orderBy('post_id','desc')->offset($offset)->limit(env('limit'))->get();
        foreach($audios as $audio) {  
        echo  '<div class="col-md-4 align-center">';
        echo   '<audio width="100%" height="auto" controls>';
        echo  '<source src="'.$audioUpload.$audio->audio.'" type="audio/mpeg">';
        echo  '</audio>';
        echo '<div class="title_heading">'.$audio->title.'</div>';
        echo '</div>';
            }
    }

    public function videos($action,$id)
    {
        $videos_total_count = DB::table('posts')->select(DB::raw("*"))->where('user_id','=',$id)->count();
        $videos = DB::table('posts')->select(DB::raw("*"))->where('user_id','=',$id)->where('type','V')->orderBy('post_id','desc')->limit(env('VIDEO_LIMIT'))->get();
         //dd($candidate);
        return view('admin.viewers-videos',compact('videos','id','action','videos_total_count'));
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }
    public function serverProcessing(Request $request)
    {
        $currentPath = url(config('app.admin_url')).'/viewers/';
        $list = $this->get_datatables($request);

        $data = array();
        $no = $request->start;
        foreach ($list as $viewer) {
            $no++;
            $row = array();
            // $row[] = '<a class="view" href="'.$currentPath.'view/'.$viewer->user_id.'"><i class="fa fa-search"></i></a><a class="edit" href="'.$currentPath.$viewer->user_id.'/edit"><i class="fa fa-edit"></i></a><a class="copy" href="'.$currentPath.'copy/'.$viewer->user_id.'"><i class="fa fa-copy"></i></a><a class="delete deleteSelSingle" style="cursor:pointer;" data-val="'.$viewer->user_id.'"><i class="fa fa-trash"></i></a>';
            $row[] = '<a class="view" href="'.$currentPath.'view/'.$viewer->user_id.'"><i class="fa fa-search"></i></a><a class="edit" href="'.$currentPath.$viewer->user_id.'/edit"><i class="fa fa-edit"></i></a><a class="delete deleteSelSingle" style="cursor:pointer;" data-val="'.$viewer->user_id.'"><i class="fa fa-trash"></i></a>';
            $row[] = '<div class="align-center"><input id="cb'.$no.'" name="key_m[]" class="delete_box blue-check" type="checkbox" data-val="'.$viewer->user_id.'"><label for="cb'.$no.'"></label></div>';
            $row[] = $viewer->username;
            // $row[] = $producer->last_name;
            $row[] = $viewer->email;
            $row[] = $viewer->mobile1;
            $row[] = $viewer->address1;
            $row[] = $viewer->country;
            $row[] = $viewer->state;
            //$row[] = $producer->city;
            //$row[] = $viewer->zipcode;
            if($viewer->active==1){
                $row[] = '<a class="btn btn-danger" href="'.$currentPath.'inactive/'.$viewer->user_id.'" onclick="return confirm(\'Are you sure?\')">Inactivate</a> <a href="'.$currentPath.'changePassword/'.$viewer->user_id.'" class="btn btn-primary">Change Password</a>';
            }else{
                $row[] = '<a class="btn btn-success" href="'.$currentPath.'active/'.$viewer->user_id.'" onclick="return confirm(\'Are you sure?\')">Activate</a> <a href="'.$currentPath.'changePassword/'.$viewer->user_id.'" class="btn btn-primary">Change Password</a>';
            }
            //$row[] = '<a href="#" class="btn btn-primary">Change Password</a>';
            $data[] = $row;
        }

        $output = array(
            "draw" => $request->draw,
            "recordsTotal" => $this->count_all($request),
            "recordsFiltered" => $this->count_filtered($request),
            "data" => $data,
        );
        echo json_encode($output);
    }

    private function _get_datatables_query($request)
    {            
        $keyword = $request->search['value'];
        $order = $request->order;
        $viewerRS = DB::table('users')
        ->select(DB::raw("*"));
        
        $strWhere = "user_type='V' and active='".$request->active."'";
        $strWhereOr = "";
        $i = 0;

        foreach ($this->column_search as $item) // loop column
        {
            if($keyword) // if datatable send POST for search{
            	$strWhereOr = $strWhereOr." $item like '%".$keyword."%' or ";
                //$candidateRS = $candidateRS->orWhere($item, 'like', '%' . $keyword . '%') ;
        }
        $strWhereOr = trim($strWhereOr, "or ");
        if($strWhereOr!=""){
	        $viewerRS = $viewerRS->whereRaw(DB::raw($strWhere." and (".$strWhereOr.")"));
	    }else{
			$viewerRS = $viewerRS->whereRaw(DB::raw($strWhere	));
		}

        
        if(isset($order)) // here order processing
        {
            $viewerRS = $viewerRS->orderBy($this->column_order[$request->order['0']['column']], $request->order['0']['dir']);
        } 
        else if(isset($this->order))
        {
            $orderby = $this->order;
            $viewerRS = $viewerRS->orderBy(key($orderby),$orderby[key($orderby)]);
        }
        return $viewerRS;
    }

    function get_datatables($request)
    {
        $viewerRS = $this->_get_datatables_query($request);
        if($request->length != -1){
            $viewerRS = $viewerRS->limit($request->length);
            if($request->start != -1){
                $viewerRS = $viewerRS->offset($request->start);
            }
        }
        
        $viewers = $viewerRS->get();
        return $viewers;
    }

    function count_filtered($request)
    {
        $viewerRS = $this->_get_datatables_query($request);
        return $viewerRS->count();
    }

    public function count_all($request)
    {
        $viewerRS = DB::table('users')->select(DB::raw("count(*) as total"))->where('user_type','V')->where('active',$request->active)->first();
        return $viewerRS->total;
    }

    public function delete(Request $request){
        $rec_exists = array();
        $del_error = '';
        $ids = explode(',',$request->ids);
        foreach ($ids as $id) {
            DB::table('users')->where('user_id', $id)->delete();
        }
        
        if($del_error == 'error'){
            $request->session()->put('error',$msg );
            return response()->json(['status' => 'error',"rec_exists"=>$rec_exists]);
        }else{
            if( count($ids) > 1){
                $msg = "User deleted successfully";
            }else{
                $msg = "User deleted successfully";
            }
            $request->session()->put('success', $msg);
            return response()->json(['status' => 'success',"rec_exists"=>$rec_exists]);
        }

    }

    public function copyContent($id)
    {
        $action = 'copy';
        $viewer = DB::table('users')->select(DB::raw("*"))->where('user_id','=',$id)->first();
        // dd($category);
        return view('admin.viewers-create',compact('id','viewer','action'));
    }
}
