<?php

namespace App\Http\Controllers;

use App\Models\User;
use App\Models\Country;
use App\Models\Appointment;
use Illuminate\Http\Request;
use App\Models\AppointmentSlot;
use App\Models\AppointmentService;
use App\Models\BookedAppointmentSlot;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\Validator;
use App\Models\AppointmentServiceCategory;
use App\Models\AppointmentServiceTimeSheet;
use App\Models\Payment;
use stdClass;

class AppointmentController extends Controller
{
    public function index(Request $request)
    {
        $categories = AppointmentServiceCategory::with(['services' => function ($q) {
            $q->with('time');
        }])->where('active', 1)->get();

        $slots = AppointmentSlot::get();
        return view('appointment', compact('categories', 'slots'));
    }

    public function getSlots(Request $request)
    {
        $date = $request->date;
        $bookedSlots = BookedAppointmentSlot::where('date', date('Y-m-d', strtotime($date)))
            ->where('service_id', $request->service_id)
            ->pluck('slot_id')->toArray();

        $times = AppointmentServiceTimeSheet::where('service_id', $request->service_id)->where('active', 1)
            ->where('day_id', date("N", strtotime($date)))->first();
     
        if ($times) {
            if (count($bookedSlots) > 0) {
                $availableSlots = AppointmentSlot::whereNotIn('id', $bookedSlots)
                    ->where('from_time', '>=', date('H:i:s', strtotime($times->from_time)))
                    ->where('to_time', '<=', date('H:i:s', strtotime($times->to_time)))
                    ->get();
            } else {
                $availableSlots = AppointmentSlot::where('from_time', '>=', date('H:i:s', strtotime($times->from_time)))
                    ->where('to_time', '<=', date('H:i:s', strtotime($times->to_time)))
                    ->get();
            }
        }
        $html = "";
        if (isset($availableSlots) && $availableSlots->count() > 0) {
            foreach ($availableSlots as $slot) {
                $html .= "<div class='slot-card'><input type='radio' name='slot_id' class='slot_id d-none' value=" . $slot->id . " />";
                $html .= date('H:i A', strtotime($slot->from_time));
                // $html .= date('H:i', strtotime($slot->to_time));
                $html .= "</div>";
            }
        } else {
            $html = "<h2 class='no_appointment'>NO APPOINTMENT AVALIABLE THIS DATE</h2>";
        }
        return $html;
    }

    public function getDays(Request $request)
    {
        $service_id = $request->service_id;
        $service = AppointmentService::with(['category', 'time'])->find($service_id);
        $html = '';
        if ($service) {
            $html = "<h4>" . $service->category->name . "</h4>";
            $html .= "<h3>" . $service->name . "</h3>";
            $label='1h';
            if($service->time){
                $label=$service->time->label;
            }
            $html .= "<h3>" . $label . "</h3>";
            $html .= "<p>" . $service->description . "</p>";
            $price = ($service->price == 0) ? 'Free' : '$' . number_format($service->price, 2);
            $html .= "<h4>" . $price . "</h4>";
        }
        $days = AppointmentServiceTimeSheet::where('service_id', $service_id)->where('active', 1)
            ->orderBy('day_id', 'asc')->get()->pluck('day_id')->toArray();
        return response()->json(['status' => true, 'days' => $days, 'html' => $html]);
    }

    public function appointmentSubmit(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'service_id' => 'required',
            'appointment_date' => 'required',
            'slot_id' => 'required',
            'first_name' => 'required',
            'email' => 'required',
            'phone' => 'required',
            'wedding_date' => 'required'
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }
        $service = AppointmentService::find($request->service_id);
        $appointment_id = $this->bookAppointment($request);
        if ($service->price == 0) {
            return redirect()->route('appointmentConfirmation');
        } else {
            $request['service'] = $service;
            $request['id'] = $appointment_id;
            session(['appointment' => $request->all()]);
            return redirect()->route('viewCart', compact('request'));
        }
    }

    public function followUpAppointmentSubmit(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'first_name' => 'required',
            'email' => 'required',
            'phone' => 'required',
            'wedding_date' => 'required',
            'appointment_date' => 'required',
            'slot_id' => 'required',
            'previous_date' => 'required',
            'previous_quote_number' => 'required',
            'no_of_guests' => 'required'

        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $previousAppointment = Appointment::where('quote_number', $request->previous_quote_number)
            ->first();

        if ($previousAppointment) {
            $request['service_id'] = $previousAppointment->service_id;
            $request['type'] = 'FU';
            $appointment_id = $this->bookAppointment($request);
            return redirect()->route('appointmentConfirmation');
        }

        return redirect()->back()->withErrors(['error' => 'Previous appointment invalid.'])->withInput();
    }

    public function bookAppointment($request)
    {
        $user = User::where('email', $request->email)->where('utype', 'U')->first();
        if ($user) {
            $user->phone = $request->phone;
            $user->save();
            $user_id = $user->id;
        } else {
            $user = new User();
            $user->first_name = $request->first_name;
            $user->last_name = isset($request->last_name) ? $request->last_name : '';
            $user->email = $request->email;
            $user->phone = $request->phone;
            $user->save();
            $user_id = $user->id;
        }
        $day = AppointmentService::find($request->service_id);

        $data = session('appointment');
        $appointment_id = 0;
        if ($data) {
            $appointment_id = $data['id'];
            $appointment = Appointment::find($appointment_id);
            $book = BookedAppointmentSlot::where('appointment_id', $appointment_id)->first();
        } else {
            $appointment = new Appointment();
            $book = new BookedAppointmentSlot();
        }

        $appointment->user_id = $user_id;
        $appointment->wedding_date = isset($request->wedding_date) ? $request->wedding_date : null;
        $appointment->no_of_guests = isset($request->no_of_guests) ? $request->no_of_guests : 0;
        $appointment->first_try_bridal_dress = isset($request->first_try_bridal_dress) ? $request->first_try_bridal_dress : 1;
        $appointment->size_in_womenswear = isset($request->size_in_womenswear) ? $request->size_in_womenswear : '';
        $appointment->hear_about_us = isset($request->hear_about_us) ? $request->hear_about_us : '';
        $appointment->day_id =  date("N", strtotime($request->appointment_date));
        $appointment->slot_id = $request->slot_id;
        $appointment->service_id = $request->service_id;
        $appointment->date = date('Y-m-d', strtotime($request->appointment_date));
        $appointment->price = $day->price;
        $appointment->type = isset($request->type) ? $request->type : 'FV';
        $appointment->status = 'P';
        $appointment->save();
        $appointment_id = $appointment->id;

        Appointment::where("id", $appointment_id)->update(['quote_number' => 'AB' . $appointment_id]);


        $book->slot_id = $request->slot_id;
        $book->service_id = $request->service_id;
        $book->date = date('Y-m-d', strtotime($request->appointment_date));
        $book->appointment_id = $appointment_id;
        $book->save();

        return $appointment_id;
        // session(['billing_detail' => null]);
        // session(['appointment' => null]);
    }

    public function viewCart()
    {
        $data = session('appointment');

        $data['price'] = $data['service']->price;
        $slot = AppointmentSlot::find($data['slot_id']);
        $data['from_time'] = $slot->from_time;
        $data['product_img'] = asset(Storage::url('public/services/' . $data['service']->image));
        return view('cart', compact('data'));
    }

    public function appointmentConfirmation()
    {
        session(['billing_detail' => null]);
        session(['appointment' => null]);
        return view('appointment-confirmation');
    }

    public function checkout()
    {
        $countries = Country::get();
        return view('appointment-billing-detail', compact('countries'));
    }

    public function submitBillingDetail(Request $request)
    {
        // dd($request->all());

        $first_name = $request->first_name;
        $last_name = $request->last_name;
        $email = $request->email;
        $phone = $request->phone;
        $postcode = $request->postcode;
        $address = $request->address;
        $country_id = $request->country_id;
        $state_id = $request->state_id;
        $city_id = $request->city_id;

        $data = session('appointment');

        $appointment_id = $data['id'];

        $payment = Payment::where('appointment_id', $appointment_id)->first();
        if (!$payment) {
            $payment = new Payment();
        }

        $payment->appointment_id = $appointment_id;
        $payment->amount = $data['service']->price;
        $payment->payment_type = 'S';
        $payment->status = 'P';
        $payment->first_name = $first_name;
        $payment->last_name = $last_name;
        $payment->email = $email;
        $payment->phone = $phone;
        $payment->post_code = $postcode;
        $payment->address = $address;
        $payment->country_id = isset($country_id) ? $country_id : 0;
        $payment->state_id = isset($state_id) ? $state_id : 0;
        $payment->city_id = isset($city_id) ? $city_id : 0;
        $payment->save();
        $payment_id = $payment->id;

        $request['payment_id'] = $payment_id;
        session(['billing_detail' => $request->all()]);

        $data['price'] = $data['service']->price;
        $slot = AppointmentSlot::find($data['slot_id']);
        $data['from_time'] = $slot->from_time;
        $data['product_img'] = asset(Storage::url('public/services/' . $data['service']->image));
        return view('payment', compact('data'));
    }
}
