<?php

namespace App\Http\Controllers;

use App\Models\Blog;
use App\Models\PageFont;
use App\Models\BlogCategory;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

class BlogPageController extends Controller
{
    /**
     * This function returns blog listing / blog detail / category wise blog listing page
     */
    public function index(Request $request, $alias = NULL)
    {
        $fonts = PageFont::where('page', 'blog')->first();

        if ($alias == NULL) {
            $blogs = Blog::latest()->where('blogs.active', 1);

            if ($request->filled('category')) {
                $blogs = $blogs->join('blog_post_categories', 'blog_post_categories.blogId', '=', 'blogs.id')
                    ->join('blog_categories', 'blog_categories.id', '=', 'blog_post_categories.blogCategoryId')
                    ->where('blog_categories.alias', $request->category)
                    ->distinct('blogs.id')->select('blogs.*');
            }

            $blogs = $blogs->paginate(9);
            $title = 'Blog | Angelic Bridal';

            return view('blog.index', compact('blogs', 'title', 'fonts'));
        } else {
            // Open blog detail page.
            $blog = Blog::where('alias', $alias)->first();
            $blog_categories = BlogCategory::latest()->take(8)->select('id', 'title', 'alias', 'image', 'created_at')->get();
            $recent_posts = Blog::latest()->take(3)->select('id', 'title', 'alias', 'image', 'created_at')->get();

            $tags = DB::table('blogs')->select('tags')->distinct()->get()->pluck('tags')
                ->flatMap(function ($t) {
                    return explode(',', $t);
                })->unique()->values()->toArray();

            $arr = [];

            foreach ($tags as $tag) {
                if ($tag != "") {
                    $arr[] = $tag;
                }
            }

            $tags = $arr;

            $title = $blog->title . ' | Angelic Bridal';

            return view('blog.detail', compact('blog', 'blog_categories', 'recent_posts', 'tags', 'title', 'fonts'));
        }
    }
}
