<?php

namespace App\Http\Controllers;

use App\Models\Payment;
use Illuminate\Http\Request;
use Srmklive\PayPal\Services\PayPal as PayPalClient;

class PayPalController extends Controller
{
     /**
     * create transaction.
     *
     * @return \Illuminate\Http\Response
     */
    public function createTransaction()
    {
        return view('transaction');
    }
    /**
     * process transaction.
     *
     * @return \Illuminate\Http\Response
     */
    public function processTransaction(Request $request)
    {
        $price=$request->price;
        $provider = new PayPalClient;
        $provider->setApiCredentials(config('paypal'));
        $paypalToken = $provider->getAccessToken();
        $response = $provider->createOrder([
            "intent" => "CAPTURE",
            "application_context" => [
                "return_url" => route('successTransaction'),
                "cancel_url" => route('cancelTransaction'),
            ],
            "purchase_units" => [
                0 => [
                    "amount" => [
                        "currency_code" => "USD",
                        "value" =>$price
                    ]
                ]
            ]
        ]);
     
        if (isset($response['id']) && $response['id'] != null) {
            // redirect to approve href
            foreach ($response['links'] as $links) {
                if ($links['rel'] == 'approve') {
                    return redirect()->away($links['href']);
                }
            }
            return redirect()->route('bookAppointment')->with('failed', 'Something went wrong!');
            
        } else {
             return redirect()->route('bookAppointment')->with('failed', 'Something went wrong!');
        
        }
    }
    /**
     * success transaction.
     *
     * @return \Illuminate\Http\Response
     */
    public function successTransaction(Request $request)
    {
        $provider = new PayPalClient;
        $provider->setApiCredentials(config('paypal'));
        $provider->getAccessToken();
        $response = $provider->capturePaymentOrder($request['token']);
        
        $billing_detail = session('billing_detail');
        $payment_id = $billing_detail['payment_id'];

        $payment = Payment::find($payment_id);
        $payment->transaction_id = $response['id'];
    

        session(['billing_detail' => null]);
        session(['appointment' => null]);
        
        if (isset($response['status']) && $response['status'] == 'COMPLETED') {
            $payment->status = 'S';
            $payment->save();
            return redirect()->route('bookAppointment')->with('success', 'Transaction completed!');
            // return redirect()
            //     ->route('submitBillingDetail')
            //     ->with('success', 'Transaction complete.');
        } else {
            $payment->status = 'F';
            $payment->save();
            return redirect()->route('bookAppointment')->with('failed', 'Something went wrong!');
        }
    }
    /**
     * cancel transaction.
     *
     * @return \Illuminate\Http\Response
     */
    public function cancelTransaction(Request $request)
    {

        $billing_detail = session('billing_detail');
        $payment_id = $billing_detail['payment_id'];

        $payment = Payment::find($payment_id);
        $payment->status = 'C';
        $payment->save();
    

        session(['billing_detail' => null]);
        session(['appointment' => null]);

        return redirect()
            ->route('submitBillingDetail')
            ->with('error', $response['message'] ?? 'You have canceled the transaction.');
    }
}
