<?php

namespace App\Http\Controllers\Admin;

use App\Models\Day;
use App\Models\User;
use App\Models\Duration;
use Illuminate\Http\Request;
use App\Models\StaffWorkingDay;
use App\Models\AppointmentService;
use App\Http\Controllers\Controller;
use App\Models\AppointmentServiceStaff;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\Storage;
use Yajra\DataTables\Facades\DataTables;
use App\Models\AppointmentServiceCategory;
use App\Models\AppointmentServiceTimeSheet;

class AppointmentServiceController extends Controller
{
    public function index(Request $request)
    {
        $title = 'Appointment Services';
        if ($request->ajax()) {
            $data = AppointmentService::where('id','>',0);
            return DataTables::of($data)
                ->addIndexColumn()
                ->addColumn('action', function ($row) {
                    $actionBtn = ' <ul class="list-inline me-auto mb-0">
                    <li class="list-inline-item align-bottom" data-bs-toggle="tooltip" title="Edit">
                    <a href="' . route('admin.appointment.services.edit', $row->id) . '" class="edit avtar avtar-xs btn-link-success btn-pc-default"><i class="ti ti-edit-circle f-18"></i></a> 
                    </li>
                    <li class="list-inline-item align-bottom" data-bs-toggle="tooltip" title="Edit">
                    <a href="javascript:void(0)" class="deleteSelSingle delete avtar avtar-xs btn-link-danger btn-pc-default" data-val=' . $row->id . '> <i class="ti ti-trash f-18"></i></a>
                    </li>';
                    return $actionBtn;
                })
                ->addColumn('image', function ($row) {
                    $image = "";
                    if ($row->image != "") {
                        $image = asset(Storage::url('services')) . '/' . $row->image;
                        return "<img src='" . $image . "' width='100'>";
                    }
                    return $image;
                })
                ->addColumn('category', function ($row) {
                    $category = "";
                    if ($row->category) {

                        return $row->category->name;
                    }
                    return $category;
                })
                ->addColumn('active', function ($row) {
                    $checked = "";
                    if ($row->active == 1) {
                        $checked = 'checked';
                    }
                    return '<div class="form-check form-switch custom-switch-v1 mb-2">
                        <input type="checkbox" class="form-check-input input-success active_item" data-name="' . $row->title . '" data-value="' . $row->active . '" data-id="' . $row->id . '" ' . $checked . '>
                    </div>';
                })
                ->rawColumns(['action', 'active', 'image'])
                ->make(true);
        }
        return view('admin.appointment.service.index', compact('title'));
    }

    public function create()
    {
        $action = 'Create';
        $title = 'Appointment Service';
        $categories = AppointmentServiceCategory::where('parent_id', 0)->get();
        $staff = User::where('utype', 'S')->where('active', 1)->get();
        $durations = Duration::get();
        $days = Day::with(['timesheet'])->get();
        return view('admin.appointment.service.service', compact('action', 'title', 'categories', 'staff', 'durations', 'days'));
    }

    public function edit($id)
    {
        $action = 'Edit';
        $title = 'Appointment Service';
        $record = AppointmentService::with(['staff'])->find($id);
        $staff_ids = [];
        if ($record->staff) {
            $staff_ids = $record->staff->pluck('id')->toArray();
        }
        $categories = AppointmentServiceCategory::where('parent_id', 0)->get();
        $staff = User::where('utype', 'S')->where('active', 1)->whereNotIn('id', $staff_ids)->get();
        $durations = Duration::get();
        $days = Day::with(['timesheet' => function ($q) use ($id) {
            $q->whereHas('service', function ($q) use ($id) {
                $q->where('id', $id);
            })->with(['service' => function ($q) use ($id) {
                $q->where('id', $id);
            }]);
        }])->get();
        // dd($days);
        return view('admin.appointment.service.service', compact('action', 'title', 'record', 'categories', 'staff', 'durations', 'days'));
    }

    private function _form_validation($request)
    {
        $rules = [
            'name' => 'required',
            'cat_id' => 'nullable',
            'rank' => 'nullable',
            'description' => 'nullable',
            'price' => 'nullable',
            'duration' => 'nullable',
            'image' => 'nullable'
        ];
        $messages = [
            'name.required' => 'Name is required',

        ];
        $request->validate($rules, $messages);

        $postData = array(
            'name' => $request->name,
            'cat_id' => isset($request->cat_id) ? $request->cat_id : 0,
            'rank' => isset($request->rank) ? $request->rank : 0,
            'price' => isset($request->price) ? $request->price : 0,
            'description' => isset($request->description) ? $request->description : '',
            'duration' => isset($request->duration) ? $request->duration : null,
            'active' => isset($request->active) ? $request->active : 0
        );
        $old_image = $request->old_image;
        $image = isset($request->image) ? 'image' : '';
        if ($request->hasFile($image)) {
            $path = "public/services";
            $File = $request->file($image);
            $imagename = time() . '_' . $File->getClientOriginalName();
            $filenametostore = $request->file($image)->storeAs($path, $imagename);
            // Storage::setVisibility($filenametostore, 'public');
            $image = $imagename;
        } else if (isset($old_image)) {
            $image = $old_image;
        }
        $postData['image'] = $image;
        return $postData;
    }

    public function store(Request $request)
    {
        $data = $this->_form_validation($request);
        $data['created_at'] = date('Y-m-d H:i:s');
        $id = AppointmentService::insertGetId($data);
        return redirect()->route('admin.appointment.services.edit', $id)->with('success', 'Data submitted successfully');

        // return redirect()->route('admin.appointment.services')->with('success', 'Data submitted successfully');
    }

    public function update($id, Request $request)
    {
        $data = $this->_form_validation($request);
        $data['updated_at'] = date('Y-m-d H:i:s');
        AppointmentService::where('id', $id)->update($data);

        return redirect()->route('admin.appointment.services.edit', $id)->with('success', 'Data updated successfully');
        // return redirect()->route('admin.appointment.services')->with('success', 'Data updated successfully');
    }


    public function getStaff(Request $request)
    {
        $staff_id = $request->staff_id;
        $staff_ids = $request->staff_ids;

        $html = '';
        if ($staff_id > 0) {
            $selectedStaff = User::where('utype', 'S')->where('active', 1)->where('id', $staff_id)->first();
            $html = "<div class='row p-3'>" .
                "<div class='col-8 label'>" . $selectedStaff->first_name . ' ' . $selectedStaff->last_name . "</div>" .
                "<div class='col-4'><input type='hidden' class='staff_ids' name='staff_id[]' value='" . $selectedStaff->id . "' />" .
                "<i class='fas fas fa-times-circle removeSelectedStaff' data-id='" . $selectedStaff->id . "'></i>" .
                "</div>" .
                "</div>";
        }
        $staff = User::where('utype', 'S')->where('active', 1);
        if ($staff_ids) {
            $staff = $staff->whereNotIn('id', $staff_ids);
        }
        $staff = $staff->get();
        $staffHtml = '<option value="">Select</option>';
        foreach ($staff as $st) {
            $staffHtml .= "<option value=" . $st->id . ">" . $st->first_name . ' ' . $st->last_name . "</option>";
        }

        return response()->json(['status' => true, 'staffHtml' => $staffHtml, 'html' => $html]);
    }
    public function staffUpdate($id, Request $request)
    {
        AppointmentServiceStaff::where('service_id', $id)->delete();
        if (count($request->staff_id) > 0) {
            foreach ($request->staff_id as $staff_id) {
                $staff = new AppointmentServiceStaff();
                $staff->service_id = $id;
                $staff->user_id = $staff_id;
                $staff->save();
            }
        }

        $users = AppointmentServiceStaff::where('service_id', $id)->get()->pluck('user_id')->toArray();
        foreach ($users as $user_id) {
            $services = AppointmentServiceStaff::where('user_id', $user_id)->get()->pluck('service_id')->toArray();
            if ($services) {
                $servicesDay = AppointmentServiceTimeSheet::whereIn('service_id', $services)->where('active', 1)->get()->pluck('day_id')->unique()->toArray();
                StaffWorkingDay::where("user_id", $id)->delete();
                if (count($servicesDay) > 0) {
                    foreach ($servicesDay as $day) {
                        $workingDay = new StaffWorkingDay();
                        $workingDay->user_id = $id;
                        $workingDay->day_id = $day;
                        $workingDay->save();
                    }
                }
            }
        }
        return redirect()->route('admin.appointment.services.edit', $id)->with('success', 'Data updated successfully');
    }

    public function timesheetUpdate($id, Request $request)
    {
        // dd($request->all());
        AppointmentServiceTimeSheet::where('service_id', $id)->delete();
        for ($x = 0; $x < 7; $x++) {
            $timesheet = new AppointmentServiceTimeSheet();
            $i = $x + 1;
            $timesheet->service_id = $id;
            $timesheet->day_id = $i;
            $timesheet->from_time = $request->from_time[$x];
            $timesheet->to_time = $request->to_time[$x];
            $timesheet->active = $request->active[$x];
            $timesheet->save();
        }

        // ////
        $users = AppointmentServiceStaff::where('service_id', $id)->get()->pluck('user_id')->toArray();
        foreach ($users as $user_id) {
            $services = AppointmentServiceStaff::where('user_id', $user_id)->get()->pluck('service_id')->toArray();
            if ($services) {
                $servicesDay = AppointmentServiceTimeSheet::whereIn('service_id', $services)->where('active', 1)->get()->pluck('day_id')->unique()->toArray();
                StaffWorkingDay::where("user_id", $id)->delete();
                if (count($servicesDay) > 0) {
                    foreach ($servicesDay as $day) {
                        $workingDay = new StaffWorkingDay();
                        $workingDay->user_id = $id;
                        $workingDay->day_id = $day;
                        $workingDay->save();
                    }
                }
            }
        }
        // ///
        return redirect()->route('admin.appointment.services.edit', $id)->with('success', 'Data updated successfully');
    }


    public function updateActive(Request $request)
    {
        $id = $request->id;
        $active = ($request->value == 0) ? 1 : 0;
        AppointmentService::where('id', $id)->update(['active' => $active]);
        $msg = 'Record has been deactivated';
        if ($active == 1) {
            $msg = 'Record has been activated';
        }
        return response()->json(['status' => true, 'msg' => $msg]);
    }

    public function destroy(Request $request)
    {
        $ids = $request->ids;
        $ids = explode(",", $ids);

        AppointmentService::whereIn('id', $ids)->delete();
        if (count($ids) > 1) {
            $msg = "Records deleted successfully";
        } else {
            $msg = "Record deleted successfully";
        }
        // $request->session()->put('success', $msg);
        Session::flash('success', $msg); 
        return response(['status' => true, 'msg' => $msg]);
    }
    
    public function removeFile(Request $request)
    {
        AppointmentService::where('id', $request->id)->update(['image' => '']);
        $msg = 'Image Removed!';
        
        // $request->session()->put('success', $msg);
        Session::flash('success', $msg); 
        return response(['status' => true, 'msg' => $msg]);
    }
}
