<?php

namespace App\Http\Controllers\Admin;

use Illuminate\Support\Str;
use App\Models\BlogCategory;
use Illuminate\Http\Request;
use App\Models\BlogPostCategory;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\Validator;

class BlogCategoryController extends Controller
{
    public function index()
    {
        return view('admin.blog.categories', [
            'data' => BlogCategory::orderBy('updated_at','desc')->get(),
        ]);
    }

    public function create()
    {
        return view('admin.blog.add-category');
    }

    public function store(Request $request) {
        $validator = Validator::make($request->all(), [
            'title' => 'required|string|max:191|unique:App\Models\BlogCategory,title',
            'alias' => 'nullable|string|max:191|unique:App\Models\BlogCategory,alias',
            'image' => 'nullable|file|max:1024000|mimes:jpg,jpeg,png,webp',
            'description' => 'nullable',
            'meta_title' => 'nullable|string|max:191|',
            'meta_keyword' => 'nullable|string|max:191|',
            'meta_description' => 'nullable',
            'og_title' => 'nullable|string|max:191',
            'og_description' => 'nullable',
            'rank' => 'nullable|numeric|min:1',
            'active' => 'nullable|boolean',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $blogCategory = new BlogCategory;
        $blogCategory->title = $request->title;
        $blogCategory->alias = $request->alias ? $request->alias : Str::slug($request->title, '-');
        $blogCategory->description = $request->description;
        $blogCategory->meta_title = $request->meta_title;
        $blogCategory->meta_keyword = $request->meta_keyword;
        $blogCategory->meta_description = $request->meta_description;
        $blogCategory->og_title = $request->og_title;
        $blogCategory->og_description = $request->og_description;
        $blogCategory->rank = $request->rank;
        $blogCategory->active = $request->active == NULL ? 0 : 1;

        if ($request->file('image') != NULL) {
            $image = $request->file('image');
            $uploadPath = "public/uploads/blog";
            $blogCategory->image = $image->store($uploadPath);
        }

        $blogCategory->save();

        session()->flash('message', 'Blog category added successfully.');
        return to_route('admin.blog-categories');
    }

    public function edit(BlogCategory $category)
    {
        if ($category->image != NULL) {
            if (Storage::exists($category->image)) {
                $category->image = asset(Storage::url($category->image));
            }
        }

        return view('admin.blog.edit-category', [
            'category' => $category,
        ]);
    }

    public function update(Request $request) {
        $validator = Validator::make($request->all(), [
            'title' => 'required|string|max:191|unique:App\Models\BlogCategory,title,' . $request->id,
            'alias' => 'nullable|string|max:191|unique:App\Models\BlogCategory,alias,' . $request->id,
            'image' => 'nullable|file|max:1024000|mimes:jpg,jpeg,png,webp',
            'description' => 'nullable',
            'meta_title' => 'nullable|string|max:191|',
            'meta_keyword' => 'nullable|string|max:191|',
            'meta_description' => 'nullable',
            'og_title' => 'nullable|string|max:191',
            'og_description' => 'nullable',
            'rank' => 'nullable|numeric|min:1',
            'active' => 'nullable|boolean',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $blogCategory = BlogCategory::where('id', $request->id)->first();
        $blogCategory->title = $request->title;
        $blogCategory->alias = $request->alias ? $request->alias : Str::slug($request->title, '-');
        $blogCategory->description = $request->description;
        $blogCategory->meta_title = $request->meta_title;
        $blogCategory->meta_keyword = $request->meta_keyword;
        $blogCategory->meta_description = $request->meta_description;
        $blogCategory->og_title = $request->og_title;
        $blogCategory->og_description = $request->og_description;
        $blogCategory->rank = $request->rank;
        $blogCategory->active = $request->active == NULL ? 0 : 1;

        if ($request->file('image') != NULL) {
            $old_file = $blogCategory->image;

            $image = $request->file('image');
            $uploadPath = "public/uploads/blog";
            $blogCategory->image = $image->store($uploadPath);

            if ($old_file != NULL) {
                if (Storage::exists($old_file)) {
                    Storage::delete($old_file);
                }
            }
        }

        $blogCategory->save();

        session()->flash('message', 'Blog category details updated successfully.');
        return to_route('admin.blog-categories');
    }

    public function delete(BlogCategory $category)
    {
        BlogPostCategory::where('blogCategoryId', $category->id)->delete();

        if ($category->delete()) {
            echo 'done';
        }

        exit;
    }
}
