<?php

namespace App\Http\Controllers\Admin;

use Carbon\Carbon;
use App\Models\Blog;
use App\Models\PageFont;
use Illuminate\Support\Str;
use App\Models\BlogCategory;
use Illuminate\Http\Request;
use App\Models\BlogPostCategory;
use Yajra\DataTables\DataTables;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\Validator;


class BlogController extends Controller
{
    public function index(Request $request)
    {
        $fonts = PageFont::where('page', 'blog')->first();

        $title = 'Blog';
        if ($request->ajax()) {
            $data = Blog::where('id','>',0);

            return DataTables::of($data)
                ->addIndexColumn()
                ->addColumn('action', function ($row) {
                    $actionBtn = ' <ul class="list-inline me-auto mb-0">
                    <li class="list-inline-item align-bottom" data-bs-toggle="tooltip" title="Edit">
                    <a href="' . route('admin.edit-blog', $row->id) . '" class="edit avtar avtar-xs btn-link-success btn-pc-default"><i class="ti ti-edit-circle f-18"></i></a>
                    </li>
                    <li class="list-inline-item align-bottom" data-bs-toggle="tooltip" title="Delete">
                    <a href="javascript:void(0)" class="deleteSelSingle delete avtar avtar-xs btn-link-danger btn-pc-default" data-val=' . $row->id . '> <i class="ti ti-trash f-18"></i></a>
                    </li>';
                    return $actionBtn;
                })
                ->editColumn('title', function ($row) {
                    return Str::limit($row->title, 100);
                })
                ->editColumn('alias', function ($row) {
                    return Str::limit($row->alias, 100);
                })
                ->editColumn('created_at', function ($row) {
                    return date('Y-m-d H:i:s', strtotime($row->created_at));
                })
                ->rawColumns(['title', 'alias', 'action'])
                ->make(true);
        }
        return view('admin.blog.index', compact('title', 'fonts'));
    }

    public function create()
    {
        return view('admin.blog.add-blog', [
            'categories' => BlogCategory::get(),
        ]);
    }

    public function store(Request $request) {
        $validator = Validator::make($request->all(), [
            'title' => 'required|string|max:191|unique:App\Models\Blog,title',
            'alias' => 'nullable|string|max:191|unique:App\Models\Blog,alias',
            'image' => 'required|file|max:1024000|mimes:jpg,jpeg,png,webp',
            'description' => 'nullable',
            'meta_title' => 'nullable|string|max:191',
            'meta_keyword' => 'nullable|string|max:191',
            'meta_description' => 'nullable',
            'og_title' => 'nullable|string|max:191',
            'og_description' => 'nullable',
            'rank' => 'nullable|min:1',
            'active' => 'boolean',
            'categories' => 'nullable',
            'tags' => 'nullable',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $blog = new Blog;
        $blog->title = $request->title;
        $blog->alias = $request->alias ? $request->alias : Str::slug($request->title, '-');
        $blog->description = $request->description;
        $blog->meta_title = $request->meta_title;
        $blog->meta_keyword = $request->meta_keyword;
        $blog->meta_description = $request->meta_description;
        $blog->og_title = $request->og_title;
        $blog->og_description = $request->og_description;
        $blog->rank = $request->rank;
        $blog->active = $request->active == NULL ? 0 : 1;
        $blog->tags = $request->tags;

        if ($request->file('image') != NULL) {
            $image = $request->file('image');
            $uploadPath = "public/uploads/blog";
            $blog->image = $image->store($uploadPath);
        }

        $blog->save();

        if ($request->filled('categories')) {
            $arr = $request->categories;

            if (is_countable(($arr))) {
                $data = [];

                foreach ($arr as $x) {
                    $data[] = [
                        'blogId' => $blog->id,
                        'blogCategoryId' => $x,
                        'created_at' => Carbon::now()
                    ];
                }

                BlogPostCategory::insert($data);
            }
        }

        return redirect()->route('admin.blog')->with('success', 'Blog added successfully');
        // session()->flash('message', 'Blog added successfully.');

        // return to_route('admin.blog');
    }

    public function edit(Blog $blog)
    {
        $categories = BlogCategory::get()->toArray();
        $assignedCategories = BlogPostCategory::select('blogCategoryId')->where('blogId', $blog->id)->get()->toArray();
        $assignedCategories = array_column($assignedCategories, 'blogCategoryId');

        if ($blog->image != NULL) {
            if (Storage::exists($blog->image)) {
                $blog->image = asset(Storage::url($blog->image));
            }
        }

        $blog->tags_arr = explode(',', $blog->tags);

        return view('admin.blog.edit-blog', [
            'blog' => $blog,
            'categories' => $categories,
            'assignedCategories' => $assignedCategories,
        ]);
    }

    public function update(Request $request) {

        $validator = Validator::make($request->all(), [
            'title' => 'required|string|max:191|unique:App\Models\Blog,title,' . $request->id,
            'alias' => 'nullable|string|max:191|unique:App\Models\Blog,alias,' . $request->id,
            'image' => 'nullable|file|max:1024000|mimes:jpg,jpeg,png,webp',
            'description' => 'nullable',
            'meta_title' => 'nullable|string|max:191',
            'meta_keyword' => 'nullable|string|max:191',
            'meta_description' => 'nullable',
            'og_title' => 'nullable|string|max:191',
            'og_description' => 'nullable',
            'rank' => 'nullable|min:1',
            'active' => 'boolean',
            'categories' => 'nullable',
            'tags' => 'nullable',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $blog = Blog::where('id', $request->id)->first();

        $blog->title = $request->title;
        $blog->alias = $request->alias ? $request->alias : Str::slug($request->title, '-');
        $blog->description = $request->description;
        $blog->meta_title = $request->meta_title;
        $blog->meta_keyword = $request->meta_keyword;
        $blog->meta_description = $request->meta_description;
        $blog->og_title = $request->og_title;
        $blog->og_description = $request->og_description;
        $blog->rank = $request->rank;
        $blog->active = $request->active == NULL ? 0 : 1;
        $blog->tags = $request->tags;

        if ($request->file('image') != NULL) {
            if ($blog->image != NULL) {
                Storage::delete($blog->image);
            }

            $image = $request->file('image');
            $uploadPath = "public/uploads/blog";
            $blog->image = $image->store($uploadPath);
        }

        $blog->update();

        BlogPostCategory::where('blogId', $request->id)->delete();

        if ($request->filled('categories')) {
            $arr = $request->categories;

            if (is_countable(($arr))) {
                $data = [];

                foreach ($arr as $x) {
                    $data[] = [
                        'blogId' => $request->id,
                        'blogCategoryId' => $x,
                        'created_at' => Carbon::now()
                    ];
                }

                BlogPostCategory::insert($data);
            }
        }
        return redirect()->route('admin.blog')->with('success', 'Blog details updated successfully');
        // session()->flash('message', 'Blog details updated successfully.');

        // return to_route('admin.blog');
    }

    public function destroy(Request $request)
    {
        $ids = $request->ids;
        $ids = explode(",", $ids);

        Blog::whereIn('id', $ids)->delete();

        if (count($ids) > 1) {
            $msg = "Records deleted successfully";
        } else {
            $msg = "Record deleted successfully";
        }

        Session::flash('success', $msg); 
        return response(['status' => true, 'msg' => $msg]);
    }


}
