<?php

namespace App\Http\Controllers\Admin;

use App\Models\Brand;
use Illuminate\Support\Str;
use Illuminate\Http\Request;
use Yajra\DataTables\DataTables;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Session;

class BrandController extends Controller
{
    public function index(Request $request)
    {
        $title = 'Designers';
        if ($request->ajax()) {
            $data = Brand::where('id','>',0);
            return DataTables::of($data)
                ->addIndexColumn()
                ->addColumn('action', function ($row) {
                    $actionBtn = ' <ul class="list-inline me-auto mb-0">
                    <li class="list-inline-item align-bottom" data-bs-toggle="tooltip" title="Edit">
                    <a href="' . route('admin.brands.edit', $row->id) . '" class="edit avtar avtar-xs btn-link-success btn-pc-default"><i class="ti ti-edit-circle f-18"></i></a>
                    </li>
                    <li class="list-inline-item align-bottom" data-bs-toggle="tooltip" title="Delete">
                    <a href="javascript:void(0)" class="deleteSelSingle delete avtar avtar-xs btn-link-danger btn-pc-default" data-val=' . $row->id . '> <i class="ti ti-trash f-18"></i></a>
                    </li>';
                    return $actionBtn;
                })
                ->rawColumns(['action'])
                ->make(true);
        }
        return view('admin.brands.index', compact('title'));
    }

    public function create()
    {
        $action = 'Create';
        $title = 'Designer';
        return view('admin.brands.brand', compact('action', 'title'));
    }

    public function edit($id)
    {
        $action = 'Edit';
        $title = 'Designer';
        $record = Brand::find($id);
        return view('admin.brands.brand', compact('action', 'title', 'record'));
    }

    private function _form_validation($request)
    {
        $rules = [
            'name' => 'required|string|max:191|unique:App\Models\Brand,name,' . $request->id,
            'alias' => 'nullable|string|max:191|unique:App\Models\Brand,alias,' . $request->id,
            'image' => 'nullable|file|max:1024000|mimes:jpg,jpeg,png,webp',
            'active' => 'nullable|boolean',
        ];
        $messages = [
            'name.required' => 'Name is required',

        ];
        $request->validate($rules, $messages);

        $postData = array(
            'name' => $request->name,
            'alias' =>$request->alias ? $request->alias : Str::slug($request->name, '-'),
            'active' => ($request->active) ? $request->active : 0
        );

        if ($request->file('image') != NULL) {
            $image = $request->file('image');
            $uploadPath = "public/uploads/brands";
            $postData['image'] = $image->store($uploadPath);
        }

        return $postData;
    }

    public function store(Request $request)
    {
        $data = $this->_form_validation($request);
        $data['created_at'] = date('Y-m-d H:i:s');
        Brand::insertGetId($data);

        return redirect()->route('admin.brands')->with('success', 'Data submitted successfully');
    }

    public function update($id, Request $request)
    {
        $data = $this->_form_validation($request);
        $data['updated_at'] = date('Y-m-d H:i:s');
        Brand::where('id', $id)->update($data);

        return redirect()->route('admin.brands')->with('success', 'Data updated successfully');
    }

    public function updateActive(Request $request)
    {
        $id = $request->id;
        $active = ($request->value == 0) ? 1 : 0;
        Brand::where('id', $id)->update(['active' => $active]);
        $msg = 'Record has been deactivated';
        if ($active == 1) {
            $msg = 'Record has been activated';
        }
        return response()->json(['status' => true, 'msg' => $msg]);
    }

    public function destroy(Request $request)
    {
        $ids = $request->ids;
        $ids = explode(",", $ids);

        Brand::whereIn('id', $ids)->delete();
        if (count($ids) > 1) {
            $msg = "Records deleted successfully";
        } else {
            $msg = "Record deleted successfully";
        }
        Session::flash('success', $msg); 
        return response(['status' => true, 'msg' => $msg]);
    }

    public function removeFile(Request $request)
    {
        Brand::where('id', $request->id)->update(['image' => '']);
        $msg = 'Image Removed!';
        
        Session::flash('success', $msg); 
        return response(['status' => true, 'msg' => $msg]);
    }
}
