<?php

namespace App\Http\Controllers\Admin;

use stdClass;
use App\Models\City;
use App\Models\State;
use App\Models\Country;
use Illuminate\Http\Request;
use Yajra\DataTables\DataTables;
use Illuminate\Support\Facades\DB;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\Validator;
use PHPUnit\Framework\Constraint\Count;

class CityController extends Controller
{

    public function index(Request $request)
    {
        $title = 'Cities';
        if ($request->ajax()) {
            $data = City::select(DB::raw("cities.*,s.name as state,c.name as country"))
            ->leftJoin('states as s','s.id','cities.state_id')
            ->leftJoin('countries as c','c.id','s.country_id');
            return DataTables::of($data)
                ->addIndexColumn()
                ->addColumn('action', function ($row) {
                    $actionBtn = ' <ul class="list-inline me-auto mb-0">
                    <li class="list-inline-item align-bottom" data-bs-toggle="tooltip" title="Edit">
                    <a href="' . route('admin.cities.edit', $row->id) . '" class="edit avtar avtar-xs btn-link-success btn-pc-default"><i class="ti ti-edit-circle f-18"></i></a>
                    </li>
                    <li class="list-inline-item align-bottom" data-bs-toggle="tooltip" title="Delete">
                    <a href="javascript:void(0)" class="deleteSelSingle delete avtar avtar-xs btn-link-danger btn-pc-default" data-val=' . $row->id . '> <i class="ti ti-trash f-18"></i></a>
                    </li>';
                    return $actionBtn;
                })
                ->rawColumns(['action'])
                ->make(true);
        }
        return view('admin.cities.index', compact('title'));
    }

    public function create()
    {
        $action = 'Create';
        $title = 'City';
        $countries=new stdClass();
        $states=new stdClass();
        return view('admin.cities.city', compact('action', 'title','countries','states'));
    }

    public function edit($id)
    {
        $action = 'Edit';
        $title = 'City';
        $record = City::find($id);
        $states=State::where('id',$record->state_id)->get();
        $countries=Country::where('id',$states[0]->country_id)->get();
        return view('admin.cities.city', compact('action', 'title', 'record','states','countries'));
    }

    // public function create()
    // {
    //     $countries = Country::get();
    //     $states = State::get();

    //     return view('admin.city.add', compact('countries', 'states'));
    // }

    private function _form_validation($request)
    {

        $rules = [
           'name' => 'required|string|max:191|unique:App\Models\City,name,' . $request->id,
            'code' => 'required|string|max:10|unique:App\Models\City,code,' . $request->id,
            'state_id' => 'nullable|exists:App\Models\state,id',
            'country_id' => 'required|exists:App\Models\Country,id',
            'active' => 'nullable',
        ];
        $messages = [
            'name.required' => 'Name is required',

        ];
        $request->validate($rules, $messages);

        $postData = array(
            'name' => $request->name,
            'code' => ($request->code) ? $request->code : '',
            'state_id' => $request->state_id,
            'active' => ($request->active) ? $request->active : 0
            // 'country_id' => $request->country_id,
        );
        return $postData;
    }

    public function store(Request $request)
    {
        $data = $this->_form_validation($request);
        $data['created_at'] = date('Y-m-d H:i:s');
        City::insertGetId($data);

        return redirect()->route('admin.cities')->with('success', 'Data submitted successfully');
    }

    public function update($id, Request $request)
    {
        $data = $this->_form_validation($request);
        $data['updated_at'] = date('Y-m-d H:i:s');
        City::where('id', $id)->update($data);

        return redirect()->route('admin.cities')->with('success', 'Data updated successfully');
    }

    public function updateActive(Request $request)
    {
        $id = $request->id;
        $active = ($request->value == 0) ? 1 : 0;
        City::where('id', $id)->update(['active' => $active]);
        $msg = 'Record has been deactivated';
        if ($active == 1) {
            $msg = 'Record has been activated';
        }
        return response()->json(['status' => true, 'msg' => $msg]);
    }

    public function destroy(Request $request)
    {
        $ids = $request->ids;
        $ids = explode(",", $ids);

        City::whereIn('id', $ids)->delete();
        if (count($ids) > 1) {
            $msg = "Records deleted successfully";
        } else {
            $msg = "Record deleted successfully";
        }
        Session::flash('success', $msg); 
        return response(['status' => true, 'msg' => $msg]);
    }
}
