<?php

namespace App\Http\Controllers\Admin;

use App\Models\Color;
use Illuminate\Support\Str;
use Illuminate\Http\Request;
use Yajra\DataTables\DataTables;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\Storage;

class ColorController extends Controller
{
    public function index(Request $request)
    {
        $title = 'Colors';
        if ($request->ajax()) {
            $data = Color::where('id','>',0);
            return DataTables::of($data)
                ->addIndexColumn()
                ->addColumn('action', function ($row) {
                    $actionBtn = ' <ul class="list-inline me-auto mb-0">
                    <li class="list-inline-item align-bottom" data-bs-toggle="tooltip" title="Edit">
                    <a href="' . route('admin.colors.edit', $row->id) . '" class="edit avtar avtar-xs btn-link-success btn-pc-default"><i class="ti ti-edit-circle f-18"></i></a>
                    </li>
                    <li class="list-inline-item align-bottom" data-bs-toggle="tooltip" title="Delete">
                    <a href="javascript:void(0)" class="deleteSelSingle delete avtar avtar-xs btn-link-danger btn-pc-default" data-val=' . $row->id . '> <i class="ti ti-trash f-18"></i></a>
                    </li>';
                    return $actionBtn;
                })
                ->addColumn('image', function ($row) {
                    $image = "";
                    if ($row->image != "") {
                        $image = asset(Storage::url('colors')) . '/' . $row->image;
                        return "<img src='" . $image . "' width='50'>";
                    }
                    return $image;
                })
                ->addColumn('active', function ($row) {
                    $checked = "";
                    if ($row->active == 1) {
                        $checked = 'checked';
                    }
                    return '<div class="form-check form-switch custom-switch-v1 mb-2">
                        <input type="checkbox" class="form-check-input input-success active_item" data-name="' . $row->title . '" data-value="' . $row->active . '" data-id="' . $row->id . '" ' . $checked . '>
                    </div>';
                })
                ->rawColumns(['action','image', 'active'])
                ->make(true);
        }
        return view('admin.color.index', compact('title'));
    }

    public function create()
    {
        $action = 'Create';
        $title = 'Color';
        return view('admin.color.color', compact('action', 'title'));
    }

    public function edit($id)
    {
        $action = 'Edit';
        $title = 'Color';
        $record = Color::find($id);
        return view('admin.color.color', compact('action', 'title', 'record'));
    }

    private function _form_validation($request)
    {
        // dd($request->all());
        $rules = [
            'code' => 'required|unique:App\Models\Color,code,' . $request->id,
            'name' => 'required',
            'alias' => 'nullable',
            'rank' => 'nullable',
            'image' => 'nullable'
        ];
        $messages = [
            'name.required' => 'Name is required',

        ];
        $request->validate($rules, $messages);

        $postData = array(
            'code' => $request->code,
            'name' => $request->name,
            'alias' => isset($request->alias) ? Str::slug($request->alias) : Str::slug($request->name),
            'rank' => isset($request->rank) ? $request->rank : 0,
            'active' => isset($request->active) ? $request->active : 0
        );

        $old_image = $request->old_image;
        $image = isset($request->image) ? 'image' : '';
        if ($request->hasFile($image)) {
            $path = "public/colors";
            $File = $request->file($image);
            $imagename = time() . '_' . $File->getClientOriginalName();
            $filenametostore = $request->file($image)->storeAs($path, $imagename);
            // Storage::setVisibility($filenametostore, 'public');
            $image = $imagename;
        } else if (isset($old_image)) {
            $image = $old_image;
        }
        $postData['image'] = $image;
        return $postData;
    }

    public function store(Request $request)
    {
        $data = $this->_form_validation($request);
        $data['created_at'] = date('Y-m-d H:i:s');
        Color::insertGetId($data);

        return redirect()->route('admin.colors')->with('success', 'Data submitted successfully');
    }

    public function update($id, Request $request)
    {
        $data = $this->_form_validation($request);
        $data['updated_at'] = date('Y-m-d H:i:s');
        Color::where('id', $id)->update($data);

        return redirect()->route('admin.colors')->with('success', 'Data updated successfully');
    }

    public function updateActive(Request $request)
    {
        $id = $request->id;
        $active = ($request->value == 0) ? 1 : 0;
        Color::where('id', $id)->update(['active' => $active]);
        $msg = 'Record has been deactivated';
        if ($active == 1) {
            $msg = 'Record has been activated';
        }
        return response()->json(['status' => true, 'msg' => $msg]);
    }

    public function destroy(Request $request)
    {
        $ids = $request->ids;
        $ids = explode(",", $ids);

        Color::whereIn('id', $ids)->delete();
        if (count($ids) > 1) {
            $msg = "Records deleted successfully";
        } else {
            $msg = "Record deleted successfully";
        }
        Session::flash('success', $msg); 
        return response(['status' => true, 'msg' => $msg]);
    }

    public function removeFile(Request $request)
    {
        Color::where('id', $request->id)->update(['image' => '']);
        $msg = 'Image Removed!';
        
        Session::flash('success', $msg); 
        return response(['status' => true, 'msg' => $msg]);
    }
}
