<?php

namespace App\Http\Controllers\Admin;

use App\Models\Country;
use Illuminate\Http\Request;
use Yajra\DataTables\DataTables;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Session;

class CountryController extends Controller
{
    public function index(Request $request)
    {
        $title = 'Countries';
        if ($request->ajax()) {
            $data = Country::where('id','>',0);
            return DataTables::of($data)
                ->addIndexColumn()
                ->addColumn('action', function ($row) {
                    $actionBtn = ' <ul class="list-inline me-auto mb-0">
                    <li class="list-inline-item align-bottom" data-bs-toggle="tooltip" title="Edit">
                    <a href="' . route('admin.countries.edit', $row->id) . '" class="edit avtar avtar-xs btn-link-success btn-pc-default"><i class="ti ti-edit-circle f-18"></i></a>
                    </li>
                    <li class="list-inline-item align-bottom" data-bs-toggle="tooltip" title="Delete">
                    <a href="javascript:void(0)" class="deleteSelSingle delete avtar avtar-xs btn-link-danger btn-pc-default" data-val=' . $row->id . '> <i class="ti ti-trash f-18"></i></a>
                    </li>';
                    return $actionBtn;
                })
                ->rawColumns(['action'])
                ->make(true);
        }
        return view('admin.countries.index', compact('title'));
    }

    public function create()
    {
        $action = 'Create';
        $title = 'Country';
        return view('admin.countries.country', compact('action', 'title'));
    }

    public function edit($id)
    {
        $action = 'Edit';
        $title = 'Country';
        $record = Country::find($id);
        return view('admin.countries.country', compact('action', 'title', 'record'));
    }

    private function _form_validation($request)
    {
        $rules = [
           'name' => 'required|string|max:191|unique:App\Models\Country,name,' . $request->id,
            'code' => 'required|string|max:10|unique:App\Models\Country,code,' . $request->id,
            'active' => 'nullable',
        ];
        $messages = [
            'name.required' => 'Name is required',

        ];
        $request->validate($rules, $messages);

        $postData = array(
            'name' => $request->name,
            'code' => ($request->code) ? $request->code : '',
            'active' => ($request->active) ? $request->active : 0
        );
        return $postData;
    }

    public function store(Request $request)
    {
        $data = $this->_form_validation($request);
        $data['created_at'] = date('Y-m-d H:i:s');
        Country::insertGetId($data);

        return redirect()->route('admin.countries')->with('success', 'Data submitted successfully');
    }

    public function update($id, Request $request)
    {
        $data = $this->_form_validation($request);
        $data['updated_at'] = date('Y-m-d H:i:s');
        Country::where('id', $id)->update($data);

        return redirect()->route('admin.countries')->with('success', 'Data updated successfully');
    }

    public function updateActive(Request $request)
    {
        $id = $request->id;
        $active = ($request->value == 0) ? 1 : 0;
        Country::where('id', $id)->update(['active' => $active]);
        $msg = 'Record has been deactivated';
        if ($active == 1) {
            $msg = 'Record has been activated';
        }
        return response()->json(['status' => true, 'msg' => $msg]);
    }

    public function destroy(Request $request)
    {
        $ids = $request->ids;
        $ids = explode(",", $ids);

        Country::whereIn('id', $ids)->delete();
        if (count($ids) > 1) {
            $msg = "Records deleted successfully";
        } else {
            $msg = "Record deleted successfully";
        }
        Session::flash('success', $msg); 
        return response(['status' => true, 'msg' => $msg]);
    }
}
