<?php

namespace App\Http\Controllers\Admin;

use App\Models\City;
use App\Models\User;
use App\Models\State;
use App\Models\Country;
use App\Models\Appointment;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\Storage;
use Yajra\DataTables\Facades\DataTables;
use Illuminate\Support\Facades\Validator;

class CustomerController extends Controller
{

    public function index(Request $request)
    {
        $title = 'Customers';
        if ($request->ajax()) {
            $data = User::with(['services'])->where('utype', 'S');

            return DataTables::of($data)
                ->addIndexColumn()
                ->addColumn('action', function ($row) {
                    $actionBtn = ' <ul class="list-inline me-auto mb-0">
                    <li class="list-inline-item align-bottom" data-bs-toggle="tooltip" title="Edit">
                    <a href="' . route('admin.customers.edit', $row->id) . '" class="edit avtar avtar-xs btn-link-success btn-pc-default"><i class="ti ti-edit-circle f-18"></i></a>
                    </li>
                    <li class="list-inline-item align-bottom" data-bs-toggle="tooltip" title="Edit">
                    <a href="javascript:void(0)" class="deleteSelSingle delete avtar avtar-xs btn-link-danger btn-pc-default" data-val=' . $row->id . '> <i class="ti ti-trash f-18"></i></a>
                    </li>';
                    return $actionBtn;
                })
                ->addColumn('image', function ($row) {
                    $image = "";
                    if ($row->image != "") {
                        $image = asset(Storage::url('uploads/customer')) . '/' . $row->image;
                        return "<img class='" . 'rounded rounded-circle' . "' src='" . $image . "' width='50' height=50>";
                    }
                    return $image;
                })
                ->addColumn('active', function ($row) {
                    $checked = "";
                    if ($row->active == 1) {
                        $checked = 'checked';
                    }
                    return '<div class="form-check form-switch custom-switch-v1 mb-2">
                        <input type="checkbox" class="form-check-input input-success active_item" data-name="' . $row->first_name . '" data-value="' . $row->active . '" data-id="' . $row->id . '" ' . $checked . '>
                    </div>';
                })
                ->rawColumns(['action', 'active', 'image'])
                ->make(true);
        }

        return view('admin.customers.index', compact('title'));
    }


    public function create()
    {
        $action = 'Create';
        $title = 'Customer';
        $countries = Country::get();
        return view('admin.customers.customer', compact('action', 'title', 'countries'));
    }

    public function edit($id)
    {
        $action = 'Edit';
        $title = 'Customer';
        $record = User::find($id);
        $countries = Country::orderBy(DB::raw('id=' . $record->country_id), 'asc')->limit(5)->get();
        $state_id = $record->state_id;
        $city_id = $record->city_id;
        $state = State::find($state_id);
        $city = City::find($city_id);
        return view('admin.customers.customer', compact('action', 'title', 'countries', 'record', 'state', 'city'));
    }

    private function _form_validation($request)
    {
        // dd($request->all());
        $rules = [
            'first_name' => 'required',
            'last_name' => 'nullable',
            'email' => 'required|email',
            'phone' => 'required|string',
            'country_id' => 'nullable',
            'state_id' => 'nullable',
            'city_id' => 'nullable',
            'zipcode' => 'nullable',
            'address' => 'nullable'
        ];
        $messages = [
            'first_name.required' => 'Name is required',

        ];
        $request->validate($rules, $messages);

        $postData = array(
            'first_name' => $request->first_name,
            'last_name' => isset($request->last_name) ? $request->last_name : '',
            'utype' => 'S',
            'email' => $request->email,
            'phone' => isset($request->phone) ? $request->phone : '',
            'country_id' => isset($request->country_id) ? $request->country_id : 0,
            'state_id' => isset($request->state_id) ? $request->state_id : 0,
            'city_id' => isset($request->city_id) ? $request->city_id : 0,
            'zipcode' => isset($request->zipcode) ? $request->zipcode : '',
            'address' => isset($request->address) ? $request->address : '',
            'active' => isset($request->active) ? $request->active : 0,
        );

        $image = isset($request->image) ? 'image' : '';
        if ($request->hasFile($image)) {
            $path = "public/uploads/customer";
            $file = $request->file($image);
            // dd($request->file($image));
            $image = time() . '_' . $file->getClientOriginalName();
            $file->storeAs($path, $image);
            // Storage::setVisibility($filenametostore, 'public');
            $postData['image'] = $image;
        } else if (isset($request->old_image)) {
            $old_image = $request->old_image;
            $postData['image']  = $old_image;
        }

        return $postData;
    }


    public function store(Request $request)
    {
        $data = $this->_form_validation($request);
        $data['created_at'] = date('Y-m-d H:i:s');
        $id = User::insertGetId($data);

        return redirect()->route('admin.customers')->with('success', 'Data submitted successfully');
    }

    public function update($id, Request $request)
    {
        $data = $this->_form_validation($request);
        $data['updated_at'] = date('Y-m-d H:i:s');
        User::where('id', $id)->update($data);

        return redirect()->route('admin.customers')->with('success', 'Data updated successfully');
    }

    public function updateActive(Request $request)
    {
        $id = $request->id;
        $active = ($request->value == 0) ? 1 : 0;
        User::where('id', $id)->update(['active' => $active]);
        $msg = 'Record has been deactivated';
        if ($active == 1) {
            $msg = 'Record has been activated';
        }
        return response()->json(['status' => true, 'msg' => $msg]);
    }

    public function removeFile(Request $request)
    {
        User::where('id', $request->id)->update(['image' => '']);
        $msg = 'Image Removed!';
        Session::flash('success', $msg); 
        // $request->session()->put('success', $msg);
        return response(['status' => true, 'msg' => $msg]);
    }

    public function destroy(Request $request)
    {
        $ids = $request->ids;
        $ids = explode(",", $ids);

        User::whereIn('id', $ids)->delete();
        if (count($ids) > 1) {
            $msg = "Records deleted successfully";
        } else {
            $msg = "Record deleted successfully";
        }
        // $request->session()->put('success', $msg);
        Session::flash('success', $msg); 
        return response(['status' => true, 'msg' => $msg]);
    }
}
