<?php

namespace App\Http\Controllers\Admin;

use App\Models\Font;
use App\Models\PageFont;
use Illuminate\Http\Request;
use Yajra\DataTables\DataTables;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\Validator;

class FontController extends Controller
{
    public function index(Request $request)
    {
        $title = 'Fonts';
        if ($request->ajax()) {
            $data = Font::where('id','>',0);
            return DataTables::of($data)
                ->addIndexColumn()
                ->addColumn('action', function ($row) {
                    $actionBtn = ' <ul class="list-inline me-auto mb-0">
                    <li class="list-inline-item align-bottom" data-bs-toggle="tooltip" title="Delete">
                    <a href="javascript:void(0)" class="deleteSelSingle delete avtar avtar-xs btn-link-danger btn-pc-default" data-val=' . $row->id . '> <i class="ti ti-trash f-18"></i></a>
                    </li>';
                    return $actionBtn;
                })
                ->rawColumns(['action'])
                ->make(true);
        }
        return view('admin.font.index', compact('title'));
    }

    public function create()
    {
        return view('admin.font.add');
    }

    public function store(Request $request) {
        $validator = Validator::make($request->all(), [
            'name' => 'required|string|max:191|unique:App\Models\Font,name',
            'file' => 'required|file|max:2048',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $font = new Font;
        $font->name = $request->name;

        if ($request->file('file') != NULL) {
            $file = $request->file('file');
            $uploadPath = "public/fonts";
            $filepath = $file->store($uploadPath);
            $font->path = str_replace("public/", "", $filepath);
        }

        $font->save();
        $this->update_css();
        return redirect()->route('admin.fonts')->with('success', 'Font added successfully');
        // session()->flash('message', 'Font added successfully.');
        // return to_route('admin.fonts');
    }

    public function update_css()
    {
        $fonts = Font::get();
        $cssContent = '';

        foreach ($fonts as $font) {
            $fontName = str_replace(' ', '-', strtolower($font->name)) ;
            $fontUrl = $font->path;

            $cssContent .= <<<CSS

            @font-face {
                font-family: '{$fontName}';
                src:  url('../storage/{$fontUrl}') format('truetype');
            }
            .font-{$fontName} {
                font-family: '{$fontName}' !important;
            }

            CSS;
        }

        $filePath = public_path('css/font.css');
        File::put($filePath, $cssContent);
    }

    public function destroy(Request $request)
    {
        $ids = $request->ids;
        $ids = explode(",", $ids);

        Font::whereIn('id', $ids)->delete();
        $this->update_css();

        if (count($ids) > 1) {
            $msg = "Records deleted successfully";
        } else {
            $msg = "Record deleted successfully";
        }

        // session()->flash('message', 'Font removed successfully.');
        Session::flash('success', $msg); 
        return response(['status' => true]);
    }

    public function update_page_fonts(Request $request)
    {
        $r = PageFont::where('page', $request->page)->first();

        for ($i = 1; $i <= 10; $i++) {
            $fontKey = 'font' . $i;

            if (isset($request->data[$fontKey])) {
                $r->$fontKey = $request->data[$fontKey];
            } else {
                $r->$fontKey = '';
            }
        }

        $r->save();

        session()->flash('message', 'Fonts saved successfully.');
        return response(['status' => true]);
    }

    public function reset_page_fonts(Request $request)
    {
        $page = $request->page;

        $r = PageFont::where('page', $page)->first();

        $r->font1 = '';
        $r->font2 = '';
        $r->font3 = '';
        $r->font4 = '';
        $r->font5 = '';
        $r->font6 = '';
        $r->font7 = '';
        $r->font8 = '';
        $r->font9 = '';
        $r->font10 = '';
        $r->save();

        session()->flash('message', 'Fonts reset successfully.');
        return response(['status' => true]);
    }
}
