<?php

namespace App\Http\Controllers\Admin;

use App\Models\Color;
use App\Models\Neckline;
use Illuminate\Support\Str;
use Illuminate\Http\Request;
use Yajra\DataTables\DataTables;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\Storage;

class NecklineController extends Controller
{
    public function index(Request $request)
    {
        $title = 'Necklines';
        if ($request->ajax()) {
            $data = Neckline::where('id','>',0);
            return DataTables::of($data)
                ->addIndexColumn()
                ->addColumn('action', function ($row) {
                    $actionBtn = ' <ul class="list-inline me-auto mb-0">
                    <li class="list-inline-item align-bottom" data-bs-toggle="tooltip" title="Edit">
                    <a href="' . route('admin.necklines.edit', $row->id) . '" class="edit avtar avtar-xs btn-link-success btn-pc-default"><i class="ti ti-edit-circle f-18"></i></a>
                    </li>
                    <li class="list-inline-item align-bottom" data-bs-toggle="tooltip" title="Delete">
                    <a href="javascript:void(0)" class="deleteSelSingle delete avtar avtar-xs btn-link-danger btn-pc-default" data-val=' . $row->id . '> <i class="ti ti-trash f-18"></i></a>
                    </li>';
                    return $actionBtn;
                })
              
                ->rawColumns(['action'])
                ->make(true);
        }
        return view('admin.necklines.index', compact('title'));
    }

    public function create()
    {
        $action = 'Create';
        $title = 'Neckline';
        return view('admin.necklines.neckline', compact('action', 'title'));
    }

    public function edit($id)
    {
        $action = 'Edit';
        $title = 'Neckline';
        $record = Neckline::find($id);
        return view('admin.necklines.neckline', compact('action', 'title', 'record'));
    }

    private function _form_validation($request)
    {

        $rules = [
            'name' => 'required|string|max:191|unique:App\Models\Neckline,name,' . $request->id
        ];
        $messages = [
            'name.required' => 'Name is required',

        ];
        $request->validate($rules, $messages);

        $postData = array(
            'name' => $request->name
        );
        return $postData;
    }

    public function store(Request $request)
    {
        $data = $this->_form_validation($request);
        $data['created_at'] = date('Y-m-d H:i:s');
        Neckline::insertGetId($data);

        return redirect()->route('admin.necklines')->with('success', 'Data submitted successfully');
    }

    public function update($id, Request $request)
    {
        $data = $this->_form_validation($request);
        $data['updated_at'] = date('Y-m-d H:i:s');
        Neckline::where('id', $id)->update($data);

        return redirect()->route('admin.necklines')->with('success', 'Data updated successfully');
    }

    public function updateActive(Request $request)
    {
        $id = $request->id;
        $active = ($request->value == 0) ? 1 : 0;
        Neckline::where('id', $id)->update(['active' => $active]);
        $msg = 'Record has been deactivated';
        if ($active == 1) {
            $msg = 'Record has been activated';
        }
        return response()->json(['status' => true, 'msg' => $msg]);
    }

    public function destroy(Request $request)
    {
        $ids = $request->ids;
        $ids = explode(",", $ids);

        Neckline::whereIn('id', $ids)->delete();
        if (count($ids) > 1) {
            $msg = "Records deleted successfully";
        } else {
            $msg = "Record deleted successfully";
        }
        Session::flash('success', $msg); 
        return response(['status' => true, 'msg' => $msg]);
    }
}
