<?php

namespace App\Http\Controllers\Admin;

use App\Models\Page;
use Illuminate\Support\Str;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Validator;

class PageController extends Controller
{
    public function index()
    {
        return view('admin.page.index', [
            'data' => Page::get(),
        ]);
    }

    public function create()
    {
        // Fetch available page types.
        $types = ['terms', 'privacy'];
        $arr = Page::whereIn('type', $types)->pluck('type')->toArray();
        $types = array_diff($types, $arr);
        $types[] = 'other';

        return view('admin.page.add', compact('types'));
    }

    public function store(Request $request) {
        $validator = Validator::make($request->all(), [
            'title' => 'required|unique:App\Models\Page,title',
            'alias' => 'nullable|unique:App\Models\Page,alias',
            'type' => 'required',
            'meta_title' => 'nullable',
            'meta_description' => 'nullable',
            'content' => 'nullable',
            'active' => 'nullable',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $page = new Page;
        $page->title = $request->title;
        $page->alias = $request->alias ? 'page/' . $request->alias : 'page/' . Str::slug($request->title, '-');
        $page->type = $request->type;
        $page->meta_title = $request->meta_title;
        $page->meta_description = $request->meta_description;
        $page->content = $request->content;
        $page->active = $request->active == NULL ? 0 : 1;
        $page->save();

        session()->flash('message', 'Page added successfully.');
        return to_route('admin.pages');
    }

    public function edit(Page $page)
    {
        // Fetch available page types.
        $types = ['terms', 'privacy'];
        $arr = Page::whereIn('type', $types)->whereNot('id', $page->id)->pluck('type')->toArray();
        $types = array_diff($types, $arr);
        $types[] = 'other';

        return view('admin.page.edit', [
            'page' => $page,
            'types' => $types,
        ]);
    }

    public function update(Request $request) {
        $validator = Validator::make($request->all(), [
            'title' => 'required|unique:App\Models\Page,title,' . $request->id,
            'alias' => 'nullable|unique:App\Models\Page,alias,' . $request->id,
            'type' => 'required',
            'meta_title' => 'nullable',
            'meta_description' => 'nullable',
            'content' => 'nullable',
            'active' => 'nullable',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $page = Page::where('id', $request->id)->first();
        $page->title = $request->title;

        if ($request->filled('alias')) {
            if ($request->alias != $page->alias) {
                $page->alias = 'page/' . $request->alias;
            }
        } else {
            $page->alias = 'page/' . Str::slug($request->title, '-');
        }

        $page->type = $request->type;
        $page->meta_title = $request->meta_title;
        $page->meta_description = $request->meta_description;
        $page->content = $request->content;
        $page->active = $request->active == NULL ? 0 : 1;
        $page->save();

        session()->flash('message', 'Page details updated successfully.');
        return to_route('admin.pages');
    }

    public function toggle(Page $page)
    {
        $page->active = $page->active ^ 1;
        $page->save();

        echo $page->active;
        exit;
    }

    public function delete(Page $page)
    {
        if ($page->delete()) {
            echo 'done';
        }

        exit;
    }
}
