<?php

namespace App\Http\Controllers\Admin;

use App\Models\Payment;
use Illuminate\Http\Request;
use Yajra\DataTables\DataTables;
use Illuminate\Support\Facades\DB;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Storage;

class PaymentsController extends Controller
{
    public function index(Request $request)
    {
        $title = 'Payments';
        if ($request->ajax()) {
            $data = Payment::select(DB::raw("payments.*,u.first_name,u.last_name,a.quote_number"))
            ->leftJoin('appointments as a','a.id','payments.appointment_id')
            ->leftJoin('users as u','u.id','a.user_id');
            return DataTables::of($data)
                ->addIndexColumn()
                ->addColumn('action', function ($row) {
                    $actionBtn = ' <ul class="list-inline me-auto mb-0">
                    <li class="list-inline-item align-bottom" data-bs-toggle="tooltip" title="Edit">
                        <a href="'. route('admin.payment-details', ['payment' => $row->id]) .'" class="avtar avtar-xs btn-link-success btn-pc-default" data-bs-toggle="tooltip" data-bs-original-title="Details">
                            <i class="ti ti-settings f-18"></i>
                        </a>
                    </li>';
                    return $actionBtn;
                })
               ->addColumn('username',function($row){
                return $row->first_name.' '.$row->last_name;
               })
               ->editColumn('appointment_id',function($row){
                return '#'.$row->appointment_id;
               })
               ->addColumn('quote_number',function($row){
                return '#'.$row->quote_number;
               })
               ->editColumn('created_at',function($row){
                return $row->created_at;
               })
                ->addColumn('status', function ($row) {
                    $status = "<span class='badge bg-danger'>Canceled</span>";
                    if ($row->status == 'S') {
                        $status = "<span class='badge bg-success'>Success</span>";
                    }
                    if ($row->status == 'P') {
                        $status = "<span class='badge bg-warning'>Pending</span>";
                    }
                    return $status;
                })
                ->rawColumns(['action','username', 'quote_number','status','created_at'])
                ->make(true);
        }
        return view('admin.payments.index', compact('title'));
    }

    public function details(Payment $payment)
    {
        return view('admin.payments.payment-details', compact('payment'));
    }
}
