<?php

namespace App\Http\Controllers\Admin;

use App\Models\Appointment;
use Illuminate\Http\Request;
use App\Models\AppointmentService;
use App\Http\Controllers\Controller;

class ReportController extends Controller
{
    public function index()
    {
        $services = AppointmentService::distinct()
            ->join('appointments', 'appointments.service_id', '=', 'appointment_services.id')
            ->select('appointment_services.id', 'appointment_services.name')
            ->get();

        $staff = Appointment::join('appointment_services', 'appointments.service_id', '=', 'appointment_services.id')
            ->join('appointment_service_staff', 'appointment_service_staff.service_id', '=', 'appointment_services.id')
            ->join('users', 'appointment_service_staff.user_id', '=', 'users.id')
            ->select('users.id', 'users.first_name', 'users.last_name')
            ->distinct('users.id')
            ->get();

        return view('admin.reports.index', compact('services', 'staff'));
    }

    // Appointment number
    public function appointment_chart(Request $request)
    {
        $query = Appointment::query();

        if ($request->status != '') {
            $query = $query->where('status', $request->status);
        }

        if ($request->service != '') {
            $query = $query->where('service_id', $request->service);
        }

        if ($request->staff != '') {
            $query = $query->join('appointment_services', 'appointments.service_id', '=', 'appointment_services.id')
                ->join('appointment_service_staff', 'appointment_service_staff.service_id', '=', 'appointment_services.id')
                ->join('users', 'appointment_service_staff.user_id', '=', 'users.id')
                ->where('users.id', $request->staff);
        }

        $appointments = $query->get();
        $groupedAppointments = [];

        switch($request->duration) {
            case 'daily':
                $groupedAppointments = $appointments->groupBy('date');
                break;
            case 'monthly':
                $groupedAppointments = $appointments->groupBy(function ($appointment) {
                    return $appointment->created_at->format('Y-m');
                });
                break;
            case 'annually':
                $groupedAppointments = $appointments->groupBy(function ($appointment) {
                    return $appointment->created_at->format('Y');
                });
                break;
        }


        $data = [];
        $colors = [
            '#1a5276', '#922b21', '#2e4053', '#154360', '#641e16',
            '#1e8449', '#2874a6', '#7b241c', '#148f77', '#b9770e',
            '#5d6d7e', '#2c3e50', '#0e6251', '#1f618d', '#7d6608',
            '#34495e', '#273746', '#117864', '#5b2c6f', '#4d5656'
        ];


        foreach ($groupedAppointments as $date => $appointments) {
            $randomColorIndex = array_rand($colors);
            $color = $colors[$randomColorIndex];

            $data[] = [
                'x' => $date,
                'y' => $appointments->count(),
                'color' => $color,
            ];

            unset($colors[$randomColorIndex]);
        }

        return response()->json($data);
    }

    // Appointment Earning
    public function appointment_chart_2(Request $request)
    {
        $query = Appointment::query();

        if ($request->status != '') {
            $query = $query->where('status', $request->status);
        }

        if ($request->service != '') {
            $query = $query->where('service_id', $request->service);
        }

        if ($request->staff != '') {
            $query = $query->join('appointment_services', 'appointments.service_id', '=', 'appointment_services.id')
                ->join('appointment_service_staff', 'appointment_service_staff.service_id', '=', 'appointment_services.id')
                ->join('users', 'appointment_service_staff.user_id', '=', 'users.id')
                ->where('users.id', $request->staff);
        }

        $appointments = $query->get();
        $groupedAppointments = [];

        switch($request->duration) {
            case 'daily':
                $groupedAppointments = $appointments->groupBy('date');
                break;
            case 'monthly':
                $groupedAppointments = $appointments->groupBy(function ($appointment) {
                    return $appointment->created_at->format('Y-m');
                });
                break;
            case 'annually':
                $groupedAppointments = $appointments->groupBy(function ($appointment) {
                    return $appointment->created_at->format('Y');
                });
                break;
        }


        $data = [];

        foreach ($groupedAppointments as $date => $appointments) {
            $data[] = [
                'x' => $date,
                'y' => $appointments->sum('price'),
            ];
        }

        return response()->json($data);
    }

    // Most Earning
    public function appointment_chart_3(Request $request)
    {
        $query = Appointment::query();

        $query->join('appointment_services', 'appointments.service_id', '=', 'appointment_services.id')
            ->join('appointment_service_staff', 'appointment_service_staff.service_id', '=', 'appointment_services.id')
            ->join('users', 'appointment_service_staff.user_id', '=', 'users.id');

        $appointments = $query->get();
        $groupedAppointments = [];

        switch ($request->duration) {
            case 'daily':
                $groupedAppointments = $appointments->groupBy(function ($appointment) {
                    return $appointment->date;
                });
                break;
            case 'monthly':
                $groupedAppointments = $appointments->groupBy(function ($appointment) {
                    return $appointment->created_at->format('Y-m');
                });
                break;
            case 'annually':
                $groupedAppointments = $appointments->groupBy(function ($appointment) {
                    return $appointment->created_at->format('Y');
                });
                break;
            default:
                $groupedAppointments = $appointments->groupBy('users.id');
                break;
        }

        $data = [];

        foreach ($groupedAppointments as $key => $userAppointments) {
            $totalValue = $userAppointments->sum('price');
            $user = $userAppointments->first()->user;
            $userIndex = array_search($user->id, array_column($data, 'user_id'));

            if ($userIndex === false) {
                $data[] = [
                    'user_id' => $user->id,
                    'user' => $user->first_name . ' ' . $user->last_name,
                    'value' => $totalValue,
                ];
            } else {
                $data[$userIndex]['value'] += $totalValue;
            }
        }

        $finalData = [];

        foreach ($data as $item) {
            $finalData[] = [
                'user' => $item['user'],
                'value' => $item['value'],
            ];
        }

        return response()->json($finalData);
    }

    public function appointment_chart_4(Request $request)
    {
        $query = Appointment::query();

        $query->join('appointment_services', 'appointments.service_id', '=', 'appointment_services.id')
            ->join('appointment_service_staff', 'appointment_service_staff.service_id', '=', 'appointment_services.id')
            ->join('users', 'appointment_service_staff.user_id', '=', 'users.id');

        $startDate = null;
        $endDate = now();

        switch ($request->duration) {
            case 'this_week':
                $startDate = now()->startOfWeek();
                break;
            case 'previous_week':
                $startDate = now()->startOfWeek()->subWeek();
                $endDate = now()->startOfWeek()->subSecond();
                break;
            case 'this_month':
                $startDate = now()->startOfMonth();
                break;
            case 'previous_month':
                $startDate = now()->startOfMonth()->subMonth();
                $endDate = now()->startOfMonth()->subSecond();
                break;
            case 'this_year':
                $startDate = now()->startOfYear();
                break;
            case 'previous_year':
                $startDate = now()->startOfYear()->subYear();
                $endDate = now()->startOfYear()->subSecond();
                break;
            default:
                $startDate = now()->startOfYear();
                break;
        }

        $query->whereBetween('appointments.date', [$startDate, $endDate]);
        $appointments = $query->get();
        $groupedAppointments = $appointments->groupBy('appointment_services.id');
        $data = [];

        foreach ($groupedAppointments as $key => $serviceAppointments) {
            $totalValue = $serviceAppointments->sum('price');
            $service = $serviceAppointments->first()->service;
            $serviceIndex = array_search($service->id, array_column($data, 'service_id'));

            if ($serviceIndex === false) {

                $data[] = [
                    'service_id' => $service->id,
                    'service' => $service->name,
                    'value' => $totalValue,
                ];
            } else {
                $data[$serviceIndex]['value'] += $totalValue;
            }
        }


        $finalData = [];

        foreach ($data as $item) {
            $finalData[] = [
                'service' => $item['service'],
                'value' => $item['value'],
            ];
        }

        return response()->json($finalData);
    }
}
