<?php

namespace App\Http\Controllers\Admin;

use App\Models\Service;
use App\Models\PageFont;
use Illuminate\Support\Str;
use Illuminate\Http\Request;
use Yajra\DataTables\DataTables;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\Validator;

class ServiceController extends Controller
{
    public function index(Request $request)
    {
        $fonts = PageFont::where('page', 'service')->first();

        $title = 'Services';
        if ($request->ajax()) {
            $data = Service::where('id','>',0);

            return DataTables::of($data)
                ->addIndexColumn()
                ->addColumn('action', function ($row) {
                    $actionBtn = ' <ul class="list-inline me-auto mb-0">
                    <li class="list-inline-item align-bottom" data-bs-toggle="tooltip" title="Edit">
                    <a href="' . route('admin.services.edit', $row->id) . '" class="edit avtar avtar-xs btn-link-success btn-pc-default"><i class="ti ti-edit-circle f-18"></i></a>
                    </li>
                    <li class="list-inline-item align-bottom" data-bs-toggle="tooltip" title="Edit">
                    <a href="javascript:void(0)" class="deleteSelSingle delete avtar avtar-xs btn-link-danger btn-pc-default" data-val=' . $row->id . '> <i class="ti ti-trash f-18"></i></a>
                    </li>';
                    return $actionBtn;
                })
                ->editColumn('name', function ($row) {
                    return Str::limit($row->name, 100);
                })
                ->editColumn('alias', function ($row) {
                    return Str::limit($row->alias, 100);
                })
                ->editColumn('created_at', function ($row) {
                    return date('Y-m-d H:i:s', strtotime($row->created_at));
                })
                ->addColumn('active', function ($row) {
                    $checked = "";
                    if ($row->active == 1) {
                        $checked = 'checked';
                    }
                    return '<div class="form-check form-switch custom-switch-v1 mb-2">
                        <input type="checkbox" class="form-check-input input-success active_item" data-name="' . $row->product_code . '" data-value="' . $row->active . '" data-id="' . $row->id . '" ' . $checked . '>
                    </div>';
                })
                ->rawColumns(['name', 'active', 'action'])
                ->make(true);
        }
        return view('admin.services.index', compact('title', 'fonts'));
    }

    public function create()
    {
        $action = 'Create';
        $title = 'Service';
        return view('admin.services.service', compact('action', 'title'));
    }

    public function edit($id)
    {
        $action = 'Edit';
        $title = 'Service';
        $record = Service::find($id);
        return view('admin.services.service', compact('action', 'title', 'record'));
    }


    private function _form_validation($request)
    {
        $rules = [
            'name' => 'required|string|max:191|unique:App\Models\Service,name,' . $request->id,
            'alias' => 'nullable|string|max:191|unique:App\Models\Service,alias,' . $request->id,
            'image' => 'nullable|file|max:1024000|mimes:jpg,jpeg,png,webp',
            'description' => 'nullable',
            'rank' => 'nullable|min:1',
            'active' => 'boolean'
        ];
        $messages = [
            'name.required' => 'Name is required',

        ];
        $request->validate($rules, $messages);

        $postData = array(
            'name' => $request->name,
            'alias' => isset($request->alias) ? Str::slug($request->alias) : Str::slug($request->name),
            'description' => isset($request->description) ? $request->description : "",
            'rank' => isset($request->rank) ? $request->rank : 0,
            'active' => isset($request->active) ? $request->active : 0
        );

        $old_image = $request->old_image;
        $image = isset($request->image) ? 'image' : '';
        if ($request->hasFile($image)) {
            $path = "public/uploads/service";
            $File = $request->file($image);
            $imagename = time() . '_' . $File->getClientOriginalName();
            $filenametostore = $request->file($image)->storeAs($path, $imagename);
            // Storage::setVisibility($filenametostore, 'public');
            $image = $imagename;
        } else if (isset($old_image)) {
            $image = $old_image;
        }
        $postData['image'] = $image;
        return $postData;
    }


    public function store(Request $request)
    {
        $data = $this->_form_validation($request);
        $data['created_at'] = date('Y-m-d H:i:s');
        Service::insertGetId($data);

        return redirect()->route('admin.services')->with('success', 'Data submitted successfully');
    }

    public function update($id, Request $request)
    {
        $data = $this->_form_validation($request);
        $data['updated_at'] = date('Y-m-d H:i:s');
        Service::where('id', $id)->update($data);

        return redirect()->route('admin.services')->with('success', 'Data updated successfully');
    }

    public function updateActive(Request $request)
    {
        $id = $request->id;
        $active = ($request->value == 0) ? 1 : 0;
        Service::where('id', $id)->update(['active' => $active]);
        $msg = 'Record has been deactivated';
        if ($active == 1) {
            $msg = 'Record has been activated';
        }
        return response()->json(['status' => true, 'msg' => $msg]);
    }

    public function destroy(Request $request)
    {
        $ids = $request->ids;
        $ids = explode(",", $ids);

        Service::whereIn('id', $ids)->delete();
        if (count($ids) > 1) {
            $msg = "Records deleted successfully";
        } else {
            $msg = "Record deleted successfully";
        }
        Session::flash('success', $msg); 
        return response(['status' => true, 'msg' => $msg]);
    }

    public function removeFile(Request $request)
    {
        Service::where('id', $request->id)->update(['image' => '']);
        $msg = 'Image Removed!';
        
        Session::flash('success', $msg); 
        return response(['status' => true, 'msg' => $msg]);
    }
}
