<?php

namespace App\Http\Controllers\Admin;

use App\Models\Settings;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\Validator;

class SettingsController extends Controller
{
    public function index()
    {
        $settings = Settings::first();

        if ($settings->logo != '') {
            if (Storage::exists($settings->logo)) {
                $settings->logo = asset(Storage::url($settings->logo));
            }
        }

        if ($settings->mobile_logo != '') {
            if (Storage::exists($settings->mobile_logo)) {
                $settings->mobile_logo = asset(Storage::url($settings->mobile_logo));
            }
        }

        if ($settings->page_404_image != '') {
            if (Storage::exists($settings->page_404_image)) {
                $settings->page_404_image = asset(Storage::url($settings->page_404_image));
            }
        }

        if ($settings->size_chart != '') {
            if (Storage::exists($settings->size_chart)) {
                $settings->size_chart = asset(Storage::url($settings->size_chart));
            }
        }

        return view('admin.settings', compact('settings'));
    }

    public function update(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'logo' => 'nullable|file|max:1024000|mimes:jpg,jpeg,png,webp',
            'mobile_logo' => 'nullable|file|max:1024000|mimes:jpg,jpeg,png,webp',
            'phone' => 'nullable',
            'email' => 'nullable|email',
            'location' => 'nullable',
            'map' => 'nullable',
            'facebook' => 'nullable|string|max:191',
            'instagram' => 'nullable|string|max:191',
            'pinterest' => 'nullable|string|max:191',
            'tiktok' => 'nullable|string|max:191',
            'x' => 'nullable|string|max:191',
            'linkedIn' => 'nullable|string|max:191',
            'page_404_content' => 'nullable',
            'page_404_image' => 'nullable|file|max:1024000|mimes:jpg,jpeg,png,webp',
            'size_chart' => 'nullable|file|max:1024000|mimes:jpg,jpeg,png,webp',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $settings = Settings::first();

        if ($request->file('logo') != '') {
            if ($settings->logo != '') {
                Storage::delete($settings->logo);
            }

            $image = $request->file('logo');
            $uploadPath = "public/uploads/settings";
            $settings->logo = $image->store($uploadPath);
        }

        if ($request->file('mobile_logo') != '') {
            if ($settings->mobile_logo != '') {
                Storage::delete($settings->mobile_logo);
            }

            $image = $request->file('mobile_logo');
            $uploadPath = "public/uploads/settings";
            $settings->mobile_logo = $image->store($uploadPath);
        }

        if ($request->filled('phone')) {
            $settings->phone = $request->phone;
        } else {
            $settings->phone = '';
        }

        if ($request->filled('email')) {
            $settings->email = $request->email;
        } else {
            $settings->email = '';
        }

        if ($request->filled('location')) {
            $settings->location = $request->location;
        } else {
            $settings->location = '';
        }

        if ($request->filled('map')) {
            $settings->map = $request->map;
        } else {
            $settings->map = '';
        }

        if ($request->filled('facebook')) {
            $settings->facebook = $request->facebook;
        } else {
            $settings->facebook = '';
        }

        if ($request->filled('instagram')) {
            $settings->instagram = $request->instagram;
        } else {
            $settings->instagram = '';
        }

        if ($request->filled('pinterest')) {
            $settings->pinterest = $request->pinterest;
        } else {
            $settings->pinterest = '';
        }

        if ($request->filled('tiktok')) {
            $settings->tiktok = $request->tiktok;
        } else {
            $settings->tiktok = '';
        }

        if ($request->filled('x')) {
            $settings->x = $request->x;
        } else {
            $settings->x = '';
        }

        if ($request->filled('linkedIn')) {
            $settings->linkedIn = $request->linkedIn;
        } else {
            $settings->linkedIn = '';
        }

        if ($request->filled('page_404_content')) {
            $settings->page_404_content = $request->page_404_content;
        } else {
            $settings->page_404_content = '';
        }

        if ($request->file('page_404_image') != '') {
            if ($settings->page_404_image != '') {
                Storage::delete($settings->page_404_image);
            }

            $image = $request->file('page_404_image');
            $uploadPath = "public/uploads/settings";
            $settings->page_404_image = $image->store($uploadPath);
        }

        if ($request->file('size_chart') != '') {
            if ($settings->size_chart != '') {
                Storage::delete($settings->size_chart);
            }

            $image = $request->file('size_chart');
            $uploadPath = "public/uploads/settings";
            $settings->size_chart = $image->store($uploadPath);
        }

        $settings->save();

        session()->flash('message', 'Settings updated successfully.');

        return to_route('admin.settings');
    }
}
