<?php

namespace App\Http\Controllers\Admin;

use App\Models\Slider;
use Illuminate\Http\Request;
use Yajra\DataTables\DataTables;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\Validator;

class SliderController extends Controller
{
    public function index(Request $request)
    {
        $title = 'Slider';
        if ($request->ajax()) {
            $data = Slider::where('id','>',0);
            return DataTables::of($data)
                ->addIndexColumn()
                ->addColumn('action', function ($row) {
                    $actionBtn = ' <ul class="list-inline me-auto mb-0">
                    <li class="list-inline-item align-bottom" data-bs-toggle="tooltip" title="Edit">
                    <a href="' . route('admin.sliders.edit', $row->id) . '" class="edit avtar avtar-xs btn-link-success btn-pc-default"><i class="ti ti-edit-circle f-18"></i></a>
                    </li>
                    <li class="list-inline-item align-bottom" data-bs-toggle="tooltip" title="Delete">
                    <a href="javascript:void(0)" class="deleteSelSingle delete avtar avtar-xs btn-link-danger btn-pc-default" data-val=' . $row->id . '> <i class="ti ti-trash f-18"></i></a>
                    </li>';
                    return $actionBtn;
                })
                ->addColumn('active', function ($row) {
                    $checked = "";
                    if ($row->active == 1) {
                        $checked = 'checked';
                    }
                    return '<div class="form-check form-switch custom-switch-v1 mb-2">
                        <input type="checkbox" class="form-check-input input-success active_item" data-name="' . $row->product_code . '" data-value="' . $row->active . '" data-id="' . $row->id . '" ' . $checked . '>
                    </div>';
                })
                ->editColumn('image',function($row){
                    if($row->image!=""){
                        return "<img src='".asset(Storage::url($row->image))."' alt='' class='img-fluid thumb-1' />";
                    }
                    return "";
                })
                ->rawColumns(['action', 'active','image'])
                ->make(true);
        }
        return view('admin.slider.index', compact('title'));
    }
    
    public function create()
    {
        $action = 'Create';
        $title = 'Slider';
        return view('admin.slider.slider',compact('action','title'));
    }

    public function store(Request $request) {
        $validator = Validator::make($request->all(), [
            'image' => 'required|file|max:1024000|mimes:jpg,jpeg,png,webp',
            'sub_image' => 'required|file|max:1024000|mimes:jpg,jpeg,png,webp',
            'title' => 'required|string|max:191',
            'subtitle' => 'nullable|string|max:191',
            'tagline' => 'nullable|string|max:191',
            'button_text' => 'nullable|string|max:50',
            'button_link' => 'nullable|string|max:191',
            'rank' => 'nullable|integer|max:9999',
            'active' => 'nullable|boolean',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $slider = new Slider;

        if ($request->file('image') != NULL) {
            $image = $request->file('image');
            $uploadPath = "public/uploads/slider";
            $slider->image = $image->store($uploadPath);
        }

        if ($request->file('sub_image') != NULL) {
            $image = $request->file('sub_image');
            $uploadPath = "public/uploads/slider";
            $slider->sub_image = $image->store($uploadPath);
        }

        $slider->title = $request->title;
        $slider->subtitle = $request->subtitle;
        $slider->tagline = $request->tagline;
        $slider->button_text = $request->button_text;
        $slider->button_link = $request->button_link;
        $slider->rank = $request->rank;
        $slider->button_link = $request->button_link;
        $slider->save();
        return redirect()->route('admin.sliders')->with('success', 'Image added to slider successfully');
        // session()->flash('message', 'Image added to slider successfully.');

        // return to_route('admin.sliders');
    }

    public function edit($id)
    {
        $action = 'Edit';
        $title = 'Slider';
        $slider=Slider::find($id);
        if ($slider->image != NULL) {
            if (Storage::exists($slider->image)) {
                $slider->image = asset(Storage::url($slider->image));
            }
        }

        if ($slider->sub_image != NULL) {
            if (Storage::exists($slider->sub_image)) {
                $slider->sub_image = asset(Storage::url($slider->sub_image));
            }
        }

        return view('admin.slider.slider', [
            'record' => $slider,
            'action' => $action,
            'title' => $title
        ]);
    }

    public function update($id,Request $request)
    {
        $validator = Validator::make($request->all(), [
            'image' => 'nullable|file|max:1024000|mimes:jpg,jpeg,png,webp',
            'sub_image' => 'nullable|file|max:1024000|mimes:jpg,jpeg,png,webp',
            'title' => 'nullable|string|max:191',
            'subtitle' => 'nullable|string|max:191',
            'tagline' => 'nullable|string|max:191',
            'button_text' => 'nullable|string|max:50',
            'button_link' => 'nullable|string|max:191',
            'rank' => 'nullable|integer|max:9999',
            'active' => 'nullable|boolean',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $slider = Slider::where('id', $id)->first();

        if ($request->file('image') != NULL) {
            $image = $request->file('image');
            $uploadPath = "public/uploads/slider";
            $slider->image = $image->store($uploadPath);
        }

        if ($request->file('sub_image') != NULL) {
            $image = $request->file('sub_image');
            $uploadPath = "public/uploads/slider";
            $slider->sub_image = $image->store($uploadPath);
        }

        $slider->title = $request->title;
        $slider->subtitle = $request->subtitle;
        $slider->tagline = $request->tagline;
        $slider->button_text = $request->button_text;
        $slider->button_link = $request->button_link;
        $slider->rank = $request->rank;
        $slider->button_link = $request->button_link;
        $slider->update();
        return redirect()->route('admin.sliders')->with('success', 'Slider details updated successfully');
        // session()->flash('message', 'Slider details updated successfully.');

        // return to_route('admin.slider');
    }

    // public function delete(Slider $slider)
    // {
    //     if ($slider->delete()) {
    //         echo 'done';
    //     }

    //     exit;
    // }

    public function updateActive(Request $request)
    {
        $id = $request->id;
        $active = ($request->value == 0) ? 1 : 0;
        Slider::where('id', $id)->update(['active' => $active]);
        $msg = 'Record has been deactivated';
        if ($active == 1) {
            $msg = 'Record has been activated';
        }
        return response()->json(['status' => true, 'msg' => $msg]);
    }

    public function destroy(Request $request)
    {
        $ids = $request->ids;
        $ids = explode(",", $ids);

        Slider::whereIn('id', $ids)->delete();
        if (count($ids) > 1) {
            $msg = "Records deleted successfully";
        } else {
            $msg = "Record deleted successfully";
        }
        // $request->session()->put('success', $msg);
        Session::flash('success', $msg); 
        return response(['status' => true, 'msg' => $msg]);
    }

    public function removeFile(Request $request)
    {
        Slider::where('id', $request->id)->update(['image' => '']);
        $msg = 'Image Removed!';
        
        Session::flash('success', $msg); 
        return response(['status' => true, 'msg' => $msg]);
    }
}
