<?php

namespace App\Http\Controllers;

use App\Models\City;
use App\Models\Page;
use App\Models\State;
use App\Models\Country;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;

class IndexController extends Controller
{
    // Get countries
    public function getCountries(Request $request)
    {
        $search = $request->searchTerm;
        if ($search == '') {
            $countries = Country::where('active', '1')->limit(5)->get();
        } else {
            $countries = Country::where('name', 'like', '%' . $search . '%')->where('active', '1')->limit(5)->get();
        }
        $response = array();
        foreach ($countries as $country) {
            $response[] = array(
                "id" => $country->id,
                "text" => $country->name
            );
        }
        return response()->json($response);
    }

    // Get states
    public function getStates(Request $request)
    {
        $search = $request->searchTerm;
        $country_id = $request->country_id;
        if ($search == '') {
            $states = State::where('active', '1')->where('country_id', $country_id)->limit(5)->get();
        } else {
            $states = State::where('name', 'like', '%' . $search . '%')->where('country_id', $country_id)->where('active', '1')->limit(5)->get();
        }
        $response = array();
        foreach ($states as $state) {
            $response[] = array(
                "id" => $state->id,
                "text" => $state->name
            );
        }
        return response()->json($response);
    }

    // Get cities
    public function getCities(Request $request)
    {
        $search = $request->searchTerm;
        $state_id = $request->state_id;
        if ($search == '') {
            $cities = City::where('active', '1')->where('state_id', $state_id)->limit(5)->get();
        } else {
            $cities = City::where('name', 'like', '%' . $search . '%')->where('state_id', $state_id)->where('active', '1')->limit(5)->get();
        }
        $response = array();
        foreach ($cities as $city) {
            $response[] = array(
                "id" => $city->id,
                "text" => $city->name
            );
        }
        return response()->json($response);
    }

    public function page($slug = '')
    {
        $page = Page::where('alias', 'page/' . $slug)
            ->first();

        return view('page', compact('page'));
    }

    /**
     * Open privacy page.
     */
    public function privacy()
    {
        $page = Page::where('type', 'privacy')->first();
        $title = 'Privacy Policy ! Angelic Bridal';

        return view('page', compact('page', 'title'));
    }

    /**
     * Open terms page.
     */
    public function terms()
    {
        $page = Page::where('type', 'terms')->first();
        $title = 'Terms and Conditions ! Angelic Bridal';

        return view('page', compact('page', 'title'));
    }
    
    public function test(){
        \Log::info('sandeep sir 111111');
    }
}
