<?php

namespace App\Http\Controllers;

use App\Models\Country;
use App\Models\City;
use App\Models\Payment;
use App\Models\State;
use Stripe\Charge;
use Stripe\Stripe;
use Stripe\PaymentIntent;
use Illuminate\Http\Request;

class PaymentController extends Controller
{
    public function showPaymentForm()
    {
        return view('payment');
    }

    public function createPaymentIntent(Request $request)
    {
        Stripe::setApiKey(config('services.stripe.secret'));
        $amount = $request->amount * 100; // Amount in cents
        $billing_detail = session('billing_detail');
        $payment_id = $billing_detail['payment_id'];

        $city_name='';
        if($billing_detail['city_id']){
            $city = City::find($billing_detail['city_id']);
            if($city){
                $city_name=$city->name;
            }
        }
        // dd($billing_detail['country_id']);
        $country = Country::find($billing_detail['country_id']);
   
        $postal_code = $billing_detail['postcode'];

        try {
            $paymentIntent = PaymentIntent::create([
                'amount' => $amount,
                'currency' => 'inr',
                'payment_method' => $request->payment_method_id,
                'confirmation_method' => 'automatic',
                'confirm' => true,
                'return_url' => route('payment.success'), // Add your return URL here
                'description' => 'Description of the goods/services being sold', // Add your description here
                'shipping' => [
                    'name' => $billing_detail['first_name'] . ' ' . $billing_detail['last_name'],
                    'address' => [
                        'line1' => $billing_detail['address'],
                        'city' => $city_name,
                        'postal_code' => $postal_code,
                        'country' => $country->code
                    ]
                ],
                'metadata' => [
                    'integration_check' => 'accept_a_payment'
                ],
            ]);

            $payment = Payment::find($payment_id);
            $payment->transaction_id = $paymentIntent->id;
            $payment->save();

            return response()->json([
                'client_secret' => $paymentIntent->client_secret,
                'payment_intent_id' => $paymentIntent->id,
            ]);
        } catch (\Exception $e) {
            return response()->json([
                'error' => $e->getMessage(),
            ]);
        }
    }

    public function paymentSuccess()
    {
        $billing_detail = session('billing_detail');
        $payment_id = $billing_detail['payment_id'];

        $payment = Payment::find($payment_id);
        $payment->status = 'S';
        $payment->save();

        session(['billing_detail' => null]);
        session(['appointment' => null]);
        return redirect()->route('bookAppointment')->with('success', 'Your have successfully paid!');
    }

    public function paymentFailure()
    {
        $billing_detail = session('billing_detail');
        $payment_id = $billing_detail['payment_id'];

        $payment = Payment::find($payment_id);
        $payment->status = 'F';
        $payment->save();

        session(['billing_detail' => null]);
        session(['appointment' => null]);
        return redirect()->route('bookAppointment')->with('failed', 'Your payment has been failed!');
    }

    public function paymentCanceled()
    {
        $billing_detail = session('billing_detail');
        $payment_id = $billing_detail['payment_id'];

        $payment = Payment::find($payment_id);
        $payment->status = 'C';
        $payment->save();

        session(['billing_detail' => null]);
        session(['appointment' => null]);
        return redirect()->route('bookAppointment')->with('failed', 'Your payment has been cancelled!');
    }
}
