<?php

namespace App\Http\Controllers;

use App\Models\Size;
use App\Models\Brand;
use App\Models\Color;
use App\Models\Fabric;
use App\Models\Season;
use App\Models\Product;
use App\Models\Category;
use App\Models\Neckline;
use App\Models\Silhouette;
use Jenssegers\Agent\Agent;
use Illuminate\Http\Request;
use App\Models\ProductVariation;
use Illuminate\Support\Facades\Storage;

class ProductController extends Controller
{
    public function index(Request $request, $category_alias)
    {
        $color = $request->color;
        $silhouette = $request->silhouette;
        $fabric = $request->fabric;
        $brand = $request->brand;
        $season = $request->season;
        $size = $request->size;
        $price = $request->price;
        $neckline = $request->neckline;

        $filters = [];
        $color_filter = '';
        $price_filter = '';

        $brand_filter = [];
        $brand_ids = [];

        $size_filter = '';
        $silhouette_filter = [];
        $silhouette_ids = [];

        $season_filter = [];
        $season_ids = [];

        $fabric_filter = [];
        $fabric_ids = [];

        $neckline_filter = [];
        $neckline_ids = [];

        $grid_type = 'four';
        if (isset($request->grid_type)) {
            $grid_type = $request->grid_type;
        }

        $agent = new Agent();
        if($agent->isMobile()) {
            $grid_type = 'two';
        }
        $search = '';
        if (isset($request->search)) {
            $search = $request->search;
        }
        // silhouette in search
        if ($silhouette != "") {
            $silhouette = trim($silhouette, ',');
            $filters['silhouette'] = explode(',', aliasToName($silhouette, ',')); //name for breadcrumb
            $silhouette_filter = explode(',', $silhouette);

            $silhouette_ids = Silhouette::whereIn('name',  $filters['silhouette'])->get()->pluck('id')->toArray();
        }

        // fabric in search
        if ($fabric != "") {
            $fabric = trim($fabric, ',');
            $filters['fabric'] = explode(',', aliasToName($fabric, ',')); //name for breadcrumb
            $fabric_filter = explode(',', $fabric);
            $fabric_ids = Fabric::whereIn('name',  $filters['fabric'])->get()->pluck('id')->toArray();
        }

        // neckline in search
        if ($neckline != "") {
            $neckline = trim($neckline, ',');
            $filters['neckline'] = explode(',', aliasToName($neckline, ',')); //name for breadcrumb
            $neckline_filter = explode(',', $neckline);

            $neckline_ids = Neckline::whereIn('name',  $filters['neckline'])->get()->pluck('id')->toArray();
        }

        // price
        $productVar = ProductVariation::where('active', 1);
        $min_price = $productVar->min('price');
        $max_price = $productVar->max('price');

        //brand in search
        if ($brand != "") {
            $brand = trim($brand, ',');
            $filters['brand'] = explode(',', aliasToName($brand)); //name for breadcrumb
            $brand_filter = explode(',', $brand);

            $brand_ids = Brand::whereIn('name',  $filters['brand'])->get()->pluck('id')->toArray();
        }

        // if ($brand != "") {
        //     $brandFilter = Brand::where('alias', $brand)->first();
        //     if ($brandFilter) {
        //         $brand_filter = $brandFilter->alias;
        //         $brand_id = $brandFilter->id;
        //         $filters['brand'] = $brandFilter->name;
        //     }
        // }

        // season in search
        if ($season != "") {
            $season = trim($season, ',');
            $filters['season'] = explode(',', aliasToName($season)); //name for breadcrumb
            $season_filter = explode(',', $season);
            $season_ids = Season::whereIn('name',  $filters['season'])->get()->pluck('id')->toArray();
        }

        $size_id = 0;
        if ($size != "") {
            $sizeFilter = Size::where('size', $size)->first();
            if ($sizeFilter) {
                $size_id = $sizeFilter->id;
                $size_filter = $sizeFilter->size;
                $filters['size'] = $sizeFilter->size;
            }
        }

        $category = Category::where('alias', $category_alias)->first();
        $subCats = Category::where("parent_id", $category->id)->get()->pluck('id')->toArray();
        array_push($subCats, $category->id);

        $products = ProductVariation::whereHas('product', function ($q) use ($subCats, $silhouette, $silhouette_ids, $brand_ids, $size_id, $season_ids, $fabric_ids, $neckline_ids, $search) {
            $q->whereHas('categories', function ($q) use ($subCats, $search) {
                $q->whereIn('categories.id', $subCats);
            });

            if ($search != "") {
                $q->where('product_code', 'like', "%{$search}%");
            }
            if (count($season_ids) > 0) {
                $q->whereHas('seasons', function ($q) use ($season_ids) {
                    $q->whereIn('seasons.id', $season_ids);
                });
            }
            if (count($fabric_ids) > 0) {
                $q->whereIn('fabric_id', $fabric_ids);
            }

            if (count($silhouette_ids) > 0) {
                $q->whereIn('silhouette_id', $silhouette_ids);
            }

            if (count($neckline_ids) > 0) {
                $q->whereIn('neckline_id', $neckline_ids);
            }

            if (count($brand_ids) > 0) {
                $q->whereIn('brand_id', $brand_ids);
            }

            if ($size_id > 0) {
                $q->whereHas('sizes', function ($q) use ($size_id) {
                    $q->where('size_id', $size_id);
                });
            }
            $q->where('active', 1);
            $q->orderBy('rank', 'asc');
        })->where('active', 1);

        //color in search
        if ($color != "") {
            $colorFilter = Color::where('alias', $color)->first();
            if ($colorFilter) {
                $color_filter = $colorFilter->alias;
                $products = $products->whereHas('color', function ($q) use ($color) {
                    $q->where('alias', $color);
                });
                $filters['color'] = $colorFilter->name;
            }
        }


        // price search
        if ($price) {
            $price = explode('-', $price);
            $range_min_price = $price[0];
            $range_max_price = $price[1];
            $products = $products->where('price', '>=', $range_min_price)->where('price', '<=', $range_max_price);
            $filters['price'] = $range_min_price . '-' . $range_max_price;
            $price_filter = $range_min_price . '-' . $range_max_price;
        } else {
            $range_min_price = $min_price;
            $range_max_price = $max_price;
        }

        $products = $products->with(['product.categories', 'images', 'color', 'product.seasons'])->paginate(9);

        if ($products->count() == 0 && $search != "") {
            abort(404);
        }
        //selected category
        $category = Category::where("alias", $category_alias)->first();
        if ($request->ajax()) {
            return view('products.listing', compact('products', 'category','grid_type'))->render();
        }

        // colors filter
        $colors = Color::whereHas('product_variations', function ($q) use ($subCats, $search) {
            $q->whereHas('product', function ($q) use ($subCats, $search) {
                $q->orderBy('rank', 'asc');
                $q->whereHas('categories', function ($q) use ($subCats) {
                    $q->whereIn('categories.id', $subCats);
                });
                if ($search != "") {
                    $q->where('product_code', 'like', "%{$search}%");
                }
            })->where('active', 1);
        })->get();

        // Silhouette filter
        if ($search != "") {
            $silhouettes = Silhouette::whereHas('products', function ($q) use ($search) {
                $q->where('product_code', 'like', "%{$search}%");
            })->get();
        } else {
            $silhouettes = Silhouette::get();
        }


        // Brand filter
        if ($search != "") {
            $brands = Brand::whereHas('products', function ($q) use ($search) {
                $q->where('product_code', 'like', "%{$search}%");
            })->get();
        } else {
            $brands = Brand::get();
        }

        // Sizes filter
        if ($search != "") {
            $sizes = Size::whereHas('products', function ($q) use ($search) {
                $q->where('product_code', 'like', "%{$search}%");
            })->get();
        } else {
            $sizes = Size::get();
        }

        // Seasons filter
        if ($search != "") {
            $seasons = Season::whereHas('products', function ($q) use ($search) {
                $q->where('product_code', 'like', "%{$search}%");
            })->get();
        } else {
            $seasons = Season::get();
        }

        // Fabric filter
        if ($search != "") {
            $fabrics = Fabric::whereHas('products', function ($q) use ($search) {
                $q->where('product_code', 'like', "%{$search}%");
            })->get();
        } else {
            $fabrics = Fabric::get();
        }

        // neckline filters
        if ($search != "") {
            $necklines = Neckline::whereHas('products', function ($q) use ($search) {
                $q->where('product_code', 'like', "%{$search}%");
            })->get();
        } else {
            $necklines = Neckline::get();
        }
        return view('products.product-listing', compact('products', 'grid_type', 'category', 'colors', 'brands', 'seasons', 'fabrics', 'necklines', 'range_min_price', 'range_max_price', 'silhouettes', 'sizes', 'color_filter', 'silhouette_filter', 'size_filter', 'brand_filter', 'filters', 'min_price', 'max_price', 'price_filter', 'season_filter', 'fabric_filter', 'neckline_filter', 'search'));
    }

    public function detail(Request $request, $category_alias, $product_code, $variation_id = 0)
    {

        $product = Product::whereHas('variations', function ($q) use ($variation_id) {
            $q->where('id', $variation_id)->where('active', 1);
        })
            ->with(['categories', 'sizes' => function ($q) {
                $q->orderBy('id', 'asc');
            }, 'variations' => function ($q) use ($variation_id) {
                $q->where('id', $variation_id)->where('active', 1);
            }])
            ->where('product_code', $product_code)
            ->first();
        if ($product) {
            $category = Category::where('alias', $category_alias)->first();
            if (!$category) {
                $category = $product->categories->first();
            }
            $images = [];
            $path = asset(Storage::url('public/products/' . $product->id));
            $variation = $product->variations->first();
            if ($variation->image != "") {
                $img['image'] = $path . '/' . $variation->image;
                $img['type'] = 'I';
                $images[] = $img;
            }
            if ($variation->video != "") {
                // $images[]=$path.'/'.$variation->video;
                $img['image'] = $path . '/' . $variation->video;
                $img['type'] = 'V';
                $images[] = $img;
            }

            foreach ($variation->images as $image) {
                $img['image'] = $path . '/' . $image->image;
                $img['type'] = 'I';
                $images[] = $img;

            }

            return view('products.product-detail', compact('product', 'images', 'category', 'variation'));
        } else {
            abort(404, 'Product not found!');
        }
    }

    public function changeView(Request $request)
    {
        $grid_type = $request->type;

        return view('products.listing', compact('grid_type'));
    }
}
