<?php

namespace App\Models;

// use Illuminate\Contracts\Auth\MustVerifyEmail;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;

class User extends Authenticatable
{
    use HasFactory, Notifiable;

    /**
     * The attributes that are mass assignable.
     *
     * @var array<int, string>
     */
    protected $fillable = [
        'name',
        'email',
        'password',
    ];

    /**
     * The attributes that should be hidden for serialization.
     *
     * @var array<int, string>
     */
    protected $hidden = [
        'password',
        'remember_token',
    ];

    /**
     * Get the attributes that should be cast.
     *
     * @return array<string, string>
     */
    protected function casts(): array
    {
        return [
            'email_verified_at' => 'datetime',
            'password' => 'hashed',
        ];
    }

    public function working_days(): HasMany
    {
        return $this->hasMany(StaffWorkingDay::class);
    }

    public function booked_appointment_slots(): HasMany
    {
        return $this->hasMany(BookedAppointmentSlot::class);
    }

    public function holidays(): HasMany
    {
        return $this->hasMany(StaffHoliday::class);
    }

    public function services() {
        return $this->belongsToMany(Service::class, AppointmentServiceStaff::class, 'user_id','service_id');
    }

    public function city() {
        return $this->belongsTo(City::class, 'city_id');
    }

    public function state() {
        return $this->belongsTo(State::class, 'state_id');
    }
    public function country() {
        return $this->belongsTo(Country::class, 'country_id');
    }

}
