@extends('admin.layouts.admin')

@section('content')
    <section class="pc-container">
        <div class="pc-content">
            <div class="page-header">
                <div class="page-block">
                    <div class="row align-items-center">
                        <div class="col-md-12">
                            <ul class="breadcrumb">
                                <li class="breadcrumb-item" aria-current="page">Blog</li>
                                <li class="breadcrumb-item">
                                    <a href="{{ route('admin.blog-categories') }}">Categories</a>
                                </li>
                                <li class="breadcrumb-item" aria-current="page">New</li>
                            </ul>
                        </div>
                        <div class="col-md-12">
                            <div class="page-header-title">
                                <h2 class="mb-0">Blog Category</h2>
                            </div>
                        </div>
                    </div>
                </div>
            </div>

            <div class="row pt-0">
                <div class="col-md-12">
                    <div class="card">
                        <div class="card-body">
                            <div>
                                @if ($errors->any())
                                    <div class="alert alert-danger">
                                        <ul>
                                            @foreach ($errors->all() as $error)
                                                <li>
                                                    {{ $error }}
                                                </li>
                                            @endforeach
                                        </ul>
                                    </div>
                                @endif
                            </div>
                            <form action="{{ route('admin.store-blog-category') }}" method="post" enctype="multipart/form-data">
                                @csrf
                                <div class="row">
                                    <div class="col-md-12">
                                        <div class="row">
                                            <div class="form-group col-md-6">
                                                <label class="form-label">Title <span class="text-danger">*</span></label>
                                                <input required name="title" type="text" class="form-control" placeholder="Title" value="{{ old('title') }}" autofocus>
                                            </div>
                                            <div class="form-group col-md-6">
                                                <label class="form-label">Alias</label>
                                                <input name="alias" type="text" class="form-control" placeholder="Will be auto generated if left blank" value="{{ old('alias') }}">
                                            </div>
                                        </div>
                                    </div>
                                </div>

                                <div class="row">
                                    <div class="col-md-12 form-group tall-ck">
                                        <label class="form-label">Description</label>
                                        <textarea name="description" class="form-control ckeditor" placeholder="Description">{!! old('description') !!}</textarea>
                                    </div>
                                </div>

                                <div class="row">
                                    <div class="form-group col-md-4">
                                        <label class="form-label">Rank</label>
                                        <input name="rank" type="number" min="0" class="form-control" placeholder="Rank" value="{{ old('rank') }}">
                                    </div>
                                    <div class="form-group col-md-4">
                                        <label class="form-label">Image</label>
                                        <input name="image" class="form-control" type="file" accept="image/jpg, image/jpeg, image/png, image/webp" onchange="loadFile(event)">
                                    </div>
                                    <div class="col-md-4">
                                        <div class="d-flex">
                                            <img class="img-fluid image-preview" src="" alt="" id="output">
                                        </div>
                                    </div>
                                </div>

                                <div class="row">
                                    <div class="col-md-12 mb-4">
                                        <hr>
                                        <h5>SEO Details</h5>
                                    </div>
                                    <div class="form-group col-md-4">
                                        <label class="form-label">Meta Title</label>
                                        <input name="meta_title" type="text" class="form-control" placeholder="Meta Title" value="{{ old('meta_title') }}">
                                    </div>
                                    <div class="form-group col-md-4">
                                        <label class="form-label">Meta Keyword</label>
                                        <input name="meta_keyword" type="text" class="form-control" placeholder="Meta Keyword" value="{{ old('meta_keyword') }}">
                                    </div>
                                    <div class="form-group col-md-4">
                                        <label class="form-label">OG Title</label>
                                        <input name="og_title" type="text" class="form-control" placeholder="OG Title" value="{{ old('og_title') }}">
                                    </div>
                                </div>

                                <div class="row">
                                    <div class="col-md-12 form-group">
                                        <label class="form-label">Meta Description</label>
                                        <textarea name="meta_description" class="form-control ckeditor" placeholder="Meta Description">{!! old('meta_description') !!}</textarea>
                                    </div>
                                </div>

                                <div class="row">
                                    <div class="col-md-12 form-group">
                                        <label class="form-label">OG Description</label>
                                        <textarea name="og_description" class="form-control ckeditor" placeholder="OG Description">{!! old('og_description') !!}</textarea>
                                    </div>
                                </div>

                                <div class="row">
                                    <div class="col-md-12">
                                        <div class="form-check form-switch custom-switch-v1">
                                            <input name="active" type="checkbox" class="form-check-input input-primary" id="activeCheckbox" value='1' checked>
                                            <label class="form-check-label" for="activeCheckbox">Active</label>
                                        </div>
                                        <input type="submit" value="Save" class="btn btn-primary m-t-20 m-b-20" data-bs-toggle="tooltip" data-bs-original-title="Save changes">
                                    </div>
                                </div>
                            </form>
                        </div>
                    </div>
                </div>
            </div>
    </section>

    <script>
        var loadFile = function(event) {
            var output = document.getElementById('output');
            output.src = URL.createObjectURL(event.target.files[0]);
            output.onload = function() {
              URL.revokeObjectURL(output.src) // free memory
            }
        };
    </script>
@endsection
