@extends('admin.layouts.admin')

@section('content')
<div class="pc-container">
    <div class="pc-content">
        <div class="page-header">
            <div class="page-block">
                <div class="row align-items-center">
                    <div class="col-md-12">
                        <ul class="breadcrumb">
                            <li class="breadcrumb-item"><a href="{{ route('admin.dashboard') }}">Home</a></li>
                            <li class="breadcrumb-item"><a href="{{ route('admin.blog') }}">Blogs</a></li>
                            <li class="breadcrumb-item" aria-current="page">Categories</li>
                        </ul>
                    </div>

                </div>
            </div>
        </div>

        <div class="row pt-0">
            @if ($message = Session::get('success'))
            <div class="col-sm-12">
                <div class="alert alert-success alert-dismissible fade show" role="alert">
                    <strong>{{ $message }}</strong>
                    <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
                </div>
            </div>
            @endif

            <div class="col-sm-12">
                <div class="card">
                    <div class="card-header">
                        <h3 class="float-start">{{ $title }}</h3>
                        <a href="{{ route('admin.colors.create') }}" class="btn btn-primary d-inline-flex align-item-center float-end">
                            <i class="ti ti-plus f-18"></i> Add Category
                        </a>
                    </div>
                    <div class="card-body">
                        <div class="dt-responsive table-responsive">
                            <table id="simpletable" class="table table-striped table-bordered nowrap">
                                <thead>
                                    <tr>
                                        <th>Title</th>
                                        <th>Alias</th>
                                        <th>Rank</th>
                                        <th>Status</th>
                                        <th>Created On</th>
                                        <th>Action</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    @foreach ($data as $item)
                                    <tr>
                                        <td>{{ $item->title }}</td>
                                        <td>{{ $item->alias }}</td>
                                        <td>{{ $item->rank }}</td>
                                        <td>
                                            @if ($item->active == '1')
                                            <span role="button" class="badge bg-success" onclick="toggle(this, {{$item->id}})">Active</span>
                                            @else
                                            <span role="button" class="badge bg-secondary" onclick="toggle(this, {{$item->id}})">Active</span>
                                            @endif
                                        </td>
                                        <td>{{ $item->created_at }}</td>
                                        <td>
                                            <div id="confirmModal{{$item->id}}" class="modal fade" tabindex="-1" role="dialog" aria-labelledby="confirmModalTitle{{$item->id}}" aria-hidden="true">
                                                <div class="modal-dialog modal-dialog-centered" role="document">
                                                    <div class="modal-content">
                                                        <div class="modal-header">
                                                            <h5 class="modal-title text-danger" id="confirmModalTitle{{$item->id}}">Remove Item</h5>
                                                            <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                                                        </div>
                                                        <div class="modal-body">
                                                            <p>Are you sure to remove this item?</p>
                                                        </div>
                                                        <div class="modal-footer">
                                                            <button type="button" class="btn btn-success" data-bs-dismiss="modal">No</button>
                                                            <a role="button" onclick="deleteBlogCategory(this, {{ $item->id }})" class="btn btn-danger text-white" data-bs-dismiss="modal">Yes</a>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>

                                            <a href="{{ route('admin.edit-blog-category', ['category' => $item->id]) }}" class="avtar avtar-xs btn-link-success btn-pc-default" data-bs-toggle="tooltip" data-bs-original-title="Edit">
                                                <i class="ti ti-edit-circle f-18"></i>
                                            </a>

                                            <span data-bs-toggle="tooltip" data-bs-original-title="Remove">
                                                <a href="javascript:void(0)" role="button" data-bs-toggle="modal" data-bs-target="#confirmModal{{$item->id}}" class="avtar avtar-xs btn-link-danger btn-pc-default">
                                                    <i class="ti ti-trash f-18"></i>
                                                </a>
                                            </span>
                                        </td>
                                    </tr>
                                    @endforeach
                                </tbody>
                            </table>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<script src="{{ asset('admin/js/plugins/jquery.dataTables.min.js') }}"></script>
<script src="{{ asset('admin/js/plugins/dataTables.bootstrap5.min.js') }}"></script>

<script>
    $('#simpletable').DataTable({
        order: [
            [4, 'desc']
        ]
    });

    function deleteBlogCategory(ele, id) {
        var url = "{{ route('admin.delete-blog-category', ['category' => 'cid']) }}";
        url = url.replace('cid', id);

        $.ajax({
            type: 'POST',
            url: url,
            headers: {
                'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
            },
            success: function(data) {
                if ($.trim(data) == 'done') {
                    $(ele).closest("tr").remove();
                }
            }
        });
    }
</script>
@endsection