@extends('admin.layouts.admin')

<link href="{{ asset('admin/css/select2.min.css') }}" rel="stylesheet" />

@section('content')
    <section class="pc-container">
        <div class="pc-content">
            <div class="page-header">
                <div class="page-block">
                    <div class="row align-items-center">
                        <div class="col-md-12">
                            <ul class="breadcrumb">
                                <li class="breadcrumb-item">
                                    Blog
                                </li>
                                <li class="breadcrumb-item" aria-current="page">
                                    <a href="{{ route('admin.blog') }}">Posts</a>
                                </li>
                                <li class="breadcrumb-item" aria-current="page">Edit</li>
                            </ul>
                        </div>
                        <div class="col-md-12">
                            <div class="page-header-title">
                                <h2 class="mb-0">Edit Blog</h2>
                            </div>
                        </div>
                    </div>
                </div>
            </div>

            <div class="row pt-0">
                <div class="col-md-12">
                    <div class="card">
                        <div class="card-body">
                            <div>
                                @if ($errors->any())
                                    <div class="alert alert-danger">
                                        <ul>
                                            @foreach ($errors->all() as $error)
                                                <li>
                                                    {{ $error }}
                                                </li>
                                            @endforeach
                                        </ul>
                                    </div>
                                @endif
                            </div>
                            <form action="{{ route('admin.update-blog') }}" method="post" enctype="multipart/form-data" class="form-data">
                                @csrf
                                <input type="hidden" name="id" value="{{ $blog->id }}">
                                <div class="row">
                                    <div class="col-md-12">
                                        <div class="row">
                                            <div class="form-group col-md-6">
                                                <label class="form-label">Title <span class="text-danger">*</span></label>
                                                <input required name="title" type="text" class="form-control" placeholder="Title" value="{{ old('title', $blog->title) }}" autofocus>
                                            </div>
                                            <div class="form-group col-md-6">
                                                <label class="form-label">Alias</label>
                                                <input name="alias" type="text" class="form-control" placeholder="Will be auto generated if left blank" value="{{ old('alias', $blog->alias) }}">
                                            </div>
                                            <div class="form-group col-md-12 tall-ck">
                                                <label class="form-label">Description</label>
                                                <textarea name="description" class="form-control ckeditor" placeholder="Description">{!! old('description', $blog->description) !!}</textarea>
                                            </div>
                                        </div>

                                        <div class="row">
                                            <div class="form-group col-md-4">
                                                <label class="form-label">Rank</label>
                                                <input name="rank" type="number" min="0" class="form-control" placeholder="Rank" value="{{ old('rank', $blog->rank) }}">
                                            </div>
                                            <div class="form-group col-md-4">
                                                <label class="form-label">Image</label>
                                                <input name="image" class="form-control" type="file" accept="image/jpg, image/jpeg, image/png, image/webp" onchange="loadFile(event)">
                                            </div>
                                            <div class="col-md-4">
                                                <div class="d-flex">
                                                    @if ($blog->image == NULL)
                                                        <img class="img-fluid image-preview" src="" alt="" id="output">
                                                    @else
                                                        <a href="{{ $blog->image }}" target="_blank">
                                                            <img class="img-fluid image-preview" src="{{ $blog->image }}" alt="" id="output">
                                                        </a>
                                                    @endif
                                                </div>
                                            </div>
                                        </div>

                                        <div class="row">
                                            <div class="form-group col-md-12">
                                                <label class="form-label">Blog Categories</label>
                                                @if ($categories)
                                                    <div class="row ms-1">
                                                        @if (is_countable($categories))
                                                            @foreach ($categories as $category)
                                                                <div class="col-md-3 form-check form-switch custom-switch-v1 mb-2">
                                                                    <input name="categories[]" type="checkbox" class="form-check-input input-primary" id="cat-{{ $category['id'] }}" value='{{ $category['id'] }}' {{ in_array($category['id'], $assignedCategories) ? 'checked' : '' }} >
                                                                    <label class="form-check-label" for="cat-{{ $category['id'] }}">{{ $category['title'] }}</label>
                                                                </div>
                                                            @endforeach
                                                        @endif
                                                    </div>
                                                @endif
                                            </div>
                                        </div>

                                        <div class="row">
                                            <div class="form-group col-md-12">
                                                <label class="form-label">Tags</label>

                                                <select id="tag-select" class="form-control" multiple>
                                                    @if (is_countable($blog->tags_arr))
                                                        @foreach ($blog->tags_arr as $tag)
                                                            <option value="{{ $tag }}">{{ $tag }}</option>
                                                        @endforeach
                                                    @endif
                                                </select>

                                                <input type="hidden" id="tags" name="tags" value="{{ old('tags', implode(',', $blog->tags_arr)) }}">
                                            </div>
                                        </div>

                                        <div class="row">
                                            <div class="col-md-12 mb-4">
                                                <hr>
                                                <h5>SEO Details</h5>
                                            </div>
                                            <div class="form-group col-md-4">
                                                <label class="form-label">Meta Title</label>
                                                <input name="meta_title" type="text" class="form-control" placeholder="Meta Title" value="{{ old('meta_title', $blog->meta_title) }}">
                                            </div>
                                            <div class="form-group col-md-4">
                                                <label class="form-label">Meta Keyword</label>
                                                <input name="meta_keyword" type="text" class="form-control" placeholder="Meta Keyword" value="{{ old('meta_keyword', $blog->meta_keyword) }}">
                                            </div>
                                            <div class="form-group col-md-4">
                                                <label class="form-label">OG Title</label>
                                                <input name="og_title" type="text" class="form-control" placeholder="OG Title" value="{{ old('og_title', $blog->og_title) }}">
                                            </div>
                                        </div>

                                        <div class="row">
                                            <div class="col-md-12 form-group">
                                                <label class="form-label">Meta Description</label>
                                                <textarea name="meta_description" class="form-control ckeditor" placeholder="Meta Description">{!! old('meta_description', $blog->meta_description) !!}</textarea>
                                            </div>
                                        </div>

                                        <div class="row">
                                            <div class="col-md-12 form-group">
                                                <label class="form-label">OG Description</label>
                                                <textarea name="og_description" class="form-control ckeditor" placeholder="OG Description">{!! old('og_description', $blog->og_description) !!}</textarea>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-12">
                                        <div class="form-check form-switch custom-switch-v1">
                                            <input name="active" type="checkbox" class="form-check-input input-primary" id="activeCheckbox" value='1' @checked(old('active', $blog->active))>
                                            <label class="form-check-label" for="activeCheckbox">Active</label>
                                        </div>
                                        <input type="submit" value="Save" class="btn btn-primary m-t-20 m-b-20" data-bs-toggle="tooltip" data-bs-original-title="Save changes">
                                    </div>
                                </div>
                            </form>
                        </div>
                    </div>
                </div>
            </div>
    </section>

    <script src="{{ asset('admin/js/select2.min.js') }}"></script>

    <script>
        var loadFile = function(event) {
            var output = document.getElementById('output');
            output.src = URL.createObjectURL(event.target.files[0]);
            output.onload = function() {
              URL.revokeObjectURL(output.src) // free memory
            }
        };

        var tags = null;

        if ('{{ $blog->tags }}' != '') {
            tags = '{{ $blog->tags }}'.split(",");
        }

        $(document).ready(function() {
            // Select2 Tags Input
            $('#tag-select').select2({
                tags: true,
            });

            if (tags != null) {
                tags.forEach(value => {
                    $('#tag-select').select2('trigger', 'select', {
                        data: { id: value, text: value }
                    });
                });
            }

            $('#tag-select').change(function() {
                let x = $("#tag-select").select2('data');
                let arr = [];

                x.forEach(function(v, i, e) {
                    arr.push(e[i].text);
                })

                $('#tags').val(arr);
            });
        });
    </script>

@endsection
