@extends('admin.layouts.admin')

@section('content')
    <section class="pc-container">
        <div class="pc-content">
            <div class="page-header">
                <div class="page-block">
                    <div class="row align-items-center">
                        <div class="col-md-12">
                            <ul class="breadcrumb">
                                <li class="breadcrumb-item">Content</li>
                                <li class="breadcrumb-item" aria-current="page">
                                    <a href="{{ route('admin.cities') }}">Cities</a>
                                </li>
                                <li class="breadcrumb-item" aria-current="page">New</li>
                            </ul>
                        </div>
                        <div class="col-md-12">
                            <div class="page-header-title">
                                <h2 class="mb-0">City</h2>
                            </div>
                        </div>
                    </div>
                </div>
            </div>

            <div class="row pt-0">
                <div class="col-md-12 col-xl-6">
                    <div class="card">
                        <div class="card-body">
                            <div>
                                @if ($errors->any())
                                    <div class="alert alert-danger">
                                        <ul>
                                            @foreach ($errors->all() as $error)
                                                <li>
                                                    {{ $error }}
                                                </li>
                                            @endforeach
                                        </ul>
                                    </div>
                                @endif
                            </div>
                            <form action="{{ route('admin.store-city') }}" method="post" class="form-data">
                                @csrf

                                <div class="row">
                                    <div class="form-group col-md-8">
                                        <label class="form-label">Name <span class="text-danger">*</span></label>
                                        <input required name="name" type="text" maxlength="100" class="form-control" placeholder="Name" value="{{ old('name') }}" autofocus>
                                    </div>

                                    <div class="form-group col-md-4">
                                        <label class="form-label">Code <span class="text-danger">*</span></label>
                                        <input required name="code" type="text" maxlength="10" class="form-control" placeholder="Code" value="{{ old('code') }}">
                                    </div>

                                    <div class="col-md-12">
                                        <div class="form-group">
                                            <label class="form-label">Country <span class="text-danger">*</span></label>

                                            <select id="country-select" class="form-control">
                                                <option selected disabled>--Not Selected--</option>

                                                @foreach ($countries as $x)
                                                    <option value="{{ $x->id }}">{{ $x->name }}</option>
                                                @endforeach

                                            </select>
                                        </div>

                                        <input id="country-id" type="hidden" name="country_id">
                                    </div>

                                    <div class="col-md-12">
                                        <div class="form-group">
                                            <label class="form-label">State <span class="text-danger">*</span></label>

                                            <select id="state-select" class="form-control">
                                                <option selected disabled>--Not Selected--</option>

                                                @foreach ($states as $cat)
                                                    <option value="{{ $cat->id }}">{{ $cat->name }}</option>
                                                @endforeach

                                            </select>
                                        </div>

                                        <input id="state-id" type="hidden" name="state_id">
                                    </div>
                                </div>

                                <div class="row">
                                    <div class="col-md-12">
                                        <div class="form-check form-switch custom-switch-v1">
                                            <input name="active" type="checkbox" class="form-check-input input-primary" id="activeCheckbox" value='1' checked>
                                            <label class="form-check-label" for="activeCheckbox">Active</label>
                                        </div>
                                        <input type="submit" value="Save" class="btn btn-primary m-t-20 m-b-20" data-bs-toggle="tooltip" data-bs-original-title="Save changes">
                                    </div>
                                </div>
                            </form>
                        </div>
                    </div>
                </div>
            </div>
    </section>

    <script>
        $(document).ready(function() {
            $('#country-select, #state-select').select2();

            function fetchStates(countryId) {
                var url = "{{ route('admin.get-states', ['country' => 'arg1']) }}";
                url = url.replace('arg1', countryId);

                $.ajax({
                    type: 'POST',
                    url: url,
                    headers: {'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')},
                    success: function(data){
                        $('#state-select').html(data);
                    }
                });
            }

            $('#country-select').change(function() {
                let x = $(this).val();

                $('#country-id').val(x);

                fetchStates(x);
            });

            $('#state-select').change(function() {
                let x = $(this).val();

                $('#state-id').val(x);
            });
        })
    </script>
@endsection
