@extends('admin.layouts.admin')

@section('content')
    <div class="pc-container">
        <div class="pc-content">
            <div class="page-header">
                <div class="page-block">
                    <div class="row align-items-center">
                        <div class="col-md-12">
                            <ul class="breadcrumb">
                                <li class="breadcrumb-item" aria-current="page">Coming Soon</li>
                            </ul>
                        </div>
                        <div class="col-md-12">
                            <div class="page-header-title">
                                <h2 class="mb-0">Coming Soon</h2>
                            </div>
                        </div>
                    </div>
                </div>
            </div>

            <div class="row pt-0">
                <div class="col-sm-12">
                    <div class="card">
                        <div class="card-body">
                            <div>
                                @if(Session::has('message'))
                                    <p class="alert {{ Session::get('alert-class', 'alert-info') }} flash-msg">{{ Session::get('message') }}</p>
                                @endif
                            </div>

                            <div class="d-flex justify-content-end">
                                <a href="{{ route('admin.add-coming') }}" role="button" class="btn btn-primary rounded-0" data-bs-toggle="tooltip" data-bs-original-title="Add">
                                    + Add
                                </a>
                            </div>

                            <ul class="nav nav-tabs mb-4">
                                <li class="nav-item">
                                  <a class="nav-link active" data-bs-toggle="tab" href="#home">List</a>
                                </li>
                                <li class="nav-item">
                                  <a class="nav-link" data-bs-toggle="tab" href="#menu1">Content</a>
                                </li>
                            </ul>

                            <div class="tab-content">
                                <div class="tab-pane container active" id="home">
                                    <div class="dt-responsive table-responsive">
                                        <table id="simpletable" class="table table-striped table-bordered nowrap">
                                            <thead>
                                                <tr>
                                                    <th>Image</th>
                                                    <th>Title</th>
                                                    <th>Status</th>
                                                    <th>Rank</th>
                                                    <th>Created On</th>
                                                    <th>Action</th>
                                                </tr>
                                            </thead>
                                            <tbody>
                                                @foreach ($data as $item)
                                                    <tr>
                                                        <td>
                                                            <img src="{{ asset(Storage::url($item->image)) }}" alt="" class="img-fluid thumb-1">
                                                        </td>
                                                        <td>{{ $item->title }}</td>
                                                        <td>
                                                            @if ($item->active == '1')
                                                                <span role="button" class="badge bg-success" onclick="toggle(this, {{$item->id}})">Active</span>
                                                            @else
                                                                <span role="button" class="badge bg-secondary" onclick="toggle(this, {{$item->id}})">Active</span>
                                                            @endif
                                                        </td>
                                                        <td>{{ $item->rank }}</td>
                                                        <td>{{ $item->created_at }}</td>
                                                        <td>
                                                            <div id="confirmModal{{$item->id}}" class="modal fade" tabindex="-1" role="dialog" aria-labelledby="confirmModalTitle{{$item->id}}" aria-hidden="true">
                                                                <div class="modal-dialog modal-dialog-centered" role="document">
                                                                    <div class="modal-content">
                                                                        <div class="modal-header">
                                                                            <h5 class="modal-title text-danger" id="confirmModalTitle{{$item->id}}">Remove Item</h5>
                                                                            <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                                                                        </div>
                                                                        <div class="modal-body">
                                                                            <p>Are you sure to remove this item?</p>
                                                                        </div>
                                                                        <div class="modal-footer">
                                                                            <button type="button" class="btn btn-success" data-bs-dismiss="modal">No</button>
                                                                            <a role="button" onclick="deleteRecord(this, {{ $item->id }})" class="btn btn-danger text-white" data-bs-dismiss="modal">Yes</a>
                                                                        </div>
                                                                    </div>
                                                                </div>
                                                            </div>

                                                            <a href="{{ route('admin.edit-coming', ['coming' => $item->id]) }}" class="avtar avtar-xs btn-link-success btn-pc-default" data-bs-toggle="tooltip" data-bs-original-title="Edit">
                                                                <i class="ti ti-edit-circle f-18"></i>
                                                            </a>

                                                            <span data-bs-toggle="tooltip" data-bs-original-title="Remove">
                                                                <a href="javascript:void(0)" role="button" data-bs-toggle="modal" data-bs-target="#confirmModal{{$item->id}}" class="avtar avtar-xs btn-link-danger btn-pc-default">
                                                                    <i class="ti ti-trash f-18"></i>
                                                                </a>
                                                            </span>
                                                        </td>
                                                    </tr>
                                                @endforeach
                                            </tbody>
                                        </table>
                                    </div>
                                </div>
                                <div class="tab-pane container fade" id="menu1">
                                    <form action="{{ route('admin.update-coming-crud') }}" method="post" class="form-data">
                                        @csrf
                                        <div class="form-group col-md-12">
                                            <label class="form-label">Top Content</label>
                                            <textarea name="top_content" class="form-control ckeditor" placeholder="Top content">{!! old('top_content', $top_content) !!}</textarea>
                                        </div>
                                        <div class="form-group col-md-12">
                                            <label class="form-label">Bottom Content</label>
                                            <textarea name="bottom_content" class="form-control ckeditor" placeholder="Bottom content">{!! old('bottom_content', $bottom_content) !!}</textarea>
                                        </div>
                                        <input type="submit" value="Save" class="btn btn-primary m-t-20 m-b-20" data-bs-toggle="tooltip" data-bs-original-title="Save changes">
                                    </form>
                                </div>
                            </div>

                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <script src="{{ asset('admin/js/plugins/jquery.dataTables.min.js') }}"></script>
    <script src="{{ asset('admin/js/plugins/dataTables.bootstrap5.min.js') }}"></script>

    <script>
        $('#simpletable').DataTable({
            order: [[3, 'desc']]
        });

        function deleteRecord(ele, id) {
            var url = "{{ route('admin.delete-coming', ['coming' => 'cid']) }}";
            url = url.replace('cid', id);

            $.ajax({
                type: 'POST',
                url: url,
                headers: {'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')},
                success: function(data){
                    if ($.trim(data) == 'done') {
                        $(ele).closest("tr").remove();
                    }
                }
            });
        }
    </script>
@endsection
