@extends('admin.layouts.admin')

@section('content')
    <section class="pc-container">
        <div class="pc-content">
            <div class="page-header">
                <div class="page-block">
                    <div class="row align-items-center">
                        <div class="col-md-12">
                            <ul class="breadcrumb">
                                <li class="breadcrumb-item">Content</li>
                                <li class="breadcrumb-item" aria-current="page">
                                    <a href="{{ route('admin.customers') }}">Customers</a>
                                </li>
                                <li class="breadcrumb-item" aria-current="page">Edit</li>
                            </ul>
                        </div>
                        <div class="col-md-12">
                            <div class="page-header-title">
                                <h2 class="mb-0">Customer</h2>
                            </div>
                        </div>
                    </div>
                </div>
            </div>

            <div class="row pt-0">
                <div class="col-md-12 col-xl-">
                    <div class="card">
                        <div class="card-body">
                            <div>
                                @if ($errors->any())
                                    <div class="alert alert-danger">
                                        <ul>
                                            @foreach ($errors->all() as $error)
                                                <li>
                                                    {{ $error }}
                                                </li>
                                            @endforeach
                                        </ul>
                                    </div>
                                @endif
                            </div>
                            <form action="{{ route('admin.update-customer') }}" method="post" class="form-data" enctype="multipart/form-data">
                                @csrf

                                <input type="hidden" name="id" value="{{ $customer->id }}">
                                <div class="row">
                                    <div class="form-group col-md-4">
                                        <label class="form-label">First Name <span class="text-danger">*</span></label>
                                        <input required name="first_name" type="text" maxlength="50" class="form-control" placeholder="First Name" value="{{ old('first_name', $customer->first_name) }}" autofocus>
                                    </div>
                                    <div class="form-group col-md-4">
                                        <label class="form-label">Last Name <span class="text-danger">*</span></label>
                                        <input required name="last_name" type="text" maxlength="50" class="form-control" placeholder="Last Name" value="{{ old('last_name', $customer->last_name) }}">
                                    </div>
                                    <div class="form-group col-md-4">
                                        <label class="form-label">Email <span class="text-danger">*</span></label>
                                        <input required name="email" type="text" maxlength="50" class="form-control" placeholder="Email" value="{{ old('email', $customer->email) }}">
                                    </div>
                                    <div class="form-group col-md-8">
                                        <label class="form-label">Address <span class="text-danger">*</span></label>
                                        <input required name="address" type="text" maxlength="20" class="form-control" placeholder="Address" value="{{ old('address', $customer->address) }}">
                                    </div>
                                    <div class="form-group col-md-4">
                                        <label class="form-label">Zipcode <span class="text-danger">*</span></label>
                                        <input required name="zipcode" type="text" maxlength="20" class="form-control" placeholder="Zipcode" value="{{ old('zipcode', $customer->zipcode) }}">
                                    </div>
                                    <div class="col-md-4">
                                        <div class="form-group">
                                            <label class="form-label">Country <span class="text-danger">*</span></label>

                                            <select required id="country-select" class="form-control">
                                                <option selected disabled>--Not Selected--</option>

                                                @foreach ($countries as $x)
                                                    <option value="{{ $x->id }}">{{ $x->name }}</option>
                                                @endforeach
                                            </select>
                                        </div>

                                        <input id="country-id" type="hidden" name="country_id">
                                    </div>

                                    <div class="col-md-4">
                                        <div class="form-group">
                                            <label class="form-label">State <span class="text-danger">*</span></label>

                                            <select required id="state-select" class="form-control">
                                                <{{-- Will be filled by JS --}}
                                            </select>
                                        </div>

                                        <input id="state-id" type="hidden" name="state_id">
                                    </div>

                                    <div class="col-md-4">
                                        <div class="form-group">
                                            <label class="form-label">City <span class="text-danger">*</span></label>

                                            <select required id="city-select" class="form-control">
                                                {{-- Will be filled by JS --}}
                                            </select>
                                        </div>

                                        <input id="city-id" type="hidden" name="city_id">
                                    </div>

                                    <div class="form-group col-md-4">
                                        <label class="form-label">Phone <span class="text-danger">*</span></label>
                                        <input required name="phone" type="text" maxlength="20" class="form-control" placeholder="Phone" value="{{ old('phone', $customer->phone) }}">
                                    </div>

                                    <div class="form-group col-md-4">
                                        <label class="form-label">Image</label>
                                        <input name="image" class="form-control" type="file" accept="image/jpg, image/jpeg, image/png, image/webp" onchange="loadFile(event)">
                                    </div>
                                    <div class="col-md-4">
                                        <div class="d-flex">
                                            @if ($customer->image == NULL)
                                                <img class="img-fluid image-preview" src="" alt="" id="output">
                                            @else
                                                <a href="{{ $customer->image }}" target="_blank">
                                                    <img class="img-fluid image-preview" src="{{ $customer->image }}" alt="" id="output">
                                                </a>
                                            @endif
                                        </div>
                                    </div>

                                </div>

                                <div class="row">
                                    <div class="col-md-12">
                                        <div class="form-check form-switch custom-switch-v1">
                                            <input name="active" type="checkbox" class="form-check-input input-primary" id="activeCheckbox" value='1' @checked($customer->active)>
                                            <label class="form-check-label" for="activeCheckbox">Active</label>
                                        </div>
                                        <input type="submit" value="Save" class="btn btn-primary m-t-20 m-b-20" data-bs-toggle="tooltip" data-bs-original-title="Save changes">
                                    </div>
                                </div>
                            </form>
                        </div>
                    </div>
                </div>
            </div>
    </section>

    <script>
         var loadFile = function(event) {
            var output = document.getElementById('output');
            output.src = URL.createObjectURL(event.target.files[0]);
            output.onload = function() {
              URL.revokeObjectURL(output.src) // free memory
            }
        };

        $(document).ready(function() {
            function fetchStates(countryId, flag = true) {
                var url = "{{ route('admin.get-states', ['country' => 'arg1']) }}";
                url = url.replace('arg1', countryId);

                $.ajax({
                    type: 'POST',
                    url: url,
                    headers: {
                        'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
                    },
                    success: function(data) {
                        $('#state-select').html(data);
                        $('#state-select').val('{{ $customer->state_id }}').trigger('change');

                        if (flag == true) {
                            fetchCities('{{ $customer->country_id }}', '{{ $customer->state_id }}');
                        } else {
                            $('#city-select').empty();
                        }

                    }
                });
            }

            function fetchCities(countryId, stateId) {
                var url = "{{ route('admin.get-cities', ['country' => 'arg1', 'state' => 'arg2']) }}";
                url = url.replace('arg1', countryId);
                url = url.replace('arg2', stateId);

                $.ajax({
                    type: 'POST',
                    url: url,
                    headers: {
                        'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
                    },
                    success: function(data) {
                        $('#city-select').html(data);

                        setTimeout(() => {
                            $('#city-select').val('{{ $customer->city_id }}').trigger('change');
                        }, 500);
                    }
                });
            }

            $('#country-select').change(function(event, flag = false) {
                let x = $(this).val();

                $('#country-id').val(x);

                fetchStates(x, flag);
            });

            $('#state-select').change(function() {
                let x = $(this).val();

                $('#state-id').val(x);

                fetchCities($('#country-select').val(), x);
            });

            $('#city-select').change(function() {
                let x = $(this).val();

                $('#city-id').val(x);
            });

            $('#country-select').val('{{ $customer->country_id }}').trigger('change', true);

            $('#country-select, #state-select, #city-select').select2();
        })
    </script>
@endsection
