@extends('admin.layouts.admin')

@section('content')
    <div class="pc-container">
        <div class="pc-content">
            <div class="page-header">
                <div class="page-block">
                    <div class="row align-items-center">
                        <div class="col-md-12">
                            <ul class="breadcrumb">
                                <li class="breadcrumb-item" aria-current="page">Content</li>
                                <li class="breadcrumb-item" aria-current="page">Customers</li>
                            </ul>
                        </div>
                        <div class="col-md-12">
                            <div class="page-header-title">
                                <h2 class="mb-0">Customers</h2>
                            </div>
                        </div>
                    </div>
                </div>
            </div>

            <div class="row pt-0">
                <div class="col-sm-12">
                    <div class="card">
                        <div class="card-body">
                            <div>
                                @if(Session::has('message'))
                                    <p class="alert {{ Session::get('alert-class', 'alert-info') }} flash-msg">{{ Session::get('message') }}</p>
                                @endif
                            </div>

                            <a href="{{ route('admin.add-customer') }}" role="button" class="btn btn-primary m-b-20" data-bs-toggle="tooltip" data-bs-original-title="Add customer">
                                + Add
                            </a>

                            <div class="dt-responsive table-responsive">
                                <table id="simpletable" class="table table-striped table-bordered nowrap">
                                    <thead>
                                        <tr>
                                            <th>Photo</th>
                                            <th>First Name</th>
                                            <th>Last Name</th>
                                            <th>Email</th>
                                            <th>Phone</th>
                                            <th>Address</th>
                                            <th>Zipcode</th>
                                            <th>City</th>
                                            <th>State</th>
                                            <th>Country</th>
                                            <th>Status</th>
                                            <th>Created On</th>
                                            <th>Action</th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        @foreach ($users as $item)
                                            <tr>
                                                <td>
                                                    <img src="{{ asset(Storage::url($item->image)) }}" alt="" class="img-fluid thumb-sm rounded rounded-circle">
                                                </td>
                                                <td>{{ $item->first_name }}</td>
                                                <td>{{ $item->last_name }}</td>
                                                <td>{{ $item->email }}</td>
                                                <td>{{ $item->phone }}</td>
                                                <td>{{ $item->address }}</td>
                                                <td>{{ $item->zipcode }}</td>
                                                <td>{{ $item->city->name ?? '' }}</td>
                                                <td>{{ $item->state->name ?? '' }} </td>
                                                <td>{{ $item->country->name ?? '' }} </td>
                                                <td>
                                                    @if ($item->active == '1')
                                                        <span role="button" class="badge bg-success" onclick="toggle(this, {{$item->id}})">Active</span>
                                                    @else
                                                        <span role="button" class="badge bg-secondary" onclick="toggle(this, {{$item->id}})">Active</span>
                                                    @endif
                                                </td>
                                                <td>{{ $item->created_at }}</td>
                                                <td>
                                                    <div id="confirmModal{{$item->id}}" class="modal fade" tabindex="-1" role="dialog" aria-labelledby="confirmModalTitle{{$item->id}}" aria-hidden="true">
                                                        <div class="modal-dialog modal-dialog-centered" role="document">
                                                            <div class="modal-content">
                                                                <div class="modal-header">
                                                                    <h5 class="modal-title text-danger" id="confirmModalTitle{{$item->id}}">Remove Item</h5>
                                                                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                                                                </div>
                                                                <div class="modal-body">
                                                                    <p>Are you sure to remove this record?</p>
                                                                </div>
                                                                <div class="modal-footer">
                                                                    <button type="button" class="btn btn-success" data-bs-dismiss="modal">No</button>
                                                                    <a role="button" onclick="deleteRecord(this, {{ $item->id }})" class="btn btn-danger text-white" data-bs-dismiss="modal">Yes</a>
                                                                </div>
                                                            </div>
                                                        </div>
                                                    </div>

                                                    <a href="{{ route('admin.edit-customer', ['customer' => $item->id]) }}" class="avtar avtar-xs btn-link-success btn-pc-default" data-bs-toggle="tooltip" data-bs-original-title="Edit">
                                                        <i class="ti ti-edit-circle f-18"></i>
                                                    </a>

                                                    <span data-bs-toggle="tooltip" data-bs-original-title="Remove">
                                                        <a href="javascript:void(0)" role="button" data-bs-toggle="modal" data-bs-target="#confirmModal{{$item->id}}" class="avtar avtar-xs btn-link-danger btn-pc-default">
                                                            <i class="ti ti-trash f-18"></i>
                                                        </a>
                                                    </span>
                                                </td>
                                            </tr>
                                        @endforeach
                                    </tbody>
                                </table>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <script src="{{ asset('admin/js/plugins/jquery.dataTables.min.js') }}"></script>
    <script src="{{ asset('admin/js/plugins/dataTables.bootstrap5.min.js') }}"></script>

    <script>
        $('#simpletable').DataTable({
            order: [[10, 'desc']]
        });

        function deleteRecord(ele, id) {
            var url = "{{ route('admin.delete-customer', ['customer' => 'cid']) }}";
            url = url.replace('cid', id);

            $.ajax({
                type: 'POST',
                url: url,
                headers: {'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')},
                success: function(data){
                    if ($.trim(data) == 'done') {
                        $(ele).closest("tr").remove();
                    }
                }
            });
        }
    </script>
@endsection
