@extends('admin.layouts.admin')

@section('content')
    <section class="pc-container home-section-container">
        <div class="pc-content">
            <div class="page-header">
                <div class="page-block">
                    <div class="row align-items-center">
                        <div class="col-md-12">
                            <ul class="breadcrumb">
                                <li class="breadcrumb-item">
                                    <a href="{{ route('admin.homepage-sections') }}">
                                        Homepage Sections
                                    </a>
                                </li>
                                <li class="breadcrumb-item">{{ ucwords(str_replace('_', ' ', $section->name)) }}</li>
                            </ul>
                        </div>
                        <div class="col-md-12">
                            <div class="page-header-title">
                                <h3 class="mb-0">{{ ucwords(str_replace('_', ' ', $section->name)) }}</h3>
                            </div>
                        </div>
                    </div>
                </div>
            </div>

            <div class="row pt-0">
                <div class="col-md-12">
                    <div class="">
                        <div class="pt-3">
                            <div>
                                @if(Session::has('message'))
                                    <p class="alert {{ Session::get('alert-class', 'alert-info') }} flash-msg">{{ Session::get('message') }}</p>
                                @endif
                            </div>

                            <div>
                                @if ($errors->any())
                                    <div class="alert alert-danger">
                                        <ul>
                                            @foreach ($errors->all() as $error)
                                                <li>
                                                    {{ $error }}
                                                </li>
                                            @endforeach
                                        </ul>
                                    </div>
                                @endif
                            </div>

                            <div class="row">
                                <div class="col-md-12">
                                    <form action="{{ route('admin.update-homepage-section', ['section' => $section->id]) }}" method="post" enctype="multipart/form-data" class="form-data">
                                        @csrf
                                        <div class="row">
                                            <div class="col-md-12">
                                                <div class="card border shadow-sm">
                                                    <div class="card-body">
                                                        <div class="row">
                                                            <div class="col-md-6">
                                                                <div class="form-group">
                                                                    <div class="d-flex justify-content-between mb-1">
                                                                        <label class="form-label">Heading <span class="text-danger">*</span></label>
                                                                        <select class="select2" name="font1">
                                                                            @include('admin.includes.font-select')
                                                                        </select>
                                                                    </div>
                                                                    <input required type="text" class="form-control" name="heading" id="" value="{{ old('heading', $section->heading) }}">
                                                                </div>
                                                            </div>
                                                            <div class="col-md-6">
                                                                <div class="form-group">
                                                                    <div class="d-flex justify-content-between mb-1">
                                                                        <label class="form-label">Tagline <span class="text-danger">*</span></label>
                                                                        <select class="select2" name="font2">
                                                                            @include('admin.includes.font-select')
                                                                        </select>
                                                                    </div>
                                                                    <input required type="text" class="form-control" name="tagline" id="" value="{{ old('tagline', $section->tagline) }}">
                                                                </div>
                                                            </div>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>

                                        <div class="card shadow-sm">
                                            <div class="card-body">
                                                <div class="row">
                                                    <div class="col-md-6">
                                                        <div class="form-group">
                                                            <div class="d-flex justify-content-between mb-1">
                                                                <label class="form-label">Sub Heading <span class="text-danger">*</span></label>
                                                                <select class="select2" name="font3">
                                                                    @include('admin.includes.font-select')
                                                                </select>
                                                            </div>
                                                            <input required type="text" class="form-control" name="sub_heading_1" id="" value="{{ old('sub_heading_1', $section->sub_heading_1) }}">
                                                        </div>
                                                        <div class="form-group">
                                                            <div class="d-flex justify-content-between mb-1">
                                                                <label class="form-label">Content <span class="text-danger">*</span></label>
                                                                <select class="select2" name="font4">
                                                                    @include('admin.includes.font-select')
                                                                </select>
                                                            </div>
                                                            <textarea required name="sub_content_1" class="form-control ckeditor" placeholder="Content">{!! old('sub_content_1', $section->sub_content_1) !!}</textarea>
                                                        </div>
                                                    </div>
                                                    <div class="col-md-6">
                                                        <div class="form-group">
                                                            <label class="form-label">Photo <span class="text-danger">*</span></label>
                                                            <input {{ $section->image_1 ? '' : 'required' }} name="image_1" class="form-control" type="file" accept="image/jpg, image/jpeg, image/png, image/webp" onchange="loadFile_1(event)">
                                                        </div>
                                                        <div class="d-flex mb-3">
                                                            @isset($section->image_1)
                                                                @if (Storage::exists($section->image_1))
                                                                    <img class="img-fluid image-preview-sm" src="{{ asset(Storage::url($section->image_1)) }}" alt="" id="output-1">
                                                                @else
                                                                    <img class="img-fluid image-preview-sm" src="" alt="" id="output-1">
                                                                @endif
                                                            @else
                                                                <img class="img-fluid image-preview-sm" src="" alt="" id="output-1">
                                                            @endisset
                                                        </div>
                                                        <div class="form-group">
                                                            <label class="form-label">URL <span class="text-danger">*</span></label>
                                                            <input type="text" name="url_1" class="form-control" placeholder="URL" value="{{ old('url_1', $section->url_1) }}">
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>

                                        <div class="card shadow-sm">
                                            <div class="card-body">
                                                <div class="row">
                                                    <div class="col-md-6">
                                                        <div class="form-group">
                                                            <div class="d-flex justify-content-between mb-1">
                                                                <label class="form-label">Sub Heading <span class="text-danger">*</span></label>
                                                                <select class="select2" name="font5">
                                                                    @include('admin.includes.font-select')
                                                                </select>
                                                            </div>
                                                            <input required type="text" class="form-control" name="sub_heading_2" value="{{ old('sub_heading_2', $section->sub_heading_2) }}">
                                                        </div>
                                                        <div class="form-group">
                                                            <div class="d-flex justify-content-between mb-1">
                                                                <label class="form-label">Content <span class="text-danger">*</span></label>
                                                                <select class="select2" name="font6">
                                                                    @include('admin.includes.font-select')
                                                                </select>
                                                            </div>
                                                            <textarea required name="sub_content_2" class="form-control ckeditor" placeholder="Content">{!! old('sub_content_2', $section->sub_content_2) !!}</textarea>
                                                        </div>
                                                    </div>
                                                    <div class="col-md-6">
                                                        <div class="form-group">
                                                            <label class="form-label">Photo <span class="text-danger">*</span></label>
                                                            <input {{ $section->image_2 ? '' : 'required' }} name="image_2" class="form-control" type="file" accept="image/jpg, image/jpeg, image/png, image/webp" onchange="loadFile_2(event)">
                                                        </div>
                                                        <div class="d-flex mb-3">
                                                            @isset($section->image_2)
                                                                @if (Storage::exists($section->image_2))
                                                                    <img class="img-fluid image-preview-sm" src="{{ asset(Storage::url($section->image_2)) }}" alt="" id="output-2">
                                                                @else
                                                                    <img class="img-fluid image-preview-sm" src="" alt="" id="output-2">
                                                                @endif
                                                            @else
                                                                <img class="img-fluid image-preview-sm" src="" alt="" id="output-2">
                                                            @endisset
                                                        </div>
                                                        <div class="form-group">
                                                            <label class="form-label">URL <span class="text-danger">*</span></label>
                                                            <input type="text" name="url_2" class="form-control" placeholder="URL" value="{{ old('url_2', $section->url_2) }}">
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>

                                        <div class="card shadow-sm">
                                            <div class="card-body">
                                                <div class="row">
                                                    <div class="col-md-6">
                                                        <div class="form-group">
                                                            <div class="d-flex justify-content-between mb-1">
                                                                <label class="form-label">Sub Heading <span class="text-danger">*</span></label>
                                                                <select class="select2" name="font7">
                                                                    @include('admin.includes.font-select')
                                                                </select>
                                                            </div>
                                                            <input required type="text" class="form-control" name="sub_heading_3" value="{{ old('sub_heading_3', $section->sub_heading_3) }}">
                                                        </div>
                                                        <div class="form-group">
                                                            <div class="d-flex justify-content-between mb-1">
                                                                <label class="form-label">Content <span class="text-danger">*</span></label>
                                                                <select class="select2" name="font8">
                                                                    @include('admin.includes.font-select')
                                                                </select>
                                                            </div>
                                                            <textarea required name="sub_content_3" class="form-control ckeditor" placeholder="Content">{!! old('sub_content_3', $section->sub_content_3) !!}</textarea>
                                                        </div>
                                                    </div>
                                                    <div class="col-md-6">
                                                        <div class="form-group">
                                                            <label class="form-label">Photo <span class="text-danger">*</span></label>
                                                            <input {{ $section->image_3 ? '' : 'required' }} name="image_3" class="form-control" type="file" accept="image/jpg, image/jpeg, image/png, image/webp" onchange="loadFile_3(event)">
                                                        </div>
                                                        <div class="d-flex mb-3">
                                                            @isset($section->image_3)
                                                                @if (Storage::exists($section->image_3))
                                                                    <img class="img-fluid image-preview-sm" src="{{ asset(Storage::url($section->image_3)) }}" alt="" id="output-3">
                                                                @else
                                                                    <img class="img-fluid image-preview-sm" src="" alt="" id="output-3">
                                                                @endif
                                                            @else
                                                                <img class="img-fluid image-preview-sm" src="" alt="" id="output-3">
                                                            @endisset
                                                        </div>
                                                        <div class="form-group">
                                                            <label class="form-label">URL <span class="text-danger">*</span></label>
                                                            <input type="text" name="url_3" class="form-control" placeholder="URL" value="{{ old('url_3', $section->url_3) }}">
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>

                                        <div class="card shadow-sm">
                                            <div class="card-body">
                                                <div class="row">
                                                    <div class="col-md-6">
                                                        <div class="form-group">
                                                            <div class="d-flex justify-content-between mb-1">
                                                                <label class="form-label">Sub Heading <span class="text-danger">*</span></label>
                                                                <select class="select2" name="font9">
                                                                    @include('admin.includes.font-select')
                                                                </select>
                                                            </div>
                                                            <input required type="text" class="form-control" name="sub_heading_4" value="{{ old('sub_heading_4', $section->sub_heading_4) }}">
                                                        </div>
                                                        <div class="form-group">
                                                            <div class="d-flex justify-content-between mb-1">
                                                                <label class="form-label">Content <span class="text-danger">*</span></label>
                                                                <select class="select2" name="font10">
                                                                    @include('admin.includes.font-select')
                                                                </select>
                                                            </div>
                                                            <textarea required name="sub_content_4" class="form-control ckeditor" placeholder="Content">{!! old('sub_content_4', $section->sub_content_4) !!}</textarea>
                                                        </div>
                                                    </div>
                                                    <div class="col-md-6">
                                                        <div class="form-group">
                                                            <label class="form-label">Photo <span class="text-danger">*</span></label>
                                                            <input {{ $section->image_4 ? '' : 'required' }} name="image_4" class="form-control" type="file" accept="image/jpg, image/jpeg, image/png, image/webp" onchange="loadFile_4(event)">
                                                        </div>
                                                        <div class="d-flex mb-3">
                                                            @isset($section->image_4)
                                                                @if (Storage::exists($section->image_4))
                                                                    <img class="img-fluid image-preview-sm" src="{{ asset(Storage::url($section->image_4)) }}" alt="" id="output-4">
                                                                @else
                                                                    <img class="img-fluid image-preview-sm" src="" alt="" id="output-4">
                                                                @endif
                                                            @else
                                                                <img class="img-fluid image-preview-sm" src="" alt="" id="output-4">
                                                            @endisset
                                                        </div>
                                                        <div class="form-group">
                                                            <label class="form-label">URL <span class="text-danger">*</span></label>
                                                            <input type="text" name="url_4" class="form-control" placeholder="URL" value="{{ old('url_4', $section->url_4) }}">
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>

                                        <div class="row">
                                            <div class="col-md-12">
                                                <input type="submit" value="Save" class="btn btn-primary rounded-0 mb-4" data-bs-toggle="tooltip" data-bs-original-title="Save changes">
                                            </div>
                                        </div>
                                    </form>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
    </section>

    @include('admin.homepage_sections.common-js')

@endsection
