@extends('admin.layouts.admin')

@section('content')
    <section class="pc-container home-section-container">
        <div class="pc-content">
            <div class="page-header">
                <div class="page-block">
                    <div class="row align-items-center">
                        <div class="col-md-12">
                            <ul class="breadcrumb">
                                <li class="breadcrumb-item">
                                    <a href="{{ route('admin.homepage-sections') }}">
                                        Homepage Sections
                                    </a>
                                </li>
                                <li class="breadcrumb-item">{{ ucwords(str_replace('_', ' ', $section->name)) }}</li>
                            </ul>
                        </div>
                        <div class="col-md-12">
                            <div class="page-header-title">
                                <h3 class="mb-0">{{ ucwords(str_replace('_', ' ', $section->name)) }}</h3>
                            </div>
                        </div>
                    </div>
                </div>
            </div>

            <div class="row pt-0">
                <div class="col-md-12">
                    <div class="">
                        <div class="pt-3">
                            <div>
                                @if(Session::has('message'))
                                    <p class="alert {{ Session::get('alert-class', 'alert-info') }} flash-msg">{{ Session::get('message') }}</p>
                                @endif
                            </div>

                            <div>
                                @if ($errors->any())
                                    <div class="alert alert-danger">
                                        <ul>
                                            @foreach ($errors->all() as $error)
                                                <li>
                                                    {{ $error }}
                                                </li>
                                            @endforeach
                                        </ul>
                                    </div>
                                @endif
                            </div>

                            <div class="row">
                                <div class="col-md-12">
                                    <form action="{{ route('admin.update-homepage-section', ['section' => $section->id]) }}" method="post" enctype="multipart/form-data" class="form-data">
                                        @csrf
                                        <div class="row">
                                            <div class="col-md-6">
                                                <div class="card border shadow-sm">
                                                    <div class="card-body">
                                                        <div class="form-group">
                                                            <label class="form-label">Logo <span class="text-danger">*</span></label>
                                                            <input {{ $section->logo ? '' : 'required' }} name="logo" class="form-control" type="file" accept="image/jpg, image/jpeg, image/png, image/webp" onchange="loadFile_1(event)">
                                                        </div>
                                                        <div class="d-flex">
                                                            @isset($section->logo)
                                                                @if (Storage::exists($section->logo))
                                                                    <img class="img-fluid image-preview-sm" src="{{ asset(Storage::url($section->logo)) }}" alt="" id="output-1">
                                                                @else
                                                                    <img class="img-fluid image-preview-sm" src="" alt="" id="output-1">
                                                                @endif
                                                            @else
                                                                <img class="img-fluid image-preview-sm" src="" alt="" id="output-1">
                                                            @endisset
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                            <div class="col-md-6">
                                                <div class="card border shadow-sm">
                                                    <div class="card-body">
                                                        <div class="form-group">
                                                            <div class="d-flex justify-content-between mb-1">
                                                                <label class="form-label">Button Text <span class="text-danger">*</span></label>
                                                                <select class="select2" name="font1">
                                                                    @include('admin.includes.font-select')
                                                                </select>
                                                            </div>
                                                            <input required type="text" class="form-control" name="button_text_1" id="" value="{{ old('button_text_1', $section->button_text_1) }}">
                                                        </div>
                                                        <div class="form-group">
                                                            <label class="form-label">Button URL <span class="text-danger">*</span></label>
                                                            <input required type="text" class="form-control" name="button_url_1" id="" value="{{ old('button_url_1', $section->button_url_1) }}">
                                                        </div>
                                                    </div>
                                                </div>
                                                <div class="card border shadow-sm">
                                                    <div class="card-body">
                                                        <div class="form-group">
                                                            <div class="d-flex justify-content-between mb-1">
                                                                <label class="form-label">Sub Heading Font <span class="text-danger">*</span></label>
                                                                <select class="select2" name="font2">
                                                                    @include('admin.includes.font-select')
                                                                </select>
                                                            </div>
                                                        </div>
                                                        <div class="form-group">
                                                            <div class="d-flex justify-content-between mb-1">
                                                                <label class="form-label">Links Font <span class="text-danger">*</span></label>
                                                                <select class="select2" name="font3">
                                                                    @include('admin.includes.font-select')
                                                                </select>
                                                            </div>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>

                                        <div class="row">
                                            <div class="col-md-12">
                                                <input type="submit" value="Save" class="btn btn-primary rounded-0 mb-4" data-bs-toggle="tooltip" data-bs-original-title="Save changes">
                                            </div>
                                        </div>
                                    </form>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
    </section>

    @include('admin.homepage_sections.common-js')

@endsection
