@extends('admin.layouts.admin')

@section('content')

    <section class="pc-container home-section-container">
        <div class="pc-content">
            <div class="page-header">
                <div class="page-block">
                    <div class="row align-items-center">
                        <div class="col-md-12">
                            <ul class="breadcrumb">
                                <li class="breadcrumb-item">
                                    <a href="{{ route('admin.homepage-sections') }}">
                                        Homepage Sections
                                    </a>
                                </li>
                                <li class="breadcrumb-item">{{ ucwords(str_replace('_', ' ', $section->name)) }}</li>
                            </ul>
                        </div>
                        <div class="col-md-12">
                            <div class="page-header-title">
                                <h3 class="mb-0">{{ ucwords(str_replace('_', ' ', $section->name)) }}</h3>
                            </div>
                        </div>
                    </div>
                </div>
            </div>

            <div class="row pt-0">
                <div class="col-md-12">
                    <div class="">
                        <div class="pt-3">
                            <div>
                                @if(Session::has('message'))
                                    <p class="alert {{ Session::get('alert-class', 'alert-info') }} flash-msg">{{ Session::get('message') }}</p>
                                @endif
                            </div>

                            <div>
                                @if ($errors->any())
                                    <div class="alert alert-danger">
                                        <ul>
                                            @foreach ($errors->all() as $error)
                                                <li>
                                                    {{ $error }}
                                                </li>
                                            @endforeach
                                        </ul>
                                    </div>
                                @endif
                            </div>

                            <form action="{{ route('admin.update-homepage-section', ['section' => $section->id]) }}" method="post" enctype="multipart/form-data" class="form-data">
                                @csrf

                                <div class="card border shadow-sm">
                                    <div class="card-body">
                                        <div class="row">
                                            <div class="col-md-6">
                                                <div class="form-group">
                                                    <div class="d-flex justify-content-between mb-1">
                                                        <label class="form-label">Heading <span class="text-danger">*</span></label>
                                                        <select class="select2" name="font1">
                                                            @include('admin.includes.font-select')
                                                        </select>
                                                    </div>
                                                    <input required type="text" class="form-control" name="heading" id="" value="{{ old('heading', $section->heading) }}">
                                                </div>
                                                <div class="form-group">
                                                    <div class="d-flex justify-content-between mb-1">
                                                        <label class="form-label">Sub Heading <span class="text-danger">*</span></label>
                                                        <select class="select2" name="font2">
                                                            @include('admin.includes.font-select')
                                                        </select>
                                                    </div>
                                                    <input type="text" class="form-control" name="sub_heading_1" value="{{ old('sub_heading_1', $section->sub_heading_1) }}">
                                                </div>
                                            </div>
                                            <div class="col-md-6">
                                                <div class="form-group">
                                                    <div class="d-flex justify-content-between mb-1">
                                                        <label class="form-label">Button Text <span class="text-danger">*</span></label>
                                                        <select class="select2" name="font3">
                                                            @include('admin.includes.font-select')
                                                        </select>
                                                    </div>
                                                    <input required type="text" class="form-control" name="button_text_1" id="" value="{{ old('button_text_1', $section->button_text_1) }}">
                                                </div>
                                                <div class="form-group">
                                                    <label class="form-label">Button URL <span class="text-danger">*</span></label>
                                                    <input required type="text" class="form-control" name="button_url_1" id="" value="{{ old('button_url_1', $section->button_url_1) }}">
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>

                                <div class="row">
                                    <div class="col-md-6 col-lg-6 col-xl-4">
                                        <div class="card border shadow-sm">
                                            <div class="card-body">
                                                <div class="form-group">
                                                    <label class="form-label">Cover Video <span class="text-muted">**</span></label>
                                                    <input name="cover_video" class="form-control" type="file" accept="video/*">
                                                </div>

                                                @if($section->cover_video != NULL)
                                                    <video controls class="w-100">
                                                        <source src="{{ asset(Storage::url($section->cover_video)) }}" type="video/mp4">
                                                        Your browser does not support the video tag.
                                                    </video>
                                                @endif
                                            </div>
                                        </div>
                                    </div>
                                    <div class="col-md-6 col-lg-6 col-xl-4">
                                        <div class="card border shadow-sm">
                                            <div class="card-body">
                                                <div class="form-group">
                                                    <label class="form-label">Cover Photo <span class="text-muted">**</span></label>
                                                    <input name="cover_image" class="form-control" type="file" accept="image/jpg, image/jpeg, image/png, image/webp" onchange="loadFile_1(event)">
                                                </div>
                                                <div class="d-flex">
                                                    @isset($section->cover_image)
                                                        @if (Storage::exists($section->cover_image))
                                                            <img class="img-fluid image-preview" src="{{ asset(Storage::url($section->cover_image)) }}" alt="" id="output-1">
                                                        @else
                                                            <img class="img-fluid image-preview" src="" alt="" id="output-1">
                                                        @endif
                                                    @else
                                                        <img class="img-fluid image-preview" src="" alt="" id="output-1">
                                                    @endisset
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                    <div class="col-md-6 col-lg-6 col-xl-4">
                                        <div class="card border shadow-sm">
                                            <div class="card-body">
                                                <div class="form-group">
                                                    <label class="form-label">Mobile Photo <span class="text-muted">**</span></label>
                                                    <input name="image_1" class="form-control" type="file" accept="image/jpg, image/jpeg, image/png, image/webp" onchange="loadFile_2(event)">
                                                </div>
                                                <div class="d-flex">
                                                    @isset($section->image_1)
                                                        @if (Storage::exists($section->image_1))
                                                            <img class="img-fluid image-preview" src="{{ asset(Storage::url($section->image_1)) }}" alt="" id="output-2">
                                                        @else
                                                            <img class="img-fluid image-preview" src="" alt="" id="output-2">
                                                        @endif
                                                    @else
                                                        <img class="img-fluid image-preview" src="" alt="" id="output-2">
                                                    @endisset
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-4">
                                        <div class="d-flex justify-content-between mb-5">
                                            <div class="form-check">
                                                <input name="video_or_image" type="radio" class="form-check-input input-primary" id="show-video" value="V" checked />
                                                <label class="form-check-label" for="show-video">Show Video</label>
                                            </div>
                                            <div class="form-check">
                                                <input name="video_or_image" type="radio" class="form-check-input input-primary" id="show-image" value="I" />
                                                <label class="form-check-label" for="show-image">Show Image</label>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-12">
                                        <input type="submit" value="Save" class="btn btn-primary rounded-0 mb-4" data-bs-toggle="tooltip" data-bs-original-title="Save changes">
                                    </div>
                                </div>
                            </form>

                            <div class="row">
                                <div class="col-md-12">
                                    <p class="text-muted mb-5">** Cover Video is required if Cover Image is not given and vice-versa. </p>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
    </section>

    @include('admin.homepage_sections.common-js')

@endsection
