@extends('admin.layouts.admin')

@section('content')
    <section class="pc-container home-section-container">
        <div class="pc-content">
            <div class="page-header">
                <div class="page-block">
                    <div class="row align-items-center">
                        <div class="col-md-12">
                            <ul class="breadcrumb">
                                <li class="breadcrumb-item">
                                    <a href="{{ route('admin.homepage-sections') }}">
                                        Homepage Sections
                                    </a>
                                </li>
                                <li class="breadcrumb-item">{{ ucwords(str_replace('_', ' ', $section->name)) }}</li>
                            </ul>
                        </div>
                        <div class="col-md-12">
                            <div class="page-header-title">
                                <h3 class="mb-0">{{ ucwords(str_replace('_', ' ', $section->name)) }}</h3>
                            </div>
                        </div>
                    </div>
                </div>
            </div>

            <div class="row pt-0">
                <div class="col-md-12">
                    <div>
                        <div class="pt-3">
                            <div>
                                @if(Session::has('message'))
                                    <p class="alert {{ Session::get('alert-class', 'alert-info') }} flash-msg">{{ Session::get('message') }}</p>
                                @endif
                            </div>

                            <div>
                                @if ($errors->any())
                                    <div class="alert alert-danger">
                                        <ul>
                                            @foreach ($errors->all() as $error)
                                                <li>
                                                    {{ $error }}
                                                </li>
                                            @endforeach
                                        </ul>
                                    </div>
                                @endif
                            </div>

                            @php
                                $products = seasonal_highlights_products();
                                $assigned_variations = explode(",", $section->products);
                            @endphp

                            <form action="{{ route('admin.update-homepage-section', ['section' => $section->id]) }}" method="post" enctype="multipart/form-data" class="form-data">
                                @csrf

                                <div class="row">
                                    <div class="col-md-12">
                                        <div class="card border shadow-sm">
                                            <div class="card-body">
                                                <div class="form-group">
                                                    <div class="d-flex justify-content-between mb-1">
                                                        <label class="form-label">Heading <span class="text-danger">*</span></label>
                                                        <select class="select2" name="font1">
                                                            @include('admin.includes.font-select')
                                                        </select>
                                                    </div>
                                                    <input required type="text" class="form-control" name="heading" id="" value="{{ old('heading', $section->heading) }}">
                                                </div>
                                                <div class="form-group">
                                                    <div class="d-flex justify-content-between mb-1">
                                                        <label class="form-label">Sub Heading <span class="text-danger">*</span></label>
                                                        <select class="select2" name="font2">
                                                            @include('admin.includes.font-select')
                                                        </select>
                                                    </div>
                                                    <input type="text" class="form-control" name="sub_heading_1" value="{{ old('sub_heading_1', $section->sub_heading_1) }}">
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>

                                <div class="row">
                                    <div class="col-md-12">
                                        <div class="card border shadow-sm">
                                            <div class="card-body">
                                                <div>
                                                    <div class="d-flex justify-content-end mb-1">
                                                        <select class="select2" name="font3">
                                                            @include('admin.includes.font-select')
                                                        </select>
                                                    </div>
                                                    <ul class="list-group">
                                                        <label class="form-label">Products <span class="text-danger">*</span></label>
                                                        @foreach ($products as $item)
                                                            <li class="list-group-item">
                                                                <div>
                                                                    <div>
                                                                        <strong>{{ $item->product_code }}</strong>
                                                                    </div>
                                                                    <div class="d-flex">
                                                                        @foreach ($item->variations as $variation )
                                                                            <div class="form-check form-switch custom-switch-v1">
                                                                                <div>
                                                                                    <a href="{{ asset(Storage::url('public/products/' . $variation->product_id . '/' . $variation->image))  }}" target="_blank" rel="noopener noreferrer">
                                                                                        <img src="{{ asset(Storage::url('public/products/' . $variation->product_id . '/' . $variation->image))  }}" alt="" class="img-fluid thumb-3">
                                                                                    </a>
                                                                                </div>
                                                                                <div class="pl-39">
                                                                                    <input name="{{ $item->product_code }}[]" type="checkbox" class="form-check-input input-primary chk" data-chk="{{ $item->product_code }}" value='{{ $variation->id }}' {{ in_array($variation->id, $assigned_variations) ? 'checked' : '' }}>
                                                                                </div>
                                                                            </div>
                                                                        @endforeach
                                                                    </div>
                                                                </div>
                                                            </li>
                                                        @endforeach
                                                    </ul>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>

                                <div class="row">
                                    <div class="col-md-12">
                                        <input type="submit" value="Save" class="btn btn-primary rounded-0 mb-4" data-bs-toggle="tooltip" data-bs-original-title="Save changes">
                                    </div>
                                </div>
                            </form>

                        </div>
                    </div>
                </div>
            </div>
    </section>

    @include('admin.homepage_sections.common-js')

    <script>
        $(document).ready(function() {
            $('.chk').on('change', function() {
                let x = $(this).attr('data-chk');
                let arr = $('[data-chk="'+ x +'"]');
                let len = arr.length;
                let ele = $(this);
                let flag = !$(ele).is(':checked');

                for (let i = 0; i < len; i++) {
                    $(arr[i]).prop('checked', false);
                }

                if (flag == false) {
                    $(ele).prop('checked', true);
                } else {
                    $(ele).prop('checked', false);
                }
            });
        });
    </script>

@endsection
