@extends('admin.layouts.admin')

@section('content')
    <section class="pc-container home-section-container">
        <div class="pc-content">
            <div class="page-header">
                <div class="page-block">
                    <div class="row align-items-center">
                        <div class="col-md-12">
                            <ul class="breadcrumb">
                                <li class="breadcrumb-item">
                                    <a href="{{ route('admin.homepage-sections') }}">
                                        Homepage Sections
                                    </a>
                                </li>
                                <li class="breadcrumb-item">{{ ucwords(str_replace('_', ' ', $section->name)) }}</li>
                            </ul>
                        </div>
                        <div class="col-md-12">
                            <div class="page-header-title">
                                <h3 class="mb-0">{{ ucwords(str_replace('_', ' ', $section->name)) }}</h3>
                            </div>
                        </div>
                    </div>
                </div>
            </div>

            <div class="row pt-0">
                <div class="col-md-12">
                    <div>
                        <div class="pt-3">
                            <div>
                                @if(Session::has('message'))
                                    <p class="alert {{ Session::get('alert-class', 'alert-info') }} flash-msg">{{ Session::get('message') }}</p>
                                @endif
                            </div>

                            <div>
                                @if ($errors->any())
                                    <div class="alert alert-danger">
                                        <ul>
                                            @foreach ($errors->all() as $error)
                                                <li>
                                                    {{ $error }}
                                                </li>
                                            @endforeach
                                        </ul>
                                    </div>
                                @endif
                            </div>

                            @php
                                $services = services();
                                $assigned_services = explode(",", $section->services);
                            @endphp

                            @if (count($services))
                                <form action="{{ route('admin.update-homepage-section', ['section' => $section->id]) }}" method="post" enctype="multipart/form-data" class="form-data">
                                    @csrf
                                    <div class="row">
                                        <div class="col-md-6">
                                            <div class="card border shadow-sm">
                                                <div class="card-body">
                                                    <div class="row">
                                                        <div class="form-group col-md-12">
                                                            <label class="form-label">Main Photo <span class="text-danger">*</span></label>
                                                            <input {{ $section->image_1 ? '' : 'required' }} name="image_1" class="form-control" type="file" accept="image/jpg, image/jpeg, image/png, image/webp" onchange="loadFile_1(event)">
                                                        </div>
                                                        <div class="col-md-12">
                                                            <div class="d-flex">
                                                                @isset($section->image_1)
                                                                    @if (Storage::exists($section->image_1))
                                                                        <img class="img-fluid image-preview" src="{{ asset(Storage::url($section->image_1)) }}" alt="" id="output-1">
                                                                    @else
                                                                        <img class="img-fluid image-preview" src="" alt="" id="output-1">
                                                                    @endif
                                                                @else
                                                                    <img class="img-fluid image-preview" src="" alt="" id="output-1">
                                                                @endisset
                                                            </div>
                                                        </div>
                                                        <div class="col-md-12 mt-2">
                                                            <div class="form-group">
                                                                <label class="form-label">URL <span class="text-danger">*</span></label>
                                                                <input required type="text" class="form-control" name="image_url_1" id="" value="{{ old('image_url_1', $section->image_url_1) }}">
                                                            </div>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>

                                        <div class="col-md-6">
                                            <div class="card border shadow-sm">
                                                <div class="card-body">
                                                    <div class="form-group">
                                                        <div class="d-flex justify-content-between mb-1">
                                                            <label class="form-label">Heading <span class="text-danger">*</span></label>
                                                            <select class="select2" name="font1">
                                                                @include('admin.includes.font-select')
                                                            </select>
                                                        </div>
                                                        <input required type="text" class="form-control" name="heading" id="" value="{{ old('heading', $section->heading) }}">
                                                    </div>
                                                    <div class="form-group">
                                                        <div class="d-flex justify-content-between mb-1">
                                                            <label class="form-label">Sub Heading <span class="text-danger">*</span></label>
                                                            <select class="select2" name="font2">
                                                                @include('admin.includes.font-select')
                                                            </select>
                                                        </div>
                                                        <input type="text" class="form-control" name="sub_heading_1" value="{{ old('sub_heading_1', $section->sub_heading_1) }}">
                                                    </div>
                                                    <div>
                                                        <ul class="list-group">
                                                            <div class="d-flex justify-content-between mb-1">
                                                                <label class="form-label">Services <span class="text-danger">*</span></label>
                                                                <select class="select2" name="font3">
                                                                    @include('admin.includes.font-select')
                                                                </select>
                                                            </div>
                                                            @foreach ($services as $item)
                                                                <li class="list-group-item border-0 py-1">
                                                                    <div class="form-check form-switch custom-switch-v1 d-flex align-items-center">
                                                                        <input name="service[]" type="checkbox" class="form-check-input input-primary" id="chk-{{ $item->id }}" value='{{ $item->id }}' {{ in_array($item->id, $assigned_services) ? 'checked' : '' }}>
                                                                        <label class="form-check-label" for="chk-{{ $item->id }}">&nbsp;&nbsp;{{ $item->name }}</label>
                                                                    </div>
                                                                </li>
                                                            @endforeach
                                                        </ul>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
                                    </div>

                                    <div class="row">
                                        <div class="col-md-12">
                                            <input type="submit" value="Save" class="btn btn-primary rounded-0 mb-4" data-bs-toggle="tooltip" data-bs-original-title="Save changes">
                                        </div>
                                    </div>
                                </form>
                            @else
                                <div class="d-flex align-items-center">
                                    <div>
                                        <img src="{{ asset('admin/images/icons/warning.png') }}" alt="" class="img-fluid">
                                    </div>
                                    <div class="f-16 mt-2 ps-2">
                                        No service available! Kindly add some services first.
                                    </div>
                                </div>
                            @endif
                        </div>
                    </div>
                </div>
            </div>
    </section>

    @include('admin.homepage_sections.common-js')

@endsection
