@extends('admin.layouts.admin')

@section('content')
    <section class="pc-container">
        <div class="pc-content">
            <div class="page-header">
                <div class="page-block">
                    <div class="row align-items-center">
                        <div class="col-md-12">
                            <ul class="breadcrumb">
                                <li class="breadcrumb-item">
                                    <a href="{{ route('admin.homepage-sections') }}">
                                        Homepage Sections
                                    </a>
                                </li>
                                <li class="breadcrumb-item">{{ ucwords(str_replace('_', ' ', $section->name)) }}</li>
                            </ul>
                        </div>
                        <div class="col-md-12">
                            <div class="page-header-title">
                                <h3 class="mb-0">{{ ucwords(str_replace('_', ' ', $section->name)) }}</h3>
                            </div>
                        </div>
                    </div>
                </div>
            </div>

            <div class="row pt-0">
                <div class="col-md-12">
                    <div>
                        @if(Session::has('message'))
                            <p class="alert {{ Session::get('alert-class', 'alert-info') }} flash-msg">{{ Session::get('message') }}</p>
                        @endif
                    </div>

                    <div>
                        @if ($errors->any())
                            <div class="alert alert-danger">
                                <ul>
                                    @foreach ($errors->all() as $error)
                                        <li>
                                            {{ $error }}
                                        </li>
                                    @endforeach
                                </ul>
                            </div>
                        @endif
                    </div>

                    @php
                        $testimonials = testimonials();
                        $assigned_testimonials = explode(',', $section->testimonials);
                    @endphp

                    @if (count($testimonials))
                        <form action="{{ route('admin.update-homepage-section', ['section' => $section->id]) }}" method="post" enctype="multipart/form-data" class="form-data">
                            @csrf

                            <div class="card shadow-sm">
                                <div class="card-body">
                                    <div class="row">
                                        <div class="col-md-4 border-end">
                                            <div class="form-group">
                                                <label class="form-label">Photo <span class="text-danger">*</span></label>
                                                <input {{ $section->image_1 ? '' : 'required' }} name="image_1" class="form-control" type="file" accept="image/jpg, image/jpeg, image/png, image/webp" onchange="loadFile_1(event)">
                                            </div>
                                            <div class="d-flex mb-3">
                                                @isset($section->image_1)
                                                    @if (Storage::exists($section->image_1))
                                                        <img class="img-fluid image-preview-sm" src="{{ asset(Storage::url($section->image_1)) }}" alt="" id="output-1">
                                                    @else
                                                        <img class="img-fluid image-preview-sm" src="" alt="" id="output-1">
                                                    @endif
                                                @else
                                                    <img class="img-fluid image-preview-sm" src="" alt="" id="output-1">
                                                @endisset
                                            </div>
                                            <div class="form-group">
                                                <label class="form-label">URL <span class="text-danger">*</span></label>
                                                <input type="text" name="url_1" class="form-control" placeholder="URL" value="{{ old('url_1', $section->url_1) }}">
                                            </div>

                                            <div class="mt-3 mb-3">
                                                <label class="form-label">Heading Font</label>
                                                <br>
                                                <select class="select2" name="font1">
                                                    @include('admin.includes.font-select')
                                                </select>
                                            </div>
                                            <div class="mb-3">
                                                <label class="form-label">Name Font</label>
                                                <br>
                                                <select class="select2" name="font2">
                                                    @include('admin.includes.font-select')
                                                </select>
                                            </div>
                                            <div>
                                                <label class="form-label">Reivew Font</label>
                                                <br>
                                                <select class="select2" name="font3">
                                                    @include('admin.includes.font-select')
                                                </select>
                                            </div>
                                        </div>
                                        <div class="col-md-8">
                                            <ul class="list-group">
                                                @foreach ($testimonials as $item)
                                                    @php
                                                        $rating = (int)$item->rating;
                                                    @endphp
                                                    <li class="list-group-item py-1 border-0">
                                                        <div class="form-check form-switch custom-switch-v1">
                                                            <input name="testimonial[]" type="checkbox" class="form-check-input input-primary" id="chk-{{ $item->id }}" value='{{ $item->id }}' {{ in_array($item->id, $assigned_testimonials) ? 'checked' : '' }}>
                                                            <label class="form-check-label" for="chk-{{ $item->id }}">
                                                                {{ $item->name }}
                                                                <br>
                                                                @while ($rating--)
                                                                    <img src="{{ asset('admin/images/icons/star.png') }}" alt="" class="img-fluid star-sm">
                                                                @endwhile
                                                                <br>
                                                                {!! Str::limit($item->content, 800) !!}
                                                            </label>
                                                        </div>
                                                    </li>
                                                @endforeach
                                            </ul>
                                        </div>
                                    </div>
                                </div>
                            </div>

                            <div class="row">
                                <div class="col-md-12">
                                    <input type="submit" value="Save" class="btn btn-primary rounded-0 mb-4" data-bs-toggle="tooltip" data-bs-original-title="Save changes">
                                </div>
                            </div>
                        </form>
                    @else
                        <div class="d-flex align-items-center">
                            <div>
                                <img src="{{ asset('admin/images/icons/warning.png') }}" alt="" class="img-fluid">
                            </div>
                            <div class="f-16 mt-2 ps-2">
                                No testimonial available!
                            </div>
                        </div>
                    @endif
                </div>
            </div>
    </section>

    @include('admin.homepage_sections.common-js')

@endsection
