@extends('admin.layouts.admin')

@section('content')
    <section class="pc-container">
        <div class="pc-content">
            <div class="page-header">
                <div class="page-block">
                    <div class="row align-items-center">
                        <div class="col-md-12">
                            <ul class="breadcrumb">
                                <li class="breadcrumb-item">
                                    <a href="{{ route('admin.pages') }}">Pages</a>
                                </li>
                                <li class="breadcrumb-item" aria-current="page">Edit</li>
                            </ul>
                        </div>
                        <div class="col-md-12">
                            <div class="page-header-title">
                                <h2 class="mb-0">Page</h2>
                            </div>
                        </div>
                    </div>
                </div>
            </div>

            <div class="row">
                <div class="col-md-12">
                    <div class="card">
                        <div class="card-body">
                            <div>
                                @if ($errors->any())
                                    <div class="alert alert-danger">
                                        <ul>
                                            @foreach ($errors->all() as $error)
                                                <li>
                                                    {{ $error }}
                                                </li>
                                            @endforeach
                                        </ul>
                                    </div>
                                @endif
                            </div>
                            <form action="{{ route('admin.update-page') }}" method="post" enctype="multipart/form-data">
                                @csrf
                                <input type="hidden" name="id" value="{{ $page->id }}">
                                <div class="row">
                                    <div class="col-md-3">
                                        <div class="form-group">
                                            <label class="form-label">Type <span class="text-danger">*</span></label>
                                            <select name="type" id="type-select" class="form-control" required>
                                                <option selected disabled>-- Not Selected --</option>
                                                <@foreach ($types as $type)
                                                    <option value="{{ $type }}">{{ ucfirst($type) }}</option>
                                                @endforeach
                                            </select>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="form-group col-md-12">
                                        <label class="form-label">Title <span class="text-danger">*</span></label>
                                        <input required name="title" type="text" class="form-control" placeholder="Item name" value="{{ old('title', $page->title) }}" autofocus>
                                    </div>
                                    <div id="alias-div" class="form-group col-md-12 d-none">
                                        <label class="form-label">Alias</label>
                                        <input id="alias-ele" name="alias" type="text" class="form-control" placeholder="Will be auto generated if left blank" value="{{ old('alias', $page->alias) }}">
                                    </div>
                                    <div class="form-group col-md-12">
                                        <label class="form-label">Meta Title</label>
                                        <input type="text" id="meta_title" name="meta_title" class="form-control" value="{{ old('meta_title', $page->meta_title) }}" />
                                    </div>
                                    <div class="form-group col-md-12">
                                        <label class="form-label">Meta Description</label>
                                        <textarea id="meta_description" name="meta_description" class="form-control">{{ old('meta_description', $page->meta_description) }}</textarea>
                                    </div>
                                    <div class="form-group col-md-12 tall-ck">
                                        <label class="form-label">Content</label>
                                        <textarea name="content" class="form-control ckeditor" placeholder="Content">{!! old('content', $page->content) !!}</textarea>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-12">
                                        <div class="form-check form-switch custom-switch-v1">
                                            <input name="active" type="checkbox" class="form-check-input input-primary" id="activeCheckbox" value='1' @checked($page->active)>
                                            <label class="form-check-label" for="activeCheckbox">Active</label>
                                        </div>
                                        <input type="submit" value="Save" class="btn btn-primary m-t-20 m-b-20" data-bs-toggle="tooltip" data-bs-original-title="Save changes">
                                    </div>
                                </div>
                            </form>
                        </div>
                    </div>
                </div>
            </div>
    </section>

    <script>
        $(document).ready(function() {
            $('#type-select').val('{{ $page->type }}');

            if ('{{ $page->type }}' == 'other') {
                $('#alias-div').removeClass('d-none');
            }

            $('#type-select').change(function() {
                let x = $('#type-select').val();

                if (x == 'other') {
                    $('#alias-div').removeClass('d-none');
                    $('#alias-ele').val('');
                } else {
                    $('#alias-div').addClass('d-none');
                    $('#alias-ele').val(x);
                }
            })
        })
    </script>
@endsection
