@extends('admin.layouts.admin')

@section('content')
    <div class="pc-container">
        <div class="pc-content">
            <div class="page-header">
                <div class="page-block">
                    <div class="row align-items-center">
                        <div class="col-md-12">
                            <ul class="breadcrumb">
                                <li class="breadcrumb-item" aria-current="page">Content</li>
                                <li class="breadcrumb-item" aria-current="page">Payments</li>
                            </ul>
                        </div>
                        <div class="col-md-12">
                            <div class="page-header-title">
                                <h2 class="mb-0">Payments</h2>
                            </div>
                        </div>
                    </div>
                </div>
            </div>

            <div class="row pt-0">
                <div class="col-sm-12">
                    <div class="card">
                        <div class="card-body">
                            <div>
                                @if(Session::has('message'))
                                    <p class="alert {{ Session::get('alert-class', 'alert-info') }} flash-msg">{{ Session::get('message') }}</p>
                                @endif
                            </div>

                            <div class="dt-responsive table-responsive">
                                <table id="simpletable" class="table table-striped table-bordered nowrap">
                                    <thead>
                                        <tr>
                                            <th>Appointment ID</th>
                                            <th>Amount</th>
                                            <th>Payment Type</th>
                                            <th>Customer</th>
                                            <th>Staff</th>
                                            <th>Service</th>
                                            <th>Status</th>
                                            <th>Created On</th>
                                            <th>Action</th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        @foreach ($data as $item)
                                            <tr>
                                                <td>{{ $item->appointment_id }}</td>
                                                <td>${{ $item->amount }}</td>
                                                <td>
                                                    @switch($item->payment_type)
                                                        @case('C')
                                                            CASH
                                                            @break
                                                        @case('S')
                                                            STRIPE
                                                            @break
                                                        @default
                                                    @endswitch
                                                </td>
                                                <td>
                                                    {{ ($item->appointment->user) ? $item->appointment->user->first_name : '' }} {{ $item->appointment->user->last_name }}
                                                </td>
                                                <td>
                                                    {{ ($item->appointment->staff->user) ? $item->appointment->staff->user->first_name : '' }} {{ ( $item->appointment->staff->user) ? $item->appointment->staff->user->last_name : '' }}
                                                </td>
                                                <td>
                                                    {{ $item->appointment->service->name }}
                                                </td>
                                                <td>
                                                    @if ($item->active == '1')
                                                        <span role="button" class="badge bg-success" onclick="toggle(this, {{$item->id}})">Active</span>
                                                    @else
                                                        <span role="button" class="badge bg-secondary" onclick="toggle(this, {{$item->id}})">Active</span>
                                                    @endif
                                                </td>
                                                <td>{{ $item->created_at }}</td>
                                                <td>
                                                    <a href="{{ route('admin.payment-details', ['payment' => $item->id]) }}" class="avtar avtar-xs btn-link-success btn-pc-default" data-bs-toggle="tooltip" data-bs-original-title="Details">
                                                        <i class="ti ti-settings f-18"></i>
                                                    </a>
                                                </td>
                                            </tr>
                                        @endforeach
                                    </tbody>
                                </table>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <script src="{{ asset('admin/js/plugins/jquery.dataTables.min.js') }}"></script>
    <script src="{{ asset('admin/js/plugins/dataTables.bootstrap5.min.js') }}"></script>

    <script>
        $('#simpletable').DataTable({
            order: [[8, 'desc']]
        });
    </script>
@endsection
