@extends('admin.layouts.admin')

@section('content')
    <section class="pc-container">
        <div class="pc-content">
            <div class="page-header">
                <div class="page-block">
                    <div class="row align-items-center">
                        <div class="col-md-12">
                            <ul class="breadcrumb">
                                <li class="breadcrumb-item" aria-current="page">
                                    <a href="{{ route('admin.services') }}">Services</a>
                                </li>
                                <li class="breadcrumb-item" aria-current="page">Edit</li>
                            </ul>
                        </div>
                        <div class="col-md-12">
                            <div class="page-header-title">
                                <h2 class="mb-0">Service</h2>
                            </div>
                        </div>
                    </div>
                </div>
            </div>

            <div class="row pt-0">
                <div class="col-md-12">
                    <div class="card">
                        <div class="card-body">
                            <div>
                                @if ($errors->any())
                                    <div class="alert alert-danger">
                                        <ul>
                                            @foreach ($errors->all() as $error)
                                                <li>
                                                    {{ $error }}
                                                </li>
                                            @endforeach
                                        </ul>
                                    </div>
                                @endif
                            </div>
                            <form action="{{ route('admin.update-service') }}" method="post" enctype="multipart/form-data" class="form-data">
                                @csrf
                                <input type="hidden" name="id" value="{{ $service->id }}">
                                <div class="row">
                                    <div class="col-md-12">
                                        <div class="row">
                                            <div class="form-group col-md-6">
                                                <label class="form-label">Name <span class="text-danger">*</span></label>
                                                <input required name="name" type="text" class="form-control" placeholder="Name" value="{{ old('name', $service->name) }}" autofocus>
                                            </div>
                                            <div class="form-group col-md-6">
                                                <label class="form-label">Alias</label>
                                                <input name="alias" type="text" class="form-control" placeholder="Will be auto generated if left blank" value="{{ old('alias', $service->alias) }}">
                                            </div>
                                            <div class="form-group col-md-12">
                                                <label class="form-label">Description</label>
                                                <textarea name="description" class="form-control ckeditor" placeholder="Description">{!! old('description', $service->description) !!}</textarea>
                                            </div>
                                        </div>
                                        <div class="row">
                                            <div class="form-group col-md-4">
                                                <label class="form-label">Rank</label>
                                                <input name="rank" type="number" min="1" max="99999" class="form-control" placeholder="Rank" value="{{ old('rank', $service->rank) }}">
                                            </div>
                                            <div class="form-group col-md-4">
                                                <label class="form-label">Image (1500*1500)</label>
                                                <input name="image" class="form-control" type="file" accept="image/jpg, image/jpeg, image/png, image/webp" onchange="loadFile(event)">
                                            </div>
                                            <div class="col-md-4">
                                                <div class="d-flex">
                                                    @if ($service->image == NULL)
                                                        <img class="img-fluid image-preview" src="" alt="" id="output">
                                                    @else
                                                        <a href="{{ $service->image }}" target="_blank">
                                                            <img class="img-fluid image-preview" src="{{ $service->image }}" alt="" id="output">
                                                        </a>
                                                    @endif
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-12">
                                        <div class="form-check form-switch custom-switch-v1">
                                            <input name="active" type="checkbox" class="form-check-input input-primary" id="activeCheckbox" value='1' checked>
                                            <label class="form-check-label" for="activeCheckbox">Active</label>
                                        </div>
                                        <input type="submit" value="Save" class="btn btn-primary m-t-20 m-b-20" data-bs-toggle="tooltip" data-bs-original-title="Save changes">
                                    </div>
                                </div>
                            </form>
                        </div>
                    </div>
                </div>
            </div>
    </section>

    <script>
        var loadFile = function(event) {
            var output = document.getElementById('output');
            output.src = URL.createObjectURL(event.target.files[0]);
            output.onload = function() {
              URL.revokeObjectURL(output.src) // free memory
            }
        };
    </script>

@endsection
