@extends('admin.layouts.admin')

@section('content')
    <section class="pc-container">
        <div class="pc-content">
            <div class="page-header">
                <div class="page-block">
                    <div class="row align-items-center">
                        <div class="col-md-12">
                            <ul class="breadcrumb">
                                <li class="breadcrumb-item" aria-current="page">
                                    <a href="{{ route('admin.slider') }}">Slider</a>
                                </li>
                                <li class="breadcrumb-item" aria-current="page">Edit</li>
                            </ul>
                        </div>
                        <div class="col-md-12">
                            <div class="page-header-title">
                                <h2 class="mb-0">Slider</h2>
                            </div>
                        </div>
                    </div>
                </div>
            </div>

            <div class="row pt-0">
                <div class="col-md-12">
                    <div class="card">
                        <div class="card-body">
                            <div>
                                @if ($errors->any())
                                    <div class="alert alert-danger">
                                        <ul>
                                            @foreach ($errors->all() as $error)
                                                <li>
                                                    {{ $error }}
                                                </li>
                                            @endforeach
                                        </ul>
                                    </div>
                                @endif
                            </div>
                            <form action="{{ route('admin.update-slider') }}" method="post" enctype="multipart/form-data" class="form-data">
                                @csrf
                                
                                <input type="hidden" name="id" value="{{ $slider->id }}">

                                <div class="row">
                                    <div class="col-md-6">
                                        <div class="row">
                                            <div class="form-group col-md-12">
                                                <label class="form-label">Image <span class="text-danger">*</span></label>
                                                <input name="image" class="form-control" type="file" accept="image/jpg, image/jpeg, image/png, image/webp" onchange="loadFile_1(event)">
                                            </div>
                                            <div class="col-md-12">
                                                <div class="d-flex">
                                                    @if ($slider->image == NULL)
                                                        <img class="img-fluid image-preview" src="" alt="" id="output-1">
                                                    @else
                                                        <a href="{{ $slider->image }}" target="_blank">
                                                            <img class="img-fluid image-preview" src="{{ $slider->image }}" alt="" id="output-1">
                                                        </a>
                                                    @endif
                                                </div>
                                            </div>
                                        </div>
                                    </div>

                                    <div class="col-md-6">
                                        <div class="row">
                                            <div class="form-group col-md-12">
                                                <label class="form-label">Sub Image <span class="text-danger">*</span></label>
                                                <input name="sub_image" class="form-control" type="file" accept="image/jpg, image/jpeg, image/png, image/webp" onchange="loadFile_2(event)">
                                            </div>

                                            <div class="col-md-12">
                                                <div class="d-flex">
                                                    @if ($slider->image == NULL)
                                                        <img class="img-fluid image-preview" src="" alt="sub image" id="output-2">
                                                    @else
                                                        <a href="{{ $slider->image }}" target="_blank">
                                                            <img class="img-fluid image-preview" src="{{ $slider->sub_image }}" alt="" id="output-2">
                                                        </a>
                                                    @endif
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>

                                <div class="row mt-2">
                                    <div class="form-group col-md-12">
                                        <label class="form-label">Title <span class="text-danger">*</span></label>
                                        <input required name="title" type="text" class="form-control" maxlength="191" placeholder="Title" value="{{ old('title', $slider->title) }}">
                                    </div>

                                    <div class="form-group col-md-6">
                                        <label class="form-label">Subtitle</label>
                                        <input name="subtitle" type="text" class="form-control" maxlength="191" placeholder="Title" value="{{ old('subtitle', $slider->subtitle) }}">
                                    </div>

                                    <div class="form-group col-md-6">
                                        <label class="form-label">Tagline</label>
                                        <input name="tagline" type="text" class="form-control" maxlength="191" placeholder="Tagline" value="{{ old('tagline', $slider->tagline) }}">
                                    </div>
                                </div>

                                <div class="row">
                                    <div class="form-group col-md-6">
                                        <label class="form-label">Button Text</label>
                                        <input name="button_text" type="text" class="form-control" maxlength="50" placeholder="Text on button" value="{{ old('button_text', $slider->button_text) }}">
                                    </div>

                                    <div class="form-group col-md-6">
                                        <label class="form-label">Button Link</label>
                                        <input name="button_link" type="text" class="form-control" placeholder="URL" value="{{ old('button_link', $slider->button_link) }}">
                                    </div>
                                </div>

                                <div class="row">
                                    <div class="form-group col-md-2">
                                        <label class="form-label">Rank</label>
                                        <input name="rank" type="number" min="0" class="form-control" placeholder="Rank" value="{{ old('rank', $slider->rank) }}">
                                    </div>
                                </div>

                                <div class="row">
                                    <div class="col-md-12">
                                        <div class="form-check form-switch custom-switch-v1">
                                            <input name="active" type="checkbox" class="form-check-input input-primary" id="activeCheckbox" value='1' @checked(old('checked', $slider->active))>
                                            <label class="form-check-label" for="activeCheckbox">Active</label>
                                        </div>
                                        <input type="submit" value="Save" class="btn btn-primary m-t-20 m-b-20" data-bs-toggle="tooltip" data-bs-original-title="Save changes">
                                    </div>
                                </div>
                            </form>
                        </div>
                    </div>
                </div>
            </div>
    </section>

    <script>
        var loadFile_1 = function(event) {
            var output_1 = document.getElementById('output-1');
            output_1.src = URL.createObjectURL(event.target.files[0]);
            output_1.onload = function() {
              URL.revokeObjectURL(output_1.src) // free memory
            }
        };

        var loadFile_2 = function(event) {
            var output_2 = document.getElementById('output-2');
            output_2.src = URL.createObjectURL(event.target.files[0]);
            output_2.onload = function() {
              URL.revokeObjectURL(output_2.src) // free memory
            }
        };
    </script>

@endsection
